# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_stdlib'},
  'syms': { 'abc': { 'abc.ABC': 'https://docs.python.org/3/library/abc.html#abc.ABC',
                     'abc.ABCMeta': 'https://docs.python.org/3/library/abc.html#abc.ABCMeta',
                     'abc.ABCMeta.__subclasshook__': 'https://docs.python.org/3/library/abc.html#abc.ABCMeta.__subclasshook__',
                     'abc.ABCMeta.register': 'https://docs.python.org/3/library/abc.html#abc.ABCMeta.register',
                     'abc.abstractclassmethod': 'https://docs.python.org/3/library/abc.html#abc.abstractclassmethod',
                     'abc.abstractmethod': 'https://docs.python.org/3/library/abc.html#abc.abstractmethod',
                     'abc.abstractproperty': 'https://docs.python.org/3/library/abc.html#abc.abstractproperty',
                     'abc.abstractstaticmethod': 'https://docs.python.org/3/library/abc.html#abc.abstractstaticmethod',
                     'abc.get_cache_token': 'https://docs.python.org/3/library/abc.html#abc.get_cache_token',
                     'abc.update_abstractmethods': 'https://docs.python.org/3/library/abc.html#abc.update_abstractmethods'},
            'aifc': { 'aifc.aifc.aifc': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.aifc',
                      'aifc.aifc.aiff': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.aiff',
                      'aifc.aifc.close': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.close',
                      'aifc.aifc.getcompname': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getcompname',
                      'aifc.aifc.getcomptype': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getcomptype',
                      'aifc.aifc.getframerate': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getframerate',
                      'aifc.aifc.getmark': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getmark',
                      'aifc.aifc.getmarkers': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getmarkers',
                      'aifc.aifc.getnchannels': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getnchannels',
                      'aifc.aifc.getnframes': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getnframes',
                      'aifc.aifc.getparams': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getparams',
                      'aifc.aifc.getsampwidth': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.getsampwidth',
                      'aifc.aifc.readframes': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.readframes',
                      'aifc.aifc.rewind': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.rewind',
                      'aifc.aifc.setcomptype': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setcomptype',
                      'aifc.aifc.setframerate': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setframerate',
                      'aifc.aifc.setmark': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setmark',
                      'aifc.aifc.setnchannels': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setnchannels',
                      'aifc.aifc.setnframes': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setnframes',
                      'aifc.aifc.setparams': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setparams',
                      'aifc.aifc.setpos': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setpos',
                      'aifc.aifc.setsampwidth': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.setsampwidth',
                      'aifc.aifc.tell': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.tell',
                      'aifc.aifc.writeframes': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.writeframes',
                      'aifc.aifc.writeframesraw': 'https://docs.python.org/3/library/aifc.html#aifc.aifc.writeframesraw',
                      'aifc.open': 'https://docs.python.org/3/library/aifc.html#aifc.open'},
            'argparse': { 'argparse.Action': 'https://docs.python.org/3/library/argparse.html#argparse.Action',
                          'argparse.ArgumentDefaultsHelpFormatter': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentDefaultsHelpFormatter',
                          'argparse.ArgumentParser': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser',
                          'argparse.ArgumentParser.add_argument': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.add_argument',
                          'argparse.ArgumentParser.add_argument_group': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.add_argument_group',
                          'argparse.ArgumentParser.add_mutually_exclusive_group': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.add_mutually_exclusive_group',
                          'argparse.ArgumentParser.add_subparsers': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.add_subparsers',
                          'argparse.ArgumentParser.convert_arg_line_to_args': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.convert_arg_line_to_args',
                          'argparse.ArgumentParser.error': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.error',
                          'argparse.ArgumentParser.exit': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.exit',
                          'argparse.ArgumentParser.format_help': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.format_help',
                          'argparse.ArgumentParser.format_usage': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.format_usage',
                          'argparse.ArgumentParser.get_default': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.get_default',
                          'argparse.ArgumentParser.parse_args': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.parse_args',
                          'argparse.ArgumentParser.parse_intermixed_args': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.parse_intermixed_args',
                          'argparse.ArgumentParser.parse_known_args': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.parse_known_args',
                          'argparse.ArgumentParser.parse_known_intermixed_args': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.parse_known_intermixed_args',
                          'argparse.ArgumentParser.print_help': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.print_help',
                          'argparse.ArgumentParser.print_usage': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.print_usage',
                          'argparse.ArgumentParser.set_defaults': 'https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.set_defaults',
                          'argparse.FileType': 'https://docs.python.org/3/library/argparse.html#argparse.FileType',
                          'argparse.MetavarTypeHelpFormatter': 'https://docs.python.org/3/library/argparse.html#argparse.MetavarTypeHelpFormatter',
                          'argparse.Namespace': 'https://docs.python.org/3/library/argparse.html#argparse.Namespace',
                          'argparse.RawDescriptionHelpFormatter': 'https://docs.python.org/3/library/argparse.html#argparse.RawDescriptionHelpFormatter',
                          'argparse.RawTextHelpFormatter': 'https://docs.python.org/3/library/argparse.html#argparse.RawTextHelpFormatter'},
            'array': { 'array.array': 'https://docs.python.org/3/library/array.html#array.array',
                       'array.array.append': 'https://docs.python.org/3/library/array.html#array.array.append',
                       'array.array.buffer_info': 'https://docs.python.org/3/library/array.html#array.array.buffer_info',
                       'array.array.byteswap': 'https://docs.python.org/3/library/array.html#array.array.byteswap',
                       'array.array.count': 'https://docs.python.org/3/library/array.html#array.array.count',
                       'array.array.extend': 'https://docs.python.org/3/library/array.html#array.array.extend',
                       'array.array.frombytes': 'https://docs.python.org/3/library/array.html#array.array.frombytes',
                       'array.array.fromfile': 'https://docs.python.org/3/library/array.html#array.array.fromfile',
                       'array.array.fromlist': 'https://docs.python.org/3/library/array.html#array.array.fromlist',
                       'array.array.fromunicode': 'https://docs.python.org/3/library/array.html#array.array.fromunicode',
                       'array.array.index': 'https://docs.python.org/3/library/array.html#array.array.index',
                       'array.array.insert': 'https://docs.python.org/3/library/array.html#array.array.insert',
                       'array.array.pop': 'https://docs.python.org/3/library/array.html#array.array.pop',
                       'array.array.remove': 'https://docs.python.org/3/library/array.html#array.array.remove',
                       'array.array.reverse': 'https://docs.python.org/3/library/array.html#array.array.reverse',
                       'array.array.tobytes': 'https://docs.python.org/3/library/array.html#array.array.tobytes',
                       'array.array.tofile': 'https://docs.python.org/3/library/array.html#array.array.tofile',
                       'array.array.tolist': 'https://docs.python.org/3/library/array.html#array.array.tolist',
                       'array.array.tounicode': 'https://docs.python.org/3/library/array.html#array.array.tounicode'},
            'ast': { 'ast.AST': 'https://docs.python.org/3/library/ast.html#ast.AST',
                     'ast.Add': 'https://docs.python.org/3/library/ast.html#ast.Add',
                     'ast.And': 'https://docs.python.org/3/library/ast.html#ast.And',
                     'ast.AnnAssign': 'https://docs.python.org/3/library/ast.html#ast.AnnAssign',
                     'ast.Assert': 'https://docs.python.org/3/library/ast.html#ast.Assert',
                     'ast.Assign': 'https://docs.python.org/3/library/ast.html#ast.Assign',
                     'ast.AsyncFor': 'https://docs.python.org/3/library/ast.html#ast.AsyncFor',
                     'ast.AsyncFunctionDef': 'https://docs.python.org/3/library/ast.html#ast.AsyncFunctionDef',
                     'ast.AsyncWith': 'https://docs.python.org/3/library/ast.html#ast.AsyncWith',
                     'ast.Attribute': 'https://docs.python.org/3/library/ast.html#ast.Attribute',
                     'ast.AugAssign': 'https://docs.python.org/3/library/ast.html#ast.AugAssign',
                     'ast.Await': 'https://docs.python.org/3/library/ast.html#ast.Await',
                     'ast.BinOp': 'https://docs.python.org/3/library/ast.html#ast.BinOp',
                     'ast.BitAnd': 'https://docs.python.org/3/library/ast.html#ast.BitAnd',
                     'ast.BitOr': 'https://docs.python.org/3/library/ast.html#ast.BitOr',
                     'ast.BitXor': 'https://docs.python.org/3/library/ast.html#ast.BitXor',
                     'ast.BoolOp': 'https://docs.python.org/3/library/ast.html#ast.BoolOp',
                     'ast.Break': 'https://docs.python.org/3/library/ast.html#ast.Break',
                     'ast.Call': 'https://docs.python.org/3/library/ast.html#ast.Call',
                     'ast.ClassDef': 'https://docs.python.org/3/library/ast.html#ast.ClassDef',
                     'ast.Compare': 'https://docs.python.org/3/library/ast.html#ast.Compare',
                     'ast.Constant': 'https://docs.python.org/3/library/ast.html#ast.Constant',
                     'ast.Continue': 'https://docs.python.org/3/library/ast.html#ast.Continue',
                     'ast.Del': 'https://docs.python.org/3/library/ast.html#ast.Del',
                     'ast.Delete': 'https://docs.python.org/3/library/ast.html#ast.Delete',
                     'ast.Dict': 'https://docs.python.org/3/library/ast.html#ast.Dict',
                     'ast.DictComp': 'https://docs.python.org/3/library/ast.html#ast.DictComp',
                     'ast.Div': 'https://docs.python.org/3/library/ast.html#ast.Div',
                     'ast.Eq': 'https://docs.python.org/3/library/ast.html#ast.Eq',
                     'ast.ExceptHandler': 'https://docs.python.org/3/library/ast.html#ast.ExceptHandler',
                     'ast.Expr': 'https://docs.python.org/3/library/ast.html#ast.Expr',
                     'ast.FloorDiv': 'https://docs.python.org/3/library/ast.html#ast.FloorDiv',
                     'ast.For': 'https://docs.python.org/3/library/ast.html#ast.For',
                     'ast.FormattedValue': 'https://docs.python.org/3/library/ast.html#ast.FormattedValue',
                     'ast.FunctionDef': 'https://docs.python.org/3/library/ast.html#ast.FunctionDef',
                     'ast.GeneratorExp': 'https://docs.python.org/3/library/ast.html#ast.GeneratorExp',
                     'ast.Global': 'https://docs.python.org/3/library/ast.html#ast.Global',
                     'ast.Gt': 'https://docs.python.org/3/library/ast.html#ast.Gt',
                     'ast.GtE': 'https://docs.python.org/3/library/ast.html#ast.GtE',
                     'ast.If': 'https://docs.python.org/3/library/ast.html#ast.If',
                     'ast.IfExp': 'https://docs.python.org/3/library/ast.html#ast.IfExp',
                     'ast.Import': 'https://docs.python.org/3/library/ast.html#ast.Import',
                     'ast.ImportFrom': 'https://docs.python.org/3/library/ast.html#ast.ImportFrom',
                     'ast.In': 'https://docs.python.org/3/library/ast.html#ast.In',
                     'ast.Invert': 'https://docs.python.org/3/library/ast.html#ast.Invert',
                     'ast.Is': 'https://docs.python.org/3/library/ast.html#ast.Is',
                     'ast.IsNot': 'https://docs.python.org/3/library/ast.html#ast.IsNot',
                     'ast.JoinedStr': 'https://docs.python.org/3/library/ast.html#ast.JoinedStr',
                     'ast.LShift': 'https://docs.python.org/3/library/ast.html#ast.LShift',
                     'ast.Lambda': 'https://docs.python.org/3/library/ast.html#ast.Lambda',
                     'ast.List': 'https://docs.python.org/3/library/ast.html#ast.List',
                     'ast.ListComp': 'https://docs.python.org/3/library/ast.html#ast.ListComp',
                     'ast.Load': 'https://docs.python.org/3/library/ast.html#ast.Load',
                     'ast.Lt': 'https://docs.python.org/3/library/ast.html#ast.Lt',
                     'ast.LtE': 'https://docs.python.org/3/library/ast.html#ast.LtE',
                     'ast.MatMult': 'https://docs.python.org/3/library/ast.html#ast.MatMult',
                     'ast.Match': 'https://docs.python.org/3/library/ast.html#ast.Match',
                     'ast.MatchAs': 'https://docs.python.org/3/library/ast.html#ast.MatchAs',
                     'ast.MatchClass': 'https://docs.python.org/3/library/ast.html#ast.MatchClass',
                     'ast.MatchMapping': 'https://docs.python.org/3/library/ast.html#ast.MatchMapping',
                     'ast.MatchOr': 'https://docs.python.org/3/library/ast.html#ast.MatchOr',
                     'ast.MatchSequence': 'https://docs.python.org/3/library/ast.html#ast.MatchSequence',
                     'ast.MatchSingleton': 'https://docs.python.org/3/library/ast.html#ast.MatchSingleton',
                     'ast.MatchStar': 'https://docs.python.org/3/library/ast.html#ast.MatchStar',
                     'ast.MatchValue': 'https://docs.python.org/3/library/ast.html#ast.MatchValue',
                     'ast.Mod': 'https://docs.python.org/3/library/ast.html#ast.Mod',
                     'ast.Mult': 'https://docs.python.org/3/library/ast.html#ast.Mult',
                     'ast.Name': 'https://docs.python.org/3/library/ast.html#ast.Name',
                     'ast.NamedExpr': 'https://docs.python.org/3/library/ast.html#ast.NamedExpr',
                     'ast.NodeTransformer': 'https://docs.python.org/3/library/ast.html#ast.NodeTransformer',
                     'ast.NodeVisitor': 'https://docs.python.org/3/library/ast.html#ast.NodeVisitor',
                     'ast.NodeVisitor.generic_visit': 'https://docs.python.org/3/library/ast.html#ast.NodeVisitor.generic_visit',
                     'ast.NodeVisitor.visit': 'https://docs.python.org/3/library/ast.html#ast.NodeVisitor.visit',
                     'ast.Nonlocal': 'https://docs.python.org/3/library/ast.html#ast.Nonlocal',
                     'ast.Not': 'https://docs.python.org/3/library/ast.html#ast.Not',
                     'ast.NotEq': 'https://docs.python.org/3/library/ast.html#ast.NotEq',
                     'ast.NotIn': 'https://docs.python.org/3/library/ast.html#ast.NotIn',
                     'ast.Or': 'https://docs.python.org/3/library/ast.html#ast.Or',
                     'ast.Pass': 'https://docs.python.org/3/library/ast.html#ast.Pass',
                     'ast.Pow': 'https://docs.python.org/3/library/ast.html#ast.Pow',
                     'ast.RShift': 'https://docs.python.org/3/library/ast.html#ast.RShift',
                     'ast.Raise': 'https://docs.python.org/3/library/ast.html#ast.Raise',
                     'ast.Return': 'https://docs.python.org/3/library/ast.html#ast.Return',
                     'ast.Set': 'https://docs.python.org/3/library/ast.html#ast.Set',
                     'ast.SetComp': 'https://docs.python.org/3/library/ast.html#ast.SetComp',
                     'ast.Slice': 'https://docs.python.org/3/library/ast.html#ast.Slice',
                     'ast.Starred': 'https://docs.python.org/3/library/ast.html#ast.Starred',
                     'ast.Store': 'https://docs.python.org/3/library/ast.html#ast.Store',
                     'ast.Sub': 'https://docs.python.org/3/library/ast.html#ast.Sub',
                     'ast.Subscript': 'https://docs.python.org/3/library/ast.html#ast.Subscript',
                     'ast.Try': 'https://docs.python.org/3/library/ast.html#ast.Try',
                     'ast.Tuple': 'https://docs.python.org/3/library/ast.html#ast.Tuple',
                     'ast.UAdd': 'https://docs.python.org/3/library/ast.html#ast.UAdd',
                     'ast.USub': 'https://docs.python.org/3/library/ast.html#ast.USub',
                     'ast.UnaryOp': 'https://docs.python.org/3/library/ast.html#ast.UnaryOp',
                     'ast.While': 'https://docs.python.org/3/library/ast.html#ast.While',
                     'ast.With': 'https://docs.python.org/3/library/ast.html#ast.With',
                     'ast.Yield': 'https://docs.python.org/3/library/ast.html#ast.Yield',
                     'ast.YieldFrom': 'https://docs.python.org/3/library/ast.html#ast.YieldFrom',
                     'ast.alias': 'https://docs.python.org/3/library/ast.html#ast.alias',
                     'ast.arg': 'https://docs.python.org/3/library/ast.html#ast.arg',
                     'ast.arguments': 'https://docs.python.org/3/library/ast.html#ast.arguments',
                     'ast.comprehension': 'https://docs.python.org/3/library/ast.html#ast.comprehension',
                     'ast.copy_location': 'https://docs.python.org/3/library/ast.html#ast.copy_location',
                     'ast.dump': 'https://docs.python.org/3/library/ast.html#ast.dump',
                     'ast.fix_missing_locations': 'https://docs.python.org/3/library/ast.html#ast.fix_missing_locations',
                     'ast.get_docstring': 'https://docs.python.org/3/library/ast.html#ast.get_docstring',
                     'ast.get_source_segment': 'https://docs.python.org/3/library/ast.html#ast.get_source_segment',
                     'ast.increment_lineno': 'https://docs.python.org/3/library/ast.html#ast.increment_lineno',
                     'ast.iter_child_nodes': 'https://docs.python.org/3/library/ast.html#ast.iter_child_nodes',
                     'ast.iter_fields': 'https://docs.python.org/3/library/ast.html#ast.iter_fields',
                     'ast.keyword': 'https://docs.python.org/3/library/ast.html#ast.keyword',
                     'ast.literal_eval': 'https://docs.python.org/3/library/ast.html#ast.literal_eval',
                     'ast.match_case': 'https://docs.python.org/3/library/ast.html#ast.match_case',
                     'ast.parse': 'https://docs.python.org/3/library/ast.html#ast.parse',
                     'ast.unparse': 'https://docs.python.org/3/library/ast.html#ast.unparse',
                     'ast.walk': 'https://docs.python.org/3/library/ast.html#ast.walk',
                     'ast.withitem': 'https://docs.python.org/3/library/ast.html#ast.withitem'},
            'asynchat': { 'asynchat.async_chat': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat',
                          'asynchat.async_chat.close_when_done': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.close_when_done',
                          'asynchat.async_chat.collect_incoming_data': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.collect_incoming_data',
                          'asynchat.async_chat.discard_buffers': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.discard_buffers',
                          'asynchat.async_chat.found_terminator': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.found_terminator',
                          'asynchat.async_chat.get_terminator': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.get_terminator',
                          'asynchat.async_chat.push': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.push',
                          'asynchat.async_chat.push_with_producer': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.push_with_producer',
                          'asynchat.async_chat.set_terminator': 'https://docs.python.org/3/library/asynchat.html#asynchat.async_chat.set_terminator'},
            'asyncio': { 'asyncio.AbstractChildWatcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractChildWatcher',
                         'asyncio.AbstractChildWatcher.add_child_handler': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractChildWatcher.add_child_handler',
                         'asyncio.AbstractChildWatcher.attach_loop': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractChildWatcher.attach_loop',
                         'asyncio.AbstractChildWatcher.close': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractChildWatcher.close',
                         'asyncio.AbstractChildWatcher.is_active': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractChildWatcher.is_active',
                         'asyncio.AbstractChildWatcher.remove_child_handler': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractChildWatcher.remove_child_handler',
                         'asyncio.AbstractEventLoop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.AbstractEventLoop',
                         'asyncio.AbstractEventLoopPolicy': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy',
                         'asyncio.AbstractEventLoopPolicy.get_child_watcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy.get_child_watcher',
                         'asyncio.AbstractEventLoopPolicy.get_event_loop': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy.get_event_loop',
                         'asyncio.AbstractEventLoopPolicy.new_event_loop': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy.new_event_loop',
                         'asyncio.AbstractEventLoopPolicy.set_child_watcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy.set_child_watcher',
                         'asyncio.AbstractEventLoopPolicy.set_event_loop': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy.set_event_loop',
                         'asyncio.BaseProtocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseProtocol',
                         'asyncio.BaseProtocol.connection_lost': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseProtocol.connection_lost',
                         'asyncio.BaseProtocol.connection_made': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseProtocol.connection_made',
                         'asyncio.BaseProtocol.pause_writing': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseProtocol.pause_writing',
                         'asyncio.BaseProtocol.resume_writing': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseProtocol.resume_writing',
                         'asyncio.BaseTransport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseTransport',
                         'asyncio.BaseTransport.close': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseTransport.close',
                         'asyncio.BaseTransport.get_extra_info': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseTransport.get_extra_info',
                         'asyncio.BaseTransport.get_protocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseTransport.get_protocol',
                         'asyncio.BaseTransport.is_closing': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseTransport.is_closing',
                         'asyncio.BaseTransport.set_protocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BaseTransport.set_protocol',
                         'asyncio.BoundedSemaphore': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.BoundedSemaphore',
                         'asyncio.BufferedProtocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BufferedProtocol',
                         'asyncio.BufferedProtocol.buffer_updated': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BufferedProtocol.buffer_updated',
                         'asyncio.BufferedProtocol.eof_received': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BufferedProtocol.eof_received',
                         'asyncio.BufferedProtocol.get_buffer': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.BufferedProtocol.get_buffer',
                         'asyncio.Condition': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition',
                         'asyncio.Condition.acquire': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.acquire',
                         'asyncio.Condition.locked': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.locked',
                         'asyncio.Condition.notify': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.notify',
                         'asyncio.Condition.notify_all': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.notify_all',
                         'asyncio.Condition.release': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.release',
                         'asyncio.Condition.wait': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.wait',
                         'asyncio.Condition.wait_for': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Condition.wait_for',
                         'asyncio.DatagramProtocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.DatagramProtocol',
                         'asyncio.DatagramProtocol.datagram_received': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.DatagramProtocol.datagram_received',
                         'asyncio.DatagramProtocol.error_received': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.DatagramProtocol.error_received',
                         'asyncio.DatagramTransport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.DatagramTransport',
                         'asyncio.DatagramTransport.abort': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.DatagramTransport.abort',
                         'asyncio.DatagramTransport.sendto': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.DatagramTransport.sendto',
                         'asyncio.DefaultEventLoopPolicy': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.DefaultEventLoopPolicy',
                         'asyncio.Event': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Event',
                         'asyncio.Event.clear': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Event.clear',
                         'asyncio.Event.is_set': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Event.is_set',
                         'asyncio.Event.set': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Event.set',
                         'asyncio.Event.wait': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Event.wait',
                         'asyncio.FastChildWatcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.FastChildWatcher',
                         'asyncio.Future': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future',
                         'asyncio.Future.add_done_callback': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.add_done_callback',
                         'asyncio.Future.cancel': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.cancel',
                         'asyncio.Future.cancelled': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.cancelled',
                         'asyncio.Future.done': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.done',
                         'asyncio.Future.exception': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.exception',
                         'asyncio.Future.get_loop': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.get_loop',
                         'asyncio.Future.remove_done_callback': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.remove_done_callback',
                         'asyncio.Future.result': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.result',
                         'asyncio.Future.set_exception': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.set_exception',
                         'asyncio.Future.set_result': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.set_result',
                         'asyncio.Handle': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Handle',
                         'asyncio.Handle.cancel': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Handle.cancel',
                         'asyncio.Handle.cancelled': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Handle.cancelled',
                         'asyncio.LifoQueue': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.LifoQueue',
                         'asyncio.Lock': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Lock',
                         'asyncio.Lock.acquire': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Lock.acquire',
                         'asyncio.Lock.locked': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Lock.locked',
                         'asyncio.Lock.release': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Lock.release',
                         'asyncio.MultiLoopChildWatcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.MultiLoopChildWatcher',
                         'asyncio.PidfdChildWatcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.PidfdChildWatcher',
                         'asyncio.PriorityQueue': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.PriorityQueue',
                         'asyncio.ProactorEventLoop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.ProactorEventLoop',
                         'asyncio.Protocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.Protocol',
                         'asyncio.Protocol.data_received': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.Protocol.data_received',
                         'asyncio.Protocol.eof_received': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.Protocol.eof_received',
                         'asyncio.Queue': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue',
                         'asyncio.Queue.empty': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.empty',
                         'asyncio.Queue.full': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.full',
                         'asyncio.Queue.get': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.get',
                         'asyncio.Queue.get_nowait': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.get_nowait',
                         'asyncio.Queue.join': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.join',
                         'asyncio.Queue.put': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.put',
                         'asyncio.Queue.put_nowait': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.put_nowait',
                         'asyncio.Queue.qsize': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.qsize',
                         'asyncio.Queue.task_done': 'https://docs.python.org/3/library/asyncio-queue.html#asyncio.Queue.task_done',
                         'asyncio.ReadTransport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.ReadTransport',
                         'asyncio.ReadTransport.is_reading': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.ReadTransport.is_reading',
                         'asyncio.ReadTransport.pause_reading': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.ReadTransport.pause_reading',
                         'asyncio.ReadTransport.resume_reading': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.ReadTransport.resume_reading',
                         'asyncio.SafeChildWatcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.SafeChildWatcher',
                         'asyncio.SelectorEventLoop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.SelectorEventLoop',
                         'asyncio.Semaphore': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Semaphore',
                         'asyncio.Semaphore.acquire': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Semaphore.acquire',
                         'asyncio.Semaphore.locked': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Semaphore.locked',
                         'asyncio.Semaphore.release': 'https://docs.python.org/3/library/asyncio-sync.html#asyncio.Semaphore.release',
                         'asyncio.Server': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server',
                         'asyncio.Server.close': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server.close',
                         'asyncio.Server.get_loop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server.get_loop',
                         'asyncio.Server.is_serving': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server.is_serving',
                         'asyncio.Server.serve_forever': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server.serve_forever',
                         'asyncio.Server.start_serving': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server.start_serving',
                         'asyncio.Server.wait_closed': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.Server.wait_closed',
                         'asyncio.StreamReader': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamReader',
                         'asyncio.StreamReader.at_eof': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamReader.at_eof',
                         'asyncio.StreamReader.read': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamReader.read',
                         'asyncio.StreamReader.readexactly': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamReader.readexactly',
                         'asyncio.StreamReader.readline': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamReader.readline',
                         'asyncio.StreamReader.readuntil': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamReader.readuntil',
                         'asyncio.StreamWriter': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter',
                         'asyncio.StreamWriter.can_write_eof': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.can_write_eof',
                         'asyncio.StreamWriter.close': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.close',
                         'asyncio.StreamWriter.drain': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.drain',
                         'asyncio.StreamWriter.get_extra_info': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.get_extra_info',
                         'asyncio.StreamWriter.is_closing': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.is_closing',
                         'asyncio.StreamWriter.wait_closed': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.wait_closed',
                         'asyncio.StreamWriter.write': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.write',
                         'asyncio.StreamWriter.write_eof': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.write_eof',
                         'asyncio.StreamWriter.writelines': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.StreamWriter.writelines',
                         'asyncio.SubprocessProtocol': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessProtocol',
                         'asyncio.SubprocessProtocol.pipe_connection_lost': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessProtocol.pipe_connection_lost',
                         'asyncio.SubprocessProtocol.pipe_data_received': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessProtocol.pipe_data_received',
                         'asyncio.SubprocessProtocol.process_exited': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessProtocol.process_exited',
                         'asyncio.SubprocessTransport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport',
                         'asyncio.SubprocessTransport.close': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.close',
                         'asyncio.SubprocessTransport.get_pid': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.get_pid',
                         'asyncio.SubprocessTransport.get_pipe_transport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.get_pipe_transport',
                         'asyncio.SubprocessTransport.get_returncode': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.get_returncode',
                         'asyncio.SubprocessTransport.kill': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.kill',
                         'asyncio.SubprocessTransport.send_signal': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.send_signal',
                         'asyncio.SubprocessTransport.terminate': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.SubprocessTransport.terminate',
                         'asyncio.Task': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task',
                         'asyncio.Task.add_done_callback': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.add_done_callback',
                         'asyncio.Task.cancel': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.cancel',
                         'asyncio.Task.cancelled': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.cancelled',
                         'asyncio.Task.done': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.done',
                         'asyncio.Task.exception': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.exception',
                         'asyncio.Task.get_coro': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.get_coro',
                         'asyncio.Task.get_name': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.get_name',
                         'asyncio.Task.get_stack': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.get_stack',
                         'asyncio.Task.print_stack': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.print_stack',
                         'asyncio.Task.remove_done_callback': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.remove_done_callback',
                         'asyncio.Task.result': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.result',
                         'asyncio.Task.set_name': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.Task.set_name',
                         'asyncio.ThreadedChildWatcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.ThreadedChildWatcher',
                         'asyncio.TimerHandle': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.TimerHandle',
                         'asyncio.TimerHandle.when': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.TimerHandle.when',
                         'asyncio.Transport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.Transport',
                         'asyncio.WindowsProactorEventLoopPolicy': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.WindowsProactorEventLoopPolicy',
                         'asyncio.WindowsSelectorEventLoopPolicy': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.WindowsSelectorEventLoopPolicy',
                         'asyncio.WriteTransport': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport',
                         'asyncio.WriteTransport.abort': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.abort',
                         'asyncio.WriteTransport.can_write_eof': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.can_write_eof',
                         'asyncio.WriteTransport.get_write_buffer_limits': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.get_write_buffer_limits',
                         'asyncio.WriteTransport.get_write_buffer_size': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.get_write_buffer_size',
                         'asyncio.WriteTransport.set_write_buffer_limits': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.set_write_buffer_limits',
                         'asyncio.WriteTransport.write': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.write',
                         'asyncio.WriteTransport.write_eof': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.write_eof',
                         'asyncio.WriteTransport.writelines': 'https://docs.python.org/3/library/asyncio-protocol.html#asyncio.WriteTransport.writelines',
                         'asyncio.all_tasks': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.all_tasks',
                         'asyncio.as_completed': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.as_completed',
                         'asyncio.coroutine': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.coroutine',
                         'asyncio.create_subprocess_exec': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.create_subprocess_exec',
                         'asyncio.create_subprocess_shell': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.create_subprocess_shell',
                         'asyncio.create_task': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.create_task',
                         'asyncio.current_task': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.current_task',
                         'asyncio.ensure_future': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.ensure_future',
                         'asyncio.gather': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.gather',
                         'asyncio.get_child_watcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.get_child_watcher',
                         'asyncio.get_event_loop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.get_event_loop',
                         'asyncio.get_event_loop_policy': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.get_event_loop_policy',
                         'asyncio.get_running_loop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.get_running_loop',
                         'asyncio.iscoroutine': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.iscoroutine',
                         'asyncio.iscoroutinefunction': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.iscoroutinefunction',
                         'asyncio.isfuture': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.isfuture',
                         'asyncio.loop.add_reader': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.add_reader',
                         'asyncio.loop.add_signal_handler': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.add_signal_handler',
                         'asyncio.loop.add_writer': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.add_writer',
                         'asyncio.loop.call_at': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.call_at',
                         'asyncio.loop.call_exception_handler': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.call_exception_handler',
                         'asyncio.loop.call_later': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.call_later',
                         'asyncio.loop.call_soon': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.call_soon',
                         'asyncio.loop.call_soon_threadsafe': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.call_soon_threadsafe',
                         'asyncio.loop.close': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.close',
                         'asyncio.loop.connect_accepted_socket': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.connect_accepted_socket',
                         'asyncio.loop.connect_read_pipe': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.connect_read_pipe',
                         'asyncio.loop.connect_write_pipe': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.connect_write_pipe',
                         'asyncio.loop.create_connection': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_connection',
                         'asyncio.loop.create_datagram_endpoint': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_datagram_endpoint',
                         'asyncio.loop.create_future': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_future',
                         'asyncio.loop.create_server': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_server',
                         'asyncio.loop.create_task': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_task',
                         'asyncio.loop.create_unix_connection': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_unix_connection',
                         'asyncio.loop.create_unix_server': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.create_unix_server',
                         'asyncio.loop.default_exception_handler': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.default_exception_handler',
                         'asyncio.loop.get_debug': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.get_debug',
                         'asyncio.loop.get_exception_handler': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.get_exception_handler',
                         'asyncio.loop.get_task_factory': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.get_task_factory',
                         'asyncio.loop.getaddrinfo': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.getaddrinfo',
                         'asyncio.loop.getnameinfo': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.getnameinfo',
                         'asyncio.loop.is_closed': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.is_closed',
                         'asyncio.loop.is_running': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.is_running',
                         'asyncio.loop.remove_reader': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.remove_reader',
                         'asyncio.loop.remove_signal_handler': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.remove_signal_handler',
                         'asyncio.loop.remove_writer': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.remove_writer',
                         'asyncio.loop.run_forever': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.run_forever',
                         'asyncio.loop.run_in_executor': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.run_in_executor',
                         'asyncio.loop.run_until_complete': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.run_until_complete',
                         'asyncio.loop.sendfile': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sendfile',
                         'asyncio.loop.set_debug': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.set_debug',
                         'asyncio.loop.set_default_executor': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.set_default_executor',
                         'asyncio.loop.set_exception_handler': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.set_exception_handler',
                         'asyncio.loop.set_task_factory': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.set_task_factory',
                         'asyncio.loop.shutdown_asyncgens': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.shutdown_asyncgens',
                         'asyncio.loop.shutdown_default_executor': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.shutdown_default_executor',
                         'asyncio.loop.sock_accept': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sock_accept',
                         'asyncio.loop.sock_connect': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sock_connect',
                         'asyncio.loop.sock_recv': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sock_recv',
                         'asyncio.loop.sock_recv_into': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sock_recv_into',
                         'asyncio.loop.sock_sendall': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sock_sendall',
                         'asyncio.loop.sock_sendfile': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.sock_sendfile',
                         'asyncio.loop.start_tls': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.start_tls',
                         'asyncio.loop.stop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.stop',
                         'asyncio.loop.subprocess_exec': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.subprocess_exec',
                         'asyncio.loop.subprocess_shell': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.subprocess_shell',
                         'asyncio.loop.time': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.time',
                         'asyncio.new_event_loop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.new_event_loop',
                         'asyncio.open_connection': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.open_connection',
                         'asyncio.open_unix_connection': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.open_unix_connection',
                         'asyncio.run': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.run',
                         'asyncio.run_coroutine_threadsafe': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.run_coroutine_threadsafe',
                         'asyncio.set_child_watcher': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.set_child_watcher',
                         'asyncio.set_event_loop': 'https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.set_event_loop',
                         'asyncio.set_event_loop_policy': 'https://docs.python.org/3/library/asyncio-policy.html#asyncio.set_event_loop_policy',
                         'asyncio.shield': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.shield',
                         'asyncio.sleep': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.sleep',
                         'asyncio.start_server': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.start_server',
                         'asyncio.start_unix_server': 'https://docs.python.org/3/library/asyncio-stream.html#asyncio.start_unix_server',
                         'asyncio.to_thread': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.to_thread',
                         'asyncio.wait': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.wait',
                         'asyncio.wait_for': 'https://docs.python.org/3/library/asyncio-task.html#asyncio.wait_for',
                         'asyncio.wrap_future': 'https://docs.python.org/3/library/asyncio-future.html#asyncio.wrap_future'},
            'asyncio.subprocess': { 'asyncio.subprocess.Process': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.subprocess.Process',
                                    'asyncio.subprocess.Process.communicate': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.subprocess.Process.communicate',
                                    'asyncio.subprocess.Process.kill': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.subprocess.Process.kill',
                                    'asyncio.subprocess.Process.send_signal': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.subprocess.Process.send_signal',
                                    'asyncio.subprocess.Process.terminate': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.subprocess.Process.terminate',
                                    'asyncio.subprocess.Process.wait': 'https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.subprocess.Process.wait'},
            'asyncore': { 'asyncore.dispatcher': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher',
                          'asyncore.dispatcher.accept': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.accept',
                          'asyncore.dispatcher.bind': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.bind',
                          'asyncore.dispatcher.close': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.close',
                          'asyncore.dispatcher.connect': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.connect',
                          'asyncore.dispatcher.create_socket': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.create_socket',
                          'asyncore.dispatcher.handle_accept': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_accept',
                          'asyncore.dispatcher.handle_accepted': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_accepted',
                          'asyncore.dispatcher.handle_close': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_close',
                          'asyncore.dispatcher.handle_connect': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_connect',
                          'asyncore.dispatcher.handle_error': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_error',
                          'asyncore.dispatcher.handle_expt': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_expt',
                          'asyncore.dispatcher.handle_read': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_read',
                          'asyncore.dispatcher.handle_write': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.handle_write',
                          'asyncore.dispatcher.listen': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.listen',
                          'asyncore.dispatcher.readable': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.readable',
                          'asyncore.dispatcher.recv': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.recv',
                          'asyncore.dispatcher.send': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.send',
                          'asyncore.dispatcher.writable': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher.writable',
                          'asyncore.dispatcher_with_send': 'https://docs.python.org/3/library/asyncore.html#asyncore.dispatcher_with_send',
                          'asyncore.file_dispatcher': 'https://docs.python.org/3/library/asyncore.html#asyncore.file_dispatcher',
                          'asyncore.file_wrapper': 'https://docs.python.org/3/library/asyncore.html#asyncore.file_wrapper',
                          'asyncore.loop': 'https://docs.python.org/3/library/asyncore.html#asyncore.loop'},
            'atexit': { 'atexit.register': 'https://docs.python.org/3/library/atexit.html#atexit.register',
                        'atexit.unregister': 'https://docs.python.org/3/library/atexit.html#atexit.unregister'},
            'audioop': { 'audioop.add': 'https://docs.python.org/3/library/audioop.html#audioop.add',
                         'audioop.adpcm2lin': 'https://docs.python.org/3/library/audioop.html#audioop.adpcm2lin',
                         'audioop.alaw2lin': 'https://docs.python.org/3/library/audioop.html#audioop.alaw2lin',
                         'audioop.avg': 'https://docs.python.org/3/library/audioop.html#audioop.avg',
                         'audioop.avgpp': 'https://docs.python.org/3/library/audioop.html#audioop.avgpp',
                         'audioop.bias': 'https://docs.python.org/3/library/audioop.html#audioop.bias',
                         'audioop.byteswap': 'https://docs.python.org/3/library/audioop.html#audioop.byteswap',
                         'audioop.cross': 'https://docs.python.org/3/library/audioop.html#audioop.cross',
                         'audioop.findfactor': 'https://docs.python.org/3/library/audioop.html#audioop.findfactor',
                         'audioop.findfit': 'https://docs.python.org/3/library/audioop.html#audioop.findfit',
                         'audioop.findmax': 'https://docs.python.org/3/library/audioop.html#audioop.findmax',
                         'audioop.getsample': 'https://docs.python.org/3/library/audioop.html#audioop.getsample',
                         'audioop.lin2adpcm': 'https://docs.python.org/3/library/audioop.html#audioop.lin2adpcm',
                         'audioop.lin2alaw': 'https://docs.python.org/3/library/audioop.html#audioop.lin2alaw',
                         'audioop.lin2lin': 'https://docs.python.org/3/library/audioop.html#audioop.lin2lin',
                         'audioop.lin2ulaw': 'https://docs.python.org/3/library/audioop.html#audioop.lin2ulaw',
                         'audioop.max': 'https://docs.python.org/3/library/audioop.html#audioop.max',
                         'audioop.maxpp': 'https://docs.python.org/3/library/audioop.html#audioop.maxpp',
                         'audioop.minmax': 'https://docs.python.org/3/library/audioop.html#audioop.minmax',
                         'audioop.mul': 'https://docs.python.org/3/library/audioop.html#audioop.mul',
                         'audioop.ratecv': 'https://docs.python.org/3/library/audioop.html#audioop.ratecv',
                         'audioop.reverse': 'https://docs.python.org/3/library/audioop.html#audioop.reverse',
                         'audioop.rms': 'https://docs.python.org/3/library/audioop.html#audioop.rms',
                         'audioop.tomono': 'https://docs.python.org/3/library/audioop.html#audioop.tomono',
                         'audioop.tostereo': 'https://docs.python.org/3/library/audioop.html#audioop.tostereo',
                         'audioop.ulaw2lin': 'https://docs.python.org/3/library/audioop.html#audioop.ulaw2lin'},
            'base64': { 'base64.a85decode': 'https://docs.python.org/3/library/base64.html#base64.a85decode',
                        'base64.a85encode': 'https://docs.python.org/3/library/base64.html#base64.a85encode',
                        'base64.b16decode': 'https://docs.python.org/3/library/base64.html#base64.b16decode',
                        'base64.b16encode': 'https://docs.python.org/3/library/base64.html#base64.b16encode',
                        'base64.b32decode': 'https://docs.python.org/3/library/base64.html#base64.b32decode',
                        'base64.b32encode': 'https://docs.python.org/3/library/base64.html#base64.b32encode',
                        'base64.b32hexdecode': 'https://docs.python.org/3/library/base64.html#base64.b32hexdecode',
                        'base64.b32hexencode': 'https://docs.python.org/3/library/base64.html#base64.b32hexencode',
                        'base64.b64decode': 'https://docs.python.org/3/library/base64.html#base64.b64decode',
                        'base64.b64encode': 'https://docs.python.org/3/library/base64.html#base64.b64encode',
                        'base64.b85decode': 'https://docs.python.org/3/library/base64.html#base64.b85decode',
                        'base64.b85encode': 'https://docs.python.org/3/library/base64.html#base64.b85encode',
                        'base64.decode': 'https://docs.python.org/3/library/base64.html#base64.decode',
                        'base64.decodebytes': 'https://docs.python.org/3/library/base64.html#base64.decodebytes',
                        'base64.encode': 'https://docs.python.org/3/library/base64.html#base64.encode',
                        'base64.encodebytes': 'https://docs.python.org/3/library/base64.html#base64.encodebytes',
                        'base64.standard_b64decode': 'https://docs.python.org/3/library/base64.html#base64.standard_b64decode',
                        'base64.standard_b64encode': 'https://docs.python.org/3/library/base64.html#base64.standard_b64encode',
                        'base64.urlsafe_b64decode': 'https://docs.python.org/3/library/base64.html#base64.urlsafe_b64decode',
                        'base64.urlsafe_b64encode': 'https://docs.python.org/3/library/base64.html#base64.urlsafe_b64encode'},
            'bdb': { 'bdb.Bdb': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb',
                     'bdb.Bdb.break_anywhere': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.break_anywhere',
                     'bdb.Bdb.break_here': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.break_here',
                     'bdb.Bdb.canonic': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.canonic',
                     'bdb.Bdb.clear_all_breaks': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.clear_all_breaks',
                     'bdb.Bdb.clear_all_file_breaks': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.clear_all_file_breaks',
                     'bdb.Bdb.clear_bpbynumber': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.clear_bpbynumber',
                     'bdb.Bdb.clear_break': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.clear_break',
                     'bdb.Bdb.dispatch_call': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.dispatch_call',
                     'bdb.Bdb.dispatch_exception': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.dispatch_exception',
                     'bdb.Bdb.dispatch_line': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.dispatch_line',
                     'bdb.Bdb.dispatch_return': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.dispatch_return',
                     'bdb.Bdb.do_clear': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.do_clear',
                     'bdb.Bdb.format_stack_entry': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.format_stack_entry',
                     'bdb.Bdb.get_all_breaks': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.get_all_breaks',
                     'bdb.Bdb.get_bpbynumber': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.get_bpbynumber',
                     'bdb.Bdb.get_break': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.get_break',
                     'bdb.Bdb.get_breaks': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.get_breaks',
                     'bdb.Bdb.get_file_breaks': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.get_file_breaks',
                     'bdb.Bdb.get_stack': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.get_stack',
                     'bdb.Bdb.is_skipped_line': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.is_skipped_line',
                     'bdb.Bdb.reset': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.reset',
                     'bdb.Bdb.run': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.run',
                     'bdb.Bdb.runcall': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.runcall',
                     'bdb.Bdb.runctx': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.runctx',
                     'bdb.Bdb.runeval': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.runeval',
                     'bdb.Bdb.set_break': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_break',
                     'bdb.Bdb.set_continue': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_continue',
                     'bdb.Bdb.set_next': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_next',
                     'bdb.Bdb.set_quit': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_quit',
                     'bdb.Bdb.set_return': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_return',
                     'bdb.Bdb.set_step': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_step',
                     'bdb.Bdb.set_trace': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_trace',
                     'bdb.Bdb.set_until': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.set_until',
                     'bdb.Bdb.stop_here': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.stop_here',
                     'bdb.Bdb.trace_dispatch': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.trace_dispatch',
                     'bdb.Bdb.user_call': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.user_call',
                     'bdb.Bdb.user_exception': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.user_exception',
                     'bdb.Bdb.user_line': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.user_line',
                     'bdb.Bdb.user_return': 'https://docs.python.org/3/library/bdb.html#bdb.Bdb.user_return',
                     'bdb.Breakpoint': 'https://docs.python.org/3/library/bdb.html#bdb.Breakpoint',
                     'bdb.Breakpoint.bpformat': 'https://docs.python.org/3/library/bdb.html#bdb.Breakpoint.bpformat',
                     'bdb.Breakpoint.bpprint': 'https://docs.python.org/3/library/bdb.html#bdb.Breakpoint.bpprint',
                     'bdb.Breakpoint.deleteMe': 'https://docs.python.org/3/library/bdb.html#bdb.Breakpoint.deleteMe',
                     'bdb.Breakpoint.disable': 'https://docs.python.org/3/library/bdb.html#bdb.Breakpoint.disable',
                     'bdb.Breakpoint.enable': 'https://docs.python.org/3/library/bdb.html#bdb.Breakpoint.enable',
                     'bdb.checkfuncname': 'https://docs.python.org/3/library/bdb.html#bdb.checkfuncname',
                     'bdb.effective': 'https://docs.python.org/3/library/bdb.html#bdb.effective',
                     'bdb.set_trace': 'https://docs.python.org/3/library/bdb.html#bdb.set_trace'},
            'binascii': { 'binascii.a2b_base64': 'https://docs.python.org/3/library/binascii.html#binascii.a2b_base64',
                          'binascii.a2b_hex': 'https://docs.python.org/3/library/binascii.html#binascii.a2b_hex',
                          'binascii.a2b_hqx': 'https://docs.python.org/3/library/binascii.html#binascii.a2b_hqx',
                          'binascii.a2b_qp': 'https://docs.python.org/3/library/binascii.html#binascii.a2b_qp',
                          'binascii.a2b_uu': 'https://docs.python.org/3/library/binascii.html#binascii.a2b_uu',
                          'binascii.b2a_base64': 'https://docs.python.org/3/library/binascii.html#binascii.b2a_base64',
                          'binascii.b2a_hex': 'https://docs.python.org/3/library/binascii.html#binascii.b2a_hex',
                          'binascii.b2a_hqx': 'https://docs.python.org/3/library/binascii.html#binascii.b2a_hqx',
                          'binascii.b2a_qp': 'https://docs.python.org/3/library/binascii.html#binascii.b2a_qp',
                          'binascii.b2a_uu': 'https://docs.python.org/3/library/binascii.html#binascii.b2a_uu',
                          'binascii.crc32': 'https://docs.python.org/3/library/binascii.html#binascii.crc32',
                          'binascii.crc_hqx': 'https://docs.python.org/3/library/binascii.html#binascii.crc_hqx',
                          'binascii.hexlify': 'https://docs.python.org/3/library/binascii.html#binascii.hexlify',
                          'binascii.rlecode_hqx': 'https://docs.python.org/3/library/binascii.html#binascii.rlecode_hqx',
                          'binascii.rledecode_hqx': 'https://docs.python.org/3/library/binascii.html#binascii.rledecode_hqx',
                          'binascii.unhexlify': 'https://docs.python.org/3/library/binascii.html#binascii.unhexlify'},
            'binhex': { 'binhex.binhex': 'https://docs.python.org/3/library/binhex.html#binhex.binhex',
                        'binhex.hexbin': 'https://docs.python.org/3/library/binhex.html#binhex.hexbin'},
            'bisect': { 'bisect.bisect': 'https://docs.python.org/3/library/bisect.html#bisect.bisect',
                        'bisect.bisect_left': 'https://docs.python.org/3/library/bisect.html#bisect.bisect_left',
                        'bisect.bisect_right': 'https://docs.python.org/3/library/bisect.html#bisect.bisect_right',
                        'bisect.insort': 'https://docs.python.org/3/library/bisect.html#bisect.insort',
                        'bisect.insort_left': 'https://docs.python.org/3/library/bisect.html#bisect.insort_left',
                        'bisect.insort_right': 'https://docs.python.org/3/library/bisect.html#bisect.insort_right'},
            'bz2': { 'bz2.BZ2Compressor': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2Compressor',
                     'bz2.BZ2Compressor.compress': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2Compressor.compress',
                     'bz2.BZ2Compressor.flush': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2Compressor.flush',
                     'bz2.BZ2Decompressor': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2Decompressor',
                     'bz2.BZ2Decompressor.decompress': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2Decompressor.decompress',
                     'bz2.BZ2File': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2File',
                     'bz2.BZ2File.peek': 'https://docs.python.org/3/library/bz2.html#bz2.BZ2File.peek',
                     'bz2.compress': 'https://docs.python.org/3/library/bz2.html#bz2.compress',
                     'bz2.decompress': 'https://docs.python.org/3/library/bz2.html#bz2.decompress',
                     'bz2.open': 'https://docs.python.org/3/library/bz2.html#bz2.open'},
            'calendar': { 'calendar.Calendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar',
                          'calendar.Calendar.itermonthdates': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.itermonthdates',
                          'calendar.Calendar.itermonthdays': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.itermonthdays',
                          'calendar.Calendar.itermonthdays2': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.itermonthdays2',
                          'calendar.Calendar.itermonthdays3': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.itermonthdays3',
                          'calendar.Calendar.itermonthdays4': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.itermonthdays4',
                          'calendar.Calendar.iterweekdays': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.iterweekdays',
                          'calendar.Calendar.monthdatescalendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.monthdatescalendar',
                          'calendar.Calendar.monthdays2calendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.monthdays2calendar',
                          'calendar.Calendar.monthdayscalendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.monthdayscalendar',
                          'calendar.Calendar.yeardatescalendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.yeardatescalendar',
                          'calendar.Calendar.yeardays2calendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.yeardays2calendar',
                          'calendar.Calendar.yeardayscalendar': 'https://docs.python.org/3/library/calendar.html#calendar.Calendar.yeardayscalendar',
                          'calendar.HTMLCalendar': 'https://docs.python.org/3/library/calendar.html#calendar.HTMLCalendar',
                          'calendar.HTMLCalendar.formatmonth': 'https://docs.python.org/3/library/calendar.html#calendar.HTMLCalendar.formatmonth',
                          'calendar.HTMLCalendar.formatyear': 'https://docs.python.org/3/library/calendar.html#calendar.HTMLCalendar.formatyear',
                          'calendar.HTMLCalendar.formatyearpage': 'https://docs.python.org/3/library/calendar.html#calendar.HTMLCalendar.formatyearpage',
                          'calendar.LocaleHTMLCalendar': 'https://docs.python.org/3/library/calendar.html#calendar.LocaleHTMLCalendar',
                          'calendar.LocaleTextCalendar': 'https://docs.python.org/3/library/calendar.html#calendar.LocaleTextCalendar',
                          'calendar.TextCalendar': 'https://docs.python.org/3/library/calendar.html#calendar.TextCalendar',
                          'calendar.TextCalendar.formatmonth': 'https://docs.python.org/3/library/calendar.html#calendar.TextCalendar.formatmonth',
                          'calendar.TextCalendar.formatyear': 'https://docs.python.org/3/library/calendar.html#calendar.TextCalendar.formatyear',
                          'calendar.TextCalendar.prmonth': 'https://docs.python.org/3/library/calendar.html#calendar.TextCalendar.prmonth',
                          'calendar.TextCalendar.pryear': 'https://docs.python.org/3/library/calendar.html#calendar.TextCalendar.pryear',
                          'calendar.calendar': 'https://docs.python.org/3/library/calendar.html#calendar.calendar',
                          'calendar.firstweekday': 'https://docs.python.org/3/library/calendar.html#calendar.firstweekday',
                          'calendar.isleap': 'https://docs.python.org/3/library/calendar.html#calendar.isleap',
                          'calendar.leapdays': 'https://docs.python.org/3/library/calendar.html#calendar.leapdays',
                          'calendar.month': 'https://docs.python.org/3/library/calendar.html#calendar.month',
                          'calendar.monthcalendar': 'https://docs.python.org/3/library/calendar.html#calendar.monthcalendar',
                          'calendar.monthrange': 'https://docs.python.org/3/library/calendar.html#calendar.monthrange',
                          'calendar.prcal': 'https://docs.python.org/3/library/calendar.html#calendar.prcal',
                          'calendar.prmonth': 'https://docs.python.org/3/library/calendar.html#calendar.prmonth',
                          'calendar.setfirstweekday': 'https://docs.python.org/3/library/calendar.html#calendar.setfirstweekday',
                          'calendar.timegm': 'https://docs.python.org/3/library/calendar.html#calendar.timegm',
                          'calendar.weekday': 'https://docs.python.org/3/library/calendar.html#calendar.weekday',
                          'calendar.weekheader': 'https://docs.python.org/3/library/calendar.html#calendar.weekheader'},
            'cgi': { 'cgi.FieldStorage.getfirst': 'https://docs.python.org/3/library/cgi.html#cgi.FieldStorage.getfirst',
                     'cgi.FieldStorage.getlist': 'https://docs.python.org/3/library/cgi.html#cgi.FieldStorage.getlist',
                     'cgi.parse': 'https://docs.python.org/3/library/cgi.html#cgi.parse',
                     'cgi.parse_header': 'https://docs.python.org/3/library/cgi.html#cgi.parse_header',
                     'cgi.parse_multipart': 'https://docs.python.org/3/library/cgi.html#cgi.parse_multipart',
                     'cgi.print_directory': 'https://docs.python.org/3/library/cgi.html#cgi.print_directory',
                     'cgi.print_environ': 'https://docs.python.org/3/library/cgi.html#cgi.print_environ',
                     'cgi.print_environ_usage': 'https://docs.python.org/3/library/cgi.html#cgi.print_environ_usage',
                     'cgi.print_form': 'https://docs.python.org/3/library/cgi.html#cgi.print_form',
                     'cgi.test': 'https://docs.python.org/3/library/cgi.html#cgi.test'},
            'cgitb': { 'cgitb.enable': 'https://docs.python.org/3/library/cgitb.html#cgitb.enable',
                       'cgitb.handler': 'https://docs.python.org/3/library/cgitb.html#cgitb.handler',
                       'cgitb.html': 'https://docs.python.org/3/library/cgitb.html#cgitb.html',
                       'cgitb.text': 'https://docs.python.org/3/library/cgitb.html#cgitb.text'},
            'chunk': { 'chunk.Chunk': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk',
                       'chunk.Chunk.close': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.close',
                       'chunk.Chunk.getname': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.getname',
                       'chunk.Chunk.getsize': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.getsize',
                       'chunk.Chunk.isatty': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.isatty',
                       'chunk.Chunk.read': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.read',
                       'chunk.Chunk.seek': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.seek',
                       'chunk.Chunk.skip': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.skip',
                       'chunk.Chunk.tell': 'https://docs.python.org/3/library/chunk.html#chunk.Chunk.tell'},
            'cmath': { 'cmath.acos': 'https://docs.python.org/3/library/cmath.html#cmath.acos',
                       'cmath.acosh': 'https://docs.python.org/3/library/cmath.html#cmath.acosh',
                       'cmath.asin': 'https://docs.python.org/3/library/cmath.html#cmath.asin',
                       'cmath.asinh': 'https://docs.python.org/3/library/cmath.html#cmath.asinh',
                       'cmath.atan': 'https://docs.python.org/3/library/cmath.html#cmath.atan',
                       'cmath.atanh': 'https://docs.python.org/3/library/cmath.html#cmath.atanh',
                       'cmath.cos': 'https://docs.python.org/3/library/cmath.html#cmath.cos',
                       'cmath.cosh': 'https://docs.python.org/3/library/cmath.html#cmath.cosh',
                       'cmath.exp': 'https://docs.python.org/3/library/cmath.html#cmath.exp',
                       'cmath.isclose': 'https://docs.python.org/3/library/cmath.html#cmath.isclose',
                       'cmath.isfinite': 'https://docs.python.org/3/library/cmath.html#cmath.isfinite',
                       'cmath.isinf': 'https://docs.python.org/3/library/cmath.html#cmath.isinf',
                       'cmath.isnan': 'https://docs.python.org/3/library/cmath.html#cmath.isnan',
                       'cmath.log': 'https://docs.python.org/3/library/cmath.html#cmath.log',
                       'cmath.log10': 'https://docs.python.org/3/library/cmath.html#cmath.log10',
                       'cmath.phase': 'https://docs.python.org/3/library/cmath.html#cmath.phase',
                       'cmath.polar': 'https://docs.python.org/3/library/cmath.html#cmath.polar',
                       'cmath.rect': 'https://docs.python.org/3/library/cmath.html#cmath.rect',
                       'cmath.sin': 'https://docs.python.org/3/library/cmath.html#cmath.sin',
                       'cmath.sinh': 'https://docs.python.org/3/library/cmath.html#cmath.sinh',
                       'cmath.sqrt': 'https://docs.python.org/3/library/cmath.html#cmath.sqrt',
                       'cmath.tan': 'https://docs.python.org/3/library/cmath.html#cmath.tan',
                       'cmath.tanh': 'https://docs.python.org/3/library/cmath.html#cmath.tanh'},
            'cmd': { 'cmd.Cmd': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd',
                     'cmd.Cmd.cmdloop': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.cmdloop',
                     'cmd.Cmd.completedefault': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.completedefault',
                     'cmd.Cmd.default': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.default',
                     'cmd.Cmd.emptyline': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.emptyline',
                     'cmd.Cmd.onecmd': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.onecmd',
                     'cmd.Cmd.postcmd': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.postcmd',
                     'cmd.Cmd.postloop': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.postloop',
                     'cmd.Cmd.precmd': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.precmd',
                     'cmd.Cmd.preloop': 'https://docs.python.org/3/library/cmd.html#cmd.Cmd.preloop'},
            'code': { 'code.InteractiveConsole': 'https://docs.python.org/3/library/code.html#code.InteractiveConsole',
                      'code.InteractiveConsole.interact': 'https://docs.python.org/3/library/code.html#code.InteractiveConsole.interact',
                      'code.InteractiveConsole.push': 'https://docs.python.org/3/library/code.html#code.InteractiveConsole.push',
                      'code.InteractiveConsole.raw_input': 'https://docs.python.org/3/library/code.html#code.InteractiveConsole.raw_input',
                      'code.InteractiveConsole.resetbuffer': 'https://docs.python.org/3/library/code.html#code.InteractiveConsole.resetbuffer',
                      'code.InteractiveInterpreter': 'https://docs.python.org/3/library/code.html#code.InteractiveInterpreter',
                      'code.InteractiveInterpreter.runcode': 'https://docs.python.org/3/library/code.html#code.InteractiveInterpreter.runcode',
                      'code.InteractiveInterpreter.runsource': 'https://docs.python.org/3/library/code.html#code.InteractiveInterpreter.runsource',
                      'code.InteractiveInterpreter.showsyntaxerror': 'https://docs.python.org/3/library/code.html#code.InteractiveInterpreter.showsyntaxerror',
                      'code.InteractiveInterpreter.showtraceback': 'https://docs.python.org/3/library/code.html#code.InteractiveInterpreter.showtraceback',
                      'code.InteractiveInterpreter.write': 'https://docs.python.org/3/library/code.html#code.InteractiveInterpreter.write',
                      'code.compile_command': 'https://docs.python.org/3/library/code.html#code.compile_command',
                      'code.interact': 'https://docs.python.org/3/library/code.html#code.interact'},
            'codecs': { 'codecs.Codec.decode': 'https://docs.python.org/3/library/codecs.html#codecs.Codec.decode',
                        'codecs.Codec.encode': 'https://docs.python.org/3/library/codecs.html#codecs.Codec.encode',
                        'codecs.CodecInfo': 'https://docs.python.org/3/library/codecs.html#codecs.CodecInfo',
                        'codecs.EncodedFile': 'https://docs.python.org/3/library/codecs.html#codecs.EncodedFile',
                        'codecs.IncrementalDecoder': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalDecoder',
                        'codecs.IncrementalDecoder.decode': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalDecoder.decode',
                        'codecs.IncrementalDecoder.getstate': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalDecoder.getstate',
                        'codecs.IncrementalDecoder.reset': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalDecoder.reset',
                        'codecs.IncrementalDecoder.setstate': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalDecoder.setstate',
                        'codecs.IncrementalEncoder': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalEncoder',
                        'codecs.IncrementalEncoder.encode': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalEncoder.encode',
                        'codecs.IncrementalEncoder.getstate': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalEncoder.getstate',
                        'codecs.IncrementalEncoder.reset': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalEncoder.reset',
                        'codecs.IncrementalEncoder.setstate': 'https://docs.python.org/3/library/codecs.html#codecs.IncrementalEncoder.setstate',
                        'codecs.StreamReader': 'https://docs.python.org/3/library/codecs.html#codecs.StreamReader',
                        'codecs.StreamReader.read': 'https://docs.python.org/3/library/codecs.html#codecs.StreamReader.read',
                        'codecs.StreamReader.readline': 'https://docs.python.org/3/library/codecs.html#codecs.StreamReader.readline',
                        'codecs.StreamReader.readlines': 'https://docs.python.org/3/library/codecs.html#codecs.StreamReader.readlines',
                        'codecs.StreamReader.reset': 'https://docs.python.org/3/library/codecs.html#codecs.StreamReader.reset',
                        'codecs.StreamReaderWriter': 'https://docs.python.org/3/library/codecs.html#codecs.StreamReaderWriter',
                        'codecs.StreamRecoder': 'https://docs.python.org/3/library/codecs.html#codecs.StreamRecoder',
                        'codecs.StreamWriter': 'https://docs.python.org/3/library/codecs.html#codecs.StreamWriter',
                        'codecs.StreamWriter.reset': 'https://docs.python.org/3/library/codecs.html#codecs.StreamWriter.reset',
                        'codecs.StreamWriter.write': 'https://docs.python.org/3/library/codecs.html#codecs.StreamWriter.write',
                        'codecs.StreamWriter.writelines': 'https://docs.python.org/3/library/codecs.html#codecs.StreamWriter.writelines',
                        'codecs.backslashreplace_errors': 'https://docs.python.org/3/library/codecs.html#codecs.backslashreplace_errors',
                        'codecs.decode': 'https://docs.python.org/3/library/codecs.html#codecs.decode',
                        'codecs.encode': 'https://docs.python.org/3/library/codecs.html#codecs.encode',
                        'codecs.getdecoder': 'https://docs.python.org/3/library/codecs.html#codecs.getdecoder',
                        'codecs.getencoder': 'https://docs.python.org/3/library/codecs.html#codecs.getencoder',
                        'codecs.getincrementaldecoder': 'https://docs.python.org/3/library/codecs.html#codecs.getincrementaldecoder',
                        'codecs.getincrementalencoder': 'https://docs.python.org/3/library/codecs.html#codecs.getincrementalencoder',
                        'codecs.getreader': 'https://docs.python.org/3/library/codecs.html#codecs.getreader',
                        'codecs.getwriter': 'https://docs.python.org/3/library/codecs.html#codecs.getwriter',
                        'codecs.ignore_errors': 'https://docs.python.org/3/library/codecs.html#codecs.ignore_errors',
                        'codecs.iterdecode': 'https://docs.python.org/3/library/codecs.html#codecs.iterdecode',
                        'codecs.iterencode': 'https://docs.python.org/3/library/codecs.html#codecs.iterencode',
                        'codecs.lookup': 'https://docs.python.org/3/library/codecs.html#codecs.lookup',
                        'codecs.lookup_error': 'https://docs.python.org/3/library/codecs.html#codecs.lookup_error',
                        'codecs.namereplace_errors': 'https://docs.python.org/3/library/codecs.html#codecs.namereplace_errors',
                        'codecs.open': 'https://docs.python.org/3/library/codecs.html#codecs.open',
                        'codecs.register': 'https://docs.python.org/3/library/codecs.html#codecs.register',
                        'codecs.register_error': 'https://docs.python.org/3/library/codecs.html#codecs.register_error',
                        'codecs.replace_errors': 'https://docs.python.org/3/library/codecs.html#codecs.replace_errors',
                        'codecs.strict_errors': 'https://docs.python.org/3/library/codecs.html#codecs.strict_errors',
                        'codecs.unregister': 'https://docs.python.org/3/library/codecs.html#codecs.unregister',
                        'codecs.xmlcharrefreplace_errors': 'https://docs.python.org/3/library/codecs.html#codecs.xmlcharrefreplace_errors'},
            'codeop': { 'codeop.CommandCompiler': 'https://docs.python.org/3/library/codeop.html#codeop.CommandCompiler',
                        'codeop.Compile': 'https://docs.python.org/3/library/codeop.html#codeop.Compile',
                        'codeop.compile_command': 'https://docs.python.org/3/library/codeop.html#codeop.compile_command'},
            'collections': { 'collections.ChainMap': 'https://docs.python.org/3/library/collections.html#collections.ChainMap',
                             'collections.ChainMap.new_child': 'https://docs.python.org/3/library/collections.html#collections.ChainMap.new_child',
                             'collections.Counter': 'https://docs.python.org/3/library/collections.html#collections.Counter',
                             'collections.Counter.elements': 'https://docs.python.org/3/library/collections.html#collections.Counter.elements',
                             'collections.Counter.fromkeys': 'https://docs.python.org/3/library/collections.html#collections.Counter.fromkeys',
                             'collections.Counter.most_common': 'https://docs.python.org/3/library/collections.html#collections.Counter.most_common',
                             'collections.Counter.subtract': 'https://docs.python.org/3/library/collections.html#collections.Counter.subtract',
                             'collections.Counter.total': 'https://docs.python.org/3/library/collections.html#collections.Counter.total',
                             'collections.Counter.update': 'https://docs.python.org/3/library/collections.html#collections.Counter.update',
                             'collections.OrderedDict': 'https://docs.python.org/3/library/collections.html#collections.OrderedDict',
                             'collections.OrderedDict.move_to_end': 'https://docs.python.org/3/library/collections.html#collections.OrderedDict.move_to_end',
                             'collections.OrderedDict.popitem': 'https://docs.python.org/3/library/collections.html#collections.OrderedDict.popitem',
                             'collections.UserDict': 'https://docs.python.org/3/library/collections.html#collections.UserDict',
                             'collections.UserList': 'https://docs.python.org/3/library/collections.html#collections.UserList',
                             'collections.UserString': 'https://docs.python.org/3/library/collections.html#collections.UserString',
                             'collections.abc': 'https://docs.python.org/3/library/collections.abc.html#module-collections.abc',
                             'collections.defaultdict': 'https://docs.python.org/3/library/collections.html#collections.defaultdict',
                             'collections.defaultdict.__missing__': 'https://docs.python.org/3/library/collections.html#collections.defaultdict.__missing__',
                             'collections.deque': 'https://docs.python.org/3/library/collections.html#collections.deque',
                             'collections.deque.append': 'https://docs.python.org/3/library/collections.html#collections.deque.append',
                             'collections.deque.appendleft': 'https://docs.python.org/3/library/collections.html#collections.deque.appendleft',
                             'collections.deque.clear': 'https://docs.python.org/3/library/collections.html#collections.deque.clear',
                             'collections.deque.copy': 'https://docs.python.org/3/library/collections.html#collections.deque.copy',
                             'collections.deque.count': 'https://docs.python.org/3/library/collections.html#collections.deque.count',
                             'collections.deque.extend': 'https://docs.python.org/3/library/collections.html#collections.deque.extend',
                             'collections.deque.extendleft': 'https://docs.python.org/3/library/collections.html#collections.deque.extendleft',
                             'collections.deque.index': 'https://docs.python.org/3/library/collections.html#collections.deque.index',
                             'collections.deque.insert': 'https://docs.python.org/3/library/collections.html#collections.deque.insert',
                             'collections.deque.pop': 'https://docs.python.org/3/library/collections.html#collections.deque.pop',
                             'collections.deque.popleft': 'https://docs.python.org/3/library/collections.html#collections.deque.popleft',
                             'collections.deque.remove': 'https://docs.python.org/3/library/collections.html#collections.deque.remove',
                             'collections.deque.reverse': 'https://docs.python.org/3/library/collections.html#collections.deque.reverse',
                             'collections.deque.rotate': 'https://docs.python.org/3/library/collections.html#collections.deque.rotate',
                             'collections.namedtuple': 'https://docs.python.org/3/library/collections.html#collections.namedtuple',
                             'collections.somenamedtuple._asdict': 'https://docs.python.org/3/library/collections.html#collections.somenamedtuple._asdict',
                             'collections.somenamedtuple._make': 'https://docs.python.org/3/library/collections.html#collections.somenamedtuple._make',
                             'collections.somenamedtuple._replace': 'https://docs.python.org/3/library/collections.html#collections.somenamedtuple._replace'},
            'collections.abc': { 'collections.abc.AsyncGenerator': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.AsyncGenerator',
                                 'collections.abc.AsyncIterable': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.AsyncIterable',
                                 'collections.abc.AsyncIterator': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.AsyncIterator',
                                 'collections.abc.Awaitable': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Awaitable',
                                 'collections.abc.ByteString': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.ByteString',
                                 'collections.abc.Callable': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Callable',
                                 'collections.abc.Collection': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Collection',
                                 'collections.abc.Container': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Container',
                                 'collections.abc.Coroutine': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Coroutine',
                                 'collections.abc.Generator': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Generator',
                                 'collections.abc.Hashable': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Hashable',
                                 'collections.abc.ItemsView': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.ItemsView',
                                 'collections.abc.Iterable': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Iterable',
                                 'collections.abc.Iterator': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Iterator',
                                 'collections.abc.KeysView': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.KeysView',
                                 'collections.abc.Mapping': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Mapping',
                                 'collections.abc.MappingView': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.MappingView',
                                 'collections.abc.MutableMapping': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.MutableMapping',
                                 'collections.abc.MutableSequence': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.MutableSequence',
                                 'collections.abc.MutableSet': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.MutableSet',
                                 'collections.abc.Reversible': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Reversible',
                                 'collections.abc.Sequence': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Sequence',
                                 'collections.abc.Set': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Set',
                                 'collections.abc.Sized': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.Sized',
                                 'collections.abc.ValuesView': 'https://docs.python.org/3/library/collections.abc.html#collections.abc.ValuesView'},
            'colorsys': { 'colorsys.hls_to_rgb': 'https://docs.python.org/3/library/colorsys.html#colorsys.hls_to_rgb',
                          'colorsys.hsv_to_rgb': 'https://docs.python.org/3/library/colorsys.html#colorsys.hsv_to_rgb',
                          'colorsys.rgb_to_hls': 'https://docs.python.org/3/library/colorsys.html#colorsys.rgb_to_hls',
                          'colorsys.rgb_to_hsv': 'https://docs.python.org/3/library/colorsys.html#colorsys.rgb_to_hsv',
                          'colorsys.rgb_to_yiq': 'https://docs.python.org/3/library/colorsys.html#colorsys.rgb_to_yiq',
                          'colorsys.yiq_to_rgb': 'https://docs.python.org/3/library/colorsys.html#colorsys.yiq_to_rgb'},
            'compileall': { 'compileall.compile_dir': 'https://docs.python.org/3/library/compileall.html#compileall.compile_dir',
                            'compileall.compile_file': 'https://docs.python.org/3/library/compileall.html#compileall.compile_file',
                            'compileall.compile_path': 'https://docs.python.org/3/library/compileall.html#compileall.compile_path'},
            'concurrent': {'concurrent.futures': 'https://docs.python.org/3/library/concurrent.futures.html#module-concurrent.futures'},
            'concurrent.futures': { 'concurrent.futures.Executor': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Executor',
                                    'concurrent.futures.Executor.map': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Executor.map',
                                    'concurrent.futures.Executor.shutdown': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Executor.shutdown',
                                    'concurrent.futures.Executor.submit': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Executor.submit',
                                    'concurrent.futures.Future': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future',
                                    'concurrent.futures.Future.add_done_callback': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.add_done_callback',
                                    'concurrent.futures.Future.cancel': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.cancel',
                                    'concurrent.futures.Future.cancelled': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.cancelled',
                                    'concurrent.futures.Future.done': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.done',
                                    'concurrent.futures.Future.exception': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.exception',
                                    'concurrent.futures.Future.result': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.result',
                                    'concurrent.futures.Future.running': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.running',
                                    'concurrent.futures.Future.set_exception': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.set_exception',
                                    'concurrent.futures.Future.set_result': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.set_result',
                                    'concurrent.futures.Future.set_running_or_notify_cancel': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.Future.set_running_or_notify_cancel',
                                    'concurrent.futures.ProcessPoolExecutor': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.ProcessPoolExecutor',
                                    'concurrent.futures.ThreadPoolExecutor': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.ThreadPoolExecutor',
                                    'concurrent.futures.as_completed': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.as_completed',
                                    'concurrent.futures.wait': 'https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.wait'},
            'configparser': { 'configparser.BasicInterpolation': 'https://docs.python.org/3/library/configparser.html#configparser.BasicInterpolation',
                              'configparser.ConfigParser': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser',
                              'configparser.ConfigParser.add_section': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.add_section',
                              'configparser.ConfigParser.defaults': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.defaults',
                              'configparser.ConfigParser.get': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.get',
                              'configparser.ConfigParser.getboolean': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.getboolean',
                              'configparser.ConfigParser.getfloat': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.getfloat',
                              'configparser.ConfigParser.getint': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.getint',
                              'configparser.ConfigParser.has_option': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.has_option',
                              'configparser.ConfigParser.has_section': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.has_section',
                              'configparser.ConfigParser.items': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.items',
                              'configparser.ConfigParser.options': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.options',
                              'configparser.ConfigParser.optionxform': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.optionxform',
                              'configparser.ConfigParser.read': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.read',
                              'configparser.ConfigParser.read_dict': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.read_dict',
                              'configparser.ConfigParser.read_file': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.read_file',
                              'configparser.ConfigParser.read_string': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.read_string',
                              'configparser.ConfigParser.readfp': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.readfp',
                              'configparser.ConfigParser.remove_option': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.remove_option',
                              'configparser.ConfigParser.remove_section': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.remove_section',
                              'configparser.ConfigParser.sections': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.sections',
                              'configparser.ConfigParser.set': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.set',
                              'configparser.ConfigParser.write': 'https://docs.python.org/3/library/configparser.html#configparser.ConfigParser.write',
                              'configparser.ExtendedInterpolation': 'https://docs.python.org/3/library/configparser.html#configparser.ExtendedInterpolation',
                              'configparser.RawConfigParser': 'https://docs.python.org/3/library/configparser.html#configparser.RawConfigParser',
                              'configparser.RawConfigParser.add_section': 'https://docs.python.org/3/library/configparser.html#configparser.RawConfigParser.add_section',
                              'configparser.RawConfigParser.set': 'https://docs.python.org/3/library/configparser.html#configparser.RawConfigParser.set'},
            'contextlib': { 'contextlib.AbstractAsyncContextManager': 'https://docs.python.org/3/library/contextlib.html#contextlib.AbstractAsyncContextManager',
                            'contextlib.AbstractContextManager': 'https://docs.python.org/3/library/contextlib.html#contextlib.AbstractContextManager',
                            'contextlib.AsyncContextDecorator': 'https://docs.python.org/3/library/contextlib.html#contextlib.AsyncContextDecorator',
                            'contextlib.AsyncExitStack': 'https://docs.python.org/3/library/contextlib.html#contextlib.AsyncExitStack',
                            'contextlib.AsyncExitStack.aclose': 'https://docs.python.org/3/library/contextlib.html#contextlib.AsyncExitStack.aclose',
                            'contextlib.AsyncExitStack.enter_async_context': 'https://docs.python.org/3/library/contextlib.html#contextlib.AsyncExitStack.enter_async_context',
                            'contextlib.AsyncExitStack.push_async_callback': 'https://docs.python.org/3/library/contextlib.html#contextlib.AsyncExitStack.push_async_callback',
                            'contextlib.AsyncExitStack.push_async_exit': 'https://docs.python.org/3/library/contextlib.html#contextlib.AsyncExitStack.push_async_exit',
                            'contextlib.ContextDecorator': 'https://docs.python.org/3/library/contextlib.html#contextlib.ContextDecorator',
                            'contextlib.ExitStack': 'https://docs.python.org/3/library/contextlib.html#contextlib.ExitStack',
                            'contextlib.ExitStack.callback': 'https://docs.python.org/3/library/contextlib.html#contextlib.ExitStack.callback',
                            'contextlib.ExitStack.close': 'https://docs.python.org/3/library/contextlib.html#contextlib.ExitStack.close',
                            'contextlib.ExitStack.enter_context': 'https://docs.python.org/3/library/contextlib.html#contextlib.ExitStack.enter_context',
                            'contextlib.ExitStack.pop_all': 'https://docs.python.org/3/library/contextlib.html#contextlib.ExitStack.pop_all',
                            'contextlib.ExitStack.push': 'https://docs.python.org/3/library/contextlib.html#contextlib.ExitStack.push',
                            'contextlib.aclosing': 'https://docs.python.org/3/library/contextlib.html#contextlib.aclosing',
                            'contextlib.asynccontextmanager': 'https://docs.python.org/3/library/contextlib.html#contextlib.asynccontextmanager',
                            'contextlib.closing': 'https://docs.python.org/3/library/contextlib.html#contextlib.closing',
                            'contextlib.contextmanager': 'https://docs.python.org/3/library/contextlib.html#contextlib.contextmanager',
                            'contextlib.nullcontext': 'https://docs.python.org/3/library/contextlib.html#contextlib.nullcontext',
                            'contextlib.redirect_stderr': 'https://docs.python.org/3/library/contextlib.html#contextlib.redirect_stderr',
                            'contextlib.redirect_stdout': 'https://docs.python.org/3/library/contextlib.html#contextlib.redirect_stdout',
                            'contextlib.suppress': 'https://docs.python.org/3/library/contextlib.html#contextlib.suppress'},
            'contextvars': { 'contextvars.Context': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context',
                             'contextvars.Context.copy': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context.copy',
                             'contextvars.Context.get': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context.get',
                             'contextvars.Context.items': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context.items',
                             'contextvars.Context.keys': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context.keys',
                             'contextvars.Context.run': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context.run',
                             'contextvars.Context.values': 'https://docs.python.org/3/library/contextvars.html#contextvars.Context.values',
                             'contextvars.ContextVar': 'https://docs.python.org/3/library/contextvars.html#contextvars.ContextVar',
                             'contextvars.ContextVar.get': 'https://docs.python.org/3/library/contextvars.html#contextvars.ContextVar.get',
                             'contextvars.ContextVar.reset': 'https://docs.python.org/3/library/contextvars.html#contextvars.ContextVar.reset',
                             'contextvars.ContextVar.set': 'https://docs.python.org/3/library/contextvars.html#contextvars.ContextVar.set',
                             'contextvars.Token': 'https://docs.python.org/3/library/contextvars.html#contextvars.Token',
                             'contextvars.copy_context': 'https://docs.python.org/3/library/contextvars.html#contextvars.copy_context'},
            'copy': { 'copy.copy': 'https://docs.python.org/3/library/copy.html#copy.copy',
                      'copy.deepcopy': 'https://docs.python.org/3/library/copy.html#copy.deepcopy'},
            'copyreg': { 'copyreg.constructor': 'https://docs.python.org/3/library/copyreg.html#copyreg.constructor',
                         'copyreg.pickle': 'https://docs.python.org/3/library/copyreg.html#copyreg.pickle'},
            'crypt': { 'crypt.crypt': 'https://docs.python.org/3/library/crypt.html#crypt.crypt',
                       'crypt.mksalt': 'https://docs.python.org/3/library/crypt.html#crypt.mksalt'},
            'csv': { 'csv.Dialect': 'https://docs.python.org/3/library/csv.html#csv.Dialect',
                     'csv.DictReader': 'https://docs.python.org/3/library/csv.html#csv.DictReader',
                     'csv.DictWriter': 'https://docs.python.org/3/library/csv.html#csv.DictWriter',
                     'csv.DictWriter.writeheader': 'https://docs.python.org/3/library/csv.html#csv.DictWriter.writeheader',
                     'csv.Sniffer': 'https://docs.python.org/3/library/csv.html#csv.Sniffer',
                     'csv.Sniffer.has_header': 'https://docs.python.org/3/library/csv.html#csv.Sniffer.has_header',
                     'csv.Sniffer.sniff': 'https://docs.python.org/3/library/csv.html#csv.Sniffer.sniff',
                     'csv.csvreader.__next__': 'https://docs.python.org/3/library/csv.html#csv.csvreader.__next__',
                     'csv.csvwriter.writerow': 'https://docs.python.org/3/library/csv.html#csv.csvwriter.writerow',
                     'csv.csvwriter.writerows': 'https://docs.python.org/3/library/csv.html#csv.csvwriter.writerows',
                     'csv.excel': 'https://docs.python.org/3/library/csv.html#csv.excel',
                     'csv.excel_tab': 'https://docs.python.org/3/library/csv.html#csv.excel_tab',
                     'csv.field_size_limit': 'https://docs.python.org/3/library/csv.html#csv.field_size_limit',
                     'csv.get_dialect': 'https://docs.python.org/3/library/csv.html#csv.get_dialect',
                     'csv.list_dialects': 'https://docs.python.org/3/library/csv.html#csv.list_dialects',
                     'csv.reader': 'https://docs.python.org/3/library/csv.html#csv.reader',
                     'csv.register_dialect': 'https://docs.python.org/3/library/csv.html#csv.register_dialect',
                     'csv.unix_dialect': 'https://docs.python.org/3/library/csv.html#csv.unix_dialect',
                     'csv.unregister_dialect': 'https://docs.python.org/3/library/csv.html#csv.unregister_dialect',
                     'csv.writer': 'https://docs.python.org/3/library/csv.html#csv.writer'},
            'ctypes': { 'ctypes.Array': 'https://docs.python.org/3/library/ctypes.html#ctypes.Array',
                        'ctypes.BigEndianStructure': 'https://docs.python.org/3/library/ctypes.html#ctypes.BigEndianStructure',
                        'ctypes.CDLL': 'https://docs.python.org/3/library/ctypes.html#ctypes.CDLL',
                        'ctypes.CFUNCTYPE': 'https://docs.python.org/3/library/ctypes.html#ctypes.CFUNCTYPE',
                        'ctypes.DllCanUnloadNow': 'https://docs.python.org/3/library/ctypes.html#ctypes.DllCanUnloadNow',
                        'ctypes.DllGetClassObject': 'https://docs.python.org/3/library/ctypes.html#ctypes.DllGetClassObject',
                        'ctypes.FormatError': 'https://docs.python.org/3/library/ctypes.html#ctypes.FormatError',
                        'ctypes.GetLastError': 'https://docs.python.org/3/library/ctypes.html#ctypes.GetLastError',
                        'ctypes.HRESULT': 'https://docs.python.org/3/library/ctypes.html#ctypes.HRESULT',
                        'ctypes.LibraryLoader': 'https://docs.python.org/3/library/ctypes.html#ctypes.LibraryLoader',
                        'ctypes.LibraryLoader.LoadLibrary': 'https://docs.python.org/3/library/ctypes.html#ctypes.LibraryLoader.LoadLibrary',
                        'ctypes.LittleEndianStructure': 'https://docs.python.org/3/library/ctypes.html#ctypes.LittleEndianStructure',
                        'ctypes.OleDLL': 'https://docs.python.org/3/library/ctypes.html#ctypes.OleDLL',
                        'ctypes.POINTER': 'https://docs.python.org/3/library/ctypes.html#ctypes.POINTER',
                        'ctypes.PYFUNCTYPE': 'https://docs.python.org/3/library/ctypes.html#ctypes.PYFUNCTYPE',
                        'ctypes.PyDLL': 'https://docs.python.org/3/library/ctypes.html#ctypes.PyDLL',
                        'ctypes.Structure': 'https://docs.python.org/3/library/ctypes.html#ctypes.Structure',
                        'ctypes.Union': 'https://docs.python.org/3/library/ctypes.html#ctypes.Union',
                        'ctypes.WINFUNCTYPE': 'https://docs.python.org/3/library/ctypes.html#ctypes.WINFUNCTYPE',
                        'ctypes.WinDLL': 'https://docs.python.org/3/library/ctypes.html#ctypes.WinDLL',
                        'ctypes.WinError': 'https://docs.python.org/3/library/ctypes.html#ctypes.WinError',
                        'ctypes._CData': 'https://docs.python.org/3/library/ctypes.html#ctypes._CData',
                        'ctypes._CData.from_address': 'https://docs.python.org/3/library/ctypes.html#ctypes._CData.from_address',
                        'ctypes._CData.from_buffer': 'https://docs.python.org/3/library/ctypes.html#ctypes._CData.from_buffer',
                        'ctypes._CData.from_buffer_copy': 'https://docs.python.org/3/library/ctypes.html#ctypes._CData.from_buffer_copy',
                        'ctypes._CData.from_param': 'https://docs.python.org/3/library/ctypes.html#ctypes._CData.from_param',
                        'ctypes._CData.in_dll': 'https://docs.python.org/3/library/ctypes.html#ctypes._CData.in_dll',
                        'ctypes._FuncPtr': 'https://docs.python.org/3/library/ctypes.html#ctypes._FuncPtr',
                        'ctypes._Pointer': 'https://docs.python.org/3/library/ctypes.html#ctypes._Pointer',
                        'ctypes._SimpleCData': 'https://docs.python.org/3/library/ctypes.html#ctypes._SimpleCData',
                        'ctypes.addressof': 'https://docs.python.org/3/library/ctypes.html#ctypes.addressof',
                        'ctypes.alignment': 'https://docs.python.org/3/library/ctypes.html#ctypes.alignment',
                        'ctypes.byref': 'https://docs.python.org/3/library/ctypes.html#ctypes.byref',
                        'ctypes.c_bool': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_bool',
                        'ctypes.c_byte': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_byte',
                        'ctypes.c_char': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_char',
                        'ctypes.c_char_p': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_char_p',
                        'ctypes.c_double': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_double',
                        'ctypes.c_float': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_float',
                        'ctypes.c_int': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_int',
                        'ctypes.c_int16': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_int16',
                        'ctypes.c_int32': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_int32',
                        'ctypes.c_int64': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_int64',
                        'ctypes.c_int8': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_int8',
                        'ctypes.c_long': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_long',
                        'ctypes.c_longdouble': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_longdouble',
                        'ctypes.c_longlong': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_longlong',
                        'ctypes.c_short': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_short',
                        'ctypes.c_size_t': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_size_t',
                        'ctypes.c_ssize_t': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_ssize_t',
                        'ctypes.c_ubyte': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_ubyte',
                        'ctypes.c_uint': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_uint',
                        'ctypes.c_uint16': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_uint16',
                        'ctypes.c_uint32': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_uint32',
                        'ctypes.c_uint64': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_uint64',
                        'ctypes.c_uint8': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_uint8',
                        'ctypes.c_ulong': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_ulong',
                        'ctypes.c_ulonglong': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_ulonglong',
                        'ctypes.c_ushort': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_ushort',
                        'ctypes.c_void_p': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_void_p',
                        'ctypes.c_wchar': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_wchar',
                        'ctypes.c_wchar_p': 'https://docs.python.org/3/library/ctypes.html#ctypes.c_wchar_p',
                        'ctypes.cast': 'https://docs.python.org/3/library/ctypes.html#ctypes.cast',
                        'ctypes.create_string_buffer': 'https://docs.python.org/3/library/ctypes.html#ctypes.create_string_buffer',
                        'ctypes.create_unicode_buffer': 'https://docs.python.org/3/library/ctypes.html#ctypes.create_unicode_buffer',
                        'ctypes.get_errno': 'https://docs.python.org/3/library/ctypes.html#ctypes.get_errno',
                        'ctypes.get_last_error': 'https://docs.python.org/3/library/ctypes.html#ctypes.get_last_error',
                        'ctypes.memmove': 'https://docs.python.org/3/library/ctypes.html#ctypes.memmove',
                        'ctypes.memset': 'https://docs.python.org/3/library/ctypes.html#ctypes.memset',
                        'ctypes.pointer': 'https://docs.python.org/3/library/ctypes.html#ctypes.pointer',
                        'ctypes.py_object': 'https://docs.python.org/3/library/ctypes.html#ctypes.py_object',
                        'ctypes.resize': 'https://docs.python.org/3/library/ctypes.html#ctypes.resize',
                        'ctypes.set_errno': 'https://docs.python.org/3/library/ctypes.html#ctypes.set_errno',
                        'ctypes.set_last_error': 'https://docs.python.org/3/library/ctypes.html#ctypes.set_last_error',
                        'ctypes.sizeof': 'https://docs.python.org/3/library/ctypes.html#ctypes.sizeof',
                        'ctypes.string_at': 'https://docs.python.org/3/library/ctypes.html#ctypes.string_at',
                        'ctypes.wstring_at': 'https://docs.python.org/3/library/ctypes.html#ctypes.wstring_at'},
            'ctypes.util': { 'ctypes.util.find_library': 'https://docs.python.org/3/library/ctypes.html#ctypes.util.find_library',
                             'ctypes.util.find_msvcrt': 'https://docs.python.org/3/library/ctypes.html#ctypes.util.find_msvcrt'},
            'curses': { 'curses.ascii': 'https://docs.python.org/3/library/curses.ascii.html#module-curses.ascii',
                        'curses.baudrate': 'https://docs.python.org/3/library/curses.html#curses.baudrate',
                        'curses.beep': 'https://docs.python.org/3/library/curses.html#curses.beep',
                        'curses.can_change_color': 'https://docs.python.org/3/library/curses.html#curses.can_change_color',
                        'curses.cbreak': 'https://docs.python.org/3/library/curses.html#curses.cbreak',
                        'curses.color_content': 'https://docs.python.org/3/library/curses.html#curses.color_content',
                        'curses.color_pair': 'https://docs.python.org/3/library/curses.html#curses.color_pair',
                        'curses.curs_set': 'https://docs.python.org/3/library/curses.html#curses.curs_set',
                        'curses.def_prog_mode': 'https://docs.python.org/3/library/curses.html#curses.def_prog_mode',
                        'curses.def_shell_mode': 'https://docs.python.org/3/library/curses.html#curses.def_shell_mode',
                        'curses.delay_output': 'https://docs.python.org/3/library/curses.html#curses.delay_output',
                        'curses.doupdate': 'https://docs.python.org/3/library/curses.html#curses.doupdate',
                        'curses.echo': 'https://docs.python.org/3/library/curses.html#curses.echo',
                        'curses.endwin': 'https://docs.python.org/3/library/curses.html#curses.endwin',
                        'curses.erasechar': 'https://docs.python.org/3/library/curses.html#curses.erasechar',
                        'curses.filter': 'https://docs.python.org/3/library/curses.html#curses.filter',
                        'curses.flash': 'https://docs.python.org/3/library/curses.html#curses.flash',
                        'curses.flushinp': 'https://docs.python.org/3/library/curses.html#curses.flushinp',
                        'curses.get_escdelay': 'https://docs.python.org/3/library/curses.html#curses.get_escdelay',
                        'curses.get_tabsize': 'https://docs.python.org/3/library/curses.html#curses.get_tabsize',
                        'curses.getmouse': 'https://docs.python.org/3/library/curses.html#curses.getmouse',
                        'curses.getsyx': 'https://docs.python.org/3/library/curses.html#curses.getsyx',
                        'curses.getwin': 'https://docs.python.org/3/library/curses.html#curses.getwin',
                        'curses.halfdelay': 'https://docs.python.org/3/library/curses.html#curses.halfdelay',
                        'curses.has_colors': 'https://docs.python.org/3/library/curses.html#curses.has_colors',
                        'curses.has_extended_color_support': 'https://docs.python.org/3/library/curses.html#curses.has_extended_color_support',
                        'curses.has_ic': 'https://docs.python.org/3/library/curses.html#curses.has_ic',
                        'curses.has_il': 'https://docs.python.org/3/library/curses.html#curses.has_il',
                        'curses.has_key': 'https://docs.python.org/3/library/curses.html#curses.has_key',
                        'curses.init_color': 'https://docs.python.org/3/library/curses.html#curses.init_color',
                        'curses.init_pair': 'https://docs.python.org/3/library/curses.html#curses.init_pair',
                        'curses.initscr': 'https://docs.python.org/3/library/curses.html#curses.initscr',
                        'curses.is_term_resized': 'https://docs.python.org/3/library/curses.html#curses.is_term_resized',
                        'curses.isendwin': 'https://docs.python.org/3/library/curses.html#curses.isendwin',
                        'curses.keyname': 'https://docs.python.org/3/library/curses.html#curses.keyname',
                        'curses.killchar': 'https://docs.python.org/3/library/curses.html#curses.killchar',
                        'curses.longname': 'https://docs.python.org/3/library/curses.html#curses.longname',
                        'curses.meta': 'https://docs.python.org/3/library/curses.html#curses.meta',
                        'curses.mouseinterval': 'https://docs.python.org/3/library/curses.html#curses.mouseinterval',
                        'curses.mousemask': 'https://docs.python.org/3/library/curses.html#curses.mousemask',
                        'curses.napms': 'https://docs.python.org/3/library/curses.html#curses.napms',
                        'curses.newpad': 'https://docs.python.org/3/library/curses.html#curses.newpad',
                        'curses.newwin': 'https://docs.python.org/3/library/curses.html#curses.newwin',
                        'curses.nl': 'https://docs.python.org/3/library/curses.html#curses.nl',
                        'curses.nocbreak': 'https://docs.python.org/3/library/curses.html#curses.nocbreak',
                        'curses.noecho': 'https://docs.python.org/3/library/curses.html#curses.noecho',
                        'curses.nonl': 'https://docs.python.org/3/library/curses.html#curses.nonl',
                        'curses.noqiflush': 'https://docs.python.org/3/library/curses.html#curses.noqiflush',
                        'curses.noraw': 'https://docs.python.org/3/library/curses.html#curses.noraw',
                        'curses.pair_content': 'https://docs.python.org/3/library/curses.html#curses.pair_content',
                        'curses.pair_number': 'https://docs.python.org/3/library/curses.html#curses.pair_number',
                        'curses.panel': 'https://docs.python.org/3/library/curses.panel.html#module-curses.panel',
                        'curses.putp': 'https://docs.python.org/3/library/curses.html#curses.putp',
                        'curses.qiflush': 'https://docs.python.org/3/library/curses.html#curses.qiflush',
                        'curses.raw': 'https://docs.python.org/3/library/curses.html#curses.raw',
                        'curses.reset_prog_mode': 'https://docs.python.org/3/library/curses.html#curses.reset_prog_mode',
                        'curses.reset_shell_mode': 'https://docs.python.org/3/library/curses.html#curses.reset_shell_mode',
                        'curses.resetty': 'https://docs.python.org/3/library/curses.html#curses.resetty',
                        'curses.resize_term': 'https://docs.python.org/3/library/curses.html#curses.resize_term',
                        'curses.resizeterm': 'https://docs.python.org/3/library/curses.html#curses.resizeterm',
                        'curses.savetty': 'https://docs.python.org/3/library/curses.html#curses.savetty',
                        'curses.set_escdelay': 'https://docs.python.org/3/library/curses.html#curses.set_escdelay',
                        'curses.set_tabsize': 'https://docs.python.org/3/library/curses.html#curses.set_tabsize',
                        'curses.setsyx': 'https://docs.python.org/3/library/curses.html#curses.setsyx',
                        'curses.setupterm': 'https://docs.python.org/3/library/curses.html#curses.setupterm',
                        'curses.start_color': 'https://docs.python.org/3/library/curses.html#curses.start_color',
                        'curses.termattrs': 'https://docs.python.org/3/library/curses.html#curses.termattrs',
                        'curses.termname': 'https://docs.python.org/3/library/curses.html#curses.termname',
                        'curses.textpad': 'https://docs.python.org/3/library/curses.html#module-curses.textpad',
                        'curses.tigetflag': 'https://docs.python.org/3/library/curses.html#curses.tigetflag',
                        'curses.tigetnum': 'https://docs.python.org/3/library/curses.html#curses.tigetnum',
                        'curses.tigetstr': 'https://docs.python.org/3/library/curses.html#curses.tigetstr',
                        'curses.tparm': 'https://docs.python.org/3/library/curses.html#curses.tparm',
                        'curses.typeahead': 'https://docs.python.org/3/library/curses.html#curses.typeahead',
                        'curses.unctrl': 'https://docs.python.org/3/library/curses.html#curses.unctrl',
                        'curses.unget_wch': 'https://docs.python.org/3/library/curses.html#curses.unget_wch',
                        'curses.ungetch': 'https://docs.python.org/3/library/curses.html#curses.ungetch',
                        'curses.ungetmouse': 'https://docs.python.org/3/library/curses.html#curses.ungetmouse',
                        'curses.update_lines_cols': 'https://docs.python.org/3/library/curses.html#curses.update_lines_cols',
                        'curses.use_default_colors': 'https://docs.python.org/3/library/curses.html#curses.use_default_colors',
                        'curses.use_env': 'https://docs.python.org/3/library/curses.html#curses.use_env',
                        'curses.window.addch': 'https://docs.python.org/3/library/curses.html#curses.window.addch',
                        'curses.window.addnstr': 'https://docs.python.org/3/library/curses.html#curses.window.addnstr',
                        'curses.window.addstr': 'https://docs.python.org/3/library/curses.html#curses.window.addstr',
                        'curses.window.attroff': 'https://docs.python.org/3/library/curses.html#curses.window.attroff',
                        'curses.window.attron': 'https://docs.python.org/3/library/curses.html#curses.window.attron',
                        'curses.window.attrset': 'https://docs.python.org/3/library/curses.html#curses.window.attrset',
                        'curses.window.bkgd': 'https://docs.python.org/3/library/curses.html#curses.window.bkgd',
                        'curses.window.bkgdset': 'https://docs.python.org/3/library/curses.html#curses.window.bkgdset',
                        'curses.window.border': 'https://docs.python.org/3/library/curses.html#curses.window.border',
                        'curses.window.box': 'https://docs.python.org/3/library/curses.html#curses.window.box',
                        'curses.window.chgat': 'https://docs.python.org/3/library/curses.html#curses.window.chgat',
                        'curses.window.clear': 'https://docs.python.org/3/library/curses.html#curses.window.clear',
                        'curses.window.clearok': 'https://docs.python.org/3/library/curses.html#curses.window.clearok',
                        'curses.window.clrtobot': 'https://docs.python.org/3/library/curses.html#curses.window.clrtobot',
                        'curses.window.clrtoeol': 'https://docs.python.org/3/library/curses.html#curses.window.clrtoeol',
                        'curses.window.cursyncup': 'https://docs.python.org/3/library/curses.html#curses.window.cursyncup',
                        'curses.window.delch': 'https://docs.python.org/3/library/curses.html#curses.window.delch',
                        'curses.window.deleteln': 'https://docs.python.org/3/library/curses.html#curses.window.deleteln',
                        'curses.window.derwin': 'https://docs.python.org/3/library/curses.html#curses.window.derwin',
                        'curses.window.echochar': 'https://docs.python.org/3/library/curses.html#curses.window.echochar',
                        'curses.window.enclose': 'https://docs.python.org/3/library/curses.html#curses.window.enclose',
                        'curses.window.erase': 'https://docs.python.org/3/library/curses.html#curses.window.erase',
                        'curses.window.get_wch': 'https://docs.python.org/3/library/curses.html#curses.window.get_wch',
                        'curses.window.getbegyx': 'https://docs.python.org/3/library/curses.html#curses.window.getbegyx',
                        'curses.window.getbkgd': 'https://docs.python.org/3/library/curses.html#curses.window.getbkgd',
                        'curses.window.getch': 'https://docs.python.org/3/library/curses.html#curses.window.getch',
                        'curses.window.getkey': 'https://docs.python.org/3/library/curses.html#curses.window.getkey',
                        'curses.window.getmaxyx': 'https://docs.python.org/3/library/curses.html#curses.window.getmaxyx',
                        'curses.window.getparyx': 'https://docs.python.org/3/library/curses.html#curses.window.getparyx',
                        'curses.window.getstr': 'https://docs.python.org/3/library/curses.html#curses.window.getstr',
                        'curses.window.getyx': 'https://docs.python.org/3/library/curses.html#curses.window.getyx',
                        'curses.window.hline': 'https://docs.python.org/3/library/curses.html#curses.window.hline',
                        'curses.window.idcok': 'https://docs.python.org/3/library/curses.html#curses.window.idcok',
                        'curses.window.idlok': 'https://docs.python.org/3/library/curses.html#curses.window.idlok',
                        'curses.window.immedok': 'https://docs.python.org/3/library/curses.html#curses.window.immedok',
                        'curses.window.inch': 'https://docs.python.org/3/library/curses.html#curses.window.inch',
                        'curses.window.insch': 'https://docs.python.org/3/library/curses.html#curses.window.insch',
                        'curses.window.insdelln': 'https://docs.python.org/3/library/curses.html#curses.window.insdelln',
                        'curses.window.insertln': 'https://docs.python.org/3/library/curses.html#curses.window.insertln',
                        'curses.window.insnstr': 'https://docs.python.org/3/library/curses.html#curses.window.insnstr',
                        'curses.window.insstr': 'https://docs.python.org/3/library/curses.html#curses.window.insstr',
                        'curses.window.instr': 'https://docs.python.org/3/library/curses.html#curses.window.instr',
                        'curses.window.is_linetouched': 'https://docs.python.org/3/library/curses.html#curses.window.is_linetouched',
                        'curses.window.is_wintouched': 'https://docs.python.org/3/library/curses.html#curses.window.is_wintouched',
                        'curses.window.keypad': 'https://docs.python.org/3/library/curses.html#curses.window.keypad',
                        'curses.window.leaveok': 'https://docs.python.org/3/library/curses.html#curses.window.leaveok',
                        'curses.window.move': 'https://docs.python.org/3/library/curses.html#curses.window.move',
                        'curses.window.mvderwin': 'https://docs.python.org/3/library/curses.html#curses.window.mvderwin',
                        'curses.window.mvwin': 'https://docs.python.org/3/library/curses.html#curses.window.mvwin',
                        'curses.window.nodelay': 'https://docs.python.org/3/library/curses.html#curses.window.nodelay',
                        'curses.window.notimeout': 'https://docs.python.org/3/library/curses.html#curses.window.notimeout',
                        'curses.window.noutrefresh': 'https://docs.python.org/3/library/curses.html#curses.window.noutrefresh',
                        'curses.window.overlay': 'https://docs.python.org/3/library/curses.html#curses.window.overlay',
                        'curses.window.overwrite': 'https://docs.python.org/3/library/curses.html#curses.window.overwrite',
                        'curses.window.putwin': 'https://docs.python.org/3/library/curses.html#curses.window.putwin',
                        'curses.window.redrawln': 'https://docs.python.org/3/library/curses.html#curses.window.redrawln',
                        'curses.window.redrawwin': 'https://docs.python.org/3/library/curses.html#curses.window.redrawwin',
                        'curses.window.refresh': 'https://docs.python.org/3/library/curses.html#curses.window.refresh',
                        'curses.window.resize': 'https://docs.python.org/3/library/curses.html#curses.window.resize',
                        'curses.window.scroll': 'https://docs.python.org/3/library/curses.html#curses.window.scroll',
                        'curses.window.scrollok': 'https://docs.python.org/3/library/curses.html#curses.window.scrollok',
                        'curses.window.setscrreg': 'https://docs.python.org/3/library/curses.html#curses.window.setscrreg',
                        'curses.window.standend': 'https://docs.python.org/3/library/curses.html#curses.window.standend',
                        'curses.window.standout': 'https://docs.python.org/3/library/curses.html#curses.window.standout',
                        'curses.window.subpad': 'https://docs.python.org/3/library/curses.html#curses.window.subpad',
                        'curses.window.subwin': 'https://docs.python.org/3/library/curses.html#curses.window.subwin',
                        'curses.window.syncdown': 'https://docs.python.org/3/library/curses.html#curses.window.syncdown',
                        'curses.window.syncok': 'https://docs.python.org/3/library/curses.html#curses.window.syncok',
                        'curses.window.syncup': 'https://docs.python.org/3/library/curses.html#curses.window.syncup',
                        'curses.window.timeout': 'https://docs.python.org/3/library/curses.html#curses.window.timeout',
                        'curses.window.touchline': 'https://docs.python.org/3/library/curses.html#curses.window.touchline',
                        'curses.window.touchwin': 'https://docs.python.org/3/library/curses.html#curses.window.touchwin',
                        'curses.window.untouchwin': 'https://docs.python.org/3/library/curses.html#curses.window.untouchwin',
                        'curses.window.vline': 'https://docs.python.org/3/library/curses.html#curses.window.vline',
                        'curses.wrapper': 'https://docs.python.org/3/library/curses.html#curses.wrapper'},
            'curses.ascii': { 'curses.ascii.alt': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.alt',
                              'curses.ascii.ascii': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.ascii',
                              'curses.ascii.ctrl': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.ctrl',
                              'curses.ascii.isalnum': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isalnum',
                              'curses.ascii.isalpha': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isalpha',
                              'curses.ascii.isascii': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isascii',
                              'curses.ascii.isblank': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isblank',
                              'curses.ascii.iscntrl': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.iscntrl',
                              'curses.ascii.isctrl': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isctrl',
                              'curses.ascii.isdigit': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isdigit',
                              'curses.ascii.isgraph': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isgraph',
                              'curses.ascii.islower': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.islower',
                              'curses.ascii.ismeta': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.ismeta',
                              'curses.ascii.isprint': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isprint',
                              'curses.ascii.ispunct': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.ispunct',
                              'curses.ascii.isspace': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isspace',
                              'curses.ascii.isupper': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isupper',
                              'curses.ascii.isxdigit': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.isxdigit',
                              'curses.ascii.unctrl': 'https://docs.python.org/3/library/curses.ascii.html#curses.ascii.unctrl'},
            'curses.panel': { 'curses.panel.Panel.above': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.above',
                              'curses.panel.Panel.below': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.below',
                              'curses.panel.Panel.bottom': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.bottom',
                              'curses.panel.Panel.hidden': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.hidden',
                              'curses.panel.Panel.hide': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.hide',
                              'curses.panel.Panel.move': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.move',
                              'curses.panel.Panel.replace': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.replace',
                              'curses.panel.Panel.set_userptr': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.set_userptr',
                              'curses.panel.Panel.show': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.show',
                              'curses.panel.Panel.top': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.top',
                              'curses.panel.Panel.userptr': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.userptr',
                              'curses.panel.Panel.window': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.Panel.window',
                              'curses.panel.bottom_panel': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.bottom_panel',
                              'curses.panel.new_panel': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.new_panel',
                              'curses.panel.top_panel': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.top_panel',
                              'curses.panel.update_panels': 'https://docs.python.org/3/library/curses.panel.html#curses.panel.update_panels'},
            'curses.textpad': { 'curses.textpad.Textbox': 'https://docs.python.org/3/library/curses.html#curses.textpad.Textbox',
                                'curses.textpad.Textbox.do_command': 'https://docs.python.org/3/library/curses.html#curses.textpad.Textbox.do_command',
                                'curses.textpad.Textbox.edit': 'https://docs.python.org/3/library/curses.html#curses.textpad.Textbox.edit',
                                'curses.textpad.Textbox.gather': 'https://docs.python.org/3/library/curses.html#curses.textpad.Textbox.gather',
                                'curses.textpad.rectangle': 'https://docs.python.org/3/library/curses.html#curses.textpad.rectangle'},
            'dataclasses': { 'dataclasses.Field': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.Field',
                             'dataclasses.asdict': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.asdict',
                             'dataclasses.astuple': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.astuple',
                             'dataclasses.dataclass': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.dataclass',
                             'dataclasses.field': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.field',
                             'dataclasses.fields': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.fields',
                             'dataclasses.is_dataclass': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.is_dataclass',
                             'dataclasses.make_dataclass': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.make_dataclass',
                             'dataclasses.replace': 'https://docs.python.org/3/library/dataclasses.html#dataclasses.replace'},
            'datetime': { 'datetime.date': 'https://docs.python.org/3/library/datetime.html#datetime.date',
                          'datetime.date.__format__': 'https://docs.python.org/3/library/datetime.html#datetime.date.__format__',
                          'datetime.date.__str__': 'https://docs.python.org/3/library/datetime.html#datetime.date.__str__',
                          'datetime.date.ctime': 'https://docs.python.org/3/library/datetime.html#datetime.date.ctime',
                          'datetime.date.fromisocalendar': 'https://docs.python.org/3/library/datetime.html#datetime.date.fromisocalendar',
                          'datetime.date.fromisoformat': 'https://docs.python.org/3/library/datetime.html#datetime.date.fromisoformat',
                          'datetime.date.fromordinal': 'https://docs.python.org/3/library/datetime.html#datetime.date.fromordinal',
                          'datetime.date.fromtimestamp': 'https://docs.python.org/3/library/datetime.html#datetime.date.fromtimestamp',
                          'datetime.date.isocalendar': 'https://docs.python.org/3/library/datetime.html#datetime.date.isocalendar',
                          'datetime.date.isoformat': 'https://docs.python.org/3/library/datetime.html#datetime.date.isoformat',
                          'datetime.date.isoweekday': 'https://docs.python.org/3/library/datetime.html#datetime.date.isoweekday',
                          'datetime.date.replace': 'https://docs.python.org/3/library/datetime.html#datetime.date.replace',
                          'datetime.date.strftime': 'https://docs.python.org/3/library/datetime.html#datetime.date.strftime',
                          'datetime.date.timetuple': 'https://docs.python.org/3/library/datetime.html#datetime.date.timetuple',
                          'datetime.date.today': 'https://docs.python.org/3/library/datetime.html#datetime.date.today',
                          'datetime.date.toordinal': 'https://docs.python.org/3/library/datetime.html#datetime.date.toordinal',
                          'datetime.date.weekday': 'https://docs.python.org/3/library/datetime.html#datetime.date.weekday',
                          'datetime.datetime': 'https://docs.python.org/3/library/datetime.html#datetime.datetime',
                          'datetime.datetime.__format__': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.__format__',
                          'datetime.datetime.__str__': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.__str__',
                          'datetime.datetime.astimezone': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.astimezone',
                          'datetime.datetime.combine': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.combine',
                          'datetime.datetime.ctime': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.ctime',
                          'datetime.datetime.date': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.date',
                          'datetime.datetime.dst': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.dst',
                          'datetime.datetime.fromisocalendar': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.fromisocalendar',
                          'datetime.datetime.fromisoformat': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.fromisoformat',
                          'datetime.datetime.fromordinal': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.fromordinal',
                          'datetime.datetime.fromtimestamp': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.fromtimestamp',
                          'datetime.datetime.isocalendar': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.isocalendar',
                          'datetime.datetime.isoformat': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.isoformat',
                          'datetime.datetime.isoweekday': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.isoweekday',
                          'datetime.datetime.now': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.now',
                          'datetime.datetime.replace': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.replace',
                          'datetime.datetime.strftime': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.strftime',
                          'datetime.datetime.strptime': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.strptime',
                          'datetime.datetime.time': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.time',
                          'datetime.datetime.timestamp': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.timestamp',
                          'datetime.datetime.timetuple': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.timetuple',
                          'datetime.datetime.timetz': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.timetz',
                          'datetime.datetime.today': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.today',
                          'datetime.datetime.toordinal': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.toordinal',
                          'datetime.datetime.tzname': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.tzname',
                          'datetime.datetime.utcfromtimestamp': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.utcfromtimestamp',
                          'datetime.datetime.utcnow': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.utcnow',
                          'datetime.datetime.utcoffset': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.utcoffset',
                          'datetime.datetime.utctimetuple': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.utctimetuple',
                          'datetime.datetime.weekday': 'https://docs.python.org/3/library/datetime.html#datetime.datetime.weekday',
                          'datetime.time': 'https://docs.python.org/3/library/datetime.html#datetime.time',
                          'datetime.time.__format__': 'https://docs.python.org/3/library/datetime.html#datetime.time.__format__',
                          'datetime.time.__str__': 'https://docs.python.org/3/library/datetime.html#datetime.time.__str__',
                          'datetime.time.dst': 'https://docs.python.org/3/library/datetime.html#datetime.time.dst',
                          'datetime.time.fromisoformat': 'https://docs.python.org/3/library/datetime.html#datetime.time.fromisoformat',
                          'datetime.time.isoformat': 'https://docs.python.org/3/library/datetime.html#datetime.time.isoformat',
                          'datetime.time.replace': 'https://docs.python.org/3/library/datetime.html#datetime.time.replace',
                          'datetime.time.strftime': 'https://docs.python.org/3/library/datetime.html#datetime.time.strftime',
                          'datetime.time.tzname': 'https://docs.python.org/3/library/datetime.html#datetime.time.tzname',
                          'datetime.time.utcoffset': 'https://docs.python.org/3/library/datetime.html#datetime.time.utcoffset',
                          'datetime.timedelta': 'https://docs.python.org/3/library/datetime.html#datetime.timedelta',
                          'datetime.timedelta.total_seconds': 'https://docs.python.org/3/library/datetime.html#datetime.timedelta.total_seconds',
                          'datetime.timezone': 'https://docs.python.org/3/library/datetime.html#datetime.timezone',
                          'datetime.timezone.dst': 'https://docs.python.org/3/library/datetime.html#datetime.timezone.dst',
                          'datetime.timezone.fromutc': 'https://docs.python.org/3/library/datetime.html#datetime.timezone.fromutc',
                          'datetime.timezone.tzname': 'https://docs.python.org/3/library/datetime.html#datetime.timezone.tzname',
                          'datetime.timezone.utcoffset': 'https://docs.python.org/3/library/datetime.html#datetime.timezone.utcoffset',
                          'datetime.tzinfo': 'https://docs.python.org/3/library/datetime.html#datetime.tzinfo',
                          'datetime.tzinfo.dst': 'https://docs.python.org/3/library/datetime.html#datetime.tzinfo.dst',
                          'datetime.tzinfo.fromutc': 'https://docs.python.org/3/library/datetime.html#datetime.tzinfo.fromutc',
                          'datetime.tzinfo.tzname': 'https://docs.python.org/3/library/datetime.html#datetime.tzinfo.tzname',
                          'datetime.tzinfo.utcoffset': 'https://docs.python.org/3/library/datetime.html#datetime.tzinfo.utcoffset'},
            'dbm': { 'dbm.dumb': 'https://docs.python.org/3/library/dbm.html#module-dbm.dumb',
                     'dbm.gnu': 'https://docs.python.org/3/library/dbm.html#module-dbm.gnu',
                     'dbm.ndbm': 'https://docs.python.org/3/library/dbm.html#module-dbm.ndbm',
                     'dbm.open': 'https://docs.python.org/3/library/dbm.html#dbm.open',
                     'dbm.whichdb': 'https://docs.python.org/3/library/dbm.html#dbm.whichdb'},
            'dbm.dumb': { 'dbm.dumb.dumbdbm.close': 'https://docs.python.org/3/library/dbm.html#dbm.dumb.dumbdbm.close',
                          'dbm.dumb.dumbdbm.sync': 'https://docs.python.org/3/library/dbm.html#dbm.dumb.dumbdbm.sync',
                          'dbm.dumb.open': 'https://docs.python.org/3/library/dbm.html#dbm.dumb.open'},
            'dbm.gnu': { 'dbm.gnu.gdbm.close': 'https://docs.python.org/3/library/dbm.html#dbm.gnu.gdbm.close',
                         'dbm.gnu.gdbm.firstkey': 'https://docs.python.org/3/library/dbm.html#dbm.gnu.gdbm.firstkey',
                         'dbm.gnu.gdbm.nextkey': 'https://docs.python.org/3/library/dbm.html#dbm.gnu.gdbm.nextkey',
                         'dbm.gnu.gdbm.reorganize': 'https://docs.python.org/3/library/dbm.html#dbm.gnu.gdbm.reorganize',
                         'dbm.gnu.gdbm.sync': 'https://docs.python.org/3/library/dbm.html#dbm.gnu.gdbm.sync',
                         'dbm.gnu.open': 'https://docs.python.org/3/library/dbm.html#dbm.gnu.open'},
            'dbm.ndbm': { 'dbm.ndbm.ndbm.close': 'https://docs.python.org/3/library/dbm.html#dbm.ndbm.ndbm.close',
                          'dbm.ndbm.open': 'https://docs.python.org/3/library/dbm.html#dbm.ndbm.open'},
            'decimal': { 'decimal.BasicContext': 'https://docs.python.org/3/library/decimal.html#decimal.BasicContext',
                         'decimal.Clamped': 'https://docs.python.org/3/library/decimal.html#decimal.Clamped',
                         'decimal.Context': 'https://docs.python.org/3/library/decimal.html#decimal.Context',
                         'decimal.Context.Etiny': 'https://docs.python.org/3/library/decimal.html#decimal.Context.Etiny',
                         'decimal.Context.Etop': 'https://docs.python.org/3/library/decimal.html#decimal.Context.Etop',
                         'decimal.Context.abs': 'https://docs.python.org/3/library/decimal.html#decimal.Context.abs',
                         'decimal.Context.add': 'https://docs.python.org/3/library/decimal.html#decimal.Context.add',
                         'decimal.Context.canonical': 'https://docs.python.org/3/library/decimal.html#decimal.Context.canonical',
                         'decimal.Context.clear_flags': 'https://docs.python.org/3/library/decimal.html#decimal.Context.clear_flags',
                         'decimal.Context.clear_traps': 'https://docs.python.org/3/library/decimal.html#decimal.Context.clear_traps',
                         'decimal.Context.compare': 'https://docs.python.org/3/library/decimal.html#decimal.Context.compare',
                         'decimal.Context.compare_signal': 'https://docs.python.org/3/library/decimal.html#decimal.Context.compare_signal',
                         'decimal.Context.compare_total': 'https://docs.python.org/3/library/decimal.html#decimal.Context.compare_total',
                         'decimal.Context.compare_total_mag': 'https://docs.python.org/3/library/decimal.html#decimal.Context.compare_total_mag',
                         'decimal.Context.copy': 'https://docs.python.org/3/library/decimal.html#decimal.Context.copy',
                         'decimal.Context.copy_abs': 'https://docs.python.org/3/library/decimal.html#decimal.Context.copy_abs',
                         'decimal.Context.copy_decimal': 'https://docs.python.org/3/library/decimal.html#decimal.Context.copy_decimal',
                         'decimal.Context.copy_negate': 'https://docs.python.org/3/library/decimal.html#decimal.Context.copy_negate',
                         'decimal.Context.copy_sign': 'https://docs.python.org/3/library/decimal.html#decimal.Context.copy_sign',
                         'decimal.Context.create_decimal': 'https://docs.python.org/3/library/decimal.html#decimal.Context.create_decimal',
                         'decimal.Context.create_decimal_from_float': 'https://docs.python.org/3/library/decimal.html#decimal.Context.create_decimal_from_float',
                         'decimal.Context.divide': 'https://docs.python.org/3/library/decimal.html#decimal.Context.divide',
                         'decimal.Context.divide_int': 'https://docs.python.org/3/library/decimal.html#decimal.Context.divide_int',
                         'decimal.Context.divmod': 'https://docs.python.org/3/library/decimal.html#decimal.Context.divmod',
                         'decimal.Context.exp': 'https://docs.python.org/3/library/decimal.html#decimal.Context.exp',
                         'decimal.Context.fma': 'https://docs.python.org/3/library/decimal.html#decimal.Context.fma',
                         'decimal.Context.is_canonical': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_canonical',
                         'decimal.Context.is_finite': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_finite',
                         'decimal.Context.is_infinite': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_infinite',
                         'decimal.Context.is_nan': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_nan',
                         'decimal.Context.is_normal': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_normal',
                         'decimal.Context.is_qnan': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_qnan',
                         'decimal.Context.is_signed': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_signed',
                         'decimal.Context.is_snan': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_snan',
                         'decimal.Context.is_subnormal': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_subnormal',
                         'decimal.Context.is_zero': 'https://docs.python.org/3/library/decimal.html#decimal.Context.is_zero',
                         'decimal.Context.ln': 'https://docs.python.org/3/library/decimal.html#decimal.Context.ln',
                         'decimal.Context.log10': 'https://docs.python.org/3/library/decimal.html#decimal.Context.log10',
                         'decimal.Context.logb': 'https://docs.python.org/3/library/decimal.html#decimal.Context.logb',
                         'decimal.Context.logical_and': 'https://docs.python.org/3/library/decimal.html#decimal.Context.logical_and',
                         'decimal.Context.logical_invert': 'https://docs.python.org/3/library/decimal.html#decimal.Context.logical_invert',
                         'decimal.Context.logical_or': 'https://docs.python.org/3/library/decimal.html#decimal.Context.logical_or',
                         'decimal.Context.logical_xor': 'https://docs.python.org/3/library/decimal.html#decimal.Context.logical_xor',
                         'decimal.Context.max': 'https://docs.python.org/3/library/decimal.html#decimal.Context.max',
                         'decimal.Context.max_mag': 'https://docs.python.org/3/library/decimal.html#decimal.Context.max_mag',
                         'decimal.Context.min': 'https://docs.python.org/3/library/decimal.html#decimal.Context.min',
                         'decimal.Context.min_mag': 'https://docs.python.org/3/library/decimal.html#decimal.Context.min_mag',
                         'decimal.Context.minus': 'https://docs.python.org/3/library/decimal.html#decimal.Context.minus',
                         'decimal.Context.multiply': 'https://docs.python.org/3/library/decimal.html#decimal.Context.multiply',
                         'decimal.Context.next_minus': 'https://docs.python.org/3/library/decimal.html#decimal.Context.next_minus',
                         'decimal.Context.next_plus': 'https://docs.python.org/3/library/decimal.html#decimal.Context.next_plus',
                         'decimal.Context.next_toward': 'https://docs.python.org/3/library/decimal.html#decimal.Context.next_toward',
                         'decimal.Context.normalize': 'https://docs.python.org/3/library/decimal.html#decimal.Context.normalize',
                         'decimal.Context.number_class': 'https://docs.python.org/3/library/decimal.html#decimal.Context.number_class',
                         'decimal.Context.plus': 'https://docs.python.org/3/library/decimal.html#decimal.Context.plus',
                         'decimal.Context.power': 'https://docs.python.org/3/library/decimal.html#decimal.Context.power',
                         'decimal.Context.quantize': 'https://docs.python.org/3/library/decimal.html#decimal.Context.quantize',
                         'decimal.Context.radix': 'https://docs.python.org/3/library/decimal.html#decimal.Context.radix',
                         'decimal.Context.remainder': 'https://docs.python.org/3/library/decimal.html#decimal.Context.remainder',
                         'decimal.Context.remainder_near': 'https://docs.python.org/3/library/decimal.html#decimal.Context.remainder_near',
                         'decimal.Context.rotate': 'https://docs.python.org/3/library/decimal.html#decimal.Context.rotate',
                         'decimal.Context.same_quantum': 'https://docs.python.org/3/library/decimal.html#decimal.Context.same_quantum',
                         'decimal.Context.scaleb': 'https://docs.python.org/3/library/decimal.html#decimal.Context.scaleb',
                         'decimal.Context.shift': 'https://docs.python.org/3/library/decimal.html#decimal.Context.shift',
                         'decimal.Context.sqrt': 'https://docs.python.org/3/library/decimal.html#decimal.Context.sqrt',
                         'decimal.Context.subtract': 'https://docs.python.org/3/library/decimal.html#decimal.Context.subtract',
                         'decimal.Context.to_eng_string': 'https://docs.python.org/3/library/decimal.html#decimal.Context.to_eng_string',
                         'decimal.Context.to_integral_exact': 'https://docs.python.org/3/library/decimal.html#decimal.Context.to_integral_exact',
                         'decimal.Context.to_sci_string': 'https://docs.python.org/3/library/decimal.html#decimal.Context.to_sci_string',
                         'decimal.Decimal': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal',
                         'decimal.Decimal.adjusted': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.adjusted',
                         'decimal.Decimal.as_integer_ratio': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.as_integer_ratio',
                         'decimal.Decimal.as_tuple': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.as_tuple',
                         'decimal.Decimal.canonical': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.canonical',
                         'decimal.Decimal.compare': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.compare',
                         'decimal.Decimal.compare_signal': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.compare_signal',
                         'decimal.Decimal.compare_total': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.compare_total',
                         'decimal.Decimal.compare_total_mag': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.compare_total_mag',
                         'decimal.Decimal.conjugate': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.conjugate',
                         'decimal.Decimal.copy_abs': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.copy_abs',
                         'decimal.Decimal.copy_negate': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.copy_negate',
                         'decimal.Decimal.copy_sign': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.copy_sign',
                         'decimal.Decimal.exp': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.exp',
                         'decimal.Decimal.fma': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.fma',
                         'decimal.Decimal.from_float': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.from_float',
                         'decimal.Decimal.is_canonical': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_canonical',
                         'decimal.Decimal.is_finite': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_finite',
                         'decimal.Decimal.is_infinite': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_infinite',
                         'decimal.Decimal.is_nan': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_nan',
                         'decimal.Decimal.is_normal': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_normal',
                         'decimal.Decimal.is_qnan': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_qnan',
                         'decimal.Decimal.is_signed': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_signed',
                         'decimal.Decimal.is_snan': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_snan',
                         'decimal.Decimal.is_subnormal': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_subnormal',
                         'decimal.Decimal.is_zero': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.is_zero',
                         'decimal.Decimal.ln': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.ln',
                         'decimal.Decimal.log10': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.log10',
                         'decimal.Decimal.logb': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.logb',
                         'decimal.Decimal.logical_and': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.logical_and',
                         'decimal.Decimal.logical_invert': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.logical_invert',
                         'decimal.Decimal.logical_or': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.logical_or',
                         'decimal.Decimal.logical_xor': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.logical_xor',
                         'decimal.Decimal.max': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.max',
                         'decimal.Decimal.max_mag': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.max_mag',
                         'decimal.Decimal.min': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.min',
                         'decimal.Decimal.min_mag': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.min_mag',
                         'decimal.Decimal.next_minus': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.next_minus',
                         'decimal.Decimal.next_plus': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.next_plus',
                         'decimal.Decimal.next_toward': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.next_toward',
                         'decimal.Decimal.normalize': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.normalize',
                         'decimal.Decimal.number_class': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.number_class',
                         'decimal.Decimal.quantize': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.quantize',
                         'decimal.Decimal.radix': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.radix',
                         'decimal.Decimal.remainder_near': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.remainder_near',
                         'decimal.Decimal.rotate': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.rotate',
                         'decimal.Decimal.same_quantum': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.same_quantum',
                         'decimal.Decimal.scaleb': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.scaleb',
                         'decimal.Decimal.shift': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.shift',
                         'decimal.Decimal.sqrt': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.sqrt',
                         'decimal.Decimal.to_eng_string': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.to_eng_string',
                         'decimal.Decimal.to_integral': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.to_integral',
                         'decimal.Decimal.to_integral_exact': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.to_integral_exact',
                         'decimal.Decimal.to_integral_value': 'https://docs.python.org/3/library/decimal.html#decimal.Decimal.to_integral_value',
                         'decimal.DecimalException': 'https://docs.python.org/3/library/decimal.html#decimal.DecimalException',
                         'decimal.DefaultContext': 'https://docs.python.org/3/library/decimal.html#decimal.DefaultContext',
                         'decimal.DivisionByZero': 'https://docs.python.org/3/library/decimal.html#decimal.DivisionByZero',
                         'decimal.ExtendedContext': 'https://docs.python.org/3/library/decimal.html#decimal.ExtendedContext',
                         'decimal.FloatOperation': 'https://docs.python.org/3/library/decimal.html#decimal.FloatOperation',
                         'decimal.Inexact': 'https://docs.python.org/3/library/decimal.html#decimal.Inexact',
                         'decimal.InvalidOperation': 'https://docs.python.org/3/library/decimal.html#decimal.InvalidOperation',
                         'decimal.Overflow': 'https://docs.python.org/3/library/decimal.html#decimal.Overflow',
                         'decimal.Rounded': 'https://docs.python.org/3/library/decimal.html#decimal.Rounded',
                         'decimal.Subnormal': 'https://docs.python.org/3/library/decimal.html#decimal.Subnormal',
                         'decimal.Underflow': 'https://docs.python.org/3/library/decimal.html#decimal.Underflow',
                         'decimal.getcontext': 'https://docs.python.org/3/library/decimal.html#decimal.getcontext',
                         'decimal.localcontext': 'https://docs.python.org/3/library/decimal.html#decimal.localcontext',
                         'decimal.setcontext': 'https://docs.python.org/3/library/decimal.html#decimal.setcontext'},
            'difflib': { 'difflib.Differ': 'https://docs.python.org/3/library/difflib.html#difflib.Differ',
                         'difflib.Differ.compare': 'https://docs.python.org/3/library/difflib.html#difflib.Differ.compare',
                         'difflib.HtmlDiff': 'https://docs.python.org/3/library/difflib.html#difflib.HtmlDiff',
                         'difflib.HtmlDiff.__init__': 'https://docs.python.org/3/library/difflib.html#difflib.HtmlDiff.__init__',
                         'difflib.HtmlDiff.make_file': 'https://docs.python.org/3/library/difflib.html#difflib.HtmlDiff.make_file',
                         'difflib.HtmlDiff.make_table': 'https://docs.python.org/3/library/difflib.html#difflib.HtmlDiff.make_table',
                         'difflib.IS_CHARACTER_JUNK': 'https://docs.python.org/3/library/difflib.html#difflib.IS_CHARACTER_JUNK',
                         'difflib.IS_LINE_JUNK': 'https://docs.python.org/3/library/difflib.html#difflib.IS_LINE_JUNK',
                         'difflib.SequenceMatcher': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher',
                         'difflib.SequenceMatcher.find_longest_match': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.find_longest_match',
                         'difflib.SequenceMatcher.get_grouped_opcodes': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.get_grouped_opcodes',
                         'difflib.SequenceMatcher.get_matching_blocks': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.get_matching_blocks',
                         'difflib.SequenceMatcher.get_opcodes': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.get_opcodes',
                         'difflib.SequenceMatcher.quick_ratio': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.quick_ratio',
                         'difflib.SequenceMatcher.ratio': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.ratio',
                         'difflib.SequenceMatcher.real_quick_ratio': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.real_quick_ratio',
                         'difflib.SequenceMatcher.set_seq1': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.set_seq1',
                         'difflib.SequenceMatcher.set_seq2': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.set_seq2',
                         'difflib.SequenceMatcher.set_seqs': 'https://docs.python.org/3/library/difflib.html#difflib.SequenceMatcher.set_seqs',
                         'difflib.context_diff': 'https://docs.python.org/3/library/difflib.html#difflib.context_diff',
                         'difflib.diff_bytes': 'https://docs.python.org/3/library/difflib.html#difflib.diff_bytes',
                         'difflib.get_close_matches': 'https://docs.python.org/3/library/difflib.html#difflib.get_close_matches',
                         'difflib.ndiff': 'https://docs.python.org/3/library/difflib.html#difflib.ndiff',
                         'difflib.restore': 'https://docs.python.org/3/library/difflib.html#difflib.restore',
                         'difflib.unified_diff': 'https://docs.python.org/3/library/difflib.html#difflib.unified_diff'},
            'dis': { 'dis.Bytecode': 'https://docs.python.org/3/library/dis.html#dis.Bytecode',
                     'dis.Bytecode.dis': 'https://docs.python.org/3/library/dis.html#dis.Bytecode.dis',
                     'dis.Bytecode.from_traceback': 'https://docs.python.org/3/library/dis.html#dis.Bytecode.from_traceback',
                     'dis.Bytecode.info': 'https://docs.python.org/3/library/dis.html#dis.Bytecode.info',
                     'dis.Instruction': 'https://docs.python.org/3/library/dis.html#dis.Instruction',
                     'dis.code_info': 'https://docs.python.org/3/library/dis.html#dis.code_info',
                     'dis.dis': 'https://docs.python.org/3/library/dis.html#dis.dis',
                     'dis.disassemble': 'https://docs.python.org/3/library/dis.html#dis.disassemble',
                     'dis.disco': 'https://docs.python.org/3/library/dis.html#dis.disco',
                     'dis.distb': 'https://docs.python.org/3/library/dis.html#dis.distb',
                     'dis.findlabels': 'https://docs.python.org/3/library/dis.html#dis.findlabels',
                     'dis.findlinestarts': 'https://docs.python.org/3/library/dis.html#dis.findlinestarts',
                     'dis.get_instructions': 'https://docs.python.org/3/library/dis.html#dis.get_instructions',
                     'dis.show_code': 'https://docs.python.org/3/library/dis.html#dis.show_code',
                     'dis.stack_effect': 'https://docs.python.org/3/library/dis.html#dis.stack_effect'},
            'distutils': { 'distutils.archive_util': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.archive_util',
                           'distutils.bcppcompiler': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.bcppcompiler',
                           'distutils.ccompiler': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.ccompiler',
                           'distutils.cmd': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.cmd',
                           'distutils.command': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command',
                           'distutils.core': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.core',
                           'distutils.cygwinccompiler': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.cygwinccompiler',
                           'distutils.debug': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.debug',
                           'distutils.dep_util': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.dep_util',
                           'distutils.dir_util': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.dir_util',
                           'distutils.dist': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.dist',
                           'distutils.errors': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.errors',
                           'distutils.extension': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.extension',
                           'distutils.fancy_getopt': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.fancy_getopt',
                           'distutils.file_util': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.file_util',
                           'distutils.filelist': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.filelist',
                           'distutils.log': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.log',
                           'distutils.msvccompiler': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.msvccompiler',
                           'distutils.spawn': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.spawn',
                           'distutils.sysconfig': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.sysconfig',
                           'distutils.text_file': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.text_file',
                           'distutils.unixccompiler': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.unixccompiler',
                           'distutils.util': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.util',
                           'distutils.version': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.version'},
            'distutils.archive_util': { 'distutils.archive_util.make_archive': 'https://docs.python.org/3/distutils/apiref.html#distutils.archive_util.make_archive',
                                        'distutils.archive_util.make_tarball': 'https://docs.python.org/3/distutils/apiref.html#distutils.archive_util.make_tarball',
                                        'distutils.archive_util.make_zipfile': 'https://docs.python.org/3/distutils/apiref.html#distutils.archive_util.make_zipfile'},
            'distutils.ccompiler': { 'distutils.ccompiler.CCompiler': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler',
                                     'distutils.ccompiler.CCompiler.add_include_dir': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.add_include_dir',
                                     'distutils.ccompiler.CCompiler.add_library': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.add_library',
                                     'distutils.ccompiler.CCompiler.add_library_dir': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.add_library_dir',
                                     'distutils.ccompiler.CCompiler.add_link_object': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.add_link_object',
                                     'distutils.ccompiler.CCompiler.add_runtime_library_dir': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.add_runtime_library_dir',
                                     'distutils.ccompiler.CCompiler.announce': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.announce',
                                     'distutils.ccompiler.CCompiler.compile': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.compile',
                                     'distutils.ccompiler.CCompiler.create_static_lib': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.create_static_lib',
                                     'distutils.ccompiler.CCompiler.debug_print': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.debug_print',
                                     'distutils.ccompiler.CCompiler.define_macro': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.define_macro',
                                     'distutils.ccompiler.CCompiler.detect_language': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.detect_language',
                                     'distutils.ccompiler.CCompiler.executable_filename': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.executable_filename',
                                     'distutils.ccompiler.CCompiler.execute': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.execute',
                                     'distutils.ccompiler.CCompiler.find_library_file': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.find_library_file',
                                     'distutils.ccompiler.CCompiler.has_function': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.has_function',
                                     'distutils.ccompiler.CCompiler.library_dir_option': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.library_dir_option',
                                     'distutils.ccompiler.CCompiler.library_filename': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.library_filename',
                                     'distutils.ccompiler.CCompiler.library_option': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.library_option',
                                     'distutils.ccompiler.CCompiler.link': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.link',
                                     'distutils.ccompiler.CCompiler.link_executable': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.link_executable',
                                     'distutils.ccompiler.CCompiler.link_shared_lib': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.link_shared_lib',
                                     'distutils.ccompiler.CCompiler.link_shared_object': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.link_shared_object',
                                     'distutils.ccompiler.CCompiler.mkpath': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.mkpath',
                                     'distutils.ccompiler.CCompiler.move_file': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.move_file',
                                     'distutils.ccompiler.CCompiler.object_filenames': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.object_filenames',
                                     'distutils.ccompiler.CCompiler.preprocess': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.preprocess',
                                     'distutils.ccompiler.CCompiler.runtime_library_dir_option': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.runtime_library_dir_option',
                                     'distutils.ccompiler.CCompiler.set_executables': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.set_executables',
                                     'distutils.ccompiler.CCompiler.set_include_dirs': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.set_include_dirs',
                                     'distutils.ccompiler.CCompiler.set_libraries': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.set_libraries',
                                     'distutils.ccompiler.CCompiler.set_library_dirs': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.set_library_dirs',
                                     'distutils.ccompiler.CCompiler.set_link_objects': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.set_link_objects',
                                     'distutils.ccompiler.CCompiler.set_runtime_library_dirs': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.set_runtime_library_dirs',
                                     'distutils.ccompiler.CCompiler.shared_object_filename': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.shared_object_filename',
                                     'distutils.ccompiler.CCompiler.spawn': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.spawn',
                                     'distutils.ccompiler.CCompiler.undefine_macro': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.undefine_macro',
                                     'distutils.ccompiler.CCompiler.warn': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.CCompiler.warn',
                                     'distutils.ccompiler.gen_lib_options': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.gen_lib_options',
                                     'distutils.ccompiler.gen_preprocess_options': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.gen_preprocess_options',
                                     'distutils.ccompiler.get_default_compiler': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.get_default_compiler',
                                     'distutils.ccompiler.new_compiler': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.new_compiler',
                                     'distutils.ccompiler.show_compilers': 'https://docs.python.org/3/distutils/apiref.html#distutils.ccompiler.show_compilers'},
            'distutils.cmd': { 'distutils.cmd.Command': 'https://docs.python.org/3/distutils/apiref.html#distutils.cmd.Command',
                               'distutils.cmd.Command.finalize_options': 'https://docs.python.org/3/distutils/apiref.html#distutils.cmd.Command.finalize_options',
                               'distutils.cmd.Command.initialize_options': 'https://docs.python.org/3/distutils/apiref.html#distutils.cmd.Command.initialize_options',
                               'distutils.cmd.Command.run': 'https://docs.python.org/3/distutils/apiref.html#distutils.cmd.Command.run'},
            'distutils.command': { 'distutils.command.bdist': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.bdist',
                                   'distutils.command.bdist_dumb': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.bdist_dumb',
                                   'distutils.command.bdist_msi': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.bdist_msi',
                                   'distutils.command.bdist_packager': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.bdist_packager',
                                   'distutils.command.bdist_rpm': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.bdist_rpm',
                                   'distutils.command.build': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.build',
                                   'distutils.command.build_clib': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.build_clib',
                                   'distutils.command.build_ext': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.build_ext',
                                   'distutils.command.build_py': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.build_py',
                                   'distutils.command.build_scripts': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.build_scripts',
                                   'distutils.command.check': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.check',
                                   'distutils.command.clean': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.clean',
                                   'distutils.command.config': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.config',
                                   'distutils.command.install': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.install',
                                   'distutils.command.install_data': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.install_data',
                                   'distutils.command.install_headers': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.install_headers',
                                   'distutils.command.install_lib': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.install_lib',
                                   'distutils.command.install_scripts': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.install_scripts',
                                   'distutils.command.register': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.register',
                                   'distutils.command.sdist': 'https://docs.python.org/3/distutils/apiref.html#module-distutils.command.sdist'},
            'distutils.command.bdist_msi': { 'distutils.command.bdist_msi.bdist_msi': 'https://docs.python.org/3/distutils/apiref.html#distutils.command.bdist_msi.bdist_msi'},
            'distutils.command.build_py': { 'distutils.command.build_py.build_py': 'https://docs.python.org/3/distutils/apiref.html#distutils.command.build_py.build_py',
                                            'distutils.command.build_py.build_py_2to3': 'https://docs.python.org/3/distutils/apiref.html#distutils.command.build_py.build_py_2to3'},
            'distutils.core': { 'distutils.core.Command': 'https://docs.python.org/3/distutils/apiref.html#distutils.core.Command',
                                'distutils.core.Distribution': 'https://docs.python.org/3/distutils/apiref.html#distutils.core.Distribution',
                                'distutils.core.Extension': 'https://docs.python.org/3/distutils/apiref.html#distutils.core.Extension',
                                'distutils.core.run_setup': 'https://docs.python.org/3/distutils/apiref.html#distutils.core.run_setup',
                                'distutils.core.setup': 'https://docs.python.org/3/distutils/apiref.html#distutils.core.setup'},
            'distutils.dep_util': { 'distutils.dep_util.newer': 'https://docs.python.org/3/distutils/apiref.html#distutils.dep_util.newer',
                                    'distutils.dep_util.newer_group': 'https://docs.python.org/3/distutils/apiref.html#distutils.dep_util.newer_group',
                                    'distutils.dep_util.newer_pairwise': 'https://docs.python.org/3/distutils/apiref.html#distutils.dep_util.newer_pairwise'},
            'distutils.dir_util': { 'distutils.dir_util.copy_tree': 'https://docs.python.org/3/distutils/apiref.html#distutils.dir_util.copy_tree',
                                    'distutils.dir_util.create_tree': 'https://docs.python.org/3/distutils/apiref.html#distutils.dir_util.create_tree',
                                    'distutils.dir_util.mkpath': 'https://docs.python.org/3/distutils/apiref.html#distutils.dir_util.mkpath',
                                    'distutils.dir_util.remove_tree': 'https://docs.python.org/3/distutils/apiref.html#distutils.dir_util.remove_tree'},
            'distutils.fancy_getopt': { 'distutils.fancy_getopt.FancyGetopt': 'https://docs.python.org/3/distutils/apiref.html#distutils.fancy_getopt.FancyGetopt',
                                        'distutils.fancy_getopt.FancyGetopt.generate_help': 'https://docs.python.org/3/distutils/apiref.html#distutils.fancy_getopt.FancyGetopt.generate_help',
                                        'distutils.fancy_getopt.FancyGetopt.get_option_order': 'https://docs.python.org/3/distutils/apiref.html#distutils.fancy_getopt.FancyGetopt.get_option_order',
                                        'distutils.fancy_getopt.FancyGetopt.getopt': 'https://docs.python.org/3/distutils/apiref.html#distutils.fancy_getopt.FancyGetopt.getopt',
                                        'distutils.fancy_getopt.fancy_getopt': 'https://docs.python.org/3/distutils/apiref.html#distutils.fancy_getopt.fancy_getopt',
                                        'distutils.fancy_getopt.wrap_text': 'https://docs.python.org/3/distutils/apiref.html#distutils.fancy_getopt.wrap_text'},
            'distutils.file_util': { 'distutils.file_util.copy_file': 'https://docs.python.org/3/distutils/apiref.html#distutils.file_util.copy_file',
                                     'distutils.file_util.move_file': 'https://docs.python.org/3/distutils/apiref.html#distutils.file_util.move_file',
                                     'distutils.file_util.write_file': 'https://docs.python.org/3/distutils/apiref.html#distutils.file_util.write_file'},
            'distutils.sysconfig': { 'distutils.sysconfig.customize_compiler': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.customize_compiler',
                                     'distutils.sysconfig.get_config_h_filename': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.get_config_h_filename',
                                     'distutils.sysconfig.get_config_var': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.get_config_var',
                                     'distutils.sysconfig.get_config_vars': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.get_config_vars',
                                     'distutils.sysconfig.get_makefile_filename': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.get_makefile_filename',
                                     'distutils.sysconfig.get_python_inc': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.get_python_inc',
                                     'distutils.sysconfig.get_python_lib': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.get_python_lib',
                                     'distutils.sysconfig.set_python_build': 'https://docs.python.org/3/distutils/apiref.html#distutils.sysconfig.set_python_build'},
            'distutils.text_file': { 'distutils.text_file.TextFile': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile',
                                     'distutils.text_file.TextFile.close': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile.close',
                                     'distutils.text_file.TextFile.open': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile.open',
                                     'distutils.text_file.TextFile.readline': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile.readline',
                                     'distutils.text_file.TextFile.readlines': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile.readlines',
                                     'distutils.text_file.TextFile.unreadline': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile.unreadline',
                                     'distutils.text_file.TextFile.warn': 'https://docs.python.org/3/distutils/apiref.html#distutils.text_file.TextFile.warn'},
            'distutils.util': { 'distutils.util.byte_compile': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.byte_compile',
                                'distutils.util.change_root': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.change_root',
                                'distutils.util.check_environ': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.check_environ',
                                'distutils.util.convert_path': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.convert_path',
                                'distutils.util.execute': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.execute',
                                'distutils.util.get_platform': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.get_platform',
                                'distutils.util.rfc822_escape': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.rfc822_escape',
                                'distutils.util.split_quoted': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.split_quoted',
                                'distutils.util.strtobool': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.strtobool',
                                'distutils.util.subst_vars': 'https://docs.python.org/3/distutils/apiref.html#distutils.util.subst_vars'},
            'doctest': { 'doctest.DebugRunner': 'https://docs.python.org/3/library/doctest.html#doctest.DebugRunner',
                         'doctest.DocFileSuite': 'https://docs.python.org/3/library/doctest.html#doctest.DocFileSuite',
                         'doctest.DocTest': 'https://docs.python.org/3/library/doctest.html#doctest.DocTest',
                         'doctest.DocTestFinder': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestFinder',
                         'doctest.DocTestFinder.find': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestFinder.find',
                         'doctest.DocTestParser': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestParser',
                         'doctest.DocTestParser.get_doctest': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestParser.get_doctest',
                         'doctest.DocTestParser.get_examples': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestParser.get_examples',
                         'doctest.DocTestParser.parse': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestParser.parse',
                         'doctest.DocTestRunner': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner',
                         'doctest.DocTestRunner.report_failure': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner.report_failure',
                         'doctest.DocTestRunner.report_start': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner.report_start',
                         'doctest.DocTestRunner.report_success': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner.report_success',
                         'doctest.DocTestRunner.report_unexpected_exception': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner.report_unexpected_exception',
                         'doctest.DocTestRunner.run': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner.run',
                         'doctest.DocTestRunner.summarize': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestRunner.summarize',
                         'doctest.DocTestSuite': 'https://docs.python.org/3/library/doctest.html#doctest.DocTestSuite',
                         'doctest.Example': 'https://docs.python.org/3/library/doctest.html#doctest.Example',
                         'doctest.OutputChecker': 'https://docs.python.org/3/library/doctest.html#doctest.OutputChecker',
                         'doctest.OutputChecker.check_output': 'https://docs.python.org/3/library/doctest.html#doctest.OutputChecker.check_output',
                         'doctest.OutputChecker.output_difference': 'https://docs.python.org/3/library/doctest.html#doctest.OutputChecker.output_difference',
                         'doctest.debug': 'https://docs.python.org/3/library/doctest.html#doctest.debug',
                         'doctest.debug_src': 'https://docs.python.org/3/library/doctest.html#doctest.debug_src',
                         'doctest.register_optionflag': 'https://docs.python.org/3/library/doctest.html#doctest.register_optionflag',
                         'doctest.run_docstring_examples': 'https://docs.python.org/3/library/doctest.html#doctest.run_docstring_examples',
                         'doctest.script_from_examples': 'https://docs.python.org/3/library/doctest.html#doctest.script_from_examples',
                         'doctest.set_unittest_reportflags': 'https://docs.python.org/3/library/doctest.html#doctest.set_unittest_reportflags',
                         'doctest.testfile': 'https://docs.python.org/3/library/doctest.html#doctest.testfile',
                         'doctest.testmod': 'https://docs.python.org/3/library/doctest.html#doctest.testmod',
                         'doctest.testsource': 'https://docs.python.org/3/library/doctest.html#doctest.testsource'},
            'email': { 'email.charset': 'https://docs.python.org/3/library/email.charset.html#module-email.charset',
                       'email.contentmanager': 'https://docs.python.org/3/library/email.contentmanager.html#module-email.contentmanager',
                       'email.contentmanager.get_content': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.get_content',
                       'email.contentmanager.set_content': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.set_content',
                       'email.encoders': 'https://docs.python.org/3/library/email.encoders.html#module-email.encoders',
                       'email.errors': 'https://docs.python.org/3/library/email.errors.html#module-email.errors',
                       'email.generator': 'https://docs.python.org/3/library/email.generator.html#module-email.generator',
                       'email.header': 'https://docs.python.org/3/library/email.header.html#module-email.header',
                       'email.headerregistry': 'https://docs.python.org/3/library/email.headerregistry.html#module-email.headerregistry',
                       'email.iterators': 'https://docs.python.org/3/library/email.iterators.html#module-email.iterators',
                       'email.message': 'https://docs.python.org/3/library/email.message.html#module-email.message',
                       'email.message_from_binary_file': 'https://docs.python.org/3/library/email.parser.html#email.message_from_binary_file',
                       'email.message_from_bytes': 'https://docs.python.org/3/library/email.parser.html#email.message_from_bytes',
                       'email.message_from_file': 'https://docs.python.org/3/library/email.parser.html#email.message_from_file',
                       'email.message_from_string': 'https://docs.python.org/3/library/email.parser.html#email.message_from_string',
                       'email.mime': 'https://docs.python.org/3/library/email.mime.html#module-email.mime',
                       'email.parser': 'https://docs.python.org/3/library/email.parser.html#module-email.parser',
                       'email.policy': 'https://docs.python.org/3/library/email.policy.html#module-email.policy',
                       'email.utils': 'https://docs.python.org/3/library/email.utils.html#module-email.utils'},
            'email.charset': { 'email.charset.Charset': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset',
                               'email.charset.Charset.__eq__': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.__eq__',
                               'email.charset.Charset.__ne__': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.__ne__',
                               'email.charset.Charset.__str__': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.__str__',
                               'email.charset.Charset.body_encode': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.body_encode',
                               'email.charset.Charset.get_body_encoding': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.get_body_encoding',
                               'email.charset.Charset.get_output_charset': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.get_output_charset',
                               'email.charset.Charset.header_encode': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.header_encode',
                               'email.charset.Charset.header_encode_lines': 'https://docs.python.org/3/library/email.charset.html#email.charset.Charset.header_encode_lines',
                               'email.charset.add_alias': 'https://docs.python.org/3/library/email.charset.html#email.charset.add_alias',
                               'email.charset.add_charset': 'https://docs.python.org/3/library/email.charset.html#email.charset.add_charset',
                               'email.charset.add_codec': 'https://docs.python.org/3/library/email.charset.html#email.charset.add_codec'},
            'email.contentmanager': { 'email.contentmanager.ContentManager': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.ContentManager',
                                      'email.contentmanager.ContentManager.add_get_handler': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.ContentManager.add_get_handler',
                                      'email.contentmanager.ContentManager.add_set_handler': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.ContentManager.add_set_handler',
                                      'email.contentmanager.ContentManager.get_content': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.ContentManager.get_content',
                                      'email.contentmanager.ContentManager.set_content': 'https://docs.python.org/3/library/email.contentmanager.html#email.contentmanager.ContentManager.set_content'},
            'email.encoders': { 'email.encoders.encode_7or8bit': 'https://docs.python.org/3/library/email.encoders.html#email.encoders.encode_7or8bit',
                                'email.encoders.encode_base64': 'https://docs.python.org/3/library/email.encoders.html#email.encoders.encode_base64',
                                'email.encoders.encode_noop': 'https://docs.python.org/3/library/email.encoders.html#email.encoders.encode_noop',
                                'email.encoders.encode_quopri': 'https://docs.python.org/3/library/email.encoders.html#email.encoders.encode_quopri'},
            'email.generator': { 'email.generator.BytesGenerator': 'https://docs.python.org/3/library/email.generator.html#email.generator.BytesGenerator',
                                 'email.generator.BytesGenerator.clone': 'https://docs.python.org/3/library/email.generator.html#email.generator.BytesGenerator.clone',
                                 'email.generator.BytesGenerator.flatten': 'https://docs.python.org/3/library/email.generator.html#email.generator.BytesGenerator.flatten',
                                 'email.generator.BytesGenerator.write': 'https://docs.python.org/3/library/email.generator.html#email.generator.BytesGenerator.write',
                                 'email.generator.DecodedGenerator': 'https://docs.python.org/3/library/email.generator.html#email.generator.DecodedGenerator',
                                 'email.generator.Generator': 'https://docs.python.org/3/library/email.generator.html#email.generator.Generator',
                                 'email.generator.Generator.clone': 'https://docs.python.org/3/library/email.generator.html#email.generator.Generator.clone',
                                 'email.generator.Generator.flatten': 'https://docs.python.org/3/library/email.generator.html#email.generator.Generator.flatten',
                                 'email.generator.Generator.write': 'https://docs.python.org/3/library/email.generator.html#email.generator.Generator.write'},
            'email.header': { 'email.header.Header': 'https://docs.python.org/3/library/email.header.html#email.header.Header',
                              'email.header.Header.__eq__': 'https://docs.python.org/3/library/email.header.html#email.header.Header.__eq__',
                              'email.header.Header.__ne__': 'https://docs.python.org/3/library/email.header.html#email.header.Header.__ne__',
                              'email.header.Header.__str__': 'https://docs.python.org/3/library/email.header.html#email.header.Header.__str__',
                              'email.header.Header.append': 'https://docs.python.org/3/library/email.header.html#email.header.Header.append',
                              'email.header.Header.encode': 'https://docs.python.org/3/library/email.header.html#email.header.Header.encode',
                              'email.header.decode_header': 'https://docs.python.org/3/library/email.header.html#email.header.decode_header',
                              'email.header.make_header': 'https://docs.python.org/3/library/email.header.html#email.header.make_header'},
            'email.headerregistry': { 'email.headerregistry.Address': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.Address',
                                      'email.headerregistry.Address.__str__': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.Address.__str__',
                                      'email.headerregistry.AddressHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.AddressHeader',
                                      'email.headerregistry.BaseHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.BaseHeader',
                                      'email.headerregistry.BaseHeader.fold': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.BaseHeader.fold',
                                      'email.headerregistry.ContentDispositionHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.ContentDispositionHeader',
                                      'email.headerregistry.ContentTransferEncoding': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.ContentTransferEncoding',
                                      'email.headerregistry.ContentTypeHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.ContentTypeHeader',
                                      'email.headerregistry.DateHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.DateHeader',
                                      'email.headerregistry.Group': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.Group',
                                      'email.headerregistry.Group.__str__': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.Group.__str__',
                                      'email.headerregistry.HeaderRegistry': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.HeaderRegistry',
                                      'email.headerregistry.HeaderRegistry.__call__': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.HeaderRegistry.__call__',
                                      'email.headerregistry.HeaderRegistry.__getitem__': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.HeaderRegistry.__getitem__',
                                      'email.headerregistry.HeaderRegistry.map_to_type': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.HeaderRegistry.map_to_type',
                                      'email.headerregistry.MIMEVersionHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.MIMEVersionHeader',
                                      'email.headerregistry.ParameterizedMIMEHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.ParameterizedMIMEHeader',
                                      'email.headerregistry.SingleAddressHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.SingleAddressHeader',
                                      'email.headerregistry.UnstructuredHeader': 'https://docs.python.org/3/library/email.headerregistry.html#email.headerregistry.UnstructuredHeader'},
            'email.iterators': { 'email.iterators._structure': 'https://docs.python.org/3/library/email.iterators.html#email.iterators._structure',
                                 'email.iterators.body_line_iterator': 'https://docs.python.org/3/library/email.iterators.html#email.iterators.body_line_iterator',
                                 'email.iterators.typed_subpart_iterator': 'https://docs.python.org/3/library/email.iterators.html#email.iterators.typed_subpart_iterator'},
            'email.message': { 'email.message.EmailMessage': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage',
                               'email.message.EmailMessage.__bytes__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__bytes__',
                               'email.message.EmailMessage.__contains__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__contains__',
                               'email.message.EmailMessage.__delitem__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__delitem__',
                               'email.message.EmailMessage.__getitem__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__getitem__',
                               'email.message.EmailMessage.__len__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__len__',
                               'email.message.EmailMessage.__setitem__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__setitem__',
                               'email.message.EmailMessage.__str__': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.__str__',
                               'email.message.EmailMessage.add_alternative': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.add_alternative',
                               'email.message.EmailMessage.add_attachment': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.add_attachment',
                               'email.message.EmailMessage.add_header': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.add_header',
                               'email.message.EmailMessage.add_related': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.add_related',
                               'email.message.EmailMessage.as_bytes': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.as_bytes',
                               'email.message.EmailMessage.as_string': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.as_string',
                               'email.message.EmailMessage.clear': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.clear',
                               'email.message.EmailMessage.clear_content': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.clear_content',
                               'email.message.EmailMessage.del_param': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.del_param',
                               'email.message.EmailMessage.get': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get',
                               'email.message.EmailMessage.get_all': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_all',
                               'email.message.EmailMessage.get_body': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_body',
                               'email.message.EmailMessage.get_boundary': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_boundary',
                               'email.message.EmailMessage.get_charsets': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_charsets',
                               'email.message.EmailMessage.get_content': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_content',
                               'email.message.EmailMessage.get_content_charset': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_content_charset',
                               'email.message.EmailMessage.get_content_disposition': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_content_disposition',
                               'email.message.EmailMessage.get_content_maintype': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_content_maintype',
                               'email.message.EmailMessage.get_content_subtype': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_content_subtype',
                               'email.message.EmailMessage.get_content_type': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_content_type',
                               'email.message.EmailMessage.get_default_type': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_default_type',
                               'email.message.EmailMessage.get_filename': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_filename',
                               'email.message.EmailMessage.get_unixfrom': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.get_unixfrom',
                               'email.message.EmailMessage.is_attachment': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.is_attachment',
                               'email.message.EmailMessage.is_multipart': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.is_multipart',
                               'email.message.EmailMessage.items': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.items',
                               'email.message.EmailMessage.iter_attachments': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.iter_attachments',
                               'email.message.EmailMessage.iter_parts': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.iter_parts',
                               'email.message.EmailMessage.keys': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.keys',
                               'email.message.EmailMessage.make_alternative': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.make_alternative',
                               'email.message.EmailMessage.make_mixed': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.make_mixed',
                               'email.message.EmailMessage.make_related': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.make_related',
                               'email.message.EmailMessage.replace_header': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.replace_header',
                               'email.message.EmailMessage.set_boundary': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.set_boundary',
                               'email.message.EmailMessage.set_content': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.set_content',
                               'email.message.EmailMessage.set_default_type': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.set_default_type',
                               'email.message.EmailMessage.set_param': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.set_param',
                               'email.message.EmailMessage.set_unixfrom': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.set_unixfrom',
                               'email.message.EmailMessage.values': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.values',
                               'email.message.EmailMessage.walk': 'https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.walk',
                               'email.message.MIMEPart': 'https://docs.python.org/3/library/email.message.html#email.message.MIMEPart',
                               'email.message.Message': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message',
                               'email.message.Message.__bytes__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__bytes__',
                               'email.message.Message.__contains__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__contains__',
                               'email.message.Message.__delitem__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__delitem__',
                               'email.message.Message.__getitem__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__getitem__',
                               'email.message.Message.__len__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__len__',
                               'email.message.Message.__setitem__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__setitem__',
                               'email.message.Message.__str__': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.__str__',
                               'email.message.Message.add_header': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.add_header',
                               'email.message.Message.as_bytes': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.as_bytes',
                               'email.message.Message.as_string': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.as_string',
                               'email.message.Message.attach': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.attach',
                               'email.message.Message.del_param': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.del_param',
                               'email.message.Message.get': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get',
                               'email.message.Message.get_all': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_all',
                               'email.message.Message.get_boundary': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_boundary',
                               'email.message.Message.get_charset': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_charset',
                               'email.message.Message.get_charsets': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_charsets',
                               'email.message.Message.get_content_charset': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_content_charset',
                               'email.message.Message.get_content_disposition': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_content_disposition',
                               'email.message.Message.get_content_maintype': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_content_maintype',
                               'email.message.Message.get_content_subtype': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_content_subtype',
                               'email.message.Message.get_content_type': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_content_type',
                               'email.message.Message.get_default_type': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_default_type',
                               'email.message.Message.get_filename': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_filename',
                               'email.message.Message.get_param': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_param',
                               'email.message.Message.get_params': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_params',
                               'email.message.Message.get_payload': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_payload',
                               'email.message.Message.get_unixfrom': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.get_unixfrom',
                               'email.message.Message.is_multipart': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.is_multipart',
                               'email.message.Message.items': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.items',
                               'email.message.Message.keys': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.keys',
                               'email.message.Message.replace_header': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.replace_header',
                               'email.message.Message.set_boundary': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_boundary',
                               'email.message.Message.set_charset': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_charset',
                               'email.message.Message.set_default_type': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_default_type',
                               'email.message.Message.set_param': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_param',
                               'email.message.Message.set_payload': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_payload',
                               'email.message.Message.set_type': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_type',
                               'email.message.Message.set_unixfrom': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.set_unixfrom',
                               'email.message.Message.values': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.values',
                               'email.message.Message.walk': 'https://docs.python.org/3/library/email.compat32-message.html#email.message.Message.walk'},
            'email.mime.application': { 'email.mime.application.MIMEApplication': 'https://docs.python.org/3/library/email.mime.html#email.mime.application.MIMEApplication'},
            'email.mime.audio': {'email.mime.audio.MIMEAudio': 'https://docs.python.org/3/library/email.mime.html#email.mime.audio.MIMEAudio'},
            'email.mime.base': {'email.mime.base.MIMEBase': 'https://docs.python.org/3/library/email.mime.html#email.mime.base.MIMEBase'},
            'email.mime.image': {'email.mime.image.MIMEImage': 'https://docs.python.org/3/library/email.mime.html#email.mime.image.MIMEImage'},
            'email.mime.message': {'email.mime.message.MIMEMessage': 'https://docs.python.org/3/library/email.mime.html#email.mime.message.MIMEMessage'},
            'email.mime.multipart': { 'email.mime.multipart.MIMEMultipart': 'https://docs.python.org/3/library/email.mime.html#email.mime.multipart.MIMEMultipart'},
            'email.mime.nonmultipart': { 'email.mime.nonmultipart.MIMENonMultipart': 'https://docs.python.org/3/library/email.mime.html#email.mime.nonmultipart.MIMENonMultipart'},
            'email.mime.text': {'email.mime.text.MIMEText': 'https://docs.python.org/3/library/email.mime.html#email.mime.text.MIMEText'},
            'email.parser': { 'email.parser.BytesFeedParser': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesFeedParser',
                              'email.parser.BytesFeedParser.close': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesFeedParser.close',
                              'email.parser.BytesFeedParser.feed': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesFeedParser.feed',
                              'email.parser.BytesHeaderParser': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesHeaderParser',
                              'email.parser.BytesParser': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesParser',
                              'email.parser.BytesParser.parse': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesParser.parse',
                              'email.parser.BytesParser.parsebytes': 'https://docs.python.org/3/library/email.parser.html#email.parser.BytesParser.parsebytes',
                              'email.parser.FeedParser': 'https://docs.python.org/3/library/email.parser.html#email.parser.FeedParser',
                              'email.parser.HeaderParser': 'https://docs.python.org/3/library/email.parser.html#email.parser.HeaderParser',
                              'email.parser.Parser': 'https://docs.python.org/3/library/email.parser.html#email.parser.Parser',
                              'email.parser.Parser.parse': 'https://docs.python.org/3/library/email.parser.html#email.parser.Parser.parse',
                              'email.parser.Parser.parsestr': 'https://docs.python.org/3/library/email.parser.html#email.parser.Parser.parsestr'},
            'email.policy': { 'email.policy.Compat32': 'https://docs.python.org/3/library/email.policy.html#email.policy.Compat32',
                              'email.policy.Compat32.fold': 'https://docs.python.org/3/library/email.policy.html#email.policy.Compat32.fold',
                              'email.policy.Compat32.fold_binary': 'https://docs.python.org/3/library/email.policy.html#email.policy.Compat32.fold_binary',
                              'email.policy.Compat32.header_fetch_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.Compat32.header_fetch_parse',
                              'email.policy.Compat32.header_source_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.Compat32.header_source_parse',
                              'email.policy.Compat32.header_store_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.Compat32.header_store_parse',
                              'email.policy.EmailPolicy': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy',
                              'email.policy.EmailPolicy.fold': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy.fold',
                              'email.policy.EmailPolicy.fold_binary': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy.fold_binary',
                              'email.policy.EmailPolicy.header_fetch_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy.header_fetch_parse',
                              'email.policy.EmailPolicy.header_max_count': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy.header_max_count',
                              'email.policy.EmailPolicy.header_source_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy.header_source_parse',
                              'email.policy.EmailPolicy.header_store_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.EmailPolicy.header_store_parse',
                              'email.policy.Policy': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy',
                              'email.policy.Policy.clone': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.clone',
                              'email.policy.Policy.fold': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.fold',
                              'email.policy.Policy.fold_binary': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.fold_binary',
                              'email.policy.Policy.handle_defect': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.handle_defect',
                              'email.policy.Policy.header_fetch_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.header_fetch_parse',
                              'email.policy.Policy.header_max_count': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.header_max_count',
                              'email.policy.Policy.header_source_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.header_source_parse',
                              'email.policy.Policy.header_store_parse': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.header_store_parse',
                              'email.policy.Policy.register_defect': 'https://docs.python.org/3/library/email.policy.html#email.policy.Policy.register_defect'},
            'email.utils': { 'email.utils.collapse_rfc2231_value': 'https://docs.python.org/3/library/email.utils.html#email.utils.collapse_rfc2231_value',
                             'email.utils.decode_params': 'https://docs.python.org/3/library/email.utils.html#email.utils.decode_params',
                             'email.utils.decode_rfc2231': 'https://docs.python.org/3/library/email.utils.html#email.utils.decode_rfc2231',
                             'email.utils.encode_rfc2231': 'https://docs.python.org/3/library/email.utils.html#email.utils.encode_rfc2231',
                             'email.utils.format_datetime': 'https://docs.python.org/3/library/email.utils.html#email.utils.format_datetime',
                             'email.utils.formataddr': 'https://docs.python.org/3/library/email.utils.html#email.utils.formataddr',
                             'email.utils.formatdate': 'https://docs.python.org/3/library/email.utils.html#email.utils.formatdate',
                             'email.utils.getaddresses': 'https://docs.python.org/3/library/email.utils.html#email.utils.getaddresses',
                             'email.utils.localtime': 'https://docs.python.org/3/library/email.utils.html#email.utils.localtime',
                             'email.utils.make_msgid': 'https://docs.python.org/3/library/email.utils.html#email.utils.make_msgid',
                             'email.utils.mktime_tz': 'https://docs.python.org/3/library/email.utils.html#email.utils.mktime_tz',
                             'email.utils.parseaddr': 'https://docs.python.org/3/library/email.utils.html#email.utils.parseaddr',
                             'email.utils.parsedate': 'https://docs.python.org/3/library/email.utils.html#email.utils.parsedate',
                             'email.utils.parsedate_to_datetime': 'https://docs.python.org/3/library/email.utils.html#email.utils.parsedate_to_datetime',
                             'email.utils.parsedate_tz': 'https://docs.python.org/3/library/email.utils.html#email.utils.parsedate_tz',
                             'email.utils.quote': 'https://docs.python.org/3/library/email.utils.html#email.utils.quote',
                             'email.utils.unquote': 'https://docs.python.org/3/library/email.utils.html#email.utils.unquote'},
            'encodings': { 'encodings.idna': 'https://docs.python.org/3/library/codecs.html#module-encodings.idna',
                           'encodings.mbcs': 'https://docs.python.org/3/library/codecs.html#module-encodings.mbcs',
                           'encodings.utf_8_sig': 'https://docs.python.org/3/library/codecs.html#module-encodings.utf_8_sig'},
            'encodings.idna': { 'encodings.idna.ToASCII': 'https://docs.python.org/3/library/codecs.html#encodings.idna.ToASCII',
                                'encodings.idna.ToUnicode': 'https://docs.python.org/3/library/codecs.html#encodings.idna.ToUnicode',
                                'encodings.idna.nameprep': 'https://docs.python.org/3/library/codecs.html#encodings.idna.nameprep'},
            'ensurepip': { 'ensurepip.bootstrap': 'https://docs.python.org/3/library/ensurepip.html#ensurepip.bootstrap',
                           'ensurepip.version': 'https://docs.python.org/3/library/ensurepip.html#ensurepip.version'},
            'enum': { 'enum.Enum': 'https://docs.python.org/3/library/enum.html#enum.Enum',
                      'enum.Flag': 'https://docs.python.org/3/library/enum.html#enum.Flag',
                      'enum.IntEnum': 'https://docs.python.org/3/library/enum.html#enum.IntEnum',
                      'enum.IntFlag': 'https://docs.python.org/3/library/enum.html#enum.IntFlag',
                      'enum.auto': 'https://docs.python.org/3/library/enum.html#enum.auto',
                      'enum.unique': 'https://docs.python.org/3/library/enum.html#enum.unique'},
            'faulthandler': { 'faulthandler.cancel_dump_traceback_later': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.cancel_dump_traceback_later',
                              'faulthandler.disable': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.disable',
                              'faulthandler.dump_traceback': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.dump_traceback',
                              'faulthandler.dump_traceback_later': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.dump_traceback_later',
                              'faulthandler.enable': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.enable',
                              'faulthandler.is_enabled': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.is_enabled',
                              'faulthandler.register': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.register',
                              'faulthandler.unregister': 'https://docs.python.org/3/library/faulthandler.html#faulthandler.unregister'},
            'fcntl': { 'fcntl.fcntl': 'https://docs.python.org/3/library/fcntl.html#fcntl.fcntl',
                       'fcntl.flock': 'https://docs.python.org/3/library/fcntl.html#fcntl.flock',
                       'fcntl.ioctl': 'https://docs.python.org/3/library/fcntl.html#fcntl.ioctl',
                       'fcntl.lockf': 'https://docs.python.org/3/library/fcntl.html#fcntl.lockf'},
            'filecmp': { 'filecmp.clear_cache': 'https://docs.python.org/3/library/filecmp.html#filecmp.clear_cache',
                         'filecmp.cmp': 'https://docs.python.org/3/library/filecmp.html#filecmp.cmp',
                         'filecmp.cmpfiles': 'https://docs.python.org/3/library/filecmp.html#filecmp.cmpfiles',
                         'filecmp.dircmp': 'https://docs.python.org/3/library/filecmp.html#filecmp.dircmp',
                         'filecmp.dircmp.report': 'https://docs.python.org/3/library/filecmp.html#filecmp.dircmp.report',
                         'filecmp.dircmp.report_full_closure': 'https://docs.python.org/3/library/filecmp.html#filecmp.dircmp.report_full_closure',
                         'filecmp.dircmp.report_partial_closure': 'https://docs.python.org/3/library/filecmp.html#filecmp.dircmp.report_partial_closure'},
            'fileinput': { 'fileinput.FileInput': 'https://docs.python.org/3/library/fileinput.html#fileinput.FileInput',
                           'fileinput.close': 'https://docs.python.org/3/library/fileinput.html#fileinput.close',
                           'fileinput.filelineno': 'https://docs.python.org/3/library/fileinput.html#fileinput.filelineno',
                           'fileinput.filename': 'https://docs.python.org/3/library/fileinput.html#fileinput.filename',
                           'fileinput.fileno': 'https://docs.python.org/3/library/fileinput.html#fileinput.fileno',
                           'fileinput.hook_compressed': 'https://docs.python.org/3/library/fileinput.html#fileinput.hook_compressed',
                           'fileinput.hook_encoded': 'https://docs.python.org/3/library/fileinput.html#fileinput.hook_encoded',
                           'fileinput.input': 'https://docs.python.org/3/library/fileinput.html#fileinput.input',
                           'fileinput.isfirstline': 'https://docs.python.org/3/library/fileinput.html#fileinput.isfirstline',
                           'fileinput.isstdin': 'https://docs.python.org/3/library/fileinput.html#fileinput.isstdin',
                           'fileinput.lineno': 'https://docs.python.org/3/library/fileinput.html#fileinput.lineno',
                           'fileinput.nextfile': 'https://docs.python.org/3/library/fileinput.html#fileinput.nextfile'},
            'fnmatch': { 'fnmatch.filter': 'https://docs.python.org/3/library/fnmatch.html#fnmatch.filter',
                         'fnmatch.fnmatch': 'https://docs.python.org/3/library/fnmatch.html#fnmatch.fnmatch',
                         'fnmatch.fnmatchcase': 'https://docs.python.org/3/library/fnmatch.html#fnmatch.fnmatchcase',
                         'fnmatch.translate': 'https://docs.python.org/3/library/fnmatch.html#fnmatch.translate'},
            'fractions': { 'fractions.Fraction': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction',
                           'fractions.Fraction.__ceil__': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.__ceil__',
                           'fractions.Fraction.__floor__': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.__floor__',
                           'fractions.Fraction.__round__': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.__round__',
                           'fractions.Fraction.as_integer_ratio': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.as_integer_ratio',
                           'fractions.Fraction.from_decimal': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.from_decimal',
                           'fractions.Fraction.from_float': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.from_float',
                           'fractions.Fraction.limit_denominator': 'https://docs.python.org/3/library/fractions.html#fractions.Fraction.limit_denominator'},
            'ftplib': { 'ftplib.FTP': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP',
                        'ftplib.FTP.abort': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.abort',
                        'ftplib.FTP.close': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.close',
                        'ftplib.FTP.connect': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.connect',
                        'ftplib.FTP.cwd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.cwd',
                        'ftplib.FTP.delete': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.delete',
                        'ftplib.FTP.dir': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.dir',
                        'ftplib.FTP.getwelcome': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.getwelcome',
                        'ftplib.FTP.login': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.login',
                        'ftplib.FTP.mkd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.mkd',
                        'ftplib.FTP.mlsd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.mlsd',
                        'ftplib.FTP.nlst': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.nlst',
                        'ftplib.FTP.ntransfercmd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.ntransfercmd',
                        'ftplib.FTP.pwd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.pwd',
                        'ftplib.FTP.quit': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.quit',
                        'ftplib.FTP.rename': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.rename',
                        'ftplib.FTP.retrbinary': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.retrbinary',
                        'ftplib.FTP.retrlines': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.retrlines',
                        'ftplib.FTP.rmd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.rmd',
                        'ftplib.FTP.sendcmd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.sendcmd',
                        'ftplib.FTP.set_debuglevel': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.set_debuglevel',
                        'ftplib.FTP.set_pasv': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.set_pasv',
                        'ftplib.FTP.size': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.size',
                        'ftplib.FTP.storbinary': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.storbinary',
                        'ftplib.FTP.storlines': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.storlines',
                        'ftplib.FTP.transfercmd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.transfercmd',
                        'ftplib.FTP.voidcmd': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP.voidcmd',
                        'ftplib.FTP_TLS': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP_TLS',
                        'ftplib.FTP_TLS.auth': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP_TLS.auth',
                        'ftplib.FTP_TLS.ccc': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP_TLS.ccc',
                        'ftplib.FTP_TLS.prot_c': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP_TLS.prot_c',
                        'ftplib.FTP_TLS.prot_p': 'https://docs.python.org/3/library/ftplib.html#ftplib.FTP_TLS.prot_p'},
            'functools': { 'functools.cache': 'https://docs.python.org/3/library/functools.html#functools.cache',
                           'functools.cached_property': 'https://docs.python.org/3/library/functools.html#functools.cached_property',
                           'functools.cmp_to_key': 'https://docs.python.org/3/library/functools.html#functools.cmp_to_key',
                           'functools.lru_cache': 'https://docs.python.org/3/library/functools.html#functools.lru_cache',
                           'functools.partial': 'https://docs.python.org/3/library/functools.html#functools.partial',
                           'functools.partialmethod': 'https://docs.python.org/3/library/functools.html#functools.partialmethod',
                           'functools.reduce': 'https://docs.python.org/3/library/functools.html#functools.reduce',
                           'functools.singledispatch': 'https://docs.python.org/3/library/functools.html#functools.singledispatch',
                           'functools.singledispatchmethod': 'https://docs.python.org/3/library/functools.html#functools.singledispatchmethod',
                           'functools.total_ordering': 'https://docs.python.org/3/library/functools.html#functools.total_ordering',
                           'functools.update_wrapper': 'https://docs.python.org/3/library/functools.html#functools.update_wrapper',
                           'functools.wraps': 'https://docs.python.org/3/library/functools.html#functools.wraps'},
            'gc': { 'gc.collect': 'https://docs.python.org/3/library/gc.html#gc.collect',
                    'gc.disable': 'https://docs.python.org/3/library/gc.html#gc.disable',
                    'gc.enable': 'https://docs.python.org/3/library/gc.html#gc.enable',
                    'gc.freeze': 'https://docs.python.org/3/library/gc.html#gc.freeze',
                    'gc.get_count': 'https://docs.python.org/3/library/gc.html#gc.get_count',
                    'gc.get_debug': 'https://docs.python.org/3/library/gc.html#gc.get_debug',
                    'gc.get_freeze_count': 'https://docs.python.org/3/library/gc.html#gc.get_freeze_count',
                    'gc.get_objects': 'https://docs.python.org/3/library/gc.html#gc.get_objects',
                    'gc.get_referents': 'https://docs.python.org/3/library/gc.html#gc.get_referents',
                    'gc.get_referrers': 'https://docs.python.org/3/library/gc.html#gc.get_referrers',
                    'gc.get_stats': 'https://docs.python.org/3/library/gc.html#gc.get_stats',
                    'gc.get_threshold': 'https://docs.python.org/3/library/gc.html#gc.get_threshold',
                    'gc.is_finalized': 'https://docs.python.org/3/library/gc.html#gc.is_finalized',
                    'gc.is_tracked': 'https://docs.python.org/3/library/gc.html#gc.is_tracked',
                    'gc.isenabled': 'https://docs.python.org/3/library/gc.html#gc.isenabled',
                    'gc.set_debug': 'https://docs.python.org/3/library/gc.html#gc.set_debug',
                    'gc.set_threshold': 'https://docs.python.org/3/library/gc.html#gc.set_threshold',
                    'gc.unfreeze': 'https://docs.python.org/3/library/gc.html#gc.unfreeze'},
            'getopt': { 'getopt.getopt': 'https://docs.python.org/3/library/getopt.html#getopt.getopt',
                        'getopt.gnu_getopt': 'https://docs.python.org/3/library/getopt.html#getopt.gnu_getopt'},
            'getpass': { 'getpass.getpass': 'https://docs.python.org/3/library/getpass.html#getpass.getpass',
                         'getpass.getuser': 'https://docs.python.org/3/library/getpass.html#getpass.getuser'},
            'gettext': { 'gettext.GNUTranslations': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations',
                         'gettext.GNUTranslations.gettext': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations.gettext',
                         'gettext.GNUTranslations.lgettext': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations.lgettext',
                         'gettext.GNUTranslations.lngettext': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations.lngettext',
                         'gettext.GNUTranslations.ngettext': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations.ngettext',
                         'gettext.GNUTranslations.npgettext': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations.npgettext',
                         'gettext.GNUTranslations.pgettext': 'https://docs.python.org/3/library/gettext.html#gettext.GNUTranslations.pgettext',
                         'gettext.NullTranslations': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations',
                         'gettext.NullTranslations._parse': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations._parse',
                         'gettext.NullTranslations.add_fallback': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.add_fallback',
                         'gettext.NullTranslations.charset': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.charset',
                         'gettext.NullTranslations.gettext': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.gettext',
                         'gettext.NullTranslations.info': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.info',
                         'gettext.NullTranslations.install': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.install',
                         'gettext.NullTranslations.lgettext': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.lgettext',
                         'gettext.NullTranslations.lngettext': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.lngettext',
                         'gettext.NullTranslations.ngettext': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.ngettext',
                         'gettext.NullTranslations.npgettext': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.npgettext',
                         'gettext.NullTranslations.output_charset': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.output_charset',
                         'gettext.NullTranslations.pgettext': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.pgettext',
                         'gettext.NullTranslations.set_output_charset': 'https://docs.python.org/3/library/gettext.html#gettext.NullTranslations.set_output_charset',
                         'gettext.bind_textdomain_codeset': 'https://docs.python.org/3/library/gettext.html#gettext.bind_textdomain_codeset',
                         'gettext.bindtextdomain': 'https://docs.python.org/3/library/gettext.html#gettext.bindtextdomain',
                         'gettext.dgettext': 'https://docs.python.org/3/library/gettext.html#gettext.dgettext',
                         'gettext.dngettext': 'https://docs.python.org/3/library/gettext.html#gettext.dngettext',
                         'gettext.dnpgettext': 'https://docs.python.org/3/library/gettext.html#gettext.dnpgettext',
                         'gettext.dpgettext': 'https://docs.python.org/3/library/gettext.html#gettext.dpgettext',
                         'gettext.find': 'https://docs.python.org/3/library/gettext.html#gettext.find',
                         'gettext.gettext': 'https://docs.python.org/3/library/gettext.html#gettext.gettext',
                         'gettext.install': 'https://docs.python.org/3/library/gettext.html#gettext.install',
                         'gettext.ldgettext': 'https://docs.python.org/3/library/gettext.html#gettext.ldgettext',
                         'gettext.ldngettext': 'https://docs.python.org/3/library/gettext.html#gettext.ldngettext',
                         'gettext.lgettext': 'https://docs.python.org/3/library/gettext.html#gettext.lgettext',
                         'gettext.lngettext': 'https://docs.python.org/3/library/gettext.html#gettext.lngettext',
                         'gettext.ngettext': 'https://docs.python.org/3/library/gettext.html#gettext.ngettext',
                         'gettext.npgettext': 'https://docs.python.org/3/library/gettext.html#gettext.npgettext',
                         'gettext.pgettext': 'https://docs.python.org/3/library/gettext.html#gettext.pgettext',
                         'gettext.textdomain': 'https://docs.python.org/3/library/gettext.html#gettext.textdomain',
                         'gettext.translation': 'https://docs.python.org/3/library/gettext.html#gettext.translation'},
            'glob': { 'glob.escape': 'https://docs.python.org/3/library/glob.html#glob.escape',
                      'glob.glob': 'https://docs.python.org/3/library/glob.html#glob.glob',
                      'glob.iglob': 'https://docs.python.org/3/library/glob.html#glob.iglob'},
            'graphlib': { 'graphlib.TopologicalSorter': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter',
                          'graphlib.TopologicalSorter.add': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter.add',
                          'graphlib.TopologicalSorter.done': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter.done',
                          'graphlib.TopologicalSorter.get_ready': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter.get_ready',
                          'graphlib.TopologicalSorter.is_active': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter.is_active',
                          'graphlib.TopologicalSorter.prepare': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter.prepare',
                          'graphlib.TopologicalSorter.static_order': 'https://docs.python.org/3/library/graphlib.html#graphlib.TopologicalSorter.static_order'},
            'grp': { 'grp.getgrall': 'https://docs.python.org/3/library/grp.html#grp.getgrall',
                     'grp.getgrgid': 'https://docs.python.org/3/library/grp.html#grp.getgrgid',
                     'grp.getgrnam': 'https://docs.python.org/3/library/grp.html#grp.getgrnam'},
            'gzip': { 'gzip.GzipFile': 'https://docs.python.org/3/library/gzip.html#gzip.GzipFile',
                      'gzip.GzipFile.peek': 'https://docs.python.org/3/library/gzip.html#gzip.GzipFile.peek',
                      'gzip.compress': 'https://docs.python.org/3/library/gzip.html#gzip.compress',
                      'gzip.decompress': 'https://docs.python.org/3/library/gzip.html#gzip.decompress',
                      'gzip.open': 'https://docs.python.org/3/library/gzip.html#gzip.open'},
            'hashlib': { 'hashlib.blake2b': 'https://docs.python.org/3/library/hashlib.html#hashlib.blake2b',
                         'hashlib.blake2s': 'https://docs.python.org/3/library/hashlib.html#hashlib.blake2s',
                         'hashlib.hash.copy': 'https://docs.python.org/3/library/hashlib.html#hashlib.hash.copy',
                         'hashlib.hash.digest': 'https://docs.python.org/3/library/hashlib.html#hashlib.hash.digest',
                         'hashlib.hash.hexdigest': 'https://docs.python.org/3/library/hashlib.html#hashlib.hash.hexdigest',
                         'hashlib.hash.update': 'https://docs.python.org/3/library/hashlib.html#hashlib.hash.update',
                         'hashlib.new': 'https://docs.python.org/3/library/hashlib.html#hashlib.new',
                         'hashlib.pbkdf2_hmac': 'https://docs.python.org/3/library/hashlib.html#hashlib.pbkdf2_hmac',
                         'hashlib.scrypt': 'https://docs.python.org/3/library/hashlib.html#hashlib.scrypt',
                         'hashlib.shake.digest': 'https://docs.python.org/3/library/hashlib.html#hashlib.shake.digest',
                         'hashlib.shake.hexdigest': 'https://docs.python.org/3/library/hashlib.html#hashlib.shake.hexdigest'},
            'heapq': { 'heapq.heapify': 'https://docs.python.org/3/library/heapq.html#heapq.heapify',
                       'heapq.heappop': 'https://docs.python.org/3/library/heapq.html#heapq.heappop',
                       'heapq.heappush': 'https://docs.python.org/3/library/heapq.html#heapq.heappush',
                       'heapq.heappushpop': 'https://docs.python.org/3/library/heapq.html#heapq.heappushpop',
                       'heapq.heapreplace': 'https://docs.python.org/3/library/heapq.html#heapq.heapreplace',
                       'heapq.merge': 'https://docs.python.org/3/library/heapq.html#heapq.merge',
                       'heapq.nlargest': 'https://docs.python.org/3/library/heapq.html#heapq.nlargest',
                       'heapq.nsmallest': 'https://docs.python.org/3/library/heapq.html#heapq.nsmallest'},
            'hmac': { 'hmac.HMAC.copy': 'https://docs.python.org/3/library/hmac.html#hmac.HMAC.copy',
                      'hmac.HMAC.digest': 'https://docs.python.org/3/library/hmac.html#hmac.HMAC.digest',
                      'hmac.HMAC.hexdigest': 'https://docs.python.org/3/library/hmac.html#hmac.HMAC.hexdigest',
                      'hmac.HMAC.update': 'https://docs.python.org/3/library/hmac.html#hmac.HMAC.update',
                      'hmac.compare_digest': 'https://docs.python.org/3/library/hmac.html#hmac.compare_digest',
                      'hmac.digest': 'https://docs.python.org/3/library/hmac.html#hmac.digest',
                      'hmac.new': 'https://docs.python.org/3/library/hmac.html#hmac.new'},
            'html': { 'html.entities': 'https://docs.python.org/3/library/html.entities.html#module-html.entities',
                      'html.escape': 'https://docs.python.org/3/library/html.html#html.escape',
                      'html.parser': 'https://docs.python.org/3/library/html.parser.html#module-html.parser',
                      'html.unescape': 'https://docs.python.org/3/library/html.html#html.unescape'},
            'html.parser': { 'html.parser.HTMLParser': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser',
                             'html.parser.HTMLParser.close': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.close',
                             'html.parser.HTMLParser.feed': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.feed',
                             'html.parser.HTMLParser.get_starttag_text': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.get_starttag_text',
                             'html.parser.HTMLParser.getpos': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.getpos',
                             'html.parser.HTMLParser.handle_charref': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_charref',
                             'html.parser.HTMLParser.handle_comment': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_comment',
                             'html.parser.HTMLParser.handle_data': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_data',
                             'html.parser.HTMLParser.handle_decl': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_decl',
                             'html.parser.HTMLParser.handle_endtag': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_endtag',
                             'html.parser.HTMLParser.handle_entityref': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_entityref',
                             'html.parser.HTMLParser.handle_pi': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_pi',
                             'html.parser.HTMLParser.handle_startendtag': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_startendtag',
                             'html.parser.HTMLParser.handle_starttag': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.handle_starttag',
                             'html.parser.HTMLParser.reset': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.reset',
                             'html.parser.HTMLParser.unknown_decl': 'https://docs.python.org/3/library/html.parser.html#html.parser.HTMLParser.unknown_decl'},
            'http': { 'http.HTTPStatus': 'https://docs.python.org/3/library/http.html#http.HTTPStatus',
                      'http.client': 'https://docs.python.org/3/library/http.client.html#module-http.client',
                      'http.cookiejar': 'https://docs.python.org/3/library/http.cookiejar.html#module-http.cookiejar',
                      'http.cookies': 'https://docs.python.org/3/library/http.cookies.html#module-http.cookies',
                      'http.server': 'https://docs.python.org/3/library/http.server.html#module-http.server'},
            'http.client': { 'http.client.HTTPConnection': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection',
                             'http.client.HTTPConnection.close': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.close',
                             'http.client.HTTPConnection.connect': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.connect',
                             'http.client.HTTPConnection.endheaders': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.endheaders',
                             'http.client.HTTPConnection.getresponse': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.getresponse',
                             'http.client.HTTPConnection.putheader': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.putheader',
                             'http.client.HTTPConnection.putrequest': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.putrequest',
                             'http.client.HTTPConnection.request': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.request',
                             'http.client.HTTPConnection.send': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.send',
                             'http.client.HTTPConnection.set_debuglevel': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.set_debuglevel',
                             'http.client.HTTPConnection.set_tunnel': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPConnection.set_tunnel',
                             'http.client.HTTPResponse': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse',
                             'http.client.HTTPResponse.fileno': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.fileno',
                             'http.client.HTTPResponse.getheader': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.getheader',
                             'http.client.HTTPResponse.getheaders': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.getheaders',
                             'http.client.HTTPResponse.getstatus': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.getstatus',
                             'http.client.HTTPResponse.geturl': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.geturl',
                             'http.client.HTTPResponse.info': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.info',
                             'http.client.HTTPResponse.read': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.read',
                             'http.client.HTTPResponse.readinto': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPResponse.readinto',
                             'http.client.HTTPSConnection': 'https://docs.python.org/3/library/http.client.html#http.client.HTTPSConnection',
                             'http.client.parse_headers': 'https://docs.python.org/3/library/http.client.html#http.client.parse_headers'},
            'http.cookiejar': { 'http.cookiejar.Cookie': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.Cookie',
                                'http.cookiejar.Cookie.get_nonstandard_attr': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.Cookie.get_nonstandard_attr',
                                'http.cookiejar.Cookie.has_nonstandard_attr': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.Cookie.has_nonstandard_attr',
                                'http.cookiejar.Cookie.is_expired': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.Cookie.is_expired',
                                'http.cookiejar.Cookie.set_nonstandard_attr': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.Cookie.set_nonstandard_attr',
                                'http.cookiejar.CookieJar': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar',
                                'http.cookiejar.CookieJar.add_cookie_header': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.add_cookie_header',
                                'http.cookiejar.CookieJar.clear': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.clear',
                                'http.cookiejar.CookieJar.clear_session_cookies': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.clear_session_cookies',
                                'http.cookiejar.CookieJar.extract_cookies': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.extract_cookies',
                                'http.cookiejar.CookieJar.make_cookies': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.make_cookies',
                                'http.cookiejar.CookieJar.set_cookie': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.set_cookie',
                                'http.cookiejar.CookieJar.set_cookie_if_ok': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.set_cookie_if_ok',
                                'http.cookiejar.CookieJar.set_policy': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookieJar.set_policy',
                                'http.cookiejar.CookiePolicy': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookiePolicy',
                                'http.cookiejar.CookiePolicy.domain_return_ok': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookiePolicy.domain_return_ok',
                                'http.cookiejar.CookiePolicy.path_return_ok': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookiePolicy.path_return_ok',
                                'http.cookiejar.CookiePolicy.return_ok': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookiePolicy.return_ok',
                                'http.cookiejar.CookiePolicy.set_ok': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.CookiePolicy.set_ok',
                                'http.cookiejar.DefaultCookiePolicy': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy',
                                'http.cookiejar.DefaultCookiePolicy.allowed_domains': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy.allowed_domains',
                                'http.cookiejar.DefaultCookiePolicy.blocked_domains': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy.blocked_domains',
                                'http.cookiejar.DefaultCookiePolicy.is_blocked': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy.is_blocked',
                                'http.cookiejar.DefaultCookiePolicy.is_not_allowed': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy.is_not_allowed',
                                'http.cookiejar.DefaultCookiePolicy.set_allowed_domains': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy.set_allowed_domains',
                                'http.cookiejar.DefaultCookiePolicy.set_blocked_domains': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.DefaultCookiePolicy.set_blocked_domains',
                                'http.cookiejar.FileCookieJar': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.FileCookieJar',
                                'http.cookiejar.FileCookieJar.load': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.FileCookieJar.load',
                                'http.cookiejar.FileCookieJar.revert': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.FileCookieJar.revert',
                                'http.cookiejar.FileCookieJar.save': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.FileCookieJar.save',
                                'http.cookiejar.LWPCookieJar': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.LWPCookieJar',
                                'http.cookiejar.MozillaCookieJar': 'https://docs.python.org/3/library/http.cookiejar.html#http.cookiejar.MozillaCookieJar'},
            'http.cookies': { 'http.cookies.BaseCookie': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.BaseCookie',
                              'http.cookies.BaseCookie.js_output': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.BaseCookie.js_output',
                              'http.cookies.BaseCookie.load': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.BaseCookie.load',
                              'http.cookies.BaseCookie.output': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.BaseCookie.output',
                              'http.cookies.BaseCookie.value_decode': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.BaseCookie.value_decode',
                              'http.cookies.BaseCookie.value_encode': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.BaseCookie.value_encode',
                              'http.cookies.Morsel': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel',
                              'http.cookies.Morsel.OutputString': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.OutputString',
                              'http.cookies.Morsel.copy': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.copy',
                              'http.cookies.Morsel.isReservedKey': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.isReservedKey',
                              'http.cookies.Morsel.js_output': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.js_output',
                              'http.cookies.Morsel.output': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.output',
                              'http.cookies.Morsel.set': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.set',
                              'http.cookies.Morsel.setdefault': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.setdefault',
                              'http.cookies.Morsel.update': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.Morsel.update',
                              'http.cookies.SimpleCookie': 'https://docs.python.org/3/library/http.cookies.html#http.cookies.SimpleCookie'},
            'http.server': { 'http.server.BaseHTTPRequestHandler': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler',
                             'http.server.BaseHTTPRequestHandler.address_string': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.address_string',
                             'http.server.BaseHTTPRequestHandler.date_time_string': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.date_time_string',
                             'http.server.BaseHTTPRequestHandler.end_headers': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.end_headers',
                             'http.server.BaseHTTPRequestHandler.flush_headers': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.flush_headers',
                             'http.server.BaseHTTPRequestHandler.handle': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.handle',
                             'http.server.BaseHTTPRequestHandler.handle_expect_100': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.handle_expect_100',
                             'http.server.BaseHTTPRequestHandler.handle_one_request': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.handle_one_request',
                             'http.server.BaseHTTPRequestHandler.log_date_time_string': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.log_date_time_string',
                             'http.server.BaseHTTPRequestHandler.log_error': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.log_error',
                             'http.server.BaseHTTPRequestHandler.log_message': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.log_message',
                             'http.server.BaseHTTPRequestHandler.log_request': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.log_request',
                             'http.server.BaseHTTPRequestHandler.send_error': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.send_error',
                             'http.server.BaseHTTPRequestHandler.send_header': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.send_header',
                             'http.server.BaseHTTPRequestHandler.send_response': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.send_response',
                             'http.server.BaseHTTPRequestHandler.send_response_only': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.send_response_only',
                             'http.server.BaseHTTPRequestHandler.version_string': 'https://docs.python.org/3/library/http.server.html#http.server.BaseHTTPRequestHandler.version_string',
                             'http.server.CGIHTTPRequestHandler': 'https://docs.python.org/3/library/http.server.html#http.server.CGIHTTPRequestHandler',
                             'http.server.CGIHTTPRequestHandler.do_POST': 'https://docs.python.org/3/library/http.server.html#http.server.CGIHTTPRequestHandler.do_POST',
                             'http.server.HTTPServer': 'https://docs.python.org/3/library/http.server.html#http.server.HTTPServer',
                             'http.server.SimpleHTTPRequestHandler': 'https://docs.python.org/3/library/http.server.html#http.server.SimpleHTTPRequestHandler',
                             'http.server.SimpleHTTPRequestHandler.do_GET': 'https://docs.python.org/3/library/http.server.html#http.server.SimpleHTTPRequestHandler.do_GET',
                             'http.server.SimpleHTTPRequestHandler.do_HEAD': 'https://docs.python.org/3/library/http.server.html#http.server.SimpleHTTPRequestHandler.do_HEAD',
                             'http.server.ThreadingHTTPServer': 'https://docs.python.org/3/library/http.server.html#http.server.ThreadingHTTPServer'},
            'imaplib': { 'imaplib.IMAP4': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4',
                         'imaplib.IMAP4.append': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.append',
                         'imaplib.IMAP4.authenticate': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.authenticate',
                         'imaplib.IMAP4.check': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.check',
                         'imaplib.IMAP4.close': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.close',
                         'imaplib.IMAP4.copy': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.copy',
                         'imaplib.IMAP4.create': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.create',
                         'imaplib.IMAP4.delete': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.delete',
                         'imaplib.IMAP4.deleteacl': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.deleteacl',
                         'imaplib.IMAP4.enable': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.enable',
                         'imaplib.IMAP4.expunge': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.expunge',
                         'imaplib.IMAP4.fetch': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.fetch',
                         'imaplib.IMAP4.getacl': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.getacl',
                         'imaplib.IMAP4.getannotation': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.getannotation',
                         'imaplib.IMAP4.getquota': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.getquota',
                         'imaplib.IMAP4.getquotaroot': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.getquotaroot',
                         'imaplib.IMAP4.list': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.list',
                         'imaplib.IMAP4.login': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.login',
                         'imaplib.IMAP4.login_cram_md5': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.login_cram_md5',
                         'imaplib.IMAP4.logout': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.logout',
                         'imaplib.IMAP4.lsub': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.lsub',
                         'imaplib.IMAP4.myrights': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.myrights',
                         'imaplib.IMAP4.namespace': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.namespace',
                         'imaplib.IMAP4.noop': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.noop',
                         'imaplib.IMAP4.open': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.open',
                         'imaplib.IMAP4.partial': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.partial',
                         'imaplib.IMAP4.proxyauth': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.proxyauth',
                         'imaplib.IMAP4.read': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.read',
                         'imaplib.IMAP4.readline': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.readline',
                         'imaplib.IMAP4.recent': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.recent',
                         'imaplib.IMAP4.rename': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.rename',
                         'imaplib.IMAP4.response': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.response',
                         'imaplib.IMAP4.search': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.search',
                         'imaplib.IMAP4.select': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.select',
                         'imaplib.IMAP4.send': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.send',
                         'imaplib.IMAP4.setacl': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.setacl',
                         'imaplib.IMAP4.setannotation': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.setannotation',
                         'imaplib.IMAP4.setquota': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.setquota',
                         'imaplib.IMAP4.shutdown': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.shutdown',
                         'imaplib.IMAP4.socket': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.socket',
                         'imaplib.IMAP4.sort': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.sort',
                         'imaplib.IMAP4.starttls': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.starttls',
                         'imaplib.IMAP4.status': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.status',
                         'imaplib.IMAP4.store': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.store',
                         'imaplib.IMAP4.subscribe': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.subscribe',
                         'imaplib.IMAP4.thread': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.thread',
                         'imaplib.IMAP4.uid': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.uid',
                         'imaplib.IMAP4.unselect': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.unselect',
                         'imaplib.IMAP4.unsubscribe': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.unsubscribe',
                         'imaplib.IMAP4.xatom': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4.xatom',
                         'imaplib.IMAP4_SSL': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4_SSL',
                         'imaplib.IMAP4_stream': 'https://docs.python.org/3/library/imaplib.html#imaplib.IMAP4_stream',
                         'imaplib.Int2AP': 'https://docs.python.org/3/library/imaplib.html#imaplib.Int2AP',
                         'imaplib.Internaldate2tuple': 'https://docs.python.org/3/library/imaplib.html#imaplib.Internaldate2tuple',
                         'imaplib.ParseFlags': 'https://docs.python.org/3/library/imaplib.html#imaplib.ParseFlags',
                         'imaplib.Time2Internaldate': 'https://docs.python.org/3/library/imaplib.html#imaplib.Time2Internaldate'},
            'imghdr': {'imghdr.what': 'https://docs.python.org/3/library/imghdr.html#imghdr.what'},
            'imp': { 'imp.NullImporter': 'https://docs.python.org/3/library/imp.html#imp.NullImporter',
                     'imp.NullImporter.find_module': 'https://docs.python.org/3/library/imp.html#imp.NullImporter.find_module',
                     'imp.acquire_lock': 'https://docs.python.org/3/library/imp.html#imp.acquire_lock',
                     'imp.cache_from_source': 'https://docs.python.org/3/library/imp.html#imp.cache_from_source',
                     'imp.find_module': 'https://docs.python.org/3/library/imp.html#imp.find_module',
                     'imp.get_magic': 'https://docs.python.org/3/library/imp.html#imp.get_magic',
                     'imp.get_suffixes': 'https://docs.python.org/3/library/imp.html#imp.get_suffixes',
                     'imp.get_tag': 'https://docs.python.org/3/library/imp.html#imp.get_tag',
                     'imp.load_module': 'https://docs.python.org/3/library/imp.html#imp.load_module',
                     'imp.lock_held': 'https://docs.python.org/3/library/imp.html#imp.lock_held',
                     'imp.new_module': 'https://docs.python.org/3/library/imp.html#imp.new_module',
                     'imp.release_lock': 'https://docs.python.org/3/library/imp.html#imp.release_lock',
                     'imp.reload': 'https://docs.python.org/3/library/imp.html#imp.reload',
                     'imp.source_from_cache': 'https://docs.python.org/3/library/imp.html#imp.source_from_cache'},
            'importlib': { 'importlib.__import__': 'https://docs.python.org/3/library/importlib.html#importlib.__import__',
                           'importlib.abc': 'https://docs.python.org/3/library/importlib.html#module-importlib.abc',
                           'importlib.find_loader': 'https://docs.python.org/3/library/importlib.html#importlib.find_loader',
                           'importlib.import_module': 'https://docs.python.org/3/library/importlib.html#importlib.import_module',
                           'importlib.invalidate_caches': 'https://docs.python.org/3/library/importlib.html#importlib.invalidate_caches',
                           'importlib.machinery': 'https://docs.python.org/3/library/importlib.html#module-importlib.machinery',
                           'importlib.metadata': 'https://docs.python.org/3/library/importlib.metadata.html#module-importlib.metadata',
                           'importlib.reload': 'https://docs.python.org/3/library/importlib.html#importlib.reload',
                           'importlib.resources': 'https://docs.python.org/3/library/importlib.html#module-importlib.resources',
                           'importlib.util': 'https://docs.python.org/3/library/importlib.html#module-importlib.util'},
            'importlib.abc': { 'importlib.abc.ExecutionLoader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ExecutionLoader',
                               'importlib.abc.ExecutionLoader.get_filename': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ExecutionLoader.get_filename',
                               'importlib.abc.FileLoader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.FileLoader',
                               'importlib.abc.FileLoader.get_data': 'https://docs.python.org/3/library/importlib.html#importlib.abc.FileLoader.get_data',
                               'importlib.abc.FileLoader.get_filename': 'https://docs.python.org/3/library/importlib.html#importlib.abc.FileLoader.get_filename',
                               'importlib.abc.FileLoader.load_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.FileLoader.load_module',
                               'importlib.abc.Finder': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Finder',
                               'importlib.abc.Finder.find_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Finder.find_module',
                               'importlib.abc.InspectLoader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader',
                               'importlib.abc.InspectLoader.exec_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader.exec_module',
                               'importlib.abc.InspectLoader.get_code': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader.get_code',
                               'importlib.abc.InspectLoader.get_source': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader.get_source',
                               'importlib.abc.InspectLoader.is_package': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader.is_package',
                               'importlib.abc.InspectLoader.load_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader.load_module',
                               'importlib.abc.InspectLoader.source_to_code': 'https://docs.python.org/3/library/importlib.html#importlib.abc.InspectLoader.source_to_code',
                               'importlib.abc.Loader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Loader',
                               'importlib.abc.Loader.create_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Loader.create_module',
                               'importlib.abc.Loader.exec_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Loader.exec_module',
                               'importlib.abc.Loader.load_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Loader.load_module',
                               'importlib.abc.Loader.module_repr': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Loader.module_repr',
                               'importlib.abc.MetaPathFinder': 'https://docs.python.org/3/library/importlib.html#importlib.abc.MetaPathFinder',
                               'importlib.abc.MetaPathFinder.find_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.MetaPathFinder.find_module',
                               'importlib.abc.MetaPathFinder.find_spec': 'https://docs.python.org/3/library/importlib.html#importlib.abc.MetaPathFinder.find_spec',
                               'importlib.abc.MetaPathFinder.invalidate_caches': 'https://docs.python.org/3/library/importlib.html#importlib.abc.MetaPathFinder.invalidate_caches',
                               'importlib.abc.PathEntryFinder': 'https://docs.python.org/3/library/importlib.html#importlib.abc.PathEntryFinder',
                               'importlib.abc.PathEntryFinder.find_loader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.PathEntryFinder.find_loader',
                               'importlib.abc.PathEntryFinder.find_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.PathEntryFinder.find_module',
                               'importlib.abc.PathEntryFinder.find_spec': 'https://docs.python.org/3/library/importlib.html#importlib.abc.PathEntryFinder.find_spec',
                               'importlib.abc.PathEntryFinder.invalidate_caches': 'https://docs.python.org/3/library/importlib.html#importlib.abc.PathEntryFinder.invalidate_caches',
                               'importlib.abc.ResourceLoader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceLoader',
                               'importlib.abc.ResourceLoader.get_data': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceLoader.get_data',
                               'importlib.abc.ResourceReader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceReader',
                               'importlib.abc.ResourceReader.contents': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceReader.contents',
                               'importlib.abc.ResourceReader.is_resource': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceReader.is_resource',
                               'importlib.abc.ResourceReader.open_resource': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceReader.open_resource',
                               'importlib.abc.ResourceReader.resource_path': 'https://docs.python.org/3/library/importlib.html#importlib.abc.ResourceReader.resource_path',
                               'importlib.abc.SourceLoader': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader',
                               'importlib.abc.SourceLoader.exec_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.exec_module',
                               'importlib.abc.SourceLoader.get_code': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.get_code',
                               'importlib.abc.SourceLoader.get_source': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.get_source',
                               'importlib.abc.SourceLoader.is_package': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.is_package',
                               'importlib.abc.SourceLoader.load_module': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.load_module',
                               'importlib.abc.SourceLoader.path_mtime': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.path_mtime',
                               'importlib.abc.SourceLoader.path_stats': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.path_stats',
                               'importlib.abc.SourceLoader.set_data': 'https://docs.python.org/3/library/importlib.html#importlib.abc.SourceLoader.set_data',
                               'importlib.abc.Traversable': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable',
                               'importlib.abc.Traversable.__truediv__': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.__truediv__',
                               'importlib.abc.Traversable.is_dir': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.is_dir',
                               'importlib.abc.Traversable.is_file': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.is_file',
                               'importlib.abc.Traversable.iterdir': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.iterdir',
                               'importlib.abc.Traversable.joinpath': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.joinpath',
                               'importlib.abc.Traversable.name': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.name',
                               'importlib.abc.Traversable.open': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.open',
                               'importlib.abc.Traversable.read_bytes': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.read_bytes',
                               'importlib.abc.Traversable.read_text': 'https://docs.python.org/3/library/importlib.html#importlib.abc.Traversable.read_text',
                               'importlib.abc.TraversableResources': 'https://docs.python.org/3/library/importlib.html#importlib.abc.TraversableResources'},
            'importlib.machinery': { 'importlib.machinery.BuiltinImporter': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.BuiltinImporter',
                                     'importlib.machinery.ExtensionFileLoader': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader',
                                     'importlib.machinery.ExtensionFileLoader.create_module': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader.create_module',
                                     'importlib.machinery.ExtensionFileLoader.exec_module': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader.exec_module',
                                     'importlib.machinery.ExtensionFileLoader.get_code': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader.get_code',
                                     'importlib.machinery.ExtensionFileLoader.get_filename': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader.get_filename',
                                     'importlib.machinery.ExtensionFileLoader.get_source': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader.get_source',
                                     'importlib.machinery.ExtensionFileLoader.is_package': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ExtensionFileLoader.is_package',
                                     'importlib.machinery.FileFinder': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.FileFinder',
                                     'importlib.machinery.FileFinder.find_loader': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.FileFinder.find_loader',
                                     'importlib.machinery.FileFinder.find_spec': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.FileFinder.find_spec',
                                     'importlib.machinery.FileFinder.invalidate_caches': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.FileFinder.invalidate_caches',
                                     'importlib.machinery.FileFinder.path_hook': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.FileFinder.path_hook',
                                     'importlib.machinery.FrozenImporter': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.FrozenImporter',
                                     'importlib.machinery.ModuleSpec': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.ModuleSpec',
                                     'importlib.machinery.PathFinder': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.PathFinder',
                                     'importlib.machinery.PathFinder.find_module': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.PathFinder.find_module',
                                     'importlib.machinery.PathFinder.find_spec': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.PathFinder.find_spec',
                                     'importlib.machinery.PathFinder.invalidate_caches': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.PathFinder.invalidate_caches',
                                     'importlib.machinery.SourceFileLoader': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourceFileLoader',
                                     'importlib.machinery.SourceFileLoader.is_package': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourceFileLoader.is_package',
                                     'importlib.machinery.SourceFileLoader.load_module': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourceFileLoader.load_module',
                                     'importlib.machinery.SourceFileLoader.path_stats': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourceFileLoader.path_stats',
                                     'importlib.machinery.SourceFileLoader.set_data': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourceFileLoader.set_data',
                                     'importlib.machinery.SourcelessFileLoader': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourcelessFileLoader',
                                     'importlib.machinery.SourcelessFileLoader.get_code': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourcelessFileLoader.get_code',
                                     'importlib.machinery.SourcelessFileLoader.get_source': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourcelessFileLoader.get_source',
                                     'importlib.machinery.SourcelessFileLoader.is_package': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourcelessFileLoader.is_package',
                                     'importlib.machinery.SourcelessFileLoader.load_module': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.SourcelessFileLoader.load_module',
                                     'importlib.machinery.WindowsRegistryFinder': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.WindowsRegistryFinder',
                                     'importlib.machinery.all_suffixes': 'https://docs.python.org/3/library/importlib.html#importlib.machinery.all_suffixes'},
            'importlib.resources': { 'importlib.resources.as_file': 'https://docs.python.org/3/library/importlib.html#importlib.resources.as_file',
                                     'importlib.resources.contents': 'https://docs.python.org/3/library/importlib.html#importlib.resources.contents',
                                     'importlib.resources.files': 'https://docs.python.org/3/library/importlib.html#importlib.resources.files',
                                     'importlib.resources.is_resource': 'https://docs.python.org/3/library/importlib.html#importlib.resources.is_resource',
                                     'importlib.resources.open_binary': 'https://docs.python.org/3/library/importlib.html#importlib.resources.open_binary',
                                     'importlib.resources.open_text': 'https://docs.python.org/3/library/importlib.html#importlib.resources.open_text',
                                     'importlib.resources.path': 'https://docs.python.org/3/library/importlib.html#importlib.resources.path',
                                     'importlib.resources.read_binary': 'https://docs.python.org/3/library/importlib.html#importlib.resources.read_binary',
                                     'importlib.resources.read_text': 'https://docs.python.org/3/library/importlib.html#importlib.resources.read_text'},
            'importlib.util': { 'importlib.util.LazyLoader': 'https://docs.python.org/3/library/importlib.html#importlib.util.LazyLoader',
                                'importlib.util.LazyLoader.factory': 'https://docs.python.org/3/library/importlib.html#importlib.util.LazyLoader.factory',
                                'importlib.util.cache_from_source': 'https://docs.python.org/3/library/importlib.html#importlib.util.cache_from_source',
                                'importlib.util.decode_source': 'https://docs.python.org/3/library/importlib.html#importlib.util.decode_source',
                                'importlib.util.find_spec': 'https://docs.python.org/3/library/importlib.html#importlib.util.find_spec',
                                'importlib.util.module_for_loader': 'https://docs.python.org/3/library/importlib.html#importlib.util.module_for_loader',
                                'importlib.util.module_from_spec': 'https://docs.python.org/3/library/importlib.html#importlib.util.module_from_spec',
                                'importlib.util.resolve_name': 'https://docs.python.org/3/library/importlib.html#importlib.util.resolve_name',
                                'importlib.util.set_loader': 'https://docs.python.org/3/library/importlib.html#importlib.util.set_loader',
                                'importlib.util.set_package': 'https://docs.python.org/3/library/importlib.html#importlib.util.set_package',
                                'importlib.util.source_from_cache': 'https://docs.python.org/3/library/importlib.html#importlib.util.source_from_cache',
                                'importlib.util.source_hash': 'https://docs.python.org/3/library/importlib.html#importlib.util.source_hash',
                                'importlib.util.spec_from_file_location': 'https://docs.python.org/3/library/importlib.html#importlib.util.spec_from_file_location',
                                'importlib.util.spec_from_loader': 'https://docs.python.org/3/library/importlib.html#importlib.util.spec_from_loader'},
            'inspect': { 'inspect.BoundArguments': 'https://docs.python.org/3/library/inspect.html#inspect.BoundArguments',
                         'inspect.BoundArguments.apply_defaults': 'https://docs.python.org/3/library/inspect.html#inspect.BoundArguments.apply_defaults',
                         'inspect.Parameter': 'https://docs.python.org/3/library/inspect.html#inspect.Parameter',
                         'inspect.Parameter.replace': 'https://docs.python.org/3/library/inspect.html#inspect.Parameter.replace',
                         'inspect.Signature': 'https://docs.python.org/3/library/inspect.html#inspect.Signature',
                         'inspect.Signature.bind': 'https://docs.python.org/3/library/inspect.html#inspect.Signature.bind',
                         'inspect.Signature.bind_partial': 'https://docs.python.org/3/library/inspect.html#inspect.Signature.bind_partial',
                         'inspect.Signature.from_callable': 'https://docs.python.org/3/library/inspect.html#inspect.Signature.from_callable',
                         'inspect.Signature.replace': 'https://docs.python.org/3/library/inspect.html#inspect.Signature.replace',
                         'inspect.cleandoc': 'https://docs.python.org/3/library/inspect.html#inspect.cleandoc',
                         'inspect.currentframe': 'https://docs.python.org/3/library/inspect.html#inspect.currentframe',
                         'inspect.formatargspec': 'https://docs.python.org/3/library/inspect.html#inspect.formatargspec',
                         'inspect.formatargvalues': 'https://docs.python.org/3/library/inspect.html#inspect.formatargvalues',
                         'inspect.get_annotations': 'https://docs.python.org/3/library/inspect.html#inspect.get_annotations',
                         'inspect.getargspec': 'https://docs.python.org/3/library/inspect.html#inspect.getargspec',
                         'inspect.getargvalues': 'https://docs.python.org/3/library/inspect.html#inspect.getargvalues',
                         'inspect.getattr_static': 'https://docs.python.org/3/library/inspect.html#inspect.getattr_static',
                         'inspect.getcallargs': 'https://docs.python.org/3/library/inspect.html#inspect.getcallargs',
                         'inspect.getclasstree': 'https://docs.python.org/3/library/inspect.html#inspect.getclasstree',
                         'inspect.getclosurevars': 'https://docs.python.org/3/library/inspect.html#inspect.getclosurevars',
                         'inspect.getcomments': 'https://docs.python.org/3/library/inspect.html#inspect.getcomments',
                         'inspect.getcoroutinelocals': 'https://docs.python.org/3/library/inspect.html#inspect.getcoroutinelocals',
                         'inspect.getcoroutinestate': 'https://docs.python.org/3/library/inspect.html#inspect.getcoroutinestate',
                         'inspect.getdoc': 'https://docs.python.org/3/library/inspect.html#inspect.getdoc',
                         'inspect.getfile': 'https://docs.python.org/3/library/inspect.html#inspect.getfile',
                         'inspect.getframeinfo': 'https://docs.python.org/3/library/inspect.html#inspect.getframeinfo',
                         'inspect.getfullargspec': 'https://docs.python.org/3/library/inspect.html#inspect.getfullargspec',
                         'inspect.getgeneratorlocals': 'https://docs.python.org/3/library/inspect.html#inspect.getgeneratorlocals',
                         'inspect.getgeneratorstate': 'https://docs.python.org/3/library/inspect.html#inspect.getgeneratorstate',
                         'inspect.getinnerframes': 'https://docs.python.org/3/library/inspect.html#inspect.getinnerframes',
                         'inspect.getmembers': 'https://docs.python.org/3/library/inspect.html#inspect.getmembers',
                         'inspect.getmodule': 'https://docs.python.org/3/library/inspect.html#inspect.getmodule',
                         'inspect.getmodulename': 'https://docs.python.org/3/library/inspect.html#inspect.getmodulename',
                         'inspect.getmro': 'https://docs.python.org/3/library/inspect.html#inspect.getmro',
                         'inspect.getouterframes': 'https://docs.python.org/3/library/inspect.html#inspect.getouterframes',
                         'inspect.getsource': 'https://docs.python.org/3/library/inspect.html#inspect.getsource',
                         'inspect.getsourcefile': 'https://docs.python.org/3/library/inspect.html#inspect.getsourcefile',
                         'inspect.getsourcelines': 'https://docs.python.org/3/library/inspect.html#inspect.getsourcelines',
                         'inspect.isabstract': 'https://docs.python.org/3/library/inspect.html#inspect.isabstract',
                         'inspect.isasyncgen': 'https://docs.python.org/3/library/inspect.html#inspect.isasyncgen',
                         'inspect.isasyncgenfunction': 'https://docs.python.org/3/library/inspect.html#inspect.isasyncgenfunction',
                         'inspect.isawaitable': 'https://docs.python.org/3/library/inspect.html#inspect.isawaitable',
                         'inspect.isbuiltin': 'https://docs.python.org/3/library/inspect.html#inspect.isbuiltin',
                         'inspect.isclass': 'https://docs.python.org/3/library/inspect.html#inspect.isclass',
                         'inspect.iscode': 'https://docs.python.org/3/library/inspect.html#inspect.iscode',
                         'inspect.iscoroutine': 'https://docs.python.org/3/library/inspect.html#inspect.iscoroutine',
                         'inspect.iscoroutinefunction': 'https://docs.python.org/3/library/inspect.html#inspect.iscoroutinefunction',
                         'inspect.isdatadescriptor': 'https://docs.python.org/3/library/inspect.html#inspect.isdatadescriptor',
                         'inspect.isframe': 'https://docs.python.org/3/library/inspect.html#inspect.isframe',
                         'inspect.isfunction': 'https://docs.python.org/3/library/inspect.html#inspect.isfunction',
                         'inspect.isgenerator': 'https://docs.python.org/3/library/inspect.html#inspect.isgenerator',
                         'inspect.isgeneratorfunction': 'https://docs.python.org/3/library/inspect.html#inspect.isgeneratorfunction',
                         'inspect.isgetsetdescriptor': 'https://docs.python.org/3/library/inspect.html#inspect.isgetsetdescriptor',
                         'inspect.ismemberdescriptor': 'https://docs.python.org/3/library/inspect.html#inspect.ismemberdescriptor',
                         'inspect.ismethod': 'https://docs.python.org/3/library/inspect.html#inspect.ismethod',
                         'inspect.ismethoddescriptor': 'https://docs.python.org/3/library/inspect.html#inspect.ismethoddescriptor',
                         'inspect.ismodule': 'https://docs.python.org/3/library/inspect.html#inspect.ismodule',
                         'inspect.isroutine': 'https://docs.python.org/3/library/inspect.html#inspect.isroutine',
                         'inspect.istraceback': 'https://docs.python.org/3/library/inspect.html#inspect.istraceback',
                         'inspect.signature': 'https://docs.python.org/3/library/inspect.html#inspect.signature',
                         'inspect.stack': 'https://docs.python.org/3/library/inspect.html#inspect.stack',
                         'inspect.trace': 'https://docs.python.org/3/library/inspect.html#inspect.trace',
                         'inspect.unwrap': 'https://docs.python.org/3/library/inspect.html#inspect.unwrap'},
            'io': { 'io.BufferedIOBase': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase',
                    'io.BufferedIOBase.detach': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase.detach',
                    'io.BufferedIOBase.read': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase.read',
                    'io.BufferedIOBase.read1': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase.read1',
                    'io.BufferedIOBase.readinto': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase.readinto',
                    'io.BufferedIOBase.readinto1': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase.readinto1',
                    'io.BufferedIOBase.write': 'https://docs.python.org/3/library/io.html#io.BufferedIOBase.write',
                    'io.BufferedRWPair': 'https://docs.python.org/3/library/io.html#io.BufferedRWPair',
                    'io.BufferedRandom': 'https://docs.python.org/3/library/io.html#io.BufferedRandom',
                    'io.BufferedReader': 'https://docs.python.org/3/library/io.html#io.BufferedReader',
                    'io.BufferedReader.peek': 'https://docs.python.org/3/library/io.html#io.BufferedReader.peek',
                    'io.BufferedReader.read': 'https://docs.python.org/3/library/io.html#io.BufferedReader.read',
                    'io.BufferedReader.read1': 'https://docs.python.org/3/library/io.html#io.BufferedReader.read1',
                    'io.BufferedWriter': 'https://docs.python.org/3/library/io.html#io.BufferedWriter',
                    'io.BufferedWriter.flush': 'https://docs.python.org/3/library/io.html#io.BufferedWriter.flush',
                    'io.BufferedWriter.write': 'https://docs.python.org/3/library/io.html#io.BufferedWriter.write',
                    'io.BytesIO': 'https://docs.python.org/3/library/io.html#io.BytesIO',
                    'io.BytesIO.getbuffer': 'https://docs.python.org/3/library/io.html#io.BytesIO.getbuffer',
                    'io.BytesIO.getvalue': 'https://docs.python.org/3/library/io.html#io.BytesIO.getvalue',
                    'io.BytesIO.read1': 'https://docs.python.org/3/library/io.html#io.BytesIO.read1',
                    'io.BytesIO.readinto1': 'https://docs.python.org/3/library/io.html#io.BytesIO.readinto1',
                    'io.FileIO': 'https://docs.python.org/3/library/io.html#io.FileIO',
                    'io.IOBase': 'https://docs.python.org/3/library/io.html#io.IOBase',
                    'io.IOBase.__del__': 'https://docs.python.org/3/library/io.html#io.IOBase.__del__',
                    'io.IOBase.close': 'https://docs.python.org/3/library/io.html#io.IOBase.close',
                    'io.IOBase.fileno': 'https://docs.python.org/3/library/io.html#io.IOBase.fileno',
                    'io.IOBase.flush': 'https://docs.python.org/3/library/io.html#io.IOBase.flush',
                    'io.IOBase.isatty': 'https://docs.python.org/3/library/io.html#io.IOBase.isatty',
                    'io.IOBase.readable': 'https://docs.python.org/3/library/io.html#io.IOBase.readable',
                    'io.IOBase.readline': 'https://docs.python.org/3/library/io.html#io.IOBase.readline',
                    'io.IOBase.readlines': 'https://docs.python.org/3/library/io.html#io.IOBase.readlines',
                    'io.IOBase.seek': 'https://docs.python.org/3/library/io.html#io.IOBase.seek',
                    'io.IOBase.seekable': 'https://docs.python.org/3/library/io.html#io.IOBase.seekable',
                    'io.IOBase.tell': 'https://docs.python.org/3/library/io.html#io.IOBase.tell',
                    'io.IOBase.truncate': 'https://docs.python.org/3/library/io.html#io.IOBase.truncate',
                    'io.IOBase.writable': 'https://docs.python.org/3/library/io.html#io.IOBase.writable',
                    'io.IOBase.writelines': 'https://docs.python.org/3/library/io.html#io.IOBase.writelines',
                    'io.IncrementalNewlineDecoder': 'https://docs.python.org/3/library/io.html#io.IncrementalNewlineDecoder',
                    'io.RawIOBase': 'https://docs.python.org/3/library/io.html#io.RawIOBase',
                    'io.RawIOBase.read': 'https://docs.python.org/3/library/io.html#io.RawIOBase.read',
                    'io.RawIOBase.readall': 'https://docs.python.org/3/library/io.html#io.RawIOBase.readall',
                    'io.RawIOBase.readinto': 'https://docs.python.org/3/library/io.html#io.RawIOBase.readinto',
                    'io.RawIOBase.write': 'https://docs.python.org/3/library/io.html#io.RawIOBase.write',
                    'io.StringIO': 'https://docs.python.org/3/library/io.html#io.StringIO',
                    'io.StringIO.getvalue': 'https://docs.python.org/3/library/io.html#io.StringIO.getvalue',
                    'io.TextIOBase': 'https://docs.python.org/3/library/io.html#io.TextIOBase',
                    'io.TextIOBase.detach': 'https://docs.python.org/3/library/io.html#io.TextIOBase.detach',
                    'io.TextIOBase.read': 'https://docs.python.org/3/library/io.html#io.TextIOBase.read',
                    'io.TextIOBase.readline': 'https://docs.python.org/3/library/io.html#io.TextIOBase.readline',
                    'io.TextIOBase.seek': 'https://docs.python.org/3/library/io.html#io.TextIOBase.seek',
                    'io.TextIOBase.tell': 'https://docs.python.org/3/library/io.html#io.TextIOBase.tell',
                    'io.TextIOBase.write': 'https://docs.python.org/3/library/io.html#io.TextIOBase.write',
                    'io.TextIOWrapper': 'https://docs.python.org/3/library/io.html#io.TextIOWrapper',
                    'io.TextIOWrapper.reconfigure': 'https://docs.python.org/3/library/io.html#io.TextIOWrapper.reconfigure',
                    'io.open': 'https://docs.python.org/3/library/io.html#io.open',
                    'io.open_code': 'https://docs.python.org/3/library/io.html#io.open_code',
                    'io.text_encoding': 'https://docs.python.org/3/library/io.html#io.text_encoding'},
            'ipaddress': { 'ipaddress.IPv4Address': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Address',
                           'ipaddress.IPv4Address.__format__': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Address.__format__',
                           'ipaddress.IPv4Interface': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Interface',
                           'ipaddress.IPv4Network': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network',
                           'ipaddress.IPv4Network.address_exclude': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.address_exclude',
                           'ipaddress.IPv4Network.compare_networks': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.compare_networks',
                           'ipaddress.IPv4Network.hosts': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.hosts',
                           'ipaddress.IPv4Network.overlaps': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.overlaps',
                           'ipaddress.IPv4Network.subnet_of': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.subnet_of',
                           'ipaddress.IPv4Network.subnets': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.subnets',
                           'ipaddress.IPv4Network.supernet': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.supernet',
                           'ipaddress.IPv4Network.supernet_of': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv4Network.supernet_of',
                           'ipaddress.IPv6Address': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Address',
                           'ipaddress.IPv6Address.__format__': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Address.__format__',
                           'ipaddress.IPv6Interface': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Interface',
                           'ipaddress.IPv6Network': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network',
                           'ipaddress.IPv6Network.address_exclude': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.address_exclude',
                           'ipaddress.IPv6Network.compare_networks': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.compare_networks',
                           'ipaddress.IPv6Network.hosts': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.hosts',
                           'ipaddress.IPv6Network.overlaps': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.overlaps',
                           'ipaddress.IPv6Network.subnet_of': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.subnet_of',
                           'ipaddress.IPv6Network.subnets': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.subnets',
                           'ipaddress.IPv6Network.supernet': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.supernet',
                           'ipaddress.IPv6Network.supernet_of': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.IPv6Network.supernet_of',
                           'ipaddress.collapse_addresses': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.collapse_addresses',
                           'ipaddress.get_mixed_type_key': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.get_mixed_type_key',
                           'ipaddress.ip_address': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.ip_address',
                           'ipaddress.ip_interface': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.ip_interface',
                           'ipaddress.ip_network': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.ip_network',
                           'ipaddress.summarize_address_range': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.summarize_address_range',
                           'ipaddress.v4_int_to_packed': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.v4_int_to_packed',
                           'ipaddress.v6_int_to_packed': 'https://docs.python.org/3/library/ipaddress.html#ipaddress.v6_int_to_packed'},
            'itertools': { 'itertools.accumulate': 'https://docs.python.org/3/library/itertools.html#itertools.accumulate',
                           'itertools.chain': 'https://docs.python.org/3/library/itertools.html#itertools.chain',
                           'itertools.chain.from_iterable': 'https://docs.python.org/3/library/itertools.html#itertools.chain.from_iterable',
                           'itertools.combinations': 'https://docs.python.org/3/library/itertools.html#itertools.combinations',
                           'itertools.combinations_with_replacement': 'https://docs.python.org/3/library/itertools.html#itertools.combinations_with_replacement',
                           'itertools.compress': 'https://docs.python.org/3/library/itertools.html#itertools.compress',
                           'itertools.count': 'https://docs.python.org/3/library/itertools.html#itertools.count',
                           'itertools.cycle': 'https://docs.python.org/3/library/itertools.html#itertools.cycle',
                           'itertools.dropwhile': 'https://docs.python.org/3/library/itertools.html#itertools.dropwhile',
                           'itertools.filterfalse': 'https://docs.python.org/3/library/itertools.html#itertools.filterfalse',
                           'itertools.groupby': 'https://docs.python.org/3/library/itertools.html#itertools.groupby',
                           'itertools.islice': 'https://docs.python.org/3/library/itertools.html#itertools.islice',
                           'itertools.pairwise': 'https://docs.python.org/3/library/itertools.html#itertools.pairwise',
                           'itertools.permutations': 'https://docs.python.org/3/library/itertools.html#itertools.permutations',
                           'itertools.product': 'https://docs.python.org/3/library/itertools.html#itertools.product',
                           'itertools.repeat': 'https://docs.python.org/3/library/itertools.html#itertools.repeat',
                           'itertools.starmap': 'https://docs.python.org/3/library/itertools.html#itertools.starmap',
                           'itertools.takewhile': 'https://docs.python.org/3/library/itertools.html#itertools.takewhile',
                           'itertools.tee': 'https://docs.python.org/3/library/itertools.html#itertools.tee',
                           'itertools.zip_longest': 'https://docs.python.org/3/library/itertools.html#itertools.zip_longest'},
            'json': { 'json.JSONDecoder': 'https://docs.python.org/3/library/json.html#json.JSONDecoder',
                      'json.JSONDecoder.decode': 'https://docs.python.org/3/library/json.html#json.JSONDecoder.decode',
                      'json.JSONDecoder.raw_decode': 'https://docs.python.org/3/library/json.html#json.JSONDecoder.raw_decode',
                      'json.JSONEncoder': 'https://docs.python.org/3/library/json.html#json.JSONEncoder',
                      'json.JSONEncoder.default': 'https://docs.python.org/3/library/json.html#json.JSONEncoder.default',
                      'json.JSONEncoder.encode': 'https://docs.python.org/3/library/json.html#json.JSONEncoder.encode',
                      'json.JSONEncoder.iterencode': 'https://docs.python.org/3/library/json.html#json.JSONEncoder.iterencode',
                      'json.dump': 'https://docs.python.org/3/library/json.html#json.dump',
                      'json.dumps': 'https://docs.python.org/3/library/json.html#json.dumps',
                      'json.load': 'https://docs.python.org/3/library/json.html#json.load',
                      'json.loads': 'https://docs.python.org/3/library/json.html#json.loads',
                      'json.tool': 'https://docs.python.org/3/library/json.html#module-json.tool'},
            'keyword': { 'keyword.iskeyword': 'https://docs.python.org/3/library/keyword.html#keyword.iskeyword',
                         'keyword.issoftkeyword': 'https://docs.python.org/3/library/keyword.html#keyword.issoftkeyword'},
            'linecache': { 'linecache.checkcache': 'https://docs.python.org/3/library/linecache.html#linecache.checkcache',
                           'linecache.clearcache': 'https://docs.python.org/3/library/linecache.html#linecache.clearcache',
                           'linecache.getline': 'https://docs.python.org/3/library/linecache.html#linecache.getline',
                           'linecache.lazycache': 'https://docs.python.org/3/library/linecache.html#linecache.lazycache'},
            'locale': { 'locale.atof': 'https://docs.python.org/3/library/locale.html#locale.atof',
                        'locale.atoi': 'https://docs.python.org/3/library/locale.html#locale.atoi',
                        'locale.bindtextdomain': 'https://docs.python.org/3/library/locale.html#locale.bindtextdomain',
                        'locale.currency': 'https://docs.python.org/3/library/locale.html#locale.currency',
                        'locale.dcgettext': 'https://docs.python.org/3/library/locale.html#locale.dcgettext',
                        'locale.delocalize': 'https://docs.python.org/3/library/locale.html#locale.delocalize',
                        'locale.dgettext': 'https://docs.python.org/3/library/locale.html#locale.dgettext',
                        'locale.format': 'https://docs.python.org/3/library/locale.html#locale.format',
                        'locale.format_string': 'https://docs.python.org/3/library/locale.html#locale.format_string',
                        'locale.getdefaultlocale': 'https://docs.python.org/3/library/locale.html#locale.getdefaultlocale',
                        'locale.getlocale': 'https://docs.python.org/3/library/locale.html#locale.getlocale',
                        'locale.getpreferredencoding': 'https://docs.python.org/3/library/locale.html#locale.getpreferredencoding',
                        'locale.gettext': 'https://docs.python.org/3/library/locale.html#locale.gettext',
                        'locale.localeconv': 'https://docs.python.org/3/library/locale.html#locale.localeconv',
                        'locale.localize': 'https://docs.python.org/3/library/locale.html#locale.localize',
                        'locale.nl_langinfo': 'https://docs.python.org/3/library/locale.html#locale.nl_langinfo',
                        'locale.normalize': 'https://docs.python.org/3/library/locale.html#locale.normalize',
                        'locale.resetlocale': 'https://docs.python.org/3/library/locale.html#locale.resetlocale',
                        'locale.setlocale': 'https://docs.python.org/3/library/locale.html#locale.setlocale',
                        'locale.str': 'https://docs.python.org/3/library/locale.html#locale.str',
                        'locale.strcoll': 'https://docs.python.org/3/library/locale.html#locale.strcoll',
                        'locale.strxfrm': 'https://docs.python.org/3/library/locale.html#locale.strxfrm',
                        'locale.textdomain': 'https://docs.python.org/3/library/locale.html#locale.textdomain'},
            'logging': { 'logging.BufferingFormatter': 'https://docs.python.org/3/library/logging.html#logging.BufferingFormatter',
                         'logging.BufferingFormatter.format': 'https://docs.python.org/3/library/logging.html#logging.BufferingFormatter.format',
                         'logging.BufferingFormatter.formatFooter': 'https://docs.python.org/3/library/logging.html#logging.BufferingFormatter.formatFooter',
                         'logging.BufferingFormatter.formatHeader': 'https://docs.python.org/3/library/logging.html#logging.BufferingFormatter.formatHeader',
                         'logging.FileHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.FileHandler',
                         'logging.FileHandler.close': 'https://docs.python.org/3/library/logging.handlers.html#logging.FileHandler.close',
                         'logging.FileHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.FileHandler.emit',
                         'logging.Filter': 'https://docs.python.org/3/library/logging.html#logging.Filter',
                         'logging.Filter.filter': 'https://docs.python.org/3/library/logging.html#logging.Filter.filter',
                         'logging.Formatter': 'https://docs.python.org/3/library/logging.html#logging.Formatter',
                         'logging.Formatter.format': 'https://docs.python.org/3/library/logging.html#logging.Formatter.format',
                         'logging.Formatter.formatException': 'https://docs.python.org/3/library/logging.html#logging.Formatter.formatException',
                         'logging.Formatter.formatStack': 'https://docs.python.org/3/library/logging.html#logging.Formatter.formatStack',
                         'logging.Formatter.formatTime': 'https://docs.python.org/3/library/logging.html#logging.Formatter.formatTime',
                         'logging.Handler': 'https://docs.python.org/3/library/logging.html#logging.Handler',
                         'logging.Handler.__init__': 'https://docs.python.org/3/library/logging.html#logging.Handler.__init__',
                         'logging.Handler.acquire': 'https://docs.python.org/3/library/logging.html#logging.Handler.acquire',
                         'logging.Handler.addFilter': 'https://docs.python.org/3/library/logging.html#logging.Handler.addFilter',
                         'logging.Handler.close': 'https://docs.python.org/3/library/logging.html#logging.Handler.close',
                         'logging.Handler.createLock': 'https://docs.python.org/3/library/logging.html#logging.Handler.createLock',
                         'logging.Handler.emit': 'https://docs.python.org/3/library/logging.html#logging.Handler.emit',
                         'logging.Handler.filter': 'https://docs.python.org/3/library/logging.html#logging.Handler.filter',
                         'logging.Handler.flush': 'https://docs.python.org/3/library/logging.html#logging.Handler.flush',
                         'logging.Handler.format': 'https://docs.python.org/3/library/logging.html#logging.Handler.format',
                         'logging.Handler.handle': 'https://docs.python.org/3/library/logging.html#logging.Handler.handle',
                         'logging.Handler.handleError': 'https://docs.python.org/3/library/logging.html#logging.Handler.handleError',
                         'logging.Handler.release': 'https://docs.python.org/3/library/logging.html#logging.Handler.release',
                         'logging.Handler.removeFilter': 'https://docs.python.org/3/library/logging.html#logging.Handler.removeFilter',
                         'logging.Handler.setFormatter': 'https://docs.python.org/3/library/logging.html#logging.Handler.setFormatter',
                         'logging.Handler.setLevel': 'https://docs.python.org/3/library/logging.html#logging.Handler.setLevel',
                         'logging.LogRecord': 'https://docs.python.org/3/library/logging.html#logging.LogRecord',
                         'logging.LogRecord.getMessage': 'https://docs.python.org/3/library/logging.html#logging.LogRecord.getMessage',
                         'logging.Logger': 'https://docs.python.org/3/library/logging.html#logging.Logger',
                         'logging.Logger.addFilter': 'https://docs.python.org/3/library/logging.html#logging.Logger.addFilter',
                         'logging.Logger.addHandler': 'https://docs.python.org/3/library/logging.html#logging.Logger.addHandler',
                         'logging.Logger.critical': 'https://docs.python.org/3/library/logging.html#logging.Logger.critical',
                         'logging.Logger.debug': 'https://docs.python.org/3/library/logging.html#logging.Logger.debug',
                         'logging.Logger.error': 'https://docs.python.org/3/library/logging.html#logging.Logger.error',
                         'logging.Logger.exception': 'https://docs.python.org/3/library/logging.html#logging.Logger.exception',
                         'logging.Logger.filter': 'https://docs.python.org/3/library/logging.html#logging.Logger.filter',
                         'logging.Logger.findCaller': 'https://docs.python.org/3/library/logging.html#logging.Logger.findCaller',
                         'logging.Logger.getChild': 'https://docs.python.org/3/library/logging.html#logging.Logger.getChild',
                         'logging.Logger.getEffectiveLevel': 'https://docs.python.org/3/library/logging.html#logging.Logger.getEffectiveLevel',
                         'logging.Logger.handle': 'https://docs.python.org/3/library/logging.html#logging.Logger.handle',
                         'logging.Logger.hasHandlers': 'https://docs.python.org/3/library/logging.html#logging.Logger.hasHandlers',
                         'logging.Logger.info': 'https://docs.python.org/3/library/logging.html#logging.Logger.info',
                         'logging.Logger.isEnabledFor': 'https://docs.python.org/3/library/logging.html#logging.Logger.isEnabledFor',
                         'logging.Logger.log': 'https://docs.python.org/3/library/logging.html#logging.Logger.log',
                         'logging.Logger.makeRecord': 'https://docs.python.org/3/library/logging.html#logging.Logger.makeRecord',
                         'logging.Logger.removeFilter': 'https://docs.python.org/3/library/logging.html#logging.Logger.removeFilter',
                         'logging.Logger.removeHandler': 'https://docs.python.org/3/library/logging.html#logging.Logger.removeHandler',
                         'logging.Logger.setLevel': 'https://docs.python.org/3/library/logging.html#logging.Logger.setLevel',
                         'logging.Logger.warning': 'https://docs.python.org/3/library/logging.html#logging.Logger.warning',
                         'logging.LoggerAdapter': 'https://docs.python.org/3/library/logging.html#logging.LoggerAdapter',
                         'logging.LoggerAdapter.process': 'https://docs.python.org/3/library/logging.html#logging.LoggerAdapter.process',
                         'logging.NullHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.NullHandler',
                         'logging.NullHandler.createLock': 'https://docs.python.org/3/library/logging.handlers.html#logging.NullHandler.createLock',
                         'logging.NullHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.NullHandler.emit',
                         'logging.NullHandler.handle': 'https://docs.python.org/3/library/logging.handlers.html#logging.NullHandler.handle',
                         'logging.StreamHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.StreamHandler',
                         'logging.StreamHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.StreamHandler.emit',
                         'logging.StreamHandler.flush': 'https://docs.python.org/3/library/logging.handlers.html#logging.StreamHandler.flush',
                         'logging.StreamHandler.setStream': 'https://docs.python.org/3/library/logging.handlers.html#logging.StreamHandler.setStream',
                         'logging.addLevelName': 'https://docs.python.org/3/library/logging.html#logging.addLevelName',
                         'logging.basicConfig': 'https://docs.python.org/3/library/logging.html#logging.basicConfig',
                         'logging.captureWarnings': 'https://docs.python.org/3/library/logging.html#logging.captureWarnings',
                         'logging.config': 'https://docs.python.org/3/library/logging.config.html#module-logging.config',
                         'logging.critical': 'https://docs.python.org/3/library/logging.html#logging.critical',
                         'logging.debug': 'https://docs.python.org/3/library/logging.html#logging.debug',
                         'logging.disable': 'https://docs.python.org/3/library/logging.html#logging.disable',
                         'logging.error': 'https://docs.python.org/3/library/logging.html#logging.error',
                         'logging.exception': 'https://docs.python.org/3/library/logging.html#logging.exception',
                         'logging.getLevelName': 'https://docs.python.org/3/library/logging.html#logging.getLevelName',
                         'logging.getLogRecordFactory': 'https://docs.python.org/3/library/logging.html#logging.getLogRecordFactory',
                         'logging.getLogger': 'https://docs.python.org/3/library/logging.html#logging.getLogger',
                         'logging.getLoggerClass': 'https://docs.python.org/3/library/logging.html#logging.getLoggerClass',
                         'logging.handlers': 'https://docs.python.org/3/library/logging.handlers.html#module-logging.handlers',
                         'logging.info': 'https://docs.python.org/3/library/logging.html#logging.info',
                         'logging.log': 'https://docs.python.org/3/library/logging.html#logging.log',
                         'logging.makeLogRecord': 'https://docs.python.org/3/library/logging.html#logging.makeLogRecord',
                         'logging.setLogRecordFactory': 'https://docs.python.org/3/library/logging.html#logging.setLogRecordFactory',
                         'logging.setLoggerClass': 'https://docs.python.org/3/library/logging.html#logging.setLoggerClass',
                         'logging.shutdown': 'https://docs.python.org/3/library/logging.html#logging.shutdown',
                         'logging.warning': 'https://docs.python.org/3/library/logging.html#logging.warning'},
            'logging.config': { 'logging.config.dictConfig': 'https://docs.python.org/3/library/logging.config.html#logging.config.dictConfig',
                                'logging.config.fileConfig': 'https://docs.python.org/3/library/logging.config.html#logging.config.fileConfig',
                                'logging.config.listen': 'https://docs.python.org/3/library/logging.config.html#logging.config.listen',
                                'logging.config.stopListening': 'https://docs.python.org/3/library/logging.config.html#logging.config.stopListening'},
            'logging.handlers': { 'logging.handlers.BaseRotatingHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BaseRotatingHandler',
                                  'logging.handlers.BaseRotatingHandler.rotate': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BaseRotatingHandler.rotate',
                                  'logging.handlers.BaseRotatingHandler.rotation_filename': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BaseRotatingHandler.rotation_filename',
                                  'logging.handlers.BufferingHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BufferingHandler',
                                  'logging.handlers.BufferingHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BufferingHandler.emit',
                                  'logging.handlers.BufferingHandler.flush': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BufferingHandler.flush',
                                  'logging.handlers.BufferingHandler.shouldFlush': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.BufferingHandler.shouldFlush',
                                  'logging.handlers.DatagramHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.DatagramHandler',
                                  'logging.handlers.DatagramHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.DatagramHandler.emit',
                                  'logging.handlers.DatagramHandler.makeSocket': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.DatagramHandler.makeSocket',
                                  'logging.handlers.DatagramHandler.send': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.DatagramHandler.send',
                                  'logging.handlers.HTTPHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.HTTPHandler',
                                  'logging.handlers.HTTPHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.HTTPHandler.emit',
                                  'logging.handlers.HTTPHandler.mapLogRecord': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.HTTPHandler.mapLogRecord',
                                  'logging.handlers.MemoryHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.MemoryHandler',
                                  'logging.handlers.MemoryHandler.close': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.MemoryHandler.close',
                                  'logging.handlers.MemoryHandler.flush': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.MemoryHandler.flush',
                                  'logging.handlers.MemoryHandler.setTarget': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.MemoryHandler.setTarget',
                                  'logging.handlers.MemoryHandler.shouldFlush': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.MemoryHandler.shouldFlush',
                                  'logging.handlers.NTEventLogHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.NTEventLogHandler',
                                  'logging.handlers.NTEventLogHandler.close': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.NTEventLogHandler.close',
                                  'logging.handlers.NTEventLogHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.NTEventLogHandler.emit',
                                  'logging.handlers.NTEventLogHandler.getEventCategory': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.NTEventLogHandler.getEventCategory',
                                  'logging.handlers.NTEventLogHandler.getEventType': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.NTEventLogHandler.getEventType',
                                  'logging.handlers.NTEventLogHandler.getMessageID': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.NTEventLogHandler.getMessageID',
                                  'logging.handlers.QueueHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueHandler',
                                  'logging.handlers.QueueHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueHandler.emit',
                                  'logging.handlers.QueueHandler.enqueue': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueHandler.enqueue',
                                  'logging.handlers.QueueHandler.prepare': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueHandler.prepare',
                                  'logging.handlers.QueueListener': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener',
                                  'logging.handlers.QueueListener.dequeue': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener.dequeue',
                                  'logging.handlers.QueueListener.enqueue_sentinel': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener.enqueue_sentinel',
                                  'logging.handlers.QueueListener.handle': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener.handle',
                                  'logging.handlers.QueueListener.prepare': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener.prepare',
                                  'logging.handlers.QueueListener.start': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener.start',
                                  'logging.handlers.QueueListener.stop': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.QueueListener.stop',
                                  'logging.handlers.RotatingFileHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.RotatingFileHandler',
                                  'logging.handlers.RotatingFileHandler.doRollover': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.RotatingFileHandler.doRollover',
                                  'logging.handlers.RotatingFileHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.RotatingFileHandler.emit',
                                  'logging.handlers.SMTPHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SMTPHandler',
                                  'logging.handlers.SMTPHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SMTPHandler.emit',
                                  'logging.handlers.SMTPHandler.getSubject': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SMTPHandler.getSubject',
                                  'logging.handlers.SocketHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler',
                                  'logging.handlers.SocketHandler.close': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.close',
                                  'logging.handlers.SocketHandler.createSocket': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.createSocket',
                                  'logging.handlers.SocketHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.emit',
                                  'logging.handlers.SocketHandler.handleError': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.handleError',
                                  'logging.handlers.SocketHandler.makePickle': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.makePickle',
                                  'logging.handlers.SocketHandler.makeSocket': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.makeSocket',
                                  'logging.handlers.SocketHandler.send': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SocketHandler.send',
                                  'logging.handlers.SysLogHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SysLogHandler',
                                  'logging.handlers.SysLogHandler.close': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SysLogHandler.close',
                                  'logging.handlers.SysLogHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SysLogHandler.emit',
                                  'logging.handlers.SysLogHandler.encodePriority': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SysLogHandler.encodePriority',
                                  'logging.handlers.SysLogHandler.mapPriority': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.SysLogHandler.mapPriority',
                                  'logging.handlers.TimedRotatingFileHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.TimedRotatingFileHandler',
                                  'logging.handlers.TimedRotatingFileHandler.doRollover': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.TimedRotatingFileHandler.doRollover',
                                  'logging.handlers.TimedRotatingFileHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.TimedRotatingFileHandler.emit',
                                  'logging.handlers.TimedRotatingFileHandler.getFilesToDelete': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.TimedRotatingFileHandler.getFilesToDelete',
                                  'logging.handlers.WatchedFileHandler': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.WatchedFileHandler',
                                  'logging.handlers.WatchedFileHandler.emit': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.WatchedFileHandler.emit',
                                  'logging.handlers.WatchedFileHandler.reopenIfNeeded': 'https://docs.python.org/3/library/logging.handlers.html#logging.handlers.WatchedFileHandler.reopenIfNeeded'},
            'logging.logging': {'logging.logging.Formatter.__init__': 'https://docs.python.org/3/howto/logging.html#logging.logging.Formatter.__init__'},
            'lzma': { 'lzma.LZMACompressor': 'https://docs.python.org/3/library/lzma.html#lzma.LZMACompressor',
                      'lzma.LZMACompressor.compress': 'https://docs.python.org/3/library/lzma.html#lzma.LZMACompressor.compress',
                      'lzma.LZMACompressor.flush': 'https://docs.python.org/3/library/lzma.html#lzma.LZMACompressor.flush',
                      'lzma.LZMADecompressor': 'https://docs.python.org/3/library/lzma.html#lzma.LZMADecompressor',
                      'lzma.LZMADecompressor.decompress': 'https://docs.python.org/3/library/lzma.html#lzma.LZMADecompressor.decompress',
                      'lzma.LZMAFile': 'https://docs.python.org/3/library/lzma.html#lzma.LZMAFile',
                      'lzma.LZMAFile.peek': 'https://docs.python.org/3/library/lzma.html#lzma.LZMAFile.peek',
                      'lzma.compress': 'https://docs.python.org/3/library/lzma.html#lzma.compress',
                      'lzma.decompress': 'https://docs.python.org/3/library/lzma.html#lzma.decompress',
                      'lzma.is_check_supported': 'https://docs.python.org/3/library/lzma.html#lzma.is_check_supported',
                      'lzma.open': 'https://docs.python.org/3/library/lzma.html#lzma.open'},
            'mailbox': { 'mailbox.Babyl': 'https://docs.python.org/3/library/mailbox.html#mailbox.Babyl',
                         'mailbox.Babyl.get_file': 'https://docs.python.org/3/library/mailbox.html#mailbox.Babyl.get_file',
                         'mailbox.Babyl.get_labels': 'https://docs.python.org/3/library/mailbox.html#mailbox.Babyl.get_labels',
                         'mailbox.Babyl.lock': 'https://docs.python.org/3/library/mailbox.html#mailbox.Babyl.lock',
                         'mailbox.Babyl.unlock': 'https://docs.python.org/3/library/mailbox.html#mailbox.Babyl.unlock',
                         'mailbox.BabylMessage': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage',
                         'mailbox.BabylMessage.add_label': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.add_label',
                         'mailbox.BabylMessage.get_labels': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.get_labels',
                         'mailbox.BabylMessage.get_visible': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.get_visible',
                         'mailbox.BabylMessage.remove_label': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.remove_label',
                         'mailbox.BabylMessage.set_labels': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.set_labels',
                         'mailbox.BabylMessage.set_visible': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.set_visible',
                         'mailbox.BabylMessage.update_visible': 'https://docs.python.org/3/library/mailbox.html#mailbox.BabylMessage.update_visible',
                         'mailbox.MH': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH',
                         'mailbox.MH.__delitem__': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.__delitem__',
                         'mailbox.MH.add_folder': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.add_folder',
                         'mailbox.MH.close': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.close',
                         'mailbox.MH.discard': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.discard',
                         'mailbox.MH.flush': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.flush',
                         'mailbox.MH.get_file': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.get_file',
                         'mailbox.MH.get_folder': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.get_folder',
                         'mailbox.MH.get_sequences': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.get_sequences',
                         'mailbox.MH.list_folders': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.list_folders',
                         'mailbox.MH.lock': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.lock',
                         'mailbox.MH.pack': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.pack',
                         'mailbox.MH.remove': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.remove',
                         'mailbox.MH.remove_folder': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.remove_folder',
                         'mailbox.MH.set_sequences': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.set_sequences',
                         'mailbox.MH.unlock': 'https://docs.python.org/3/library/mailbox.html#mailbox.MH.unlock',
                         'mailbox.MHMessage': 'https://docs.python.org/3/library/mailbox.html#mailbox.MHMessage',
                         'mailbox.MHMessage.add_sequence': 'https://docs.python.org/3/library/mailbox.html#mailbox.MHMessage.add_sequence',
                         'mailbox.MHMessage.get_sequences': 'https://docs.python.org/3/library/mailbox.html#mailbox.MHMessage.get_sequences',
                         'mailbox.MHMessage.remove_sequence': 'https://docs.python.org/3/library/mailbox.html#mailbox.MHMessage.remove_sequence',
                         'mailbox.MHMessage.set_sequences': 'https://docs.python.org/3/library/mailbox.html#mailbox.MHMessage.set_sequences',
                         'mailbox.MMDF': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDF',
                         'mailbox.MMDF.get_file': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDF.get_file',
                         'mailbox.MMDF.lock': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDF.lock',
                         'mailbox.MMDF.unlock': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDF.unlock',
                         'mailbox.MMDFMessage': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage',
                         'mailbox.MMDFMessage.add_flag': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage.add_flag',
                         'mailbox.MMDFMessage.get_flags': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage.get_flags',
                         'mailbox.MMDFMessage.get_from': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage.get_from',
                         'mailbox.MMDFMessage.remove_flag': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage.remove_flag',
                         'mailbox.MMDFMessage.set_flags': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage.set_flags',
                         'mailbox.MMDFMessage.set_from': 'https://docs.python.org/3/library/mailbox.html#mailbox.MMDFMessage.set_from',
                         'mailbox.Mailbox': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox',
                         'mailbox.Mailbox.__contains__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.__contains__',
                         'mailbox.Mailbox.__delitem__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.__delitem__',
                         'mailbox.Mailbox.__getitem__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.__getitem__',
                         'mailbox.Mailbox.__iter__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.__iter__',
                         'mailbox.Mailbox.__len__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.__len__',
                         'mailbox.Mailbox.__setitem__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.__setitem__',
                         'mailbox.Mailbox.add': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.add',
                         'mailbox.Mailbox.clear': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.clear',
                         'mailbox.Mailbox.close': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.close',
                         'mailbox.Mailbox.discard': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.discard',
                         'mailbox.Mailbox.flush': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.flush',
                         'mailbox.Mailbox.get': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.get',
                         'mailbox.Mailbox.get_bytes': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.get_bytes',
                         'mailbox.Mailbox.get_file': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.get_file',
                         'mailbox.Mailbox.get_message': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.get_message',
                         'mailbox.Mailbox.get_string': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.get_string',
                         'mailbox.Mailbox.items': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.items',
                         'mailbox.Mailbox.iteritems': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.iteritems',
                         'mailbox.Mailbox.iterkeys': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.iterkeys',
                         'mailbox.Mailbox.itervalues': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.itervalues',
                         'mailbox.Mailbox.keys': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.keys',
                         'mailbox.Mailbox.lock': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.lock',
                         'mailbox.Mailbox.pop': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.pop',
                         'mailbox.Mailbox.popitem': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.popitem',
                         'mailbox.Mailbox.remove': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.remove',
                         'mailbox.Mailbox.unlock': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.unlock',
                         'mailbox.Mailbox.update': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.update',
                         'mailbox.Mailbox.values': 'https://docs.python.org/3/library/mailbox.html#mailbox.Mailbox.values',
                         'mailbox.Maildir': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir',
                         'mailbox.Maildir.__setitem__': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.__setitem__',
                         'mailbox.Maildir.add': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.add',
                         'mailbox.Maildir.add_folder': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.add_folder',
                         'mailbox.Maildir.clean': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.clean',
                         'mailbox.Maildir.close': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.close',
                         'mailbox.Maildir.flush': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.flush',
                         'mailbox.Maildir.get_file': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.get_file',
                         'mailbox.Maildir.get_folder': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.get_folder',
                         'mailbox.Maildir.list_folders': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.list_folders',
                         'mailbox.Maildir.lock': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.lock',
                         'mailbox.Maildir.remove_folder': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.remove_folder',
                         'mailbox.Maildir.unlock': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.unlock',
                         'mailbox.Maildir.update': 'https://docs.python.org/3/library/mailbox.html#mailbox.Maildir.update',
                         'mailbox.MaildirMessage': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage',
                         'mailbox.MaildirMessage.add_flag': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.add_flag',
                         'mailbox.MaildirMessage.get_date': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.get_date',
                         'mailbox.MaildirMessage.get_flags': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.get_flags',
                         'mailbox.MaildirMessage.get_info': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.get_info',
                         'mailbox.MaildirMessage.get_subdir': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.get_subdir',
                         'mailbox.MaildirMessage.remove_flag': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.remove_flag',
                         'mailbox.MaildirMessage.set_date': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.set_date',
                         'mailbox.MaildirMessage.set_flags': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.set_flags',
                         'mailbox.MaildirMessage.set_info': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.set_info',
                         'mailbox.MaildirMessage.set_subdir': 'https://docs.python.org/3/library/mailbox.html#mailbox.MaildirMessage.set_subdir',
                         'mailbox.Message': 'https://docs.python.org/3/library/mailbox.html#mailbox.Message',
                         'mailbox.mbox': 'https://docs.python.org/3/library/mailbox.html#mailbox.mbox',
                         'mailbox.mbox.get_file': 'https://docs.python.org/3/library/mailbox.html#mailbox.mbox.get_file',
                         'mailbox.mbox.lock': 'https://docs.python.org/3/library/mailbox.html#mailbox.mbox.lock',
                         'mailbox.mbox.unlock': 'https://docs.python.org/3/library/mailbox.html#mailbox.mbox.unlock',
                         'mailbox.mboxMessage': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage',
                         'mailbox.mboxMessage.add_flag': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage.add_flag',
                         'mailbox.mboxMessage.get_flags': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage.get_flags',
                         'mailbox.mboxMessage.get_from': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage.get_from',
                         'mailbox.mboxMessage.remove_flag': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage.remove_flag',
                         'mailbox.mboxMessage.set_flags': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage.set_flags',
                         'mailbox.mboxMessage.set_from': 'https://docs.python.org/3/library/mailbox.html#mailbox.mboxMessage.set_from'},
            'mailcap': { 'mailcap.findmatch': 'https://docs.python.org/3/library/mailcap.html#mailcap.findmatch',
                         'mailcap.getcaps': 'https://docs.python.org/3/library/mailcap.html#mailcap.getcaps'},
            'marshal': { 'marshal.dump': 'https://docs.python.org/3/library/marshal.html#marshal.dump',
                         'marshal.dumps': 'https://docs.python.org/3/library/marshal.html#marshal.dumps',
                         'marshal.load': 'https://docs.python.org/3/library/marshal.html#marshal.load',
                         'marshal.loads': 'https://docs.python.org/3/library/marshal.html#marshal.loads'},
            'math': { 'math.acos': 'https://docs.python.org/3/library/math.html#math.acos',
                      'math.acosh': 'https://docs.python.org/3/library/math.html#math.acosh',
                      'math.asin': 'https://docs.python.org/3/library/math.html#math.asin',
                      'math.asinh': 'https://docs.python.org/3/library/math.html#math.asinh',
                      'math.atan': 'https://docs.python.org/3/library/math.html#math.atan',
                      'math.atan2': 'https://docs.python.org/3/library/math.html#math.atan2',
                      'math.atanh': 'https://docs.python.org/3/library/math.html#math.atanh',
                      'math.ceil': 'https://docs.python.org/3/library/math.html#math.ceil',
                      'math.comb': 'https://docs.python.org/3/library/math.html#math.comb',
                      'math.copysign': 'https://docs.python.org/3/library/math.html#math.copysign',
                      'math.cos': 'https://docs.python.org/3/library/math.html#math.cos',
                      'math.cosh': 'https://docs.python.org/3/library/math.html#math.cosh',
                      'math.degrees': 'https://docs.python.org/3/library/math.html#math.degrees',
                      'math.dist': 'https://docs.python.org/3/library/math.html#math.dist',
                      'math.erf': 'https://docs.python.org/3/library/math.html#math.erf',
                      'math.erfc': 'https://docs.python.org/3/library/math.html#math.erfc',
                      'math.exp': 'https://docs.python.org/3/library/math.html#math.exp',
                      'math.expm1': 'https://docs.python.org/3/library/math.html#math.expm1',
                      'math.fabs': 'https://docs.python.org/3/library/math.html#math.fabs',
                      'math.factorial': 'https://docs.python.org/3/library/math.html#math.factorial',
                      'math.floor': 'https://docs.python.org/3/library/math.html#math.floor',
                      'math.fmod': 'https://docs.python.org/3/library/math.html#math.fmod',
                      'math.frexp': 'https://docs.python.org/3/library/math.html#math.frexp',
                      'math.fsum': 'https://docs.python.org/3/library/math.html#math.fsum',
                      'math.gamma': 'https://docs.python.org/3/library/math.html#math.gamma',
                      'math.gcd': 'https://docs.python.org/3/library/math.html#math.gcd',
                      'math.hypot': 'https://docs.python.org/3/library/math.html#math.hypot',
                      'math.isclose': 'https://docs.python.org/3/library/math.html#math.isclose',
                      'math.isfinite': 'https://docs.python.org/3/library/math.html#math.isfinite',
                      'math.isinf': 'https://docs.python.org/3/library/math.html#math.isinf',
                      'math.isnan': 'https://docs.python.org/3/library/math.html#math.isnan',
                      'math.isqrt': 'https://docs.python.org/3/library/math.html#math.isqrt',
                      'math.lcm': 'https://docs.python.org/3/library/math.html#math.lcm',
                      'math.ldexp': 'https://docs.python.org/3/library/math.html#math.ldexp',
                      'math.lgamma': 'https://docs.python.org/3/library/math.html#math.lgamma',
                      'math.log': 'https://docs.python.org/3/library/math.html#math.log',
                      'math.log10': 'https://docs.python.org/3/library/math.html#math.log10',
                      'math.log1p': 'https://docs.python.org/3/library/math.html#math.log1p',
                      'math.log2': 'https://docs.python.org/3/library/math.html#math.log2',
                      'math.modf': 'https://docs.python.org/3/library/math.html#math.modf',
                      'math.nextafter': 'https://docs.python.org/3/library/math.html#math.nextafter',
                      'math.perm': 'https://docs.python.org/3/library/math.html#math.perm',
                      'math.pow': 'https://docs.python.org/3/library/math.html#math.pow',
                      'math.prod': 'https://docs.python.org/3/library/math.html#math.prod',
                      'math.radians': 'https://docs.python.org/3/library/math.html#math.radians',
                      'math.remainder': 'https://docs.python.org/3/library/math.html#math.remainder',
                      'math.sin': 'https://docs.python.org/3/library/math.html#math.sin',
                      'math.sinh': 'https://docs.python.org/3/library/math.html#math.sinh',
                      'math.sqrt': 'https://docs.python.org/3/library/math.html#math.sqrt',
                      'math.tan': 'https://docs.python.org/3/library/math.html#math.tan',
                      'math.tanh': 'https://docs.python.org/3/library/math.html#math.tanh',
                      'math.trunc': 'https://docs.python.org/3/library/math.html#math.trunc',
                      'math.ulp': 'https://docs.python.org/3/library/math.html#math.ulp'},
            'mimetypes': { 'mimetypes.MimeTypes': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes',
                           'mimetypes.MimeTypes.guess_all_extensions': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes.guess_all_extensions',
                           'mimetypes.MimeTypes.guess_extension': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes.guess_extension',
                           'mimetypes.MimeTypes.guess_type': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes.guess_type',
                           'mimetypes.MimeTypes.read': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes.read',
                           'mimetypes.MimeTypes.read_windows_registry': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes.read_windows_registry',
                           'mimetypes.MimeTypes.readfp': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.MimeTypes.readfp',
                           'mimetypes.add_type': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.add_type',
                           'mimetypes.guess_all_extensions': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.guess_all_extensions',
                           'mimetypes.guess_extension': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.guess_extension',
                           'mimetypes.guess_type': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.guess_type',
                           'mimetypes.init': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.init',
                           'mimetypes.read_mime_types': 'https://docs.python.org/3/library/mimetypes.html#mimetypes.read_mime_types'},
            'mmap': { 'mmap.mmap': 'https://docs.python.org/3/library/mmap.html#mmap.mmap',
                      'mmap.mmap.close': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.close',
                      'mmap.mmap.find': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.find',
                      'mmap.mmap.flush': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.flush',
                      'mmap.mmap.madvise': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.madvise',
                      'mmap.mmap.move': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.move',
                      'mmap.mmap.read': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.read',
                      'mmap.mmap.read_byte': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.read_byte',
                      'mmap.mmap.readline': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.readline',
                      'mmap.mmap.resize': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.resize',
                      'mmap.mmap.rfind': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.rfind',
                      'mmap.mmap.seek': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.seek',
                      'mmap.mmap.size': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.size',
                      'mmap.mmap.tell': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.tell',
                      'mmap.mmap.write': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.write',
                      'mmap.mmap.write_byte': 'https://docs.python.org/3/library/mmap.html#mmap.mmap.write_byte'},
            'modulefinder': { 'modulefinder.AddPackagePath': 'https://docs.python.org/3/library/modulefinder.html#modulefinder.AddPackagePath',
                              'modulefinder.ModuleFinder': 'https://docs.python.org/3/library/modulefinder.html#modulefinder.ModuleFinder',
                              'modulefinder.ModuleFinder.report': 'https://docs.python.org/3/library/modulefinder.html#modulefinder.ModuleFinder.report',
                              'modulefinder.ModuleFinder.run_script': 'https://docs.python.org/3/library/modulefinder.html#modulefinder.ModuleFinder.run_script',
                              'modulefinder.ReplacePackage': 'https://docs.python.org/3/library/modulefinder.html#modulefinder.ReplacePackage'},
            'msilib': { 'msilib.Binary': 'https://docs.python.org/3/library/msilib.html#msilib.Binary',
                        'msilib.CAB': 'https://docs.python.org/3/library/msilib.html#msilib.CAB',
                        'msilib.CAB.append': 'https://docs.python.org/3/library/msilib.html#msilib.CAB.append',
                        'msilib.CAB.commit': 'https://docs.python.org/3/library/msilib.html#msilib.CAB.commit',
                        'msilib.Control': 'https://docs.python.org/3/library/msilib.html#msilib.Control',
                        'msilib.Control.condition': 'https://docs.python.org/3/library/msilib.html#msilib.Control.condition',
                        'msilib.Control.event': 'https://docs.python.org/3/library/msilib.html#msilib.Control.event',
                        'msilib.Control.mapping': 'https://docs.python.org/3/library/msilib.html#msilib.Control.mapping',
                        'msilib.CreateRecord': 'https://docs.python.org/3/library/msilib.html#msilib.CreateRecord',
                        'msilib.Database.Close': 'https://docs.python.org/3/library/msilib.html#msilib.Database.Close',
                        'msilib.Database.Commit': 'https://docs.python.org/3/library/msilib.html#msilib.Database.Commit',
                        'msilib.Database.GetSummaryInformation': 'https://docs.python.org/3/library/msilib.html#msilib.Database.GetSummaryInformation',
                        'msilib.Database.OpenView': 'https://docs.python.org/3/library/msilib.html#msilib.Database.OpenView',
                        'msilib.Dialog': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog',
                        'msilib.Dialog.bitmap': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.bitmap',
                        'msilib.Dialog.checkbox': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.checkbox',
                        'msilib.Dialog.control': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.control',
                        'msilib.Dialog.line': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.line',
                        'msilib.Dialog.pushbutton': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.pushbutton',
                        'msilib.Dialog.radiogroup': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.radiogroup',
                        'msilib.Dialog.text': 'https://docs.python.org/3/library/msilib.html#msilib.Dialog.text',
                        'msilib.Directory': 'https://docs.python.org/3/library/msilib.html#msilib.Directory',
                        'msilib.Directory.add_file': 'https://docs.python.org/3/library/msilib.html#msilib.Directory.add_file',
                        'msilib.Directory.glob': 'https://docs.python.org/3/library/msilib.html#msilib.Directory.glob',
                        'msilib.Directory.remove_pyc': 'https://docs.python.org/3/library/msilib.html#msilib.Directory.remove_pyc',
                        'msilib.Directory.start_component': 'https://docs.python.org/3/library/msilib.html#msilib.Directory.start_component',
                        'msilib.FCICreate': 'https://docs.python.org/3/library/msilib.html#msilib.FCICreate',
                        'msilib.Feature': 'https://docs.python.org/3/library/msilib.html#msilib.Feature',
                        'msilib.Feature.set_current': 'https://docs.python.org/3/library/msilib.html#msilib.Feature.set_current',
                        'msilib.OpenDatabase': 'https://docs.python.org/3/library/msilib.html#msilib.OpenDatabase',
                        'msilib.RadioButtonGroup': 'https://docs.python.org/3/library/msilib.html#msilib.RadioButtonGroup',
                        'msilib.RadioButtonGroup.add': 'https://docs.python.org/3/library/msilib.html#msilib.RadioButtonGroup.add',
                        'msilib.Record.ClearData': 'https://docs.python.org/3/library/msilib.html#msilib.Record.ClearData',
                        'msilib.Record.GetFieldCount': 'https://docs.python.org/3/library/msilib.html#msilib.Record.GetFieldCount',
                        'msilib.Record.GetInteger': 'https://docs.python.org/3/library/msilib.html#msilib.Record.GetInteger',
                        'msilib.Record.GetString': 'https://docs.python.org/3/library/msilib.html#msilib.Record.GetString',
                        'msilib.Record.SetInteger': 'https://docs.python.org/3/library/msilib.html#msilib.Record.SetInteger',
                        'msilib.Record.SetStream': 'https://docs.python.org/3/library/msilib.html#msilib.Record.SetStream',
                        'msilib.Record.SetString': 'https://docs.python.org/3/library/msilib.html#msilib.Record.SetString',
                        'msilib.SummaryInformation.GetProperty': 'https://docs.python.org/3/library/msilib.html#msilib.SummaryInformation.GetProperty',
                        'msilib.SummaryInformation.GetPropertyCount': 'https://docs.python.org/3/library/msilib.html#msilib.SummaryInformation.GetPropertyCount',
                        'msilib.SummaryInformation.Persist': 'https://docs.python.org/3/library/msilib.html#msilib.SummaryInformation.Persist',
                        'msilib.SummaryInformation.SetProperty': 'https://docs.python.org/3/library/msilib.html#msilib.SummaryInformation.SetProperty',
                        'msilib.UuidCreate': 'https://docs.python.org/3/library/msilib.html#msilib.UuidCreate',
                        'msilib.View.Close': 'https://docs.python.org/3/library/msilib.html#msilib.View.Close',
                        'msilib.View.Execute': 'https://docs.python.org/3/library/msilib.html#msilib.View.Execute',
                        'msilib.View.Fetch': 'https://docs.python.org/3/library/msilib.html#msilib.View.Fetch',
                        'msilib.View.GetColumnInfo': 'https://docs.python.org/3/library/msilib.html#msilib.View.GetColumnInfo',
                        'msilib.View.Modify': 'https://docs.python.org/3/library/msilib.html#msilib.View.Modify',
                        'msilib.add_data': 'https://docs.python.org/3/library/msilib.html#msilib.add_data',
                        'msilib.add_stream': 'https://docs.python.org/3/library/msilib.html#msilib.add_stream',
                        'msilib.add_tables': 'https://docs.python.org/3/library/msilib.html#msilib.add_tables',
                        'msilib.gen_uuid': 'https://docs.python.org/3/library/msilib.html#msilib.gen_uuid',
                        'msilib.init_database': 'https://docs.python.org/3/library/msilib.html#msilib.init_database'},
            'msvcrt': { 'msvcrt.get_osfhandle': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.get_osfhandle',
                        'msvcrt.getch': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.getch',
                        'msvcrt.getche': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.getche',
                        'msvcrt.getwch': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.getwch',
                        'msvcrt.getwche': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.getwche',
                        'msvcrt.heapmin': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.heapmin',
                        'msvcrt.kbhit': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.kbhit',
                        'msvcrt.locking': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.locking',
                        'msvcrt.open_osfhandle': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.open_osfhandle',
                        'msvcrt.putch': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.putch',
                        'msvcrt.putwch': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.putwch',
                        'msvcrt.setmode': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.setmode',
                        'msvcrt.ungetch': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.ungetch',
                        'msvcrt.ungetwch': 'https://docs.python.org/3/library/msvcrt.html#msvcrt.ungetwch'},
            'multiprocessing': { 'multiprocessing.Array': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Array',
                                 'multiprocessing.Barrier': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Barrier',
                                 'multiprocessing.BoundedSemaphore': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.BoundedSemaphore',
                                 'multiprocessing.Condition': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Condition',
                                 'multiprocessing.Event': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Event',
                                 'multiprocessing.JoinableQueue': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.JoinableQueue',
                                 'multiprocessing.JoinableQueue.join': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.JoinableQueue.join',
                                 'multiprocessing.JoinableQueue.task_done': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.JoinableQueue.task_done',
                                 'multiprocessing.Lock': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Lock',
                                 'multiprocessing.Lock.acquire': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Lock.acquire',
                                 'multiprocessing.Lock.release': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Lock.release',
                                 'multiprocessing.Manager': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Manager',
                                 'multiprocessing.Pipe': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Pipe',
                                 'multiprocessing.Process': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process',
                                 'multiprocessing.Process.close': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.close',
                                 'multiprocessing.Process.is_alive': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.is_alive',
                                 'multiprocessing.Process.join': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.join',
                                 'multiprocessing.Process.kill': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.kill',
                                 'multiprocessing.Process.run': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.run',
                                 'multiprocessing.Process.start': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.start',
                                 'multiprocessing.Process.terminate': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Process.terminate',
                                 'multiprocessing.Queue': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue',
                                 'multiprocessing.Queue.cancel_join_thread': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.cancel_join_thread',
                                 'multiprocessing.Queue.close': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.close',
                                 'multiprocessing.Queue.empty': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.empty',
                                 'multiprocessing.Queue.full': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.full',
                                 'multiprocessing.Queue.get': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.get',
                                 'multiprocessing.Queue.get_nowait': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.get_nowait',
                                 'multiprocessing.Queue.join_thread': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.join_thread',
                                 'multiprocessing.Queue.put': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.put',
                                 'multiprocessing.Queue.put_nowait': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.put_nowait',
                                 'multiprocessing.Queue.qsize': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Queue.qsize',
                                 'multiprocessing.RLock': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.RLock',
                                 'multiprocessing.RLock.acquire': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.RLock.acquire',
                                 'multiprocessing.RLock.release': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.RLock.release',
                                 'multiprocessing.Semaphore': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Semaphore',
                                 'multiprocessing.SimpleQueue': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.SimpleQueue',
                                 'multiprocessing.SimpleQueue.close': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.SimpleQueue.close',
                                 'multiprocessing.SimpleQueue.empty': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.SimpleQueue.empty',
                                 'multiprocessing.SimpleQueue.get': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.SimpleQueue.get',
                                 'multiprocessing.SimpleQueue.put': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.SimpleQueue.put',
                                 'multiprocessing.Value': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.Value',
                                 'multiprocessing.active_children': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.active_children',
                                 'multiprocessing.connection': 'https://docs.python.org/3/library/multiprocessing.html#module-multiprocessing.connection',
                                 'multiprocessing.cpu_count': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.cpu_count',
                                 'multiprocessing.current_process': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.current_process',
                                 'multiprocessing.dummy': 'https://docs.python.org/3/library/multiprocessing.html#module-multiprocessing.dummy',
                                 'multiprocessing.freeze_support': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.freeze_support',
                                 'multiprocessing.get_all_start_methods': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.get_all_start_methods',
                                 'multiprocessing.get_context': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.get_context',
                                 'multiprocessing.get_logger': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.get_logger',
                                 'multiprocessing.get_start_method': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.get_start_method',
                                 'multiprocessing.log_to_stderr': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.log_to_stderr',
                                 'multiprocessing.managers': 'https://docs.python.org/3/library/multiprocessing.html#module-multiprocessing.managers',
                                 'multiprocessing.parent_process': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.parent_process',
                                 'multiprocessing.pool': 'https://docs.python.org/3/library/multiprocessing.html#module-multiprocessing.pool',
                                 'multiprocessing.set_executable': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.set_executable',
                                 'multiprocessing.set_start_method': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.set_start_method',
                                 'multiprocessing.shared_memory': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#module-multiprocessing.shared_memory',
                                 'multiprocessing.sharedctypes': 'https://docs.python.org/3/library/multiprocessing.html#module-multiprocessing.sharedctypes'},
            'multiprocessing.connection': { 'multiprocessing.connection.Client': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Client',
                                            'multiprocessing.connection.Connection': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection',
                                            'multiprocessing.connection.Connection.close': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.close',
                                            'multiprocessing.connection.Connection.fileno': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.fileno',
                                            'multiprocessing.connection.Connection.poll': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.poll',
                                            'multiprocessing.connection.Connection.recv': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.recv',
                                            'multiprocessing.connection.Connection.recv_bytes': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.recv_bytes',
                                            'multiprocessing.connection.Connection.recv_bytes_into': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.recv_bytes_into',
                                            'multiprocessing.connection.Connection.send': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.send',
                                            'multiprocessing.connection.Connection.send_bytes': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Connection.send_bytes',
                                            'multiprocessing.connection.Listener': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Listener',
                                            'multiprocessing.connection.Listener.accept': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Listener.accept',
                                            'multiprocessing.connection.Listener.close': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.Listener.close',
                                            'multiprocessing.connection.answer_challenge': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.answer_challenge',
                                            'multiprocessing.connection.deliver_challenge': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.deliver_challenge',
                                            'multiprocessing.connection.wait': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.connection.wait'},
            'multiprocessing.managers': { 'multiprocessing.managers.BaseManager': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseManager',
                                          'multiprocessing.managers.BaseManager.connect': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseManager.connect',
                                          'multiprocessing.managers.BaseManager.get_server': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseManager.get_server',
                                          'multiprocessing.managers.BaseManager.register': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseManager.register',
                                          'multiprocessing.managers.BaseManager.shutdown': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseManager.shutdown',
                                          'multiprocessing.managers.BaseManager.start': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseManager.start',
                                          'multiprocessing.managers.BaseProxy': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseProxy',
                                          'multiprocessing.managers.BaseProxy.__repr__': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseProxy.__repr__',
                                          'multiprocessing.managers.BaseProxy.__str__': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseProxy.__str__',
                                          'multiprocessing.managers.BaseProxy._callmethod': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseProxy._callmethod',
                                          'multiprocessing.managers.BaseProxy._getvalue': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.BaseProxy._getvalue',
                                          'multiprocessing.managers.Namespace': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.Namespace',
                                          'multiprocessing.managers.SharedMemoryManager': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.managers.SharedMemoryManager',
                                          'multiprocessing.managers.SharedMemoryManager.ShareableList': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.managers.SharedMemoryManager.ShareableList',
                                          'multiprocessing.managers.SharedMemoryManager.SharedMemory': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.managers.SharedMemoryManager.SharedMemory',
                                          'multiprocessing.managers.SyncManager': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager',
                                          'multiprocessing.managers.SyncManager.Array': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Array',
                                          'multiprocessing.managers.SyncManager.Barrier': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Barrier',
                                          'multiprocessing.managers.SyncManager.BoundedSemaphore': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.BoundedSemaphore',
                                          'multiprocessing.managers.SyncManager.Condition': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Condition',
                                          'multiprocessing.managers.SyncManager.Event': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Event',
                                          'multiprocessing.managers.SyncManager.Lock': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Lock',
                                          'multiprocessing.managers.SyncManager.Namespace': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Namespace',
                                          'multiprocessing.managers.SyncManager.Queue': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Queue',
                                          'multiprocessing.managers.SyncManager.RLock': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.RLock',
                                          'multiprocessing.managers.SyncManager.Semaphore': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Semaphore',
                                          'multiprocessing.managers.SyncManager.Value': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.Value',
                                          'multiprocessing.managers.SyncManager.dict': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.dict',
                                          'multiprocessing.managers.SyncManager.list': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.managers.SyncManager.list'},
            'multiprocessing.pool': { 'multiprocessing.pool.AsyncResult': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.AsyncResult',
                                      'multiprocessing.pool.AsyncResult.get': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.AsyncResult.get',
                                      'multiprocessing.pool.AsyncResult.ready': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.AsyncResult.ready',
                                      'multiprocessing.pool.AsyncResult.successful': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.AsyncResult.successful',
                                      'multiprocessing.pool.AsyncResult.wait': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.AsyncResult.wait',
                                      'multiprocessing.pool.Pool': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool',
                                      'multiprocessing.pool.Pool.apply': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.apply',
                                      'multiprocessing.pool.Pool.apply_async': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.apply_async',
                                      'multiprocessing.pool.Pool.close': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.close',
                                      'multiprocessing.pool.Pool.imap': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.imap',
                                      'multiprocessing.pool.Pool.imap_unordered': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.imap_unordered',
                                      'multiprocessing.pool.Pool.join': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.join',
                                      'multiprocessing.pool.Pool.map': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.map',
                                      'multiprocessing.pool.Pool.map_async': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.map_async',
                                      'multiprocessing.pool.Pool.starmap': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.starmap',
                                      'multiprocessing.pool.Pool.starmap_async': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.starmap_async',
                                      'multiprocessing.pool.Pool.terminate': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.terminate',
                                      'multiprocessing.pool.ThreadPool': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.ThreadPool'},
            'multiprocessing.shared_memory': { 'multiprocessing.shared_memory.ShareableList': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.shared_memory.ShareableList',
                                               'multiprocessing.shared_memory.ShareableList.count': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.shared_memory.ShareableList.count',
                                               'multiprocessing.shared_memory.ShareableList.index': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.shared_memory.ShareableList.index',
                                               'multiprocessing.shared_memory.SharedMemory': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.shared_memory.SharedMemory',
                                               'multiprocessing.shared_memory.SharedMemory.close': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.shared_memory.SharedMemory.close',
                                               'multiprocessing.shared_memory.SharedMemory.unlink': 'https://docs.python.org/3/library/multiprocessing.shared_memory.html#multiprocessing.shared_memory.SharedMemory.unlink'},
            'multiprocessing.sharedctypes': { 'multiprocessing.sharedctypes.Array': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.sharedctypes.Array',
                                              'multiprocessing.sharedctypes.RawArray': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.sharedctypes.RawArray',
                                              'multiprocessing.sharedctypes.RawValue': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.sharedctypes.RawValue',
                                              'multiprocessing.sharedctypes.Value': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.sharedctypes.Value',
                                              'multiprocessing.sharedctypes.copy': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.sharedctypes.copy',
                                              'multiprocessing.sharedctypes.synchronized': 'https://docs.python.org/3/library/multiprocessing.html#multiprocessing.sharedctypes.synchronized'},
            'netrc': { 'netrc.netrc': 'https://docs.python.org/3/library/netrc.html#netrc.netrc',
                       'netrc.netrc.__repr__': 'https://docs.python.org/3/library/netrc.html#netrc.netrc.__repr__',
                       'netrc.netrc.authenticators': 'https://docs.python.org/3/library/netrc.html#netrc.netrc.authenticators'},
            'nis': { 'nis.cat': 'https://docs.python.org/3/library/nis.html#nis.cat',
                     'nis.get_default_domain': 'https://docs.python.org/3/library/nis.html#nis.get_default_domain',
                     'nis.maps': 'https://docs.python.org/3/library/nis.html#nis.maps',
                     'nis.match': 'https://docs.python.org/3/library/nis.html#nis.match'},
            'nntplib': { 'nntplib.NNTP': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP',
                         'nntplib.NNTP.article': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.article',
                         'nntplib.NNTP.body': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.body',
                         'nntplib.NNTP.date': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.date',
                         'nntplib.NNTP.description': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.description',
                         'nntplib.NNTP.descriptions': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.descriptions',
                         'nntplib.NNTP.getcapabilities': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.getcapabilities',
                         'nntplib.NNTP.getwelcome': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.getwelcome',
                         'nntplib.NNTP.group': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.group',
                         'nntplib.NNTP.head': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.head',
                         'nntplib.NNTP.help': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.help',
                         'nntplib.NNTP.ihave': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.ihave',
                         'nntplib.NNTP.last': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.last',
                         'nntplib.NNTP.list': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.list',
                         'nntplib.NNTP.login': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.login',
                         'nntplib.NNTP.newgroups': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.newgroups',
                         'nntplib.NNTP.newnews': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.newnews',
                         'nntplib.NNTP.next': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.next',
                         'nntplib.NNTP.over': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.over',
                         'nntplib.NNTP.post': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.post',
                         'nntplib.NNTP.quit': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.quit',
                         'nntplib.NNTP.set_debuglevel': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.set_debuglevel',
                         'nntplib.NNTP.slave': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.slave',
                         'nntplib.NNTP.starttls': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.starttls',
                         'nntplib.NNTP.stat': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.stat',
                         'nntplib.NNTP.xhdr': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.xhdr',
                         'nntplib.NNTP.xover': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP.xover',
                         'nntplib.NNTP_SSL': 'https://docs.python.org/3/library/nntplib.html#nntplib.NNTP_SSL',
                         'nntplib.decode_header': 'https://docs.python.org/3/library/nntplib.html#nntplib.decode_header'},
            'numbers': { 'numbers.Complex': 'https://docs.python.org/3/library/numbers.html#numbers.Complex',
                         'numbers.Complex.conjugate': 'https://docs.python.org/3/library/numbers.html#numbers.Complex.conjugate',
                         'numbers.Integral': 'https://docs.python.org/3/library/numbers.html#numbers.Integral',
                         'numbers.Number': 'https://docs.python.org/3/library/numbers.html#numbers.Number',
                         'numbers.Rational': 'https://docs.python.org/3/library/numbers.html#numbers.Rational',
                         'numbers.Real': 'https://docs.python.org/3/library/numbers.html#numbers.Real'},
            'operator': { 'operator.__abs__': 'https://docs.python.org/3/library/operator.html#operator.__abs__',
                          'operator.__add__': 'https://docs.python.org/3/library/operator.html#operator.__add__',
                          'operator.__and__': 'https://docs.python.org/3/library/operator.html#operator.__and__',
                          'operator.__concat__': 'https://docs.python.org/3/library/operator.html#operator.__concat__',
                          'operator.__contains__': 'https://docs.python.org/3/library/operator.html#operator.__contains__',
                          'operator.__delitem__': 'https://docs.python.org/3/library/operator.html#operator.__delitem__',
                          'operator.__eq__': 'https://docs.python.org/3/library/operator.html#operator.__eq__',
                          'operator.__floordiv__': 'https://docs.python.org/3/library/operator.html#operator.__floordiv__',
                          'operator.__ge__': 'https://docs.python.org/3/library/operator.html#operator.__ge__',
                          'operator.__getitem__': 'https://docs.python.org/3/library/operator.html#operator.__getitem__',
                          'operator.__gt__': 'https://docs.python.org/3/library/operator.html#operator.__gt__',
                          'operator.__iadd__': 'https://docs.python.org/3/library/operator.html#operator.__iadd__',
                          'operator.__iand__': 'https://docs.python.org/3/library/operator.html#operator.__iand__',
                          'operator.__iconcat__': 'https://docs.python.org/3/library/operator.html#operator.__iconcat__',
                          'operator.__ifloordiv__': 'https://docs.python.org/3/library/operator.html#operator.__ifloordiv__',
                          'operator.__ilshift__': 'https://docs.python.org/3/library/operator.html#operator.__ilshift__',
                          'operator.__imatmul__': 'https://docs.python.org/3/library/operator.html#operator.__imatmul__',
                          'operator.__imod__': 'https://docs.python.org/3/library/operator.html#operator.__imod__',
                          'operator.__imul__': 'https://docs.python.org/3/library/operator.html#operator.__imul__',
                          'operator.__index__': 'https://docs.python.org/3/library/operator.html#operator.__index__',
                          'operator.__inv__': 'https://docs.python.org/3/library/operator.html#operator.__inv__',
                          'operator.__invert__': 'https://docs.python.org/3/library/operator.html#operator.__invert__',
                          'operator.__ior__': 'https://docs.python.org/3/library/operator.html#operator.__ior__',
                          'operator.__ipow__': 'https://docs.python.org/3/library/operator.html#operator.__ipow__',
                          'operator.__irshift__': 'https://docs.python.org/3/library/operator.html#operator.__irshift__',
                          'operator.__isub__': 'https://docs.python.org/3/library/operator.html#operator.__isub__',
                          'operator.__itruediv__': 'https://docs.python.org/3/library/operator.html#operator.__itruediv__',
                          'operator.__ixor__': 'https://docs.python.org/3/library/operator.html#operator.__ixor__',
                          'operator.__le__': 'https://docs.python.org/3/library/operator.html#operator.__le__',
                          'operator.__lshift__': 'https://docs.python.org/3/library/operator.html#operator.__lshift__',
                          'operator.__lt__': 'https://docs.python.org/3/library/operator.html#operator.__lt__',
                          'operator.__matmul__': 'https://docs.python.org/3/library/operator.html#operator.__matmul__',
                          'operator.__mod__': 'https://docs.python.org/3/library/operator.html#operator.__mod__',
                          'operator.__mul__': 'https://docs.python.org/3/library/operator.html#operator.__mul__',
                          'operator.__ne__': 'https://docs.python.org/3/library/operator.html#operator.__ne__',
                          'operator.__neg__': 'https://docs.python.org/3/library/operator.html#operator.__neg__',
                          'operator.__not__': 'https://docs.python.org/3/library/operator.html#operator.__not__',
                          'operator.__or__': 'https://docs.python.org/3/library/operator.html#operator.__or__',
                          'operator.__pos__': 'https://docs.python.org/3/library/operator.html#operator.__pos__',
                          'operator.__pow__': 'https://docs.python.org/3/library/operator.html#operator.__pow__',
                          'operator.__rshift__': 'https://docs.python.org/3/library/operator.html#operator.__rshift__',
                          'operator.__setitem__': 'https://docs.python.org/3/library/operator.html#operator.__setitem__',
                          'operator.__sub__': 'https://docs.python.org/3/library/operator.html#operator.__sub__',
                          'operator.__truediv__': 'https://docs.python.org/3/library/operator.html#operator.__truediv__',
                          'operator.__xor__': 'https://docs.python.org/3/library/operator.html#operator.__xor__',
                          'operator.abs': 'https://docs.python.org/3/library/operator.html#operator.abs',
                          'operator.add': 'https://docs.python.org/3/library/operator.html#operator.add',
                          'operator.and_': 'https://docs.python.org/3/library/operator.html#operator.and_',
                          'operator.attrgetter': 'https://docs.python.org/3/library/operator.html#operator.attrgetter',
                          'operator.concat': 'https://docs.python.org/3/library/operator.html#operator.concat',
                          'operator.contains': 'https://docs.python.org/3/library/operator.html#operator.contains',
                          'operator.countOf': 'https://docs.python.org/3/library/operator.html#operator.countOf',
                          'operator.delitem': 'https://docs.python.org/3/library/operator.html#operator.delitem',
                          'operator.eq': 'https://docs.python.org/3/library/operator.html#operator.eq',
                          'operator.floordiv': 'https://docs.python.org/3/library/operator.html#operator.floordiv',
                          'operator.ge': 'https://docs.python.org/3/library/operator.html#operator.ge',
                          'operator.getitem': 'https://docs.python.org/3/library/operator.html#operator.getitem',
                          'operator.gt': 'https://docs.python.org/3/library/operator.html#operator.gt',
                          'operator.iadd': 'https://docs.python.org/3/library/operator.html#operator.iadd',
                          'operator.iand': 'https://docs.python.org/3/library/operator.html#operator.iand',
                          'operator.iconcat': 'https://docs.python.org/3/library/operator.html#operator.iconcat',
                          'operator.ifloordiv': 'https://docs.python.org/3/library/operator.html#operator.ifloordiv',
                          'operator.ilshift': 'https://docs.python.org/3/library/operator.html#operator.ilshift',
                          'operator.imatmul': 'https://docs.python.org/3/library/operator.html#operator.imatmul',
                          'operator.imod': 'https://docs.python.org/3/library/operator.html#operator.imod',
                          'operator.imul': 'https://docs.python.org/3/library/operator.html#operator.imul',
                          'operator.index': 'https://docs.python.org/3/library/operator.html#operator.index',
                          'operator.indexOf': 'https://docs.python.org/3/library/operator.html#operator.indexOf',
                          'operator.inv': 'https://docs.python.org/3/library/operator.html#operator.inv',
                          'operator.invert': 'https://docs.python.org/3/library/operator.html#operator.invert',
                          'operator.ior': 'https://docs.python.org/3/library/operator.html#operator.ior',
                          'operator.ipow': 'https://docs.python.org/3/library/operator.html#operator.ipow',
                          'operator.irshift': 'https://docs.python.org/3/library/operator.html#operator.irshift',
                          'operator.is_': 'https://docs.python.org/3/library/operator.html#operator.is_',
                          'operator.is_not': 'https://docs.python.org/3/library/operator.html#operator.is_not',
                          'operator.isub': 'https://docs.python.org/3/library/operator.html#operator.isub',
                          'operator.itemgetter': 'https://docs.python.org/3/library/operator.html#operator.itemgetter',
                          'operator.itruediv': 'https://docs.python.org/3/library/operator.html#operator.itruediv',
                          'operator.ixor': 'https://docs.python.org/3/library/operator.html#operator.ixor',
                          'operator.le': 'https://docs.python.org/3/library/operator.html#operator.le',
                          'operator.length_hint': 'https://docs.python.org/3/library/operator.html#operator.length_hint',
                          'operator.lshift': 'https://docs.python.org/3/library/operator.html#operator.lshift',
                          'operator.lt': 'https://docs.python.org/3/library/operator.html#operator.lt',
                          'operator.matmul': 'https://docs.python.org/3/library/operator.html#operator.matmul',
                          'operator.methodcaller': 'https://docs.python.org/3/library/operator.html#operator.methodcaller',
                          'operator.mod': 'https://docs.python.org/3/library/operator.html#operator.mod',
                          'operator.mul': 'https://docs.python.org/3/library/operator.html#operator.mul',
                          'operator.ne': 'https://docs.python.org/3/library/operator.html#operator.ne',
                          'operator.neg': 'https://docs.python.org/3/library/operator.html#operator.neg',
                          'operator.not_': 'https://docs.python.org/3/library/operator.html#operator.not_',
                          'operator.or_': 'https://docs.python.org/3/library/operator.html#operator.or_',
                          'operator.pos': 'https://docs.python.org/3/library/operator.html#operator.pos',
                          'operator.pow': 'https://docs.python.org/3/library/operator.html#operator.pow',
                          'operator.rshift': 'https://docs.python.org/3/library/operator.html#operator.rshift',
                          'operator.setitem': 'https://docs.python.org/3/library/operator.html#operator.setitem',
                          'operator.sub': 'https://docs.python.org/3/library/operator.html#operator.sub',
                          'operator.truediv': 'https://docs.python.org/3/library/operator.html#operator.truediv',
                          'operator.truth': 'https://docs.python.org/3/library/operator.html#operator.truth',
                          'operator.xor': 'https://docs.python.org/3/library/operator.html#operator.xor'},
            'optparse': { 'optparse.OptionGroup': 'https://docs.python.org/3/library/optparse.html#optparse.OptionGroup',
                          'optparse.OptionParser': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser',
                          'optparse.OptionParser.add_option': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.add_option',
                          'optparse.OptionParser.disable_interspersed_args': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.disable_interspersed_args',
                          'optparse.OptionParser.enable_interspersed_args': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.enable_interspersed_args',
                          'optparse.OptionParser.get_option': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.get_option',
                          'optparse.OptionParser.get_option_group': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.get_option_group',
                          'optparse.OptionParser.get_usage': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.get_usage',
                          'optparse.OptionParser.get_version': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.get_version',
                          'optparse.OptionParser.has_option': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.has_option',
                          'optparse.OptionParser.print_usage': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.print_usage',
                          'optparse.OptionParser.print_version': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.print_version',
                          'optparse.OptionParser.remove_option': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.remove_option',
                          'optparse.OptionParser.set_defaults': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.set_defaults',
                          'optparse.OptionParser.set_usage': 'https://docs.python.org/3/library/optparse.html#optparse.OptionParser.set_usage'},
            'os': { 'os.DirEntry': 'https://docs.python.org/3/library/os.html#os.DirEntry',
                    'os.DirEntry.inode': 'https://docs.python.org/3/library/os.html#os.DirEntry.inode',
                    'os.DirEntry.is_dir': 'https://docs.python.org/3/library/os.html#os.DirEntry.is_dir',
                    'os.DirEntry.is_file': 'https://docs.python.org/3/library/os.html#os.DirEntry.is_file',
                    'os.DirEntry.is_symlink': 'https://docs.python.org/3/library/os.html#os.DirEntry.is_symlink',
                    'os.DirEntry.stat': 'https://docs.python.org/3/library/os.html#os.DirEntry.stat',
                    'os.PathLike': 'https://docs.python.org/3/library/os.html#os.PathLike',
                    'os.PathLike.__fspath__': 'https://docs.python.org/3/library/os.html#os.PathLike.__fspath__',
                    'os.WCOREDUMP': 'https://docs.python.org/3/library/os.html#os.WCOREDUMP',
                    'os.WEXITSTATUS': 'https://docs.python.org/3/library/os.html#os.WEXITSTATUS',
                    'os.WIFCONTINUED': 'https://docs.python.org/3/library/os.html#os.WIFCONTINUED',
                    'os.WIFEXITED': 'https://docs.python.org/3/library/os.html#os.WIFEXITED',
                    'os.WIFSIGNALED': 'https://docs.python.org/3/library/os.html#os.WIFSIGNALED',
                    'os.WIFSTOPPED': 'https://docs.python.org/3/library/os.html#os.WIFSTOPPED',
                    'os.WSTOPSIG': 'https://docs.python.org/3/library/os.html#os.WSTOPSIG',
                    'os.WTERMSIG': 'https://docs.python.org/3/library/os.html#os.WTERMSIG',
                    'os._exit': 'https://docs.python.org/3/library/os.html#os._exit',
                    'os.abort': 'https://docs.python.org/3/library/os.html#os.abort',
                    'os.access': 'https://docs.python.org/3/library/os.html#os.access',
                    'os.add_dll_directory': 'https://docs.python.org/3/library/os.html#os.add_dll_directory',
                    'os.chdir': 'https://docs.python.org/3/library/os.html#os.chdir',
                    'os.chflags': 'https://docs.python.org/3/library/os.html#os.chflags',
                    'os.chmod': 'https://docs.python.org/3/library/os.html#os.chmod',
                    'os.chown': 'https://docs.python.org/3/library/os.html#os.chown',
                    'os.chroot': 'https://docs.python.org/3/library/os.html#os.chroot',
                    'os.close': 'https://docs.python.org/3/library/os.html#os.close',
                    'os.closerange': 'https://docs.python.org/3/library/os.html#os.closerange',
                    'os.confstr': 'https://docs.python.org/3/library/os.html#os.confstr',
                    'os.copy_file_range': 'https://docs.python.org/3/library/os.html#os.copy_file_range',
                    'os.cpu_count': 'https://docs.python.org/3/library/os.html#os.cpu_count',
                    'os.ctermid': 'https://docs.python.org/3/library/os.html#os.ctermid',
                    'os.device_encoding': 'https://docs.python.org/3/library/os.html#os.device_encoding',
                    'os.dup': 'https://docs.python.org/3/library/os.html#os.dup',
                    'os.dup2': 'https://docs.python.org/3/library/os.html#os.dup2',
                    'os.eventfd': 'https://docs.python.org/3/library/os.html#os.eventfd',
                    'os.eventfd_read': 'https://docs.python.org/3/library/os.html#os.eventfd_read',
                    'os.eventfd_write': 'https://docs.python.org/3/library/os.html#os.eventfd_write',
                    'os.execl': 'https://docs.python.org/3/library/os.html#os.execl',
                    'os.execle': 'https://docs.python.org/3/library/os.html#os.execle',
                    'os.execlp': 'https://docs.python.org/3/library/os.html#os.execlp',
                    'os.execlpe': 'https://docs.python.org/3/library/os.html#os.execlpe',
                    'os.execv': 'https://docs.python.org/3/library/os.html#os.execv',
                    'os.execve': 'https://docs.python.org/3/library/os.html#os.execve',
                    'os.execvp': 'https://docs.python.org/3/library/os.html#os.execvp',
                    'os.execvpe': 'https://docs.python.org/3/library/os.html#os.execvpe',
                    'os.fchdir': 'https://docs.python.org/3/library/os.html#os.fchdir',
                    'os.fchmod': 'https://docs.python.org/3/library/os.html#os.fchmod',
                    'os.fchown': 'https://docs.python.org/3/library/os.html#os.fchown',
                    'os.fdatasync': 'https://docs.python.org/3/library/os.html#os.fdatasync',
                    'os.fdopen': 'https://docs.python.org/3/library/os.html#os.fdopen',
                    'os.fork': 'https://docs.python.org/3/library/os.html#os.fork',
                    'os.forkpty': 'https://docs.python.org/3/library/os.html#os.forkpty',
                    'os.fpathconf': 'https://docs.python.org/3/library/os.html#os.fpathconf',
                    'os.fsdecode': 'https://docs.python.org/3/library/os.html#os.fsdecode',
                    'os.fsencode': 'https://docs.python.org/3/library/os.html#os.fsencode',
                    'os.fspath': 'https://docs.python.org/3/library/os.html#os.fspath',
                    'os.fstat': 'https://docs.python.org/3/library/os.html#os.fstat',
                    'os.fstatvfs': 'https://docs.python.org/3/library/os.html#os.fstatvfs',
                    'os.fsync': 'https://docs.python.org/3/library/os.html#os.fsync',
                    'os.ftruncate': 'https://docs.python.org/3/library/os.html#os.ftruncate',
                    'os.fwalk': 'https://docs.python.org/3/library/os.html#os.fwalk',
                    'os.get_blocking': 'https://docs.python.org/3/library/os.html#os.get_blocking',
                    'os.get_exec_path': 'https://docs.python.org/3/library/os.html#os.get_exec_path',
                    'os.get_handle_inheritable': 'https://docs.python.org/3/library/os.html#os.get_handle_inheritable',
                    'os.get_inheritable': 'https://docs.python.org/3/library/os.html#os.get_inheritable',
                    'os.get_terminal_size': 'https://docs.python.org/3/library/os.html#os.get_terminal_size',
                    'os.getcwd': 'https://docs.python.org/3/library/os.html#os.getcwd',
                    'os.getcwdb': 'https://docs.python.org/3/library/os.html#os.getcwdb',
                    'os.getegid': 'https://docs.python.org/3/library/os.html#os.getegid',
                    'os.getenv': 'https://docs.python.org/3/library/os.html#os.getenv',
                    'os.getenvb': 'https://docs.python.org/3/library/os.html#os.getenvb',
                    'os.geteuid': 'https://docs.python.org/3/library/os.html#os.geteuid',
                    'os.getgid': 'https://docs.python.org/3/library/os.html#os.getgid',
                    'os.getgrouplist': 'https://docs.python.org/3/library/os.html#os.getgrouplist',
                    'os.getgroups': 'https://docs.python.org/3/library/os.html#os.getgroups',
                    'os.getloadavg': 'https://docs.python.org/3/library/os.html#os.getloadavg',
                    'os.getlogin': 'https://docs.python.org/3/library/os.html#os.getlogin',
                    'os.getpgid': 'https://docs.python.org/3/library/os.html#os.getpgid',
                    'os.getpgrp': 'https://docs.python.org/3/library/os.html#os.getpgrp',
                    'os.getpid': 'https://docs.python.org/3/library/os.html#os.getpid',
                    'os.getppid': 'https://docs.python.org/3/library/os.html#os.getppid',
                    'os.getpriority': 'https://docs.python.org/3/library/os.html#os.getpriority',
                    'os.getrandom': 'https://docs.python.org/3/library/os.html#os.getrandom',
                    'os.getresgid': 'https://docs.python.org/3/library/os.html#os.getresgid',
                    'os.getresuid': 'https://docs.python.org/3/library/os.html#os.getresuid',
                    'os.getsid': 'https://docs.python.org/3/library/os.html#os.getsid',
                    'os.getuid': 'https://docs.python.org/3/library/os.html#os.getuid',
                    'os.getxattr': 'https://docs.python.org/3/library/os.html#os.getxattr',
                    'os.initgroups': 'https://docs.python.org/3/library/os.html#os.initgroups',
                    'os.isatty': 'https://docs.python.org/3/library/os.html#os.isatty',
                    'os.kill': 'https://docs.python.org/3/library/os.html#os.kill',
                    'os.killpg': 'https://docs.python.org/3/library/os.html#os.killpg',
                    'os.lchflags': 'https://docs.python.org/3/library/os.html#os.lchflags',
                    'os.lchmod': 'https://docs.python.org/3/library/os.html#os.lchmod',
                    'os.lchown': 'https://docs.python.org/3/library/os.html#os.lchown',
                    'os.link': 'https://docs.python.org/3/library/os.html#os.link',
                    'os.listdir': 'https://docs.python.org/3/library/os.html#os.listdir',
                    'os.listxattr': 'https://docs.python.org/3/library/os.html#os.listxattr',
                    'os.lockf': 'https://docs.python.org/3/library/os.html#os.lockf',
                    'os.lseek': 'https://docs.python.org/3/library/os.html#os.lseek',
                    'os.lstat': 'https://docs.python.org/3/library/os.html#os.lstat',
                    'os.major': 'https://docs.python.org/3/library/os.html#os.major',
                    'os.makedev': 'https://docs.python.org/3/library/os.html#os.makedev',
                    'os.makedirs': 'https://docs.python.org/3/library/os.html#os.makedirs',
                    'os.memfd_create': 'https://docs.python.org/3/library/os.html#os.memfd_create',
                    'os.minor': 'https://docs.python.org/3/library/os.html#os.minor',
                    'os.mkdir': 'https://docs.python.org/3/library/os.html#os.mkdir',
                    'os.mkfifo': 'https://docs.python.org/3/library/os.html#os.mkfifo',
                    'os.mknod': 'https://docs.python.org/3/library/os.html#os.mknod',
                    'os.nice': 'https://docs.python.org/3/library/os.html#os.nice',
                    'os.open': 'https://docs.python.org/3/library/os.html#os.open',
                    'os.openpty': 'https://docs.python.org/3/library/os.html#os.openpty',
                    'os.path': 'https://docs.python.org/3/library/os.path.html#module-os.path',
                    'os.pathconf': 'https://docs.python.org/3/library/os.html#os.pathconf',
                    'os.pidfd_open': 'https://docs.python.org/3/library/os.html#os.pidfd_open',
                    'os.pipe': 'https://docs.python.org/3/library/os.html#os.pipe',
                    'os.pipe2': 'https://docs.python.org/3/library/os.html#os.pipe2',
                    'os.plock': 'https://docs.python.org/3/library/os.html#os.plock',
                    'os.popen': 'https://docs.python.org/3/library/os.html#os.popen',
                    'os.posix_fadvise': 'https://docs.python.org/3/library/os.html#os.posix_fadvise',
                    'os.posix_fallocate': 'https://docs.python.org/3/library/os.html#os.posix_fallocate',
                    'os.posix_spawn': 'https://docs.python.org/3/library/os.html#os.posix_spawn',
                    'os.posix_spawnp': 'https://docs.python.org/3/library/os.html#os.posix_spawnp',
                    'os.pread': 'https://docs.python.org/3/library/os.html#os.pread',
                    'os.preadv': 'https://docs.python.org/3/library/os.html#os.preadv',
                    'os.putenv': 'https://docs.python.org/3/library/os.html#os.putenv',
                    'os.pwrite': 'https://docs.python.org/3/library/os.html#os.pwrite',
                    'os.pwritev': 'https://docs.python.org/3/library/os.html#os.pwritev',
                    'os.read': 'https://docs.python.org/3/library/os.html#os.read',
                    'os.readlink': 'https://docs.python.org/3/library/os.html#os.readlink',
                    'os.readv': 'https://docs.python.org/3/library/os.html#os.readv',
                    'os.register_at_fork': 'https://docs.python.org/3/library/os.html#os.register_at_fork',
                    'os.remove': 'https://docs.python.org/3/library/os.html#os.remove',
                    'os.removedirs': 'https://docs.python.org/3/library/os.html#os.removedirs',
                    'os.removexattr': 'https://docs.python.org/3/library/os.html#os.removexattr',
                    'os.rename': 'https://docs.python.org/3/library/os.html#os.rename',
                    'os.renames': 'https://docs.python.org/3/library/os.html#os.renames',
                    'os.replace': 'https://docs.python.org/3/library/os.html#os.replace',
                    'os.rmdir': 'https://docs.python.org/3/library/os.html#os.rmdir',
                    'os.scandir': 'https://docs.python.org/3/library/os.html#os.scandir',
                    'os.scandir.close': 'https://docs.python.org/3/library/os.html#os.scandir.close',
                    'os.sched_get_priority_max': 'https://docs.python.org/3/library/os.html#os.sched_get_priority_max',
                    'os.sched_get_priority_min': 'https://docs.python.org/3/library/os.html#os.sched_get_priority_min',
                    'os.sched_getaffinity': 'https://docs.python.org/3/library/os.html#os.sched_getaffinity',
                    'os.sched_getparam': 'https://docs.python.org/3/library/os.html#os.sched_getparam',
                    'os.sched_getscheduler': 'https://docs.python.org/3/library/os.html#os.sched_getscheduler',
                    'os.sched_param': 'https://docs.python.org/3/library/os.html#os.sched_param',
                    'os.sched_rr_get_interval': 'https://docs.python.org/3/library/os.html#os.sched_rr_get_interval',
                    'os.sched_setaffinity': 'https://docs.python.org/3/library/os.html#os.sched_setaffinity',
                    'os.sched_setparam': 'https://docs.python.org/3/library/os.html#os.sched_setparam',
                    'os.sched_setscheduler': 'https://docs.python.org/3/library/os.html#os.sched_setscheduler',
                    'os.sched_yield': 'https://docs.python.org/3/library/os.html#os.sched_yield',
                    'os.sendfile': 'https://docs.python.org/3/library/os.html#os.sendfile',
                    'os.set_blocking': 'https://docs.python.org/3/library/os.html#os.set_blocking',
                    'os.set_handle_inheritable': 'https://docs.python.org/3/library/os.html#os.set_handle_inheritable',
                    'os.set_inheritable': 'https://docs.python.org/3/library/os.html#os.set_inheritable',
                    'os.setegid': 'https://docs.python.org/3/library/os.html#os.setegid',
                    'os.seteuid': 'https://docs.python.org/3/library/os.html#os.seteuid',
                    'os.setgid': 'https://docs.python.org/3/library/os.html#os.setgid',
                    'os.setgroups': 'https://docs.python.org/3/library/os.html#os.setgroups',
                    'os.setpgid': 'https://docs.python.org/3/library/os.html#os.setpgid',
                    'os.setpgrp': 'https://docs.python.org/3/library/os.html#os.setpgrp',
                    'os.setpriority': 'https://docs.python.org/3/library/os.html#os.setpriority',
                    'os.setregid': 'https://docs.python.org/3/library/os.html#os.setregid',
                    'os.setresgid': 'https://docs.python.org/3/library/os.html#os.setresgid',
                    'os.setresuid': 'https://docs.python.org/3/library/os.html#os.setresuid',
                    'os.setreuid': 'https://docs.python.org/3/library/os.html#os.setreuid',
                    'os.setsid': 'https://docs.python.org/3/library/os.html#os.setsid',
                    'os.setuid': 'https://docs.python.org/3/library/os.html#os.setuid',
                    'os.setxattr': 'https://docs.python.org/3/library/os.html#os.setxattr',
                    'os.spawnl': 'https://docs.python.org/3/library/os.html#os.spawnl',
                    'os.spawnle': 'https://docs.python.org/3/library/os.html#os.spawnle',
                    'os.spawnlp': 'https://docs.python.org/3/library/os.html#os.spawnlp',
                    'os.spawnlpe': 'https://docs.python.org/3/library/os.html#os.spawnlpe',
                    'os.spawnv': 'https://docs.python.org/3/library/os.html#os.spawnv',
                    'os.spawnve': 'https://docs.python.org/3/library/os.html#os.spawnve',
                    'os.spawnvp': 'https://docs.python.org/3/library/os.html#os.spawnvp',
                    'os.spawnvpe': 'https://docs.python.org/3/library/os.html#os.spawnvpe',
                    'os.splice': 'https://docs.python.org/3/library/os.html#os.splice',
                    'os.startfile': 'https://docs.python.org/3/library/os.html#os.startfile',
                    'os.stat': 'https://docs.python.org/3/library/os.html#os.stat',
                    'os.stat_result': 'https://docs.python.org/3/library/os.html#os.stat_result',
                    'os.statvfs': 'https://docs.python.org/3/library/os.html#os.statvfs',
                    'os.strerror': 'https://docs.python.org/3/library/os.html#os.strerror',
                    'os.symlink': 'https://docs.python.org/3/library/os.html#os.symlink',
                    'os.sync': 'https://docs.python.org/3/library/os.html#os.sync',
                    'os.sysconf': 'https://docs.python.org/3/library/os.html#os.sysconf',
                    'os.system': 'https://docs.python.org/3/library/os.html#os.system',
                    'os.tcgetpgrp': 'https://docs.python.org/3/library/os.html#os.tcgetpgrp',
                    'os.tcsetpgrp': 'https://docs.python.org/3/library/os.html#os.tcsetpgrp',
                    'os.terminal_size': 'https://docs.python.org/3/library/os.html#os.terminal_size',
                    'os.times': 'https://docs.python.org/3/library/os.html#os.times',
                    'os.truncate': 'https://docs.python.org/3/library/os.html#os.truncate',
                    'os.ttyname': 'https://docs.python.org/3/library/os.html#os.ttyname',
                    'os.umask': 'https://docs.python.org/3/library/os.html#os.umask',
                    'os.uname': 'https://docs.python.org/3/library/os.html#os.uname',
                    'os.unlink': 'https://docs.python.org/3/library/os.html#os.unlink',
                    'os.unsetenv': 'https://docs.python.org/3/library/os.html#os.unsetenv',
                    'os.urandom': 'https://docs.python.org/3/library/os.html#os.urandom',
                    'os.utime': 'https://docs.python.org/3/library/os.html#os.utime',
                    'os.wait': 'https://docs.python.org/3/library/os.html#os.wait',
                    'os.wait3': 'https://docs.python.org/3/library/os.html#os.wait3',
                    'os.wait4': 'https://docs.python.org/3/library/os.html#os.wait4',
                    'os.waitid': 'https://docs.python.org/3/library/os.html#os.waitid',
                    'os.waitpid': 'https://docs.python.org/3/library/os.html#os.waitpid',
                    'os.waitstatus_to_exitcode': 'https://docs.python.org/3/library/os.html#os.waitstatus_to_exitcode',
                    'os.walk': 'https://docs.python.org/3/library/os.html#os.walk',
                    'os.write': 'https://docs.python.org/3/library/os.html#os.write',
                    'os.writev': 'https://docs.python.org/3/library/os.html#os.writev'},
            'os.path': { 'os.path.abspath': 'https://docs.python.org/3/library/os.path.html#os.path.abspath',
                         'os.path.basename': 'https://docs.python.org/3/library/os.path.html#os.path.basename',
                         'os.path.commonpath': 'https://docs.python.org/3/library/os.path.html#os.path.commonpath',
                         'os.path.commonprefix': 'https://docs.python.org/3/library/os.path.html#os.path.commonprefix',
                         'os.path.dirname': 'https://docs.python.org/3/library/os.path.html#os.path.dirname',
                         'os.path.exists': 'https://docs.python.org/3/library/os.path.html#os.path.exists',
                         'os.path.expanduser': 'https://docs.python.org/3/library/os.path.html#os.path.expanduser',
                         'os.path.expandvars': 'https://docs.python.org/3/library/os.path.html#os.path.expandvars',
                         'os.path.getatime': 'https://docs.python.org/3/library/os.path.html#os.path.getatime',
                         'os.path.getctime': 'https://docs.python.org/3/library/os.path.html#os.path.getctime',
                         'os.path.getmtime': 'https://docs.python.org/3/library/os.path.html#os.path.getmtime',
                         'os.path.getsize': 'https://docs.python.org/3/library/os.path.html#os.path.getsize',
                         'os.path.isabs': 'https://docs.python.org/3/library/os.path.html#os.path.isabs',
                         'os.path.isdir': 'https://docs.python.org/3/library/os.path.html#os.path.isdir',
                         'os.path.isfile': 'https://docs.python.org/3/library/os.path.html#os.path.isfile',
                         'os.path.islink': 'https://docs.python.org/3/library/os.path.html#os.path.islink',
                         'os.path.ismount': 'https://docs.python.org/3/library/os.path.html#os.path.ismount',
                         'os.path.join': 'https://docs.python.org/3/library/os.path.html#os.path.join',
                         'os.path.lexists': 'https://docs.python.org/3/library/os.path.html#os.path.lexists',
                         'os.path.normcase': 'https://docs.python.org/3/library/os.path.html#os.path.normcase',
                         'os.path.normpath': 'https://docs.python.org/3/library/os.path.html#os.path.normpath',
                         'os.path.realpath': 'https://docs.python.org/3/library/os.path.html#os.path.realpath',
                         'os.path.relpath': 'https://docs.python.org/3/library/os.path.html#os.path.relpath',
                         'os.path.samefile': 'https://docs.python.org/3/library/os.path.html#os.path.samefile',
                         'os.path.sameopenfile': 'https://docs.python.org/3/library/os.path.html#os.path.sameopenfile',
                         'os.path.samestat': 'https://docs.python.org/3/library/os.path.html#os.path.samestat',
                         'os.path.split': 'https://docs.python.org/3/library/os.path.html#os.path.split',
                         'os.path.splitdrive': 'https://docs.python.org/3/library/os.path.html#os.path.splitdrive',
                         'os.path.splitext': 'https://docs.python.org/3/library/os.path.html#os.path.splitext'},
            'ossaudiodev': { 'ossaudiodev.open': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.open',
                             'ossaudiodev.openmixer': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.openmixer',
                             'ossaudiodev.oss_audio_device.bufsize': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.bufsize',
                             'ossaudiodev.oss_audio_device.channels': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.channels',
                             'ossaudiodev.oss_audio_device.close': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.close',
                             'ossaudiodev.oss_audio_device.fileno': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.fileno',
                             'ossaudiodev.oss_audio_device.getfmts': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.getfmts',
                             'ossaudiodev.oss_audio_device.nonblock': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.nonblock',
                             'ossaudiodev.oss_audio_device.obufcount': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.obufcount',
                             'ossaudiodev.oss_audio_device.obuffree': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.obuffree',
                             'ossaudiodev.oss_audio_device.post': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.post',
                             'ossaudiodev.oss_audio_device.read': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.read',
                             'ossaudiodev.oss_audio_device.reset': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.reset',
                             'ossaudiodev.oss_audio_device.setfmt': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.setfmt',
                             'ossaudiodev.oss_audio_device.setparameters': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.setparameters',
                             'ossaudiodev.oss_audio_device.speed': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.speed',
                             'ossaudiodev.oss_audio_device.sync': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.sync',
                             'ossaudiodev.oss_audio_device.write': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.write',
                             'ossaudiodev.oss_audio_device.writeall': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_audio_device.writeall',
                             'ossaudiodev.oss_mixer_device.close': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.close',
                             'ossaudiodev.oss_mixer_device.controls': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.controls',
                             'ossaudiodev.oss_mixer_device.fileno': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.fileno',
                             'ossaudiodev.oss_mixer_device.get': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.get',
                             'ossaudiodev.oss_mixer_device.get_recsrc': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.get_recsrc',
                             'ossaudiodev.oss_mixer_device.reccontrols': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.reccontrols',
                             'ossaudiodev.oss_mixer_device.set': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.set',
                             'ossaudiodev.oss_mixer_device.set_recsrc': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.set_recsrc',
                             'ossaudiodev.oss_mixer_device.stereocontrols': 'https://docs.python.org/3/library/ossaudiodev.html#ossaudiodev.oss_mixer_device.stereocontrols'},
            'pathlib': { 'pathlib.Path': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path',
                         'pathlib.Path.chmod': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.chmod',
                         'pathlib.Path.cwd': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.cwd',
                         'pathlib.Path.exists': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.exists',
                         'pathlib.Path.expanduser': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.expanduser',
                         'pathlib.Path.glob': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.glob',
                         'pathlib.Path.group': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.group',
                         'pathlib.Path.hardlink_to': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.hardlink_to',
                         'pathlib.Path.home': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.home',
                         'pathlib.Path.is_block_device': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_block_device',
                         'pathlib.Path.is_char_device': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_char_device',
                         'pathlib.Path.is_dir': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_dir',
                         'pathlib.Path.is_fifo': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_fifo',
                         'pathlib.Path.is_file': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_file',
                         'pathlib.Path.is_mount': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_mount',
                         'pathlib.Path.is_socket': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_socket',
                         'pathlib.Path.is_symlink': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.is_symlink',
                         'pathlib.Path.iterdir': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.iterdir',
                         'pathlib.Path.lchmod': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.lchmod',
                         'pathlib.Path.link_to': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.link_to',
                         'pathlib.Path.lstat': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.lstat',
                         'pathlib.Path.mkdir': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.mkdir',
                         'pathlib.Path.open': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.open',
                         'pathlib.Path.owner': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.owner',
                         'pathlib.Path.read_bytes': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.read_bytes',
                         'pathlib.Path.read_text': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.read_text',
                         'pathlib.Path.readlink': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.readlink',
                         'pathlib.Path.rename': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.rename',
                         'pathlib.Path.replace': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.replace',
                         'pathlib.Path.resolve': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.resolve',
                         'pathlib.Path.rglob': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.rglob',
                         'pathlib.Path.rmdir': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.rmdir',
                         'pathlib.Path.samefile': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.samefile',
                         'pathlib.Path.stat': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.stat',
                         'pathlib.Path.symlink_to': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.symlink_to',
                         'pathlib.Path.touch': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.touch',
                         'pathlib.Path.unlink': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.unlink',
                         'pathlib.Path.write_bytes': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.write_bytes',
                         'pathlib.Path.write_text': 'https://docs.python.org/3/library/pathlib.html#pathlib.Path.write_text',
                         'pathlib.PosixPath': 'https://docs.python.org/3/library/pathlib.html#pathlib.PosixPath',
                         'pathlib.PurePath': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath',
                         'pathlib.PurePath.as_posix': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.as_posix',
                         'pathlib.PurePath.as_uri': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.as_uri',
                         'pathlib.PurePath.is_absolute': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.is_absolute',
                         'pathlib.PurePath.is_relative_to': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.is_relative_to',
                         'pathlib.PurePath.is_reserved': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.is_reserved',
                         'pathlib.PurePath.joinpath': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.joinpath',
                         'pathlib.PurePath.match': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.match',
                         'pathlib.PurePath.relative_to': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.relative_to',
                         'pathlib.PurePath.with_name': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.with_name',
                         'pathlib.PurePath.with_stem': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.with_stem',
                         'pathlib.PurePath.with_suffix': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePath.with_suffix',
                         'pathlib.PurePosixPath': 'https://docs.python.org/3/library/pathlib.html#pathlib.PurePosixPath',
                         'pathlib.PureWindowsPath': 'https://docs.python.org/3/library/pathlib.html#pathlib.PureWindowsPath',
                         'pathlib.WindowsPath': 'https://docs.python.org/3/library/pathlib.html#pathlib.WindowsPath'},
            'pdb': { 'pdb.Pdb': 'https://docs.python.org/3/library/pdb.html#pdb.Pdb',
                     'pdb.Pdb.run': 'https://docs.python.org/3/library/pdb.html#pdb.Pdb.run',
                     'pdb.Pdb.runcall': 'https://docs.python.org/3/library/pdb.html#pdb.Pdb.runcall',
                     'pdb.Pdb.runeval': 'https://docs.python.org/3/library/pdb.html#pdb.Pdb.runeval',
                     'pdb.Pdb.set_trace': 'https://docs.python.org/3/library/pdb.html#pdb.Pdb.set_trace',
                     'pdb.pm': 'https://docs.python.org/3/library/pdb.html#pdb.pm',
                     'pdb.post_mortem': 'https://docs.python.org/3/library/pdb.html#pdb.post_mortem',
                     'pdb.run': 'https://docs.python.org/3/library/pdb.html#pdb.run',
                     'pdb.runcall': 'https://docs.python.org/3/library/pdb.html#pdb.runcall',
                     'pdb.runeval': 'https://docs.python.org/3/library/pdb.html#pdb.runeval',
                     'pdb.set_trace': 'https://docs.python.org/3/library/pdb.html#pdb.set_trace'},
            'pickle': { 'pickle.PickleBuffer': 'https://docs.python.org/3/library/pickle.html#pickle.PickleBuffer',
                        'pickle.PickleBuffer.raw': 'https://docs.python.org/3/library/pickle.html#pickle.PickleBuffer.raw',
                        'pickle.PickleBuffer.release': 'https://docs.python.org/3/library/pickle.html#pickle.PickleBuffer.release',
                        'pickle.Pickler': 'https://docs.python.org/3/library/pickle.html#pickle.Pickler',
                        'pickle.Pickler.dump': 'https://docs.python.org/3/library/pickle.html#pickle.Pickler.dump',
                        'pickle.Pickler.persistent_id': 'https://docs.python.org/3/library/pickle.html#pickle.Pickler.persistent_id',
                        'pickle.Pickler.reducer_override': 'https://docs.python.org/3/library/pickle.html#pickle.Pickler.reducer_override',
                        'pickle.Unpickler': 'https://docs.python.org/3/library/pickle.html#pickle.Unpickler',
                        'pickle.Unpickler.find_class': 'https://docs.python.org/3/library/pickle.html#pickle.Unpickler.find_class',
                        'pickle.Unpickler.load': 'https://docs.python.org/3/library/pickle.html#pickle.Unpickler.load',
                        'pickle.Unpickler.persistent_load': 'https://docs.python.org/3/library/pickle.html#pickle.Unpickler.persistent_load',
                        'pickle.dump': 'https://docs.python.org/3/library/pickle.html#pickle.dump',
                        'pickle.dumps': 'https://docs.python.org/3/library/pickle.html#pickle.dumps',
                        'pickle.load': 'https://docs.python.org/3/library/pickle.html#pickle.load',
                        'pickle.loads': 'https://docs.python.org/3/library/pickle.html#pickle.loads'},
            'pickletools': { 'pickletools.dis': 'https://docs.python.org/3/library/pickletools.html#pickletools.dis',
                             'pickletools.genops': 'https://docs.python.org/3/library/pickletools.html#pickletools.genops',
                             'pickletools.optimize': 'https://docs.python.org/3/library/pickletools.html#pickletools.optimize'},
            'pipes': { 'pipes.Template': 'https://docs.python.org/3/library/pipes.html#pipes.Template',
                       'pipes.Template.append': 'https://docs.python.org/3/library/pipes.html#pipes.Template.append',
                       'pipes.Template.clone': 'https://docs.python.org/3/library/pipes.html#pipes.Template.clone',
                       'pipes.Template.copy': 'https://docs.python.org/3/library/pipes.html#pipes.Template.copy',
                       'pipes.Template.debug': 'https://docs.python.org/3/library/pipes.html#pipes.Template.debug',
                       'pipes.Template.open': 'https://docs.python.org/3/library/pipes.html#pipes.Template.open',
                       'pipes.Template.prepend': 'https://docs.python.org/3/library/pipes.html#pipes.Template.prepend',
                       'pipes.Template.reset': 'https://docs.python.org/3/library/pipes.html#pipes.Template.reset'},
            'pkgutil': { 'pkgutil.ImpImporter': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.ImpImporter',
                         'pkgutil.ImpLoader': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.ImpLoader',
                         'pkgutil.ModuleInfo': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.ModuleInfo',
                         'pkgutil.extend_path': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.extend_path',
                         'pkgutil.find_loader': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.find_loader',
                         'pkgutil.get_data': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.get_data',
                         'pkgutil.get_importer': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.get_importer',
                         'pkgutil.get_loader': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.get_loader',
                         'pkgutil.iter_importers': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.iter_importers',
                         'pkgutil.iter_modules': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.iter_modules',
                         'pkgutil.resolve_name': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.resolve_name',
                         'pkgutil.walk_packages': 'https://docs.python.org/3/library/pkgutil.html#pkgutil.walk_packages'},
            'platform': { 'platform.architecture': 'https://docs.python.org/3/library/platform.html#platform.architecture',
                          'platform.freedesktop_os_release': 'https://docs.python.org/3/library/platform.html#platform.freedesktop_os_release',
                          'platform.java_ver': 'https://docs.python.org/3/library/platform.html#platform.java_ver',
                          'platform.libc_ver': 'https://docs.python.org/3/library/platform.html#platform.libc_ver',
                          'platform.mac_ver': 'https://docs.python.org/3/library/platform.html#platform.mac_ver',
                          'platform.machine': 'https://docs.python.org/3/library/platform.html#platform.machine',
                          'platform.node': 'https://docs.python.org/3/library/platform.html#platform.node',
                          'platform.platform': 'https://docs.python.org/3/library/platform.html#platform.platform',
                          'platform.processor': 'https://docs.python.org/3/library/platform.html#platform.processor',
                          'platform.python_branch': 'https://docs.python.org/3/library/platform.html#platform.python_branch',
                          'platform.python_build': 'https://docs.python.org/3/library/platform.html#platform.python_build',
                          'platform.python_compiler': 'https://docs.python.org/3/library/platform.html#platform.python_compiler',
                          'platform.python_implementation': 'https://docs.python.org/3/library/platform.html#platform.python_implementation',
                          'platform.python_revision': 'https://docs.python.org/3/library/platform.html#platform.python_revision',
                          'platform.python_version': 'https://docs.python.org/3/library/platform.html#platform.python_version',
                          'platform.python_version_tuple': 'https://docs.python.org/3/library/platform.html#platform.python_version_tuple',
                          'platform.release': 'https://docs.python.org/3/library/platform.html#platform.release',
                          'platform.system': 'https://docs.python.org/3/library/platform.html#platform.system',
                          'platform.system_alias': 'https://docs.python.org/3/library/platform.html#platform.system_alias',
                          'platform.uname': 'https://docs.python.org/3/library/platform.html#platform.uname',
                          'platform.version': 'https://docs.python.org/3/library/platform.html#platform.version',
                          'platform.win32_edition': 'https://docs.python.org/3/library/platform.html#platform.win32_edition',
                          'platform.win32_is_iot': 'https://docs.python.org/3/library/platform.html#platform.win32_is_iot',
                          'platform.win32_ver': 'https://docs.python.org/3/library/platform.html#platform.win32_ver'},
            'plistlib': { 'plistlib.UID': 'https://docs.python.org/3/library/plistlib.html#plistlib.UID',
                          'plistlib.dump': 'https://docs.python.org/3/library/plistlib.html#plistlib.dump',
                          'plistlib.dumps': 'https://docs.python.org/3/library/plistlib.html#plistlib.dumps',
                          'plistlib.load': 'https://docs.python.org/3/library/plistlib.html#plistlib.load',
                          'plistlib.loads': 'https://docs.python.org/3/library/plistlib.html#plistlib.loads'},
            'poplib': { 'poplib.POP3': 'https://docs.python.org/3/library/poplib.html#poplib.POP3',
                        'poplib.POP3.apop': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.apop',
                        'poplib.POP3.capa': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.capa',
                        'poplib.POP3.dele': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.dele',
                        'poplib.POP3.getwelcome': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.getwelcome',
                        'poplib.POP3.list': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.list',
                        'poplib.POP3.noop': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.noop',
                        'poplib.POP3.pass_': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.pass_',
                        'poplib.POP3.quit': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.quit',
                        'poplib.POP3.retr': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.retr',
                        'poplib.POP3.rpop': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.rpop',
                        'poplib.POP3.rset': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.rset',
                        'poplib.POP3.set_debuglevel': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.set_debuglevel',
                        'poplib.POP3.stat': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.stat',
                        'poplib.POP3.stls': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.stls',
                        'poplib.POP3.top': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.top',
                        'poplib.POP3.uidl': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.uidl',
                        'poplib.POP3.user': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.user',
                        'poplib.POP3.utf8': 'https://docs.python.org/3/library/poplib.html#poplib.POP3.utf8',
                        'poplib.POP3_SSL': 'https://docs.python.org/3/library/poplib.html#poplib.POP3_SSL'},
            'pprint': { 'pprint.PrettyPrinter': 'https://docs.python.org/3/library/pprint.html#pprint.PrettyPrinter',
                        'pprint.PrettyPrinter.format': 'https://docs.python.org/3/library/pprint.html#pprint.PrettyPrinter.format',
                        'pprint.PrettyPrinter.isreadable': 'https://docs.python.org/3/library/pprint.html#pprint.PrettyPrinter.isreadable',
                        'pprint.PrettyPrinter.isrecursive': 'https://docs.python.org/3/library/pprint.html#pprint.PrettyPrinter.isrecursive',
                        'pprint.PrettyPrinter.pformat': 'https://docs.python.org/3/library/pprint.html#pprint.PrettyPrinter.pformat',
                        'pprint.PrettyPrinter.pprint': 'https://docs.python.org/3/library/pprint.html#pprint.PrettyPrinter.pprint',
                        'pprint.isreadable': 'https://docs.python.org/3/library/pprint.html#pprint.isreadable',
                        'pprint.isrecursive': 'https://docs.python.org/3/library/pprint.html#pprint.isrecursive',
                        'pprint.pformat': 'https://docs.python.org/3/library/pprint.html#pprint.pformat',
                        'pprint.pp': 'https://docs.python.org/3/library/pprint.html#pprint.pp',
                        'pprint.pprint': 'https://docs.python.org/3/library/pprint.html#pprint.pprint',
                        'pprint.saferepr': 'https://docs.python.org/3/library/pprint.html#pprint.saferepr'},
            'profile': { 'profile.Profile': 'https://docs.python.org/3/library/profile.html#profile.Profile',
                         'profile.Profile.create_stats': 'https://docs.python.org/3/library/profile.html#profile.Profile.create_stats',
                         'profile.Profile.disable': 'https://docs.python.org/3/library/profile.html#profile.Profile.disable',
                         'profile.Profile.dump_stats': 'https://docs.python.org/3/library/profile.html#profile.Profile.dump_stats',
                         'profile.Profile.enable': 'https://docs.python.org/3/library/profile.html#profile.Profile.enable',
                         'profile.Profile.print_stats': 'https://docs.python.org/3/library/profile.html#profile.Profile.print_stats',
                         'profile.Profile.run': 'https://docs.python.org/3/library/profile.html#profile.Profile.run',
                         'profile.Profile.runcall': 'https://docs.python.org/3/library/profile.html#profile.Profile.runcall',
                         'profile.Profile.runctx': 'https://docs.python.org/3/library/profile.html#profile.Profile.runctx',
                         'profile.run': 'https://docs.python.org/3/library/profile.html#profile.run',
                         'profile.runctx': 'https://docs.python.org/3/library/profile.html#profile.runctx'},
            'pstats': { 'pstats.Stats': 'https://docs.python.org/3/library/profile.html#pstats.Stats',
                        'pstats.Stats.add': 'https://docs.python.org/3/library/profile.html#pstats.Stats.add',
                        'pstats.Stats.dump_stats': 'https://docs.python.org/3/library/profile.html#pstats.Stats.dump_stats',
                        'pstats.Stats.get_stats_profile': 'https://docs.python.org/3/library/profile.html#pstats.Stats.get_stats_profile',
                        'pstats.Stats.print_callees': 'https://docs.python.org/3/library/profile.html#pstats.Stats.print_callees',
                        'pstats.Stats.print_callers': 'https://docs.python.org/3/library/profile.html#pstats.Stats.print_callers',
                        'pstats.Stats.print_stats': 'https://docs.python.org/3/library/profile.html#pstats.Stats.print_stats',
                        'pstats.Stats.reverse_order': 'https://docs.python.org/3/library/profile.html#pstats.Stats.reverse_order',
                        'pstats.Stats.sort_stats': 'https://docs.python.org/3/library/profile.html#pstats.Stats.sort_stats',
                        'pstats.Stats.strip_dirs': 'https://docs.python.org/3/library/profile.html#pstats.Stats.strip_dirs'},
            'pty': { 'pty.fork': 'https://docs.python.org/3/library/pty.html#pty.fork',
                     'pty.openpty': 'https://docs.python.org/3/library/pty.html#pty.openpty',
                     'pty.spawn': 'https://docs.python.org/3/library/pty.html#pty.spawn'},
            'pwd': { 'pwd.getpwall': 'https://docs.python.org/3/library/pwd.html#pwd.getpwall',
                     'pwd.getpwnam': 'https://docs.python.org/3/library/pwd.html#pwd.getpwnam',
                     'pwd.getpwuid': 'https://docs.python.org/3/library/pwd.html#pwd.getpwuid'},
            'py_compile': { 'py_compile.PycInvalidationMode': 'https://docs.python.org/3/library/py_compile.html#py_compile.PycInvalidationMode',
                            'py_compile.compile': 'https://docs.python.org/3/library/py_compile.html#py_compile.compile'},
            'pyclbr': { 'pyclbr.readmodule': 'https://docs.python.org/3/library/pyclbr.html#pyclbr.readmodule',
                        'pyclbr.readmodule_ex': 'https://docs.python.org/3/library/pyclbr.html#pyclbr.readmodule_ex'},
            'queue': { 'queue.LifoQueue': 'https://docs.python.org/3/library/queue.html#queue.LifoQueue',
                       'queue.PriorityQueue': 'https://docs.python.org/3/library/queue.html#queue.PriorityQueue',
                       'queue.Queue': 'https://docs.python.org/3/library/queue.html#queue.Queue',
                       'queue.Queue.empty': 'https://docs.python.org/3/library/queue.html#queue.Queue.empty',
                       'queue.Queue.full': 'https://docs.python.org/3/library/queue.html#queue.Queue.full',
                       'queue.Queue.get': 'https://docs.python.org/3/library/queue.html#queue.Queue.get',
                       'queue.Queue.get_nowait': 'https://docs.python.org/3/library/queue.html#queue.Queue.get_nowait',
                       'queue.Queue.join': 'https://docs.python.org/3/library/queue.html#queue.Queue.join',
                       'queue.Queue.put': 'https://docs.python.org/3/library/queue.html#queue.Queue.put',
                       'queue.Queue.put_nowait': 'https://docs.python.org/3/library/queue.html#queue.Queue.put_nowait',
                       'queue.Queue.qsize': 'https://docs.python.org/3/library/queue.html#queue.Queue.qsize',
                       'queue.Queue.task_done': 'https://docs.python.org/3/library/queue.html#queue.Queue.task_done',
                       'queue.SimpleQueue': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue',
                       'queue.SimpleQueue.empty': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue.empty',
                       'queue.SimpleQueue.get': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue.get',
                       'queue.SimpleQueue.get_nowait': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue.get_nowait',
                       'queue.SimpleQueue.put': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue.put',
                       'queue.SimpleQueue.put_nowait': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue.put_nowait',
                       'queue.SimpleQueue.qsize': 'https://docs.python.org/3/library/queue.html#queue.SimpleQueue.qsize'},
            'quopri': { 'quopri.decode': 'https://docs.python.org/3/library/quopri.html#quopri.decode',
                        'quopri.decodestring': 'https://docs.python.org/3/library/quopri.html#quopri.decodestring',
                        'quopri.encode': 'https://docs.python.org/3/library/quopri.html#quopri.encode',
                        'quopri.encodestring': 'https://docs.python.org/3/library/quopri.html#quopri.encodestring'},
            'random': { 'random.Random': 'https://docs.python.org/3/library/random.html#random.Random',
                        'random.SystemRandom': 'https://docs.python.org/3/library/random.html#random.SystemRandom',
                        'random.betavariate': 'https://docs.python.org/3/library/random.html#random.betavariate',
                        'random.choice': 'https://docs.python.org/3/library/random.html#random.choice',
                        'random.choices': 'https://docs.python.org/3/library/random.html#random.choices',
                        'random.expovariate': 'https://docs.python.org/3/library/random.html#random.expovariate',
                        'random.gammavariate': 'https://docs.python.org/3/library/random.html#random.gammavariate',
                        'random.gauss': 'https://docs.python.org/3/library/random.html#random.gauss',
                        'random.getrandbits': 'https://docs.python.org/3/library/random.html#random.getrandbits',
                        'random.getstate': 'https://docs.python.org/3/library/random.html#random.getstate',
                        'random.lognormvariate': 'https://docs.python.org/3/library/random.html#random.lognormvariate',
                        'random.normalvariate': 'https://docs.python.org/3/library/random.html#random.normalvariate',
                        'random.paretovariate': 'https://docs.python.org/3/library/random.html#random.paretovariate',
                        'random.randbytes': 'https://docs.python.org/3/library/random.html#random.randbytes',
                        'random.randint': 'https://docs.python.org/3/library/random.html#random.randint',
                        'random.random': 'https://docs.python.org/3/library/random.html#random.random',
                        'random.randrange': 'https://docs.python.org/3/library/random.html#random.randrange',
                        'random.sample': 'https://docs.python.org/3/library/random.html#random.sample',
                        'random.seed': 'https://docs.python.org/3/library/random.html#random.seed',
                        'random.setstate': 'https://docs.python.org/3/library/random.html#random.setstate',
                        'random.shuffle': 'https://docs.python.org/3/library/random.html#random.shuffle',
                        'random.triangular': 'https://docs.python.org/3/library/random.html#random.triangular',
                        'random.uniform': 'https://docs.python.org/3/library/random.html#random.uniform',
                        'random.vonmisesvariate': 'https://docs.python.org/3/library/random.html#random.vonmisesvariate',
                        'random.weibullvariate': 'https://docs.python.org/3/library/random.html#random.weibullvariate'},
            're': { 're.Match.__getitem__': 'https://docs.python.org/3/library/re.html#re.Match.__getitem__',
                    're.Match.end': 'https://docs.python.org/3/library/re.html#re.Match.end',
                    're.Match.expand': 'https://docs.python.org/3/library/re.html#re.Match.expand',
                    're.Match.group': 'https://docs.python.org/3/library/re.html#re.Match.group',
                    're.Match.groupdict': 'https://docs.python.org/3/library/re.html#re.Match.groupdict',
                    're.Match.groups': 'https://docs.python.org/3/library/re.html#re.Match.groups',
                    're.Match.span': 'https://docs.python.org/3/library/re.html#re.Match.span',
                    're.Match.start': 'https://docs.python.org/3/library/re.html#re.Match.start',
                    're.Pattern.findall': 'https://docs.python.org/3/library/re.html#re.Pattern.findall',
                    're.Pattern.finditer': 'https://docs.python.org/3/library/re.html#re.Pattern.finditer',
                    're.Pattern.fullmatch': 'https://docs.python.org/3/library/re.html#re.Pattern.fullmatch',
                    're.Pattern.match': 'https://docs.python.org/3/library/re.html#re.Pattern.match',
                    're.Pattern.search': 'https://docs.python.org/3/library/re.html#re.Pattern.search',
                    're.Pattern.split': 'https://docs.python.org/3/library/re.html#re.Pattern.split',
                    're.Pattern.sub': 'https://docs.python.org/3/library/re.html#re.Pattern.sub',
                    're.Pattern.subn': 'https://docs.python.org/3/library/re.html#re.Pattern.subn',
                    're.compile': 'https://docs.python.org/3/library/re.html#re.compile',
                    're.escape': 'https://docs.python.org/3/library/re.html#re.escape',
                    're.findall': 'https://docs.python.org/3/library/re.html#re.findall',
                    're.finditer': 'https://docs.python.org/3/library/re.html#re.finditer',
                    're.fullmatch': 'https://docs.python.org/3/library/re.html#re.fullmatch',
                    're.match': 'https://docs.python.org/3/library/re.html#re.match',
                    're.purge': 'https://docs.python.org/3/library/re.html#re.purge',
                    're.search': 'https://docs.python.org/3/library/re.html#re.search',
                    're.split': 'https://docs.python.org/3/library/re.html#re.split',
                    're.sub': 'https://docs.python.org/3/library/re.html#re.sub',
                    're.subn': 'https://docs.python.org/3/library/re.html#re.subn'},
            'readline': { 'readline.add_history': 'https://docs.python.org/3/library/readline.html#readline.add_history',
                          'readline.append_history_file': 'https://docs.python.org/3/library/readline.html#readline.append_history_file',
                          'readline.clear_history': 'https://docs.python.org/3/library/readline.html#readline.clear_history',
                          'readline.get_begidx': 'https://docs.python.org/3/library/readline.html#readline.get_begidx',
                          'readline.get_completer': 'https://docs.python.org/3/library/readline.html#readline.get_completer',
                          'readline.get_completer_delims': 'https://docs.python.org/3/library/readline.html#readline.get_completer_delims',
                          'readline.get_completion_type': 'https://docs.python.org/3/library/readline.html#readline.get_completion_type',
                          'readline.get_current_history_length': 'https://docs.python.org/3/library/readline.html#readline.get_current_history_length',
                          'readline.get_endidx': 'https://docs.python.org/3/library/readline.html#readline.get_endidx',
                          'readline.get_history_item': 'https://docs.python.org/3/library/readline.html#readline.get_history_item',
                          'readline.get_history_length': 'https://docs.python.org/3/library/readline.html#readline.get_history_length',
                          'readline.get_line_buffer': 'https://docs.python.org/3/library/readline.html#readline.get_line_buffer',
                          'readline.insert_text': 'https://docs.python.org/3/library/readline.html#readline.insert_text',
                          'readline.parse_and_bind': 'https://docs.python.org/3/library/readline.html#readline.parse_and_bind',
                          'readline.read_history_file': 'https://docs.python.org/3/library/readline.html#readline.read_history_file',
                          'readline.read_init_file': 'https://docs.python.org/3/library/readline.html#readline.read_init_file',
                          'readline.redisplay': 'https://docs.python.org/3/library/readline.html#readline.redisplay',
                          'readline.remove_history_item': 'https://docs.python.org/3/library/readline.html#readline.remove_history_item',
                          'readline.replace_history_item': 'https://docs.python.org/3/library/readline.html#readline.replace_history_item',
                          'readline.set_auto_history': 'https://docs.python.org/3/library/readline.html#readline.set_auto_history',
                          'readline.set_completer': 'https://docs.python.org/3/library/readline.html#readline.set_completer',
                          'readline.set_completer_delims': 'https://docs.python.org/3/library/readline.html#readline.set_completer_delims',
                          'readline.set_completion_display_matches_hook': 'https://docs.python.org/3/library/readline.html#readline.set_completion_display_matches_hook',
                          'readline.set_history_length': 'https://docs.python.org/3/library/readline.html#readline.set_history_length',
                          'readline.set_pre_input_hook': 'https://docs.python.org/3/library/readline.html#readline.set_pre_input_hook',
                          'readline.set_startup_hook': 'https://docs.python.org/3/library/readline.html#readline.set_startup_hook',
                          'readline.write_history_file': 'https://docs.python.org/3/library/readline.html#readline.write_history_file'},
            'reprlib': { 'reprlib.Repr': 'https://docs.python.org/3/library/reprlib.html#reprlib.Repr',
                         'reprlib.Repr.repr': 'https://docs.python.org/3/library/reprlib.html#reprlib.Repr.repr',
                         'reprlib.Repr.repr1': 'https://docs.python.org/3/library/reprlib.html#reprlib.Repr.repr1',
                         'reprlib.recursive_repr': 'https://docs.python.org/3/library/reprlib.html#reprlib.recursive_repr',
                         'reprlib.repr': 'https://docs.python.org/3/library/reprlib.html#reprlib.repr'},
            'resource': { 'resource.getpagesize': 'https://docs.python.org/3/library/resource.html#resource.getpagesize',
                          'resource.getrlimit': 'https://docs.python.org/3/library/resource.html#resource.getrlimit',
                          'resource.getrusage': 'https://docs.python.org/3/library/resource.html#resource.getrusage',
                          'resource.prlimit': 'https://docs.python.org/3/library/resource.html#resource.prlimit',
                          'resource.setrlimit': 'https://docs.python.org/3/library/resource.html#resource.setrlimit'},
            'rlcompleter': {'rlcompleter.Completer.complete': 'https://docs.python.org/3/library/rlcompleter.html#rlcompleter.Completer.complete'},
            'runpy': { 'runpy.run_module': 'https://docs.python.org/3/library/runpy.html#runpy.run_module',
                       'runpy.run_path': 'https://docs.python.org/3/library/runpy.html#runpy.run_path'},
            'sched': { 'sched.scheduler': 'https://docs.python.org/3/library/sched.html#sched.scheduler',
                       'sched.scheduler.cancel': 'https://docs.python.org/3/library/sched.html#sched.scheduler.cancel',
                       'sched.scheduler.empty': 'https://docs.python.org/3/library/sched.html#sched.scheduler.empty',
                       'sched.scheduler.enter': 'https://docs.python.org/3/library/sched.html#sched.scheduler.enter',
                       'sched.scheduler.enterabs': 'https://docs.python.org/3/library/sched.html#sched.scheduler.enterabs',
                       'sched.scheduler.run': 'https://docs.python.org/3/library/sched.html#sched.scheduler.run'},
            'secrets': { 'secrets.SystemRandom': 'https://docs.python.org/3/library/secrets.html#secrets.SystemRandom',
                         'secrets.choice': 'https://docs.python.org/3/library/secrets.html#secrets.choice',
                         'secrets.compare_digest': 'https://docs.python.org/3/library/secrets.html#secrets.compare_digest',
                         'secrets.randbelow': 'https://docs.python.org/3/library/secrets.html#secrets.randbelow',
                         'secrets.randbits': 'https://docs.python.org/3/library/secrets.html#secrets.randbits',
                         'secrets.token_bytes': 'https://docs.python.org/3/library/secrets.html#secrets.token_bytes',
                         'secrets.token_hex': 'https://docs.python.org/3/library/secrets.html#secrets.token_hex',
                         'secrets.token_urlsafe': 'https://docs.python.org/3/library/secrets.html#secrets.token_urlsafe'},
            'select': { 'select.devpoll': 'https://docs.python.org/3/library/select.html#select.devpoll',
                        'select.devpoll.close': 'https://docs.python.org/3/library/select.html#select.devpoll.close',
                        'select.devpoll.fileno': 'https://docs.python.org/3/library/select.html#select.devpoll.fileno',
                        'select.devpoll.modify': 'https://docs.python.org/3/library/select.html#select.devpoll.modify',
                        'select.devpoll.poll': 'https://docs.python.org/3/library/select.html#select.devpoll.poll',
                        'select.devpoll.register': 'https://docs.python.org/3/library/select.html#select.devpoll.register',
                        'select.devpoll.unregister': 'https://docs.python.org/3/library/select.html#select.devpoll.unregister',
                        'select.epoll': 'https://docs.python.org/3/library/select.html#select.epoll',
                        'select.epoll.close': 'https://docs.python.org/3/library/select.html#select.epoll.close',
                        'select.epoll.fileno': 'https://docs.python.org/3/library/select.html#select.epoll.fileno',
                        'select.epoll.fromfd': 'https://docs.python.org/3/library/select.html#select.epoll.fromfd',
                        'select.epoll.modify': 'https://docs.python.org/3/library/select.html#select.epoll.modify',
                        'select.epoll.poll': 'https://docs.python.org/3/library/select.html#select.epoll.poll',
                        'select.epoll.register': 'https://docs.python.org/3/library/select.html#select.epoll.register',
                        'select.epoll.unregister': 'https://docs.python.org/3/library/select.html#select.epoll.unregister',
                        'select.kevent': 'https://docs.python.org/3/library/select.html#select.kevent',
                        'select.kqueue': 'https://docs.python.org/3/library/select.html#select.kqueue',
                        'select.kqueue.close': 'https://docs.python.org/3/library/select.html#select.kqueue.close',
                        'select.kqueue.control': 'https://docs.python.org/3/library/select.html#select.kqueue.control',
                        'select.kqueue.fileno': 'https://docs.python.org/3/library/select.html#select.kqueue.fileno',
                        'select.kqueue.fromfd': 'https://docs.python.org/3/library/select.html#select.kqueue.fromfd',
                        'select.poll': 'https://docs.python.org/3/library/select.html#select.poll',
                        'select.poll.modify': 'https://docs.python.org/3/library/select.html#select.poll.modify',
                        'select.poll.poll': 'https://docs.python.org/3/library/select.html#select.poll.poll',
                        'select.poll.register': 'https://docs.python.org/3/library/select.html#select.poll.register',
                        'select.poll.unregister': 'https://docs.python.org/3/library/select.html#select.poll.unregister',
                        'select.select': 'https://docs.python.org/3/library/select.html#select.select'},
            'selectors': { 'selectors.BaseSelector': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector',
                           'selectors.BaseSelector.close': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.close',
                           'selectors.BaseSelector.get_key': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.get_key',
                           'selectors.BaseSelector.get_map': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.get_map',
                           'selectors.BaseSelector.modify': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.modify',
                           'selectors.BaseSelector.register': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.register',
                           'selectors.BaseSelector.select': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.select',
                           'selectors.BaseSelector.unregister': 'https://docs.python.org/3/library/selectors.html#selectors.BaseSelector.unregister',
                           'selectors.DefaultSelector': 'https://docs.python.org/3/library/selectors.html#selectors.DefaultSelector',
                           'selectors.DevpollSelector': 'https://docs.python.org/3/library/selectors.html#selectors.DevpollSelector',
                           'selectors.DevpollSelector.fileno': 'https://docs.python.org/3/library/selectors.html#selectors.DevpollSelector.fileno',
                           'selectors.EpollSelector': 'https://docs.python.org/3/library/selectors.html#selectors.EpollSelector',
                           'selectors.EpollSelector.fileno': 'https://docs.python.org/3/library/selectors.html#selectors.EpollSelector.fileno',
                           'selectors.KqueueSelector': 'https://docs.python.org/3/library/selectors.html#selectors.KqueueSelector',
                           'selectors.KqueueSelector.fileno': 'https://docs.python.org/3/library/selectors.html#selectors.KqueueSelector.fileno',
                           'selectors.PollSelector': 'https://docs.python.org/3/library/selectors.html#selectors.PollSelector',
                           'selectors.SelectSelector': 'https://docs.python.org/3/library/selectors.html#selectors.SelectSelector',
                           'selectors.SelectorKey': 'https://docs.python.org/3/library/selectors.html#selectors.SelectorKey'},
            'shelve': { 'shelve.BsdDbShelf': 'https://docs.python.org/3/library/shelve.html#shelve.BsdDbShelf',
                        'shelve.DbfilenameShelf': 'https://docs.python.org/3/library/shelve.html#shelve.DbfilenameShelf',
                        'shelve.Shelf': 'https://docs.python.org/3/library/shelve.html#shelve.Shelf',
                        'shelve.Shelf.close': 'https://docs.python.org/3/library/shelve.html#shelve.Shelf.close',
                        'shelve.Shelf.sync': 'https://docs.python.org/3/library/shelve.html#shelve.Shelf.sync',
                        'shelve.open': 'https://docs.python.org/3/library/shelve.html#shelve.open'},
            'shlex': { 'shlex.join': 'https://docs.python.org/3/library/shlex.html#shlex.join',
                       'shlex.quote': 'https://docs.python.org/3/library/shlex.html#shlex.quote',
                       'shlex.shlex': 'https://docs.python.org/3/library/shlex.html#shlex.shlex',
                       'shlex.shlex.error_leader': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.error_leader',
                       'shlex.shlex.get_token': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.get_token',
                       'shlex.shlex.pop_source': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.pop_source',
                       'shlex.shlex.push_source': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.push_source',
                       'shlex.shlex.push_token': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.push_token',
                       'shlex.shlex.read_token': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.read_token',
                       'shlex.shlex.sourcehook': 'https://docs.python.org/3/library/shlex.html#shlex.shlex.sourcehook',
                       'shlex.split': 'https://docs.python.org/3/library/shlex.html#shlex.split'},
            'shutil': { 'shutil.chown': 'https://docs.python.org/3/library/shutil.html#shutil.chown',
                        'shutil.copy': 'https://docs.python.org/3/library/shutil.html#shutil.copy',
                        'shutil.copy2': 'https://docs.python.org/3/library/shutil.html#shutil.copy2',
                        'shutil.copyfile': 'https://docs.python.org/3/library/shutil.html#shutil.copyfile',
                        'shutil.copyfileobj': 'https://docs.python.org/3/library/shutil.html#shutil.copyfileobj',
                        'shutil.copymode': 'https://docs.python.org/3/library/shutil.html#shutil.copymode',
                        'shutil.copystat': 'https://docs.python.org/3/library/shutil.html#shutil.copystat',
                        'shutil.copytree': 'https://docs.python.org/3/library/shutil.html#shutil.copytree',
                        'shutil.disk_usage': 'https://docs.python.org/3/library/shutil.html#shutil.disk_usage',
                        'shutil.get_archive_formats': 'https://docs.python.org/3/library/shutil.html#shutil.get_archive_formats',
                        'shutil.get_terminal_size': 'https://docs.python.org/3/library/shutil.html#shutil.get_terminal_size',
                        'shutil.get_unpack_formats': 'https://docs.python.org/3/library/shutil.html#shutil.get_unpack_formats',
                        'shutil.ignore_patterns': 'https://docs.python.org/3/library/shutil.html#shutil.ignore_patterns',
                        'shutil.make_archive': 'https://docs.python.org/3/library/shutil.html#shutil.make_archive',
                        'shutil.move': 'https://docs.python.org/3/library/shutil.html#shutil.move',
                        'shutil.register_archive_format': 'https://docs.python.org/3/library/shutil.html#shutil.register_archive_format',
                        'shutil.register_unpack_format': 'https://docs.python.org/3/library/shutil.html#shutil.register_unpack_format',
                        'shutil.rmtree': 'https://docs.python.org/3/library/shutil.html#shutil.rmtree',
                        'shutil.unpack_archive': 'https://docs.python.org/3/library/shutil.html#shutil.unpack_archive',
                        'shutil.unregister_archive_format': 'https://docs.python.org/3/library/shutil.html#shutil.unregister_archive_format',
                        'shutil.unregister_unpack_format': 'https://docs.python.org/3/library/shutil.html#shutil.unregister_unpack_format',
                        'shutil.which': 'https://docs.python.org/3/library/shutil.html#shutil.which'},
            'signal': { 'signal.alarm': 'https://docs.python.org/3/library/signal.html#signal.alarm',
                        'signal.getitimer': 'https://docs.python.org/3/library/signal.html#signal.getitimer',
                        'signal.getsignal': 'https://docs.python.org/3/library/signal.html#signal.getsignal',
                        'signal.pause': 'https://docs.python.org/3/library/signal.html#signal.pause',
                        'signal.pidfd_send_signal': 'https://docs.python.org/3/library/signal.html#signal.pidfd_send_signal',
                        'signal.pthread_kill': 'https://docs.python.org/3/library/signal.html#signal.pthread_kill',
                        'signal.pthread_sigmask': 'https://docs.python.org/3/library/signal.html#signal.pthread_sigmask',
                        'signal.raise_signal': 'https://docs.python.org/3/library/signal.html#signal.raise_signal',
                        'signal.set_wakeup_fd': 'https://docs.python.org/3/library/signal.html#signal.set_wakeup_fd',
                        'signal.setitimer': 'https://docs.python.org/3/library/signal.html#signal.setitimer',
                        'signal.siginterrupt': 'https://docs.python.org/3/library/signal.html#signal.siginterrupt',
                        'signal.signal': 'https://docs.python.org/3/library/signal.html#signal.signal',
                        'signal.sigpending': 'https://docs.python.org/3/library/signal.html#signal.sigpending',
                        'signal.sigtimedwait': 'https://docs.python.org/3/library/signal.html#signal.sigtimedwait',
                        'signal.sigwait': 'https://docs.python.org/3/library/signal.html#signal.sigwait',
                        'signal.sigwaitinfo': 'https://docs.python.org/3/library/signal.html#signal.sigwaitinfo',
                        'signal.strsignal': 'https://docs.python.org/3/library/signal.html#signal.strsignal',
                        'signal.valid_signals': 'https://docs.python.org/3/library/signal.html#signal.valid_signals'},
            'site': { 'site.addsitedir': 'https://docs.python.org/3/library/site.html#site.addsitedir',
                      'site.getsitepackages': 'https://docs.python.org/3/library/site.html#site.getsitepackages',
                      'site.getuserbase': 'https://docs.python.org/3/library/site.html#site.getuserbase',
                      'site.getusersitepackages': 'https://docs.python.org/3/library/site.html#site.getusersitepackages',
                      'site.main': 'https://docs.python.org/3/library/site.html#site.main'},
            'smtpd': { 'smtpd.DebuggingServer': 'https://docs.python.org/3/library/smtpd.html#smtpd.DebuggingServer',
                       'smtpd.MailmanProxy': 'https://docs.python.org/3/library/smtpd.html#smtpd.MailmanProxy',
                       'smtpd.PureProxy': 'https://docs.python.org/3/library/smtpd.html#smtpd.PureProxy',
                       'smtpd.SMTPChannel': 'https://docs.python.org/3/library/smtpd.html#smtpd.SMTPChannel',
                       'smtpd.SMTPServer': 'https://docs.python.org/3/library/smtpd.html#smtpd.SMTPServer',
                       'smtpd.SMTPServer.process_message': 'https://docs.python.org/3/library/smtpd.html#smtpd.SMTPServer.process_message'},
            'smtplib': { 'smtplib.LMTP': 'https://docs.python.org/3/library/smtplib.html#smtplib.LMTP',
                         'smtplib.SMTP': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP',
                         'smtplib.SMTP.auth': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.auth',
                         'smtplib.SMTP.connect': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.connect',
                         'smtplib.SMTP.docmd': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.docmd',
                         'smtplib.SMTP.ehlo': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.ehlo',
                         'smtplib.SMTP.ehlo_or_helo_if_needed': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.ehlo_or_helo_if_needed',
                         'smtplib.SMTP.has_extn': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.has_extn',
                         'smtplib.SMTP.helo': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.helo',
                         'smtplib.SMTP.login': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.login',
                         'smtplib.SMTP.quit': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.quit',
                         'smtplib.SMTP.send_message': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.send_message',
                         'smtplib.SMTP.sendmail': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.sendmail',
                         'smtplib.SMTP.set_debuglevel': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.set_debuglevel',
                         'smtplib.SMTP.starttls': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.starttls',
                         'smtplib.SMTP.verify': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.verify',
                         'smtplib.SMTP_SSL': 'https://docs.python.org/3/library/smtplib.html#smtplib.SMTP_SSL'},
            'sndhdr': { 'sndhdr.what': 'https://docs.python.org/3/library/sndhdr.html#sndhdr.what',
                        'sndhdr.whathdr': 'https://docs.python.org/3/library/sndhdr.html#sndhdr.whathdr'},
            'socket': { 'socket.CMSG_LEN': 'https://docs.python.org/3/library/socket.html#socket.CMSG_LEN',
                        'socket.CMSG_SPACE': 'https://docs.python.org/3/library/socket.html#socket.CMSG_SPACE',
                        'socket.close': 'https://docs.python.org/3/library/socket.html#socket.close',
                        'socket.create_connection': 'https://docs.python.org/3/library/socket.html#socket.create_connection',
                        'socket.create_server': 'https://docs.python.org/3/library/socket.html#socket.create_server',
                        'socket.fromfd': 'https://docs.python.org/3/library/socket.html#socket.fromfd',
                        'socket.fromshare': 'https://docs.python.org/3/library/socket.html#socket.fromshare',
                        'socket.getaddrinfo': 'https://docs.python.org/3/library/socket.html#socket.getaddrinfo',
                        'socket.getdefaulttimeout': 'https://docs.python.org/3/library/socket.html#socket.getdefaulttimeout',
                        'socket.getfqdn': 'https://docs.python.org/3/library/socket.html#socket.getfqdn',
                        'socket.gethostbyaddr': 'https://docs.python.org/3/library/socket.html#socket.gethostbyaddr',
                        'socket.gethostbyname': 'https://docs.python.org/3/library/socket.html#socket.gethostbyname',
                        'socket.gethostbyname_ex': 'https://docs.python.org/3/library/socket.html#socket.gethostbyname_ex',
                        'socket.gethostname': 'https://docs.python.org/3/library/socket.html#socket.gethostname',
                        'socket.getnameinfo': 'https://docs.python.org/3/library/socket.html#socket.getnameinfo',
                        'socket.getprotobyname': 'https://docs.python.org/3/library/socket.html#socket.getprotobyname',
                        'socket.getservbyname': 'https://docs.python.org/3/library/socket.html#socket.getservbyname',
                        'socket.getservbyport': 'https://docs.python.org/3/library/socket.html#socket.getservbyport',
                        'socket.has_dualstack_ipv6': 'https://docs.python.org/3/library/socket.html#socket.has_dualstack_ipv6',
                        'socket.htonl': 'https://docs.python.org/3/library/socket.html#socket.htonl',
                        'socket.htons': 'https://docs.python.org/3/library/socket.html#socket.htons',
                        'socket.if_indextoname': 'https://docs.python.org/3/library/socket.html#socket.if_indextoname',
                        'socket.if_nameindex': 'https://docs.python.org/3/library/socket.html#socket.if_nameindex',
                        'socket.if_nametoindex': 'https://docs.python.org/3/library/socket.html#socket.if_nametoindex',
                        'socket.inet_aton': 'https://docs.python.org/3/library/socket.html#socket.inet_aton',
                        'socket.inet_ntoa': 'https://docs.python.org/3/library/socket.html#socket.inet_ntoa',
                        'socket.inet_ntop': 'https://docs.python.org/3/library/socket.html#socket.inet_ntop',
                        'socket.inet_pton': 'https://docs.python.org/3/library/socket.html#socket.inet_pton',
                        'socket.ntohl': 'https://docs.python.org/3/library/socket.html#socket.ntohl',
                        'socket.ntohs': 'https://docs.python.org/3/library/socket.html#socket.ntohs',
                        'socket.recv_fds': 'https://docs.python.org/3/library/socket.html#socket.recv_fds',
                        'socket.send_fds': 'https://docs.python.org/3/library/socket.html#socket.send_fds',
                        'socket.setdefaulttimeout': 'https://docs.python.org/3/library/socket.html#socket.setdefaulttimeout',
                        'socket.sethostname': 'https://docs.python.org/3/library/socket.html#socket.sethostname',
                        'socket.socket': 'https://docs.python.org/3/library/socket.html#socket.socket',
                        'socket.socket.accept': 'https://docs.python.org/3/library/socket.html#socket.socket.accept',
                        'socket.socket.bind': 'https://docs.python.org/3/library/socket.html#socket.socket.bind',
                        'socket.socket.close': 'https://docs.python.org/3/library/socket.html#socket.socket.close',
                        'socket.socket.connect': 'https://docs.python.org/3/library/socket.html#socket.socket.connect',
                        'socket.socket.connect_ex': 'https://docs.python.org/3/library/socket.html#socket.socket.connect_ex',
                        'socket.socket.detach': 'https://docs.python.org/3/library/socket.html#socket.socket.detach',
                        'socket.socket.dup': 'https://docs.python.org/3/library/socket.html#socket.socket.dup',
                        'socket.socket.fileno': 'https://docs.python.org/3/library/socket.html#socket.socket.fileno',
                        'socket.socket.get_inheritable': 'https://docs.python.org/3/library/socket.html#socket.socket.get_inheritable',
                        'socket.socket.getblocking': 'https://docs.python.org/3/library/socket.html#socket.socket.getblocking',
                        'socket.socket.getpeername': 'https://docs.python.org/3/library/socket.html#socket.socket.getpeername',
                        'socket.socket.getsockname': 'https://docs.python.org/3/library/socket.html#socket.socket.getsockname',
                        'socket.socket.getsockopt': 'https://docs.python.org/3/library/socket.html#socket.socket.getsockopt',
                        'socket.socket.gettimeout': 'https://docs.python.org/3/library/socket.html#socket.socket.gettimeout',
                        'socket.socket.ioctl': 'https://docs.python.org/3/library/socket.html#socket.socket.ioctl',
                        'socket.socket.listen': 'https://docs.python.org/3/library/socket.html#socket.socket.listen',
                        'socket.socket.makefile': 'https://docs.python.org/3/library/socket.html#socket.socket.makefile',
                        'socket.socket.recv': 'https://docs.python.org/3/library/socket.html#socket.socket.recv',
                        'socket.socket.recv_into': 'https://docs.python.org/3/library/socket.html#socket.socket.recv_into',
                        'socket.socket.recvfrom': 'https://docs.python.org/3/library/socket.html#socket.socket.recvfrom',
                        'socket.socket.recvfrom_into': 'https://docs.python.org/3/library/socket.html#socket.socket.recvfrom_into',
                        'socket.socket.recvmsg': 'https://docs.python.org/3/library/socket.html#socket.socket.recvmsg',
                        'socket.socket.recvmsg_into': 'https://docs.python.org/3/library/socket.html#socket.socket.recvmsg_into',
                        'socket.socket.send': 'https://docs.python.org/3/library/socket.html#socket.socket.send',
                        'socket.socket.sendall': 'https://docs.python.org/3/library/socket.html#socket.socket.sendall',
                        'socket.socket.sendfile': 'https://docs.python.org/3/library/socket.html#socket.socket.sendfile',
                        'socket.socket.sendmsg': 'https://docs.python.org/3/library/socket.html#socket.socket.sendmsg',
                        'socket.socket.sendmsg_afalg': 'https://docs.python.org/3/library/socket.html#socket.socket.sendmsg_afalg',
                        'socket.socket.sendto': 'https://docs.python.org/3/library/socket.html#socket.socket.sendto',
                        'socket.socket.set_inheritable': 'https://docs.python.org/3/library/socket.html#socket.socket.set_inheritable',
                        'socket.socket.setblocking': 'https://docs.python.org/3/library/socket.html#socket.socket.setblocking',
                        'socket.socket.setsockopt': 'https://docs.python.org/3/library/socket.html#socket.socket.setsockopt',
                        'socket.socket.settimeout': 'https://docs.python.org/3/library/socket.html#socket.socket.settimeout',
                        'socket.socket.share': 'https://docs.python.org/3/library/socket.html#socket.socket.share',
                        'socket.socket.shutdown': 'https://docs.python.org/3/library/socket.html#socket.socket.shutdown',
                        'socket.socketpair': 'https://docs.python.org/3/library/socket.html#socket.socketpair'},
            'socketserver': { 'socketserver.BaseRequestHandler': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseRequestHandler',
                              'socketserver.BaseRequestHandler.finish': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseRequestHandler.finish',
                              'socketserver.BaseRequestHandler.handle': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseRequestHandler.handle',
                              'socketserver.BaseRequestHandler.setup': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseRequestHandler.setup',
                              'socketserver.BaseServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer',
                              'socketserver.BaseServer.fileno': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.fileno',
                              'socketserver.BaseServer.finish_request': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.finish_request',
                              'socketserver.BaseServer.get_request': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.get_request',
                              'socketserver.BaseServer.handle_error': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.handle_error',
                              'socketserver.BaseServer.handle_request': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.handle_request',
                              'socketserver.BaseServer.handle_timeout': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.handle_timeout',
                              'socketserver.BaseServer.process_request': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.process_request',
                              'socketserver.BaseServer.serve_forever': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.serve_forever',
                              'socketserver.BaseServer.server_activate': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.server_activate',
                              'socketserver.BaseServer.server_bind': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.server_bind',
                              'socketserver.BaseServer.server_close': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.server_close',
                              'socketserver.BaseServer.service_actions': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.service_actions',
                              'socketserver.BaseServer.shutdown': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.shutdown',
                              'socketserver.BaseServer.verify_request': 'https://docs.python.org/3/library/socketserver.html#socketserver.BaseServer.verify_request',
                              'socketserver.DatagramRequestHandler': 'https://docs.python.org/3/library/socketserver.html#socketserver.DatagramRequestHandler',
                              'socketserver.ForkingMixIn': 'https://docs.python.org/3/library/socketserver.html#socketserver.ForkingMixIn',
                              'socketserver.ForkingTCPServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.ForkingTCPServer',
                              'socketserver.ForkingUDPServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.ForkingUDPServer',
                              'socketserver.StreamRequestHandler': 'https://docs.python.org/3/library/socketserver.html#socketserver.StreamRequestHandler',
                              'socketserver.TCPServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.TCPServer',
                              'socketserver.ThreadingMixIn': 'https://docs.python.org/3/library/socketserver.html#socketserver.ThreadingMixIn',
                              'socketserver.ThreadingTCPServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.ThreadingTCPServer',
                              'socketserver.ThreadingUDPServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.ThreadingUDPServer',
                              'socketserver.UDPServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.UDPServer',
                              'socketserver.UnixDatagramServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.UnixDatagramServer',
                              'socketserver.UnixStreamServer': 'https://docs.python.org/3/library/socketserver.html#socketserver.UnixStreamServer'},
            'spwd': { 'spwd.getspall': 'https://docs.python.org/3/library/spwd.html#spwd.getspall',
                      'spwd.getspnam': 'https://docs.python.org/3/library/spwd.html#spwd.getspnam'},
            'sqlite3': { 'sqlite3.Connection': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection',
                         'sqlite3.Connection.backup': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.backup',
                         'sqlite3.Connection.close': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.close',
                         'sqlite3.Connection.commit': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.commit',
                         'sqlite3.Connection.create_aggregate': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.create_aggregate',
                         'sqlite3.Connection.create_collation': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.create_collation',
                         'sqlite3.Connection.create_function': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.create_function',
                         'sqlite3.Connection.cursor': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.cursor',
                         'sqlite3.Connection.enable_load_extension': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.enable_load_extension',
                         'sqlite3.Connection.execute': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.execute',
                         'sqlite3.Connection.executemany': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.executemany',
                         'sqlite3.Connection.executescript': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.executescript',
                         'sqlite3.Connection.interrupt': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.interrupt',
                         'sqlite3.Connection.iterdump': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.iterdump',
                         'sqlite3.Connection.load_extension': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.load_extension',
                         'sqlite3.Connection.rollback': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.rollback',
                         'sqlite3.Connection.set_authorizer': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.set_authorizer',
                         'sqlite3.Connection.set_progress_handler': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.set_progress_handler',
                         'sqlite3.Connection.set_trace_callback': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Connection.set_trace_callback',
                         'sqlite3.Cursor': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor',
                         'sqlite3.Cursor.close': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.close',
                         'sqlite3.Cursor.execute': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.execute',
                         'sqlite3.Cursor.executemany': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.executemany',
                         'sqlite3.Cursor.executescript': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.executescript',
                         'sqlite3.Cursor.fetchall': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.fetchall',
                         'sqlite3.Cursor.fetchmany': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.fetchmany',
                         'sqlite3.Cursor.fetchone': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.fetchone',
                         'sqlite3.Cursor.setinputsizes': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.setinputsizes',
                         'sqlite3.Cursor.setoutputsize': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Cursor.setoutputsize',
                         'sqlite3.PrepareProtocol': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.PrepareProtocol',
                         'sqlite3.Row': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Row',
                         'sqlite3.Row.keys': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.Row.keys',
                         'sqlite3.complete_statement': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.complete_statement',
                         'sqlite3.connect': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.connect',
                         'sqlite3.enable_callback_tracebacks': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.enable_callback_tracebacks',
                         'sqlite3.register_adapter': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.register_adapter',
                         'sqlite3.register_converter': 'https://docs.python.org/3/library/sqlite3.html#sqlite3.register_converter'},
            'ssl': { 'ssl.AlertDescription': 'https://docs.python.org/3/library/ssl.html#ssl.AlertDescription',
                     'ssl.DER_cert_to_PEM_cert': 'https://docs.python.org/3/library/ssl.html#ssl.DER_cert_to_PEM_cert',
                     'ssl.MemoryBIO': 'https://docs.python.org/3/library/ssl.html#ssl.MemoryBIO',
                     'ssl.MemoryBIO.read': 'https://docs.python.org/3/library/ssl.html#ssl.MemoryBIO.read',
                     'ssl.MemoryBIO.write': 'https://docs.python.org/3/library/ssl.html#ssl.MemoryBIO.write',
                     'ssl.MemoryBIO.write_eof': 'https://docs.python.org/3/library/ssl.html#ssl.MemoryBIO.write_eof',
                     'ssl.Options': 'https://docs.python.org/3/library/ssl.html#ssl.Options',
                     'ssl.PEM_cert_to_DER_cert': 'https://docs.python.org/3/library/ssl.html#ssl.PEM_cert_to_DER_cert',
                     'ssl.RAND_add': 'https://docs.python.org/3/library/ssl.html#ssl.RAND_add',
                     'ssl.RAND_bytes': 'https://docs.python.org/3/library/ssl.html#ssl.RAND_bytes',
                     'ssl.RAND_pseudo_bytes': 'https://docs.python.org/3/library/ssl.html#ssl.RAND_pseudo_bytes',
                     'ssl.RAND_status': 'https://docs.python.org/3/library/ssl.html#ssl.RAND_status',
                     'ssl.SSLContext': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext',
                     'ssl.SSLContext.cert_store_stats': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.cert_store_stats',
                     'ssl.SSLContext.get_ca_certs': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.get_ca_certs',
                     'ssl.SSLContext.get_ciphers': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.get_ciphers',
                     'ssl.SSLContext.load_cert_chain': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.load_cert_chain',
                     'ssl.SSLContext.load_default_certs': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.load_default_certs',
                     'ssl.SSLContext.load_dh_params': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.load_dh_params',
                     'ssl.SSLContext.load_verify_locations': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.load_verify_locations',
                     'ssl.SSLContext.session_stats': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.session_stats',
                     'ssl.SSLContext.set_alpn_protocols': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.set_alpn_protocols',
                     'ssl.SSLContext.set_ciphers': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.set_ciphers',
                     'ssl.SSLContext.set_default_verify_paths': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.set_default_verify_paths',
                     'ssl.SSLContext.set_ecdh_curve': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.set_ecdh_curve',
                     'ssl.SSLContext.set_npn_protocols': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.set_npn_protocols',
                     'ssl.SSLContext.wrap_bio': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.wrap_bio',
                     'ssl.SSLContext.wrap_socket': 'https://docs.python.org/3/library/ssl.html#ssl.SSLContext.wrap_socket',
                     'ssl.SSLErrorNumber': 'https://docs.python.org/3/library/ssl.html#ssl.SSLErrorNumber',
                     'ssl.SSLObject': 'https://docs.python.org/3/library/ssl.html#ssl.SSLObject',
                     'ssl.SSLSession': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSession',
                     'ssl.SSLSocket': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket',
                     'ssl.SSLSocket.cipher': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.cipher',
                     'ssl.SSLSocket.compression': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.compression',
                     'ssl.SSLSocket.do_handshake': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.do_handshake',
                     'ssl.SSLSocket.get_channel_binding': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.get_channel_binding',
                     'ssl.SSLSocket.getpeercert': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.getpeercert',
                     'ssl.SSLSocket.pending': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.pending',
                     'ssl.SSLSocket.read': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.read',
                     'ssl.SSLSocket.selected_alpn_protocol': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.selected_alpn_protocol',
                     'ssl.SSLSocket.selected_npn_protocol': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.selected_npn_protocol',
                     'ssl.SSLSocket.shared_ciphers': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.shared_ciphers',
                     'ssl.SSLSocket.unwrap': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.unwrap',
                     'ssl.SSLSocket.verify_client_post_handshake': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.verify_client_post_handshake',
                     'ssl.SSLSocket.version': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.version',
                     'ssl.SSLSocket.write': 'https://docs.python.org/3/library/ssl.html#ssl.SSLSocket.write',
                     'ssl.TLSVersion': 'https://docs.python.org/3/library/ssl.html#ssl.TLSVersion',
                     'ssl.VerifyFlags': 'https://docs.python.org/3/library/ssl.html#ssl.VerifyFlags',
                     'ssl.VerifyMode': 'https://docs.python.org/3/library/ssl.html#ssl.VerifyMode',
                     'ssl.cert_time_to_seconds': 'https://docs.python.org/3/library/ssl.html#ssl.cert_time_to_seconds',
                     'ssl.create_default_context': 'https://docs.python.org/3/library/ssl.html#ssl.create_default_context',
                     'ssl.enum_certificates': 'https://docs.python.org/3/library/ssl.html#ssl.enum_certificates',
                     'ssl.enum_crls': 'https://docs.python.org/3/library/ssl.html#ssl.enum_crls',
                     'ssl.get_default_verify_paths': 'https://docs.python.org/3/library/ssl.html#ssl.get_default_verify_paths',
                     'ssl.get_server_certificate': 'https://docs.python.org/3/library/ssl.html#ssl.get_server_certificate',
                     'ssl.match_hostname': 'https://docs.python.org/3/library/ssl.html#ssl.match_hostname',
                     'ssl.wrap_socket': 'https://docs.python.org/3/library/ssl.html#ssl.wrap_socket'},
            'stat': { 'stat.S_IFMT': 'https://docs.python.org/3/library/stat.html#stat.S_IFMT',
                      'stat.S_IMODE': 'https://docs.python.org/3/library/stat.html#stat.S_IMODE',
                      'stat.S_ISBLK': 'https://docs.python.org/3/library/stat.html#stat.S_ISBLK',
                      'stat.S_ISCHR': 'https://docs.python.org/3/library/stat.html#stat.S_ISCHR',
                      'stat.S_ISDIR': 'https://docs.python.org/3/library/stat.html#stat.S_ISDIR',
                      'stat.S_ISDOOR': 'https://docs.python.org/3/library/stat.html#stat.S_ISDOOR',
                      'stat.S_ISFIFO': 'https://docs.python.org/3/library/stat.html#stat.S_ISFIFO',
                      'stat.S_ISLNK': 'https://docs.python.org/3/library/stat.html#stat.S_ISLNK',
                      'stat.S_ISPORT': 'https://docs.python.org/3/library/stat.html#stat.S_ISPORT',
                      'stat.S_ISREG': 'https://docs.python.org/3/library/stat.html#stat.S_ISREG',
                      'stat.S_ISSOCK': 'https://docs.python.org/3/library/stat.html#stat.S_ISSOCK',
                      'stat.S_ISWHT': 'https://docs.python.org/3/library/stat.html#stat.S_ISWHT',
                      'stat.filemode': 'https://docs.python.org/3/library/stat.html#stat.filemode'},
            'statistics': { 'statistics.NormalDist': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist',
                            'statistics.NormalDist.cdf': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.cdf',
                            'statistics.NormalDist.from_samples': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.from_samples',
                            'statistics.NormalDist.inv_cdf': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.inv_cdf',
                            'statistics.NormalDist.overlap': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.overlap',
                            'statistics.NormalDist.pdf': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.pdf',
                            'statistics.NormalDist.quantiles': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.quantiles',
                            'statistics.NormalDist.samples': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.samples',
                            'statistics.NormalDist.zscore': 'https://docs.python.org/3/library/statistics.html#statistics.NormalDist.zscore',
                            'statistics.correlation': 'https://docs.python.org/3/library/statistics.html#statistics.correlation',
                            'statistics.covariance': 'https://docs.python.org/3/library/statistics.html#statistics.covariance',
                            'statistics.fmean': 'https://docs.python.org/3/library/statistics.html#statistics.fmean',
                            'statistics.geometric_mean': 'https://docs.python.org/3/library/statistics.html#statistics.geometric_mean',
                            'statistics.harmonic_mean': 'https://docs.python.org/3/library/statistics.html#statistics.harmonic_mean',
                            'statistics.linear_regression': 'https://docs.python.org/3/library/statistics.html#statistics.linear_regression',
                            'statistics.mean': 'https://docs.python.org/3/library/statistics.html#statistics.mean',
                            'statistics.median': 'https://docs.python.org/3/library/statistics.html#statistics.median',
                            'statistics.median_grouped': 'https://docs.python.org/3/library/statistics.html#statistics.median_grouped',
                            'statistics.median_high': 'https://docs.python.org/3/library/statistics.html#statistics.median_high',
                            'statistics.median_low': 'https://docs.python.org/3/library/statistics.html#statistics.median_low',
                            'statistics.mode': 'https://docs.python.org/3/library/statistics.html#statistics.mode',
                            'statistics.multimode': 'https://docs.python.org/3/library/statistics.html#statistics.multimode',
                            'statistics.pstdev': 'https://docs.python.org/3/library/statistics.html#statistics.pstdev',
                            'statistics.pvariance': 'https://docs.python.org/3/library/statistics.html#statistics.pvariance',
                            'statistics.quantiles': 'https://docs.python.org/3/library/statistics.html#statistics.quantiles',
                            'statistics.stdev': 'https://docs.python.org/3/library/statistics.html#statistics.stdev',
                            'statistics.variance': 'https://docs.python.org/3/library/statistics.html#statistics.variance'},
            'string': { 'string.Formatter': 'https://docs.python.org/3/library/string.html#string.Formatter',
                        'string.Formatter.check_unused_args': 'https://docs.python.org/3/library/string.html#string.Formatter.check_unused_args',
                        'string.Formatter.convert_field': 'https://docs.python.org/3/library/string.html#string.Formatter.convert_field',
                        'string.Formatter.format': 'https://docs.python.org/3/library/string.html#string.Formatter.format',
                        'string.Formatter.format_field': 'https://docs.python.org/3/library/string.html#string.Formatter.format_field',
                        'string.Formatter.get_field': 'https://docs.python.org/3/library/string.html#string.Formatter.get_field',
                        'string.Formatter.get_value': 'https://docs.python.org/3/library/string.html#string.Formatter.get_value',
                        'string.Formatter.parse': 'https://docs.python.org/3/library/string.html#string.Formatter.parse',
                        'string.Formatter.vformat': 'https://docs.python.org/3/library/string.html#string.Formatter.vformat',
                        'string.Template': 'https://docs.python.org/3/library/string.html#string.Template',
                        'string.Template.safe_substitute': 'https://docs.python.org/3/library/string.html#string.Template.safe_substitute',
                        'string.Template.substitute': 'https://docs.python.org/3/library/string.html#string.Template.substitute',
                        'string.capwords': 'https://docs.python.org/3/library/string.html#string.capwords'},
            'stringprep': { 'stringprep.in_table_a1': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_a1',
                            'stringprep.in_table_b1': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_b1',
                            'stringprep.in_table_c11': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c11',
                            'stringprep.in_table_c11_c12': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c11_c12',
                            'stringprep.in_table_c12': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c12',
                            'stringprep.in_table_c21': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c21',
                            'stringprep.in_table_c21_c22': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c21_c22',
                            'stringprep.in_table_c22': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c22',
                            'stringprep.in_table_c3': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c3',
                            'stringprep.in_table_c4': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c4',
                            'stringprep.in_table_c5': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c5',
                            'stringprep.in_table_c6': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c6',
                            'stringprep.in_table_c7': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c7',
                            'stringprep.in_table_c8': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c8',
                            'stringprep.in_table_c9': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_c9',
                            'stringprep.in_table_d1': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_d1',
                            'stringprep.in_table_d2': 'https://docs.python.org/3/library/stringprep.html#stringprep.in_table_d2',
                            'stringprep.map_table_b2': 'https://docs.python.org/3/library/stringprep.html#stringprep.map_table_b2',
                            'stringprep.map_table_b3': 'https://docs.python.org/3/library/stringprep.html#stringprep.map_table_b3'},
            'struct': { 'struct.Struct': 'https://docs.python.org/3/library/struct.html#struct.Struct',
                        'struct.Struct.iter_unpack': 'https://docs.python.org/3/library/struct.html#struct.Struct.iter_unpack',
                        'struct.Struct.pack': 'https://docs.python.org/3/library/struct.html#struct.Struct.pack',
                        'struct.Struct.pack_into': 'https://docs.python.org/3/library/struct.html#struct.Struct.pack_into',
                        'struct.Struct.unpack': 'https://docs.python.org/3/library/struct.html#struct.Struct.unpack',
                        'struct.Struct.unpack_from': 'https://docs.python.org/3/library/struct.html#struct.Struct.unpack_from',
                        'struct.calcsize': 'https://docs.python.org/3/library/struct.html#struct.calcsize',
                        'struct.iter_unpack': 'https://docs.python.org/3/library/struct.html#struct.iter_unpack',
                        'struct.pack': 'https://docs.python.org/3/library/struct.html#struct.pack',
                        'struct.pack_into': 'https://docs.python.org/3/library/struct.html#struct.pack_into',
                        'struct.unpack': 'https://docs.python.org/3/library/struct.html#struct.unpack',
                        'struct.unpack_from': 'https://docs.python.org/3/library/struct.html#struct.unpack_from'},
            'subprocess': { 'subprocess.CompletedProcess': 'https://docs.python.org/3/library/subprocess.html#subprocess.CompletedProcess',
                            'subprocess.CompletedProcess.check_returncode': 'https://docs.python.org/3/library/subprocess.html#subprocess.CompletedProcess.check_returncode',
                            'subprocess.Popen': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen',
                            'subprocess.Popen.communicate': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen.communicate',
                            'subprocess.Popen.kill': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen.kill',
                            'subprocess.Popen.poll': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen.poll',
                            'subprocess.Popen.send_signal': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen.send_signal',
                            'subprocess.Popen.terminate': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen.terminate',
                            'subprocess.Popen.wait': 'https://docs.python.org/3/library/subprocess.html#subprocess.Popen.wait',
                            'subprocess.STARTUPINFO': 'https://docs.python.org/3/library/subprocess.html#subprocess.STARTUPINFO',
                            'subprocess.call': 'https://docs.python.org/3/library/subprocess.html#subprocess.call',
                            'subprocess.check_call': 'https://docs.python.org/3/library/subprocess.html#subprocess.check_call',
                            'subprocess.check_output': 'https://docs.python.org/3/library/subprocess.html#subprocess.check_output',
                            'subprocess.getoutput': 'https://docs.python.org/3/library/subprocess.html#subprocess.getoutput',
                            'subprocess.getstatusoutput': 'https://docs.python.org/3/library/subprocess.html#subprocess.getstatusoutput',
                            'subprocess.run': 'https://docs.python.org/3/library/subprocess.html#subprocess.run'},
            'sunau': { 'sunau.AU_read.close': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.close',
                       'sunau.AU_read.getcompname': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getcompname',
                       'sunau.AU_read.getcomptype': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getcomptype',
                       'sunau.AU_read.getframerate': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getframerate',
                       'sunau.AU_read.getmark': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getmark',
                       'sunau.AU_read.getmarkers': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getmarkers',
                       'sunau.AU_read.getnchannels': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getnchannels',
                       'sunau.AU_read.getnframes': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getnframes',
                       'sunau.AU_read.getparams': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getparams',
                       'sunau.AU_read.getsampwidth': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.getsampwidth',
                       'sunau.AU_read.readframes': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.readframes',
                       'sunau.AU_read.rewind': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.rewind',
                       'sunau.AU_read.setpos': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.setpos',
                       'sunau.AU_read.tell': 'https://docs.python.org/3/library/sunau.html#sunau.AU_read.tell',
                       'sunau.AU_write.close': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.close',
                       'sunau.AU_write.setcomptype': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.setcomptype',
                       'sunau.AU_write.setframerate': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.setframerate',
                       'sunau.AU_write.setnchannels': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.setnchannels',
                       'sunau.AU_write.setnframes': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.setnframes',
                       'sunau.AU_write.setparams': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.setparams',
                       'sunau.AU_write.setsampwidth': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.setsampwidth',
                       'sunau.AU_write.tell': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.tell',
                       'sunau.AU_write.writeframes': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.writeframes',
                       'sunau.AU_write.writeframesraw': 'https://docs.python.org/3/library/sunau.html#sunau.AU_write.writeframesraw',
                       'sunau.open': 'https://docs.python.org/3/library/sunau.html#sunau.open'},
            'symtable': { 'symtable.Class': 'https://docs.python.org/3/library/symtable.html#symtable.Class',
                          'symtable.Class.get_methods': 'https://docs.python.org/3/library/symtable.html#symtable.Class.get_methods',
                          'symtable.Function': 'https://docs.python.org/3/library/symtable.html#symtable.Function',
                          'symtable.Function.get_frees': 'https://docs.python.org/3/library/symtable.html#symtable.Function.get_frees',
                          'symtable.Function.get_globals': 'https://docs.python.org/3/library/symtable.html#symtable.Function.get_globals',
                          'symtable.Function.get_locals': 'https://docs.python.org/3/library/symtable.html#symtable.Function.get_locals',
                          'symtable.Function.get_nonlocals': 'https://docs.python.org/3/library/symtable.html#symtable.Function.get_nonlocals',
                          'symtable.Function.get_parameters': 'https://docs.python.org/3/library/symtable.html#symtable.Function.get_parameters',
                          'symtable.Symbol': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol',
                          'symtable.Symbol.get_name': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.get_name',
                          'symtable.Symbol.get_namespace': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.get_namespace',
                          'symtable.Symbol.get_namespaces': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.get_namespaces',
                          'symtable.Symbol.is_annotated': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_annotated',
                          'symtable.Symbol.is_assigned': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_assigned',
                          'symtable.Symbol.is_declared_global': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_declared_global',
                          'symtable.Symbol.is_free': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_free',
                          'symtable.Symbol.is_global': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_global',
                          'symtable.Symbol.is_imported': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_imported',
                          'symtable.Symbol.is_local': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_local',
                          'symtable.Symbol.is_namespace': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_namespace',
                          'symtable.Symbol.is_nonlocal': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_nonlocal',
                          'symtable.Symbol.is_parameter': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_parameter',
                          'symtable.Symbol.is_referenced': 'https://docs.python.org/3/library/symtable.html#symtable.Symbol.is_referenced',
                          'symtable.SymbolTable': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable',
                          'symtable.SymbolTable.get_children': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_children',
                          'symtable.SymbolTable.get_id': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_id',
                          'symtable.SymbolTable.get_identifiers': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_identifiers',
                          'symtable.SymbolTable.get_lineno': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_lineno',
                          'symtable.SymbolTable.get_name': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_name',
                          'symtable.SymbolTable.get_symbols': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_symbols',
                          'symtable.SymbolTable.get_type': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.get_type',
                          'symtable.SymbolTable.has_children': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.has_children',
                          'symtable.SymbolTable.is_nested': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.is_nested',
                          'symtable.SymbolTable.is_optimized': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.is_optimized',
                          'symtable.SymbolTable.lookup': 'https://docs.python.org/3/library/symtable.html#symtable.SymbolTable.lookup',
                          'symtable.symtable': 'https://docs.python.org/3/library/symtable.html#symtable.symtable'},
            'sys': { 'sys._clear_type_cache': 'https://docs.python.org/3/library/sys.html#sys._clear_type_cache',
                     'sys._current_exceptions': 'https://docs.python.org/3/library/sys.html#sys._current_exceptions',
                     'sys._current_frames': 'https://docs.python.org/3/library/sys.html#sys._current_frames',
                     'sys._debugmallocstats': 'https://docs.python.org/3/library/sys.html#sys._debugmallocstats',
                     'sys._enablelegacywindowsfsencoding': 'https://docs.python.org/3/library/sys.html#sys._enablelegacywindowsfsencoding',
                     'sys._getframe': 'https://docs.python.org/3/library/sys.html#sys._getframe',
                     'sys.addaudithook': 'https://docs.python.org/3/library/sys.html#sys.addaudithook',
                     'sys.audit': 'https://docs.python.org/3/library/sys.html#sys.audit',
                     'sys.breakpointhook': 'https://docs.python.org/3/library/sys.html#sys.breakpointhook',
                     'sys.call_tracing': 'https://docs.python.org/3/library/sys.html#sys.call_tracing',
                     'sys.displayhook': 'https://docs.python.org/3/library/sys.html#sys.displayhook',
                     'sys.exc_info': 'https://docs.python.org/3/library/sys.html#sys.exc_info',
                     'sys.excepthook': 'https://docs.python.org/3/library/sys.html#sys.excepthook',
                     'sys.exit': 'https://docs.python.org/3/library/sys.html#sys.exit',
                     'sys.get_asyncgen_hooks': 'https://docs.python.org/3/library/sys.html#sys.get_asyncgen_hooks',
                     'sys.get_coroutine_origin_tracking_depth': 'https://docs.python.org/3/library/sys.html#sys.get_coroutine_origin_tracking_depth',
                     'sys.get_int_max_str_digits': 'https://docs.python.org/3/library/sys.html#sys.get_int_max_str_digits',
                     'sys.getallocatedblocks': 'https://docs.python.org/3/library/sys.html#sys.getallocatedblocks',
                     'sys.getandroidapilevel': 'https://docs.python.org/3/library/sys.html#sys.getandroidapilevel',
                     'sys.getdefaultencoding': 'https://docs.python.org/3/library/sys.html#sys.getdefaultencoding',
                     'sys.getdlopenflags': 'https://docs.python.org/3/library/sys.html#sys.getdlopenflags',
                     'sys.getfilesystemencodeerrors': 'https://docs.python.org/3/library/sys.html#sys.getfilesystemencodeerrors',
                     'sys.getfilesystemencoding': 'https://docs.python.org/3/library/sys.html#sys.getfilesystemencoding',
                     'sys.getprofile': 'https://docs.python.org/3/library/sys.html#sys.getprofile',
                     'sys.getrecursionlimit': 'https://docs.python.org/3/library/sys.html#sys.getrecursionlimit',
                     'sys.getrefcount': 'https://docs.python.org/3/library/sys.html#sys.getrefcount',
                     'sys.getsizeof': 'https://docs.python.org/3/library/sys.html#sys.getsizeof',
                     'sys.getswitchinterval': 'https://docs.python.org/3/library/sys.html#sys.getswitchinterval',
                     'sys.gettrace': 'https://docs.python.org/3/library/sys.html#sys.gettrace',
                     'sys.getwindowsversion': 'https://docs.python.org/3/library/sys.html#sys.getwindowsversion',
                     'sys.intern': 'https://docs.python.org/3/library/sys.html#sys.intern',
                     'sys.is_finalizing': 'https://docs.python.org/3/library/sys.html#sys.is_finalizing',
                     'sys.set_asyncgen_hooks': 'https://docs.python.org/3/library/sys.html#sys.set_asyncgen_hooks',
                     'sys.set_coroutine_origin_tracking_depth': 'https://docs.python.org/3/library/sys.html#sys.set_coroutine_origin_tracking_depth',
                     'sys.set_int_max_str_digits': 'https://docs.python.org/3/library/sys.html#sys.set_int_max_str_digits',
                     'sys.setdlopenflags': 'https://docs.python.org/3/library/sys.html#sys.setdlopenflags',
                     'sys.setprofile': 'https://docs.python.org/3/library/sys.html#sys.setprofile',
                     'sys.setrecursionlimit': 'https://docs.python.org/3/library/sys.html#sys.setrecursionlimit',
                     'sys.setswitchinterval': 'https://docs.python.org/3/library/sys.html#sys.setswitchinterval',
                     'sys.settrace': 'https://docs.python.org/3/library/sys.html#sys.settrace',
                     'sys.unraisablehook': 'https://docs.python.org/3/library/sys.html#sys.unraisablehook'},
            'sysconfig': { 'sysconfig._get_preferred_schemes': 'https://docs.python.org/3/library/sysconfig.html#sysconfig._get_preferred_schemes',
                           'sysconfig.get_config_h_filename': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_config_h_filename',
                           'sysconfig.get_config_var': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_config_var',
                           'sysconfig.get_config_vars': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_config_vars',
                           'sysconfig.get_default_scheme': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_default_scheme',
                           'sysconfig.get_makefile_filename': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_makefile_filename',
                           'sysconfig.get_path': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_path',
                           'sysconfig.get_path_names': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_path_names',
                           'sysconfig.get_paths': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_paths',
                           'sysconfig.get_platform': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_platform',
                           'sysconfig.get_preferred_scheme': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_preferred_scheme',
                           'sysconfig.get_python_version': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_python_version',
                           'sysconfig.get_scheme_names': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.get_scheme_names',
                           'sysconfig.is_python_build': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.is_python_build',
                           'sysconfig.parse_config_h': 'https://docs.python.org/3/library/sysconfig.html#sysconfig.parse_config_h'},
            'syslog': { 'syslog.closelog': 'https://docs.python.org/3/library/syslog.html#syslog.closelog',
                        'syslog.openlog': 'https://docs.python.org/3/library/syslog.html#syslog.openlog',
                        'syslog.setlogmask': 'https://docs.python.org/3/library/syslog.html#syslog.setlogmask',
                        'syslog.syslog': 'https://docs.python.org/3/library/syslog.html#syslog.syslog'},
            'tabnanny': { 'tabnanny.check': 'https://docs.python.org/3/library/tabnanny.html#tabnanny.check',
                          'tabnanny.process_tokens': 'https://docs.python.org/3/library/tabnanny.html#tabnanny.process_tokens'},
            'tarfile': { 'tarfile.TarFile': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile',
                         'tarfile.TarFile.add': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.add',
                         'tarfile.TarFile.addfile': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.addfile',
                         'tarfile.TarFile.close': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.close',
                         'tarfile.TarFile.extract': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.extract',
                         'tarfile.TarFile.extractall': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.extractall',
                         'tarfile.TarFile.extractfile': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.extractfile',
                         'tarfile.TarFile.getmember': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.getmember',
                         'tarfile.TarFile.getmembers': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.getmembers',
                         'tarfile.TarFile.getnames': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.getnames',
                         'tarfile.TarFile.gettarinfo': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.gettarinfo',
                         'tarfile.TarFile.list': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.list',
                         'tarfile.TarFile.next': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.next',
                         'tarfile.TarFile.open': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarFile.open',
                         'tarfile.TarInfo': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo',
                         'tarfile.TarInfo.frombuf': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.frombuf',
                         'tarfile.TarInfo.fromtarfile': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.fromtarfile',
                         'tarfile.TarInfo.isblk': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.isblk',
                         'tarfile.TarInfo.ischr': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.ischr',
                         'tarfile.TarInfo.isdev': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.isdev',
                         'tarfile.TarInfo.isdir': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.isdir',
                         'tarfile.TarInfo.isfifo': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.isfifo',
                         'tarfile.TarInfo.isfile': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.isfile',
                         'tarfile.TarInfo.islnk': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.islnk',
                         'tarfile.TarInfo.isreg': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.isreg',
                         'tarfile.TarInfo.issym': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.issym',
                         'tarfile.TarInfo.tobuf': 'https://docs.python.org/3/library/tarfile.html#tarfile.TarInfo.tobuf',
                         'tarfile.is_tarfile': 'https://docs.python.org/3/library/tarfile.html#tarfile.is_tarfile',
                         'tarfile.open': 'https://docs.python.org/3/library/tarfile.html#tarfile.open'},
            'telnetlib': { 'telnetlib.Telnet': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet',
                           'telnetlib.Telnet.close': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.close',
                           'telnetlib.Telnet.expect': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.expect',
                           'telnetlib.Telnet.fileno': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.fileno',
                           'telnetlib.Telnet.get_socket': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.get_socket',
                           'telnetlib.Telnet.interact': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.interact',
                           'telnetlib.Telnet.msg': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.msg',
                           'telnetlib.Telnet.mt_interact': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.mt_interact',
                           'telnetlib.Telnet.open': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.open',
                           'telnetlib.Telnet.read_all': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_all',
                           'telnetlib.Telnet.read_eager': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_eager',
                           'telnetlib.Telnet.read_lazy': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_lazy',
                           'telnetlib.Telnet.read_sb_data': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_sb_data',
                           'telnetlib.Telnet.read_some': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_some',
                           'telnetlib.Telnet.read_until': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_until',
                           'telnetlib.Telnet.read_very_eager': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_very_eager',
                           'telnetlib.Telnet.read_very_lazy': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.read_very_lazy',
                           'telnetlib.Telnet.set_debuglevel': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.set_debuglevel',
                           'telnetlib.Telnet.set_option_negotiation_callback': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.set_option_negotiation_callback',
                           'telnetlib.Telnet.write': 'https://docs.python.org/3/library/telnetlib.html#telnetlib.Telnet.write'},
            'tempfile': { 'tempfile.NamedTemporaryFile': 'https://docs.python.org/3/library/tempfile.html#tempfile.NamedTemporaryFile',
                          'tempfile.SpooledTemporaryFile': 'https://docs.python.org/3/library/tempfile.html#tempfile.SpooledTemporaryFile',
                          'tempfile.TemporaryDirectory': 'https://docs.python.org/3/library/tempfile.html#tempfile.TemporaryDirectory',
                          'tempfile.TemporaryFile': 'https://docs.python.org/3/library/tempfile.html#tempfile.TemporaryFile',
                          'tempfile.gettempdir': 'https://docs.python.org/3/library/tempfile.html#tempfile.gettempdir',
                          'tempfile.gettempdirb': 'https://docs.python.org/3/library/tempfile.html#tempfile.gettempdirb',
                          'tempfile.gettempprefix': 'https://docs.python.org/3/library/tempfile.html#tempfile.gettempprefix',
                          'tempfile.gettempprefixb': 'https://docs.python.org/3/library/tempfile.html#tempfile.gettempprefixb',
                          'tempfile.mkdtemp': 'https://docs.python.org/3/library/tempfile.html#tempfile.mkdtemp',
                          'tempfile.mkstemp': 'https://docs.python.org/3/library/tempfile.html#tempfile.mkstemp',
                          'tempfile.mktemp': 'https://docs.python.org/3/library/tempfile.html#tempfile.mktemp'},
            'termios': { 'termios.tcdrain': 'https://docs.python.org/3/library/termios.html#termios.tcdrain',
                         'termios.tcflow': 'https://docs.python.org/3/library/termios.html#termios.tcflow',
                         'termios.tcflush': 'https://docs.python.org/3/library/termios.html#termios.tcflush',
                         'termios.tcgetattr': 'https://docs.python.org/3/library/termios.html#termios.tcgetattr',
                         'termios.tcsendbreak': 'https://docs.python.org/3/library/termios.html#termios.tcsendbreak',
                         'termios.tcsetattr': 'https://docs.python.org/3/library/termios.html#termios.tcsetattr'},
            'test': {'test.support': 'https://docs.python.org/3/library/test.html#module-test.support'},
            'test.support': { 'test.support.BasicTestRunner': 'https://docs.python.org/3/library/test.html#test.support.BasicTestRunner',
                              'test.support.BasicTestRunner.run': 'https://docs.python.org/3/library/test.html#test.support.BasicTestRunner.run',
                              'test.support.Matcher': 'https://docs.python.org/3/library/test.html#test.support.Matcher',
                              'test.support.Matcher.match_value': 'https://docs.python.org/3/library/test.html#test.support.Matcher.match_value',
                              'test.support.Matcher.matches': 'https://docs.python.org/3/library/test.html#test.support.Matcher.matches',
                              'test.support.SaveSignals': 'https://docs.python.org/3/library/test.html#test.support.SaveSignals',
                              'test.support.SaveSignals.restore': 'https://docs.python.org/3/library/test.html#test.support.SaveSignals.restore',
                              'test.support.SaveSignals.save': 'https://docs.python.org/3/library/test.html#test.support.SaveSignals.save',
                              'test.support.SuppressCrashReport': 'https://docs.python.org/3/library/test.html#test.support.SuppressCrashReport',
                              'test.support.adjust_int_max_str_digits': 'https://docs.python.org/3/library/test.html#test.support.adjust_int_max_str_digits',
                              'test.support.anticipate_failure': 'https://docs.python.org/3/library/test.html#test.support.anticipate_failure',
                              'test.support.args_from_interpreter_flags': 'https://docs.python.org/3/library/test.html#test.support.args_from_interpreter_flags',
                              'test.support.bigaddrspacetest': 'https://docs.python.org/3/library/test.html#test.support.bigaddrspacetest',
                              'test.support.bigmemtest': 'https://docs.python.org/3/library/test.html#test.support.bigmemtest',
                              'test.support.bytecode_helper': 'https://docs.python.org/3/library/test.html#module-test.support.bytecode_helper',
                              'test.support.calcobjsize': 'https://docs.python.org/3/library/test.html#test.support.calcobjsize',
                              'test.support.calcvobjsize': 'https://docs.python.org/3/library/test.html#test.support.calcvobjsize',
                              'test.support.captured_stderr': 'https://docs.python.org/3/library/test.html#test.support.captured_stderr',
                              'test.support.captured_stdin': 'https://docs.python.org/3/library/test.html#test.support.captured_stdin',
                              'test.support.captured_stdout': 'https://docs.python.org/3/library/test.html#test.support.captured_stdout',
                              'test.support.catch_unraisable_exception': 'https://docs.python.org/3/library/test.html#test.support.catch_unraisable_exception',
                              'test.support.check__all__': 'https://docs.python.org/3/library/test.html#test.support.check__all__',
                              'test.support.check_disallow_instantiation': 'https://docs.python.org/3/library/test.html#test.support.check_disallow_instantiation',
                              'test.support.check_free_after_iterating': 'https://docs.python.org/3/library/test.html#test.support.check_free_after_iterating',
                              'test.support.check_impl_detail': 'https://docs.python.org/3/library/test.html#test.support.check_impl_detail',
                              'test.support.check_syntax_error': 'https://docs.python.org/3/library/test.html#test.support.check_syntax_error',
                              'test.support.checksizeof': 'https://docs.python.org/3/library/test.html#test.support.checksizeof',
                              'test.support.cpython_only': 'https://docs.python.org/3/library/test.html#test.support.cpython_only',
                              'test.support.detect_api_mismatch': 'https://docs.python.org/3/library/test.html#test.support.detect_api_mismatch',
                              'test.support.disable_faulthandler': 'https://docs.python.org/3/library/test.html#test.support.disable_faulthandler',
                              'test.support.disable_gc': 'https://docs.python.org/3/library/test.html#test.support.disable_gc',
                              'test.support.findfile': 'https://docs.python.org/3/library/test.html#test.support.findfile',
                              'test.support.gc_collect': 'https://docs.python.org/3/library/test.html#test.support.gc_collect',
                              'test.support.get_attribute': 'https://docs.python.org/3/library/test.html#test.support.get_attribute',
                              'test.support.get_original_stdout': 'https://docs.python.org/3/library/test.html#test.support.get_original_stdout',
                              'test.support.impl_detail': 'https://docs.python.org/3/library/test.html#test.support.impl_detail',
                              'test.support.import_helper': 'https://docs.python.org/3/library/test.html#module-test.support.import_helper',
                              'test.support.is_resource_enabled': 'https://docs.python.org/3/library/test.html#test.support.is_resource_enabled',
                              'test.support.load_package_tests': 'https://docs.python.org/3/library/test.html#test.support.load_package_tests',
                              'test.support.match_test': 'https://docs.python.org/3/library/test.html#test.support.match_test',
                              'test.support.missing_compiler_executable': 'https://docs.python.org/3/library/test.html#test.support.missing_compiler_executable',
                              'test.support.no_tracing': 'https://docs.python.org/3/library/test.html#test.support.no_tracing',
                              'test.support.open_urlresource': 'https://docs.python.org/3/library/test.html#test.support.open_urlresource',
                              'test.support.optim_args_from_interpreter_flags': 'https://docs.python.org/3/library/test.html#test.support.optim_args_from_interpreter_flags',
                              'test.support.os_helper': 'https://docs.python.org/3/library/test.html#module-test.support.os_helper',
                              'test.support.patch': 'https://docs.python.org/3/library/test.html#test.support.patch',
                              'test.support.print_warning': 'https://docs.python.org/3/library/test.html#test.support.print_warning',
                              'test.support.python_is_optimized': 'https://docs.python.org/3/library/test.html#test.support.python_is_optimized',
                              'test.support.reap_children': 'https://docs.python.org/3/library/test.html#test.support.reap_children',
                              'test.support.record_original_stdout': 'https://docs.python.org/3/library/test.html#test.support.record_original_stdout',
                              'test.support.refcount_test': 'https://docs.python.org/3/library/test.html#test.support.refcount_test',
                              'test.support.requires': 'https://docs.python.org/3/library/test.html#test.support.requires',
                              'test.support.requires_IEEE_754': 'https://docs.python.org/3/library/test.html#test.support.requires_IEEE_754',
                              'test.support.requires_bz2': 'https://docs.python.org/3/library/test.html#test.support.requires_bz2',
                              'test.support.requires_docstrings': 'https://docs.python.org/3/library/test.html#test.support.requires_docstrings',
                              'test.support.requires_freebsd_version': 'https://docs.python.org/3/library/test.html#test.support.requires_freebsd_version',
                              'test.support.requires_gzip': 'https://docs.python.org/3/library/test.html#test.support.requires_gzip',
                              'test.support.requires_linux_version': 'https://docs.python.org/3/library/test.html#test.support.requires_linux_version',
                              'test.support.requires_lzma': 'https://docs.python.org/3/library/test.html#test.support.requires_lzma',
                              'test.support.requires_mac_version': 'https://docs.python.org/3/library/test.html#test.support.requires_mac_version',
                              'test.support.requires_resource': 'https://docs.python.org/3/library/test.html#test.support.requires_resource',
                              'test.support.requires_zlib': 'https://docs.python.org/3/library/test.html#test.support.requires_zlib',
                              'test.support.run_doctest': 'https://docs.python.org/3/library/test.html#test.support.run_doctest',
                              'test.support.run_in_subinterp': 'https://docs.python.org/3/library/test.html#test.support.run_in_subinterp',
                              'test.support.run_unittest': 'https://docs.python.org/3/library/test.html#test.support.run_unittest',
                              'test.support.run_with_locale': 'https://docs.python.org/3/library/test.html#test.support.run_with_locale',
                              'test.support.run_with_tz': 'https://docs.python.org/3/library/test.html#test.support.run_with_tz',
                              'test.support.script_helper': 'https://docs.python.org/3/library/test.html#module-test.support.script_helper',
                              'test.support.set_match_tests': 'https://docs.python.org/3/library/test.html#test.support.set_match_tests',
                              'test.support.set_memlimit': 'https://docs.python.org/3/library/test.html#test.support.set_memlimit',
                              'test.support.setswitchinterval': 'https://docs.python.org/3/library/test.html#test.support.setswitchinterval',
                              'test.support.skip_if_broken_multiprocessing_synchronize': 'https://docs.python.org/3/library/test.html#test.support.skip_if_broken_multiprocessing_synchronize',
                              'test.support.socket_helper': 'https://docs.python.org/3/library/test.html#module-test.support.socket_helper',
                              'test.support.sortdict': 'https://docs.python.org/3/library/test.html#test.support.sortdict',
                              'test.support.swap_attr': 'https://docs.python.org/3/library/test.html#test.support.swap_attr',
                              'test.support.swap_item': 'https://docs.python.org/3/library/test.html#test.support.swap_item',
                              'test.support.system_must_validate_cert': 'https://docs.python.org/3/library/test.html#test.support.system_must_validate_cert',
                              'test.support.threading_helper': 'https://docs.python.org/3/library/test.html#module-test.support.threading_helper',
                              'test.support.wait_process': 'https://docs.python.org/3/library/test.html#test.support.wait_process',
                              'test.support.warnings_helper': 'https://docs.python.org/3/library/test.html#module-test.support.warnings_helper',
                              'test.support.with_pymalloc': 'https://docs.python.org/3/library/test.html#test.support.with_pymalloc'},
            'test.support.bytecode_helper': { 'test.support.bytecode_helper.BytecodeTestCase': 'https://docs.python.org/3/library/test.html#test.support.bytecode_helper.BytecodeTestCase',
                                              'test.support.bytecode_helper.BytecodeTestCase.assertInBytecode': 'https://docs.python.org/3/library/test.html#test.support.bytecode_helper.BytecodeTestCase.assertInBytecode',
                                              'test.support.bytecode_helper.BytecodeTestCase.assertNotInBytecode': 'https://docs.python.org/3/library/test.html#test.support.bytecode_helper.BytecodeTestCase.assertNotInBytecode',
                                              'test.support.bytecode_helper.BytecodeTestCase.get_disassembly_as_string': 'https://docs.python.org/3/library/test.html#test.support.bytecode_helper.BytecodeTestCase.get_disassembly_as_string'},
            'test.support.import_helper': { 'test.support.import_helper.CleanImport': 'https://docs.python.org/3/library/test.html#test.support.import_helper.CleanImport',
                                            'test.support.import_helper.DirsOnSysPath': 'https://docs.python.org/3/library/test.html#test.support.import_helper.DirsOnSysPath',
                                            'test.support.import_helper.forget': 'https://docs.python.org/3/library/test.html#test.support.import_helper.forget',
                                            'test.support.import_helper.import_fresh_module': 'https://docs.python.org/3/library/test.html#test.support.import_helper.import_fresh_module',
                                            'test.support.import_helper.import_module': 'https://docs.python.org/3/library/test.html#test.support.import_helper.import_module',
                                            'test.support.import_helper.make_legacy_pyc': 'https://docs.python.org/3/library/test.html#test.support.import_helper.make_legacy_pyc',
                                            'test.support.import_helper.modules_cleanup': 'https://docs.python.org/3/library/test.html#test.support.import_helper.modules_cleanup',
                                            'test.support.import_helper.modules_setup': 'https://docs.python.org/3/library/test.html#test.support.import_helper.modules_setup',
                                            'test.support.import_helper.unload': 'https://docs.python.org/3/library/test.html#test.support.import_helper.unload'},
            'test.support.os_helper': { 'test.support.os_helper.EnvironmentVarGuard': 'https://docs.python.org/3/library/test.html#test.support.os_helper.EnvironmentVarGuard',
                                        'test.support.os_helper.EnvironmentVarGuard.set': 'https://docs.python.org/3/library/test.html#test.support.os_helper.EnvironmentVarGuard.set',
                                        'test.support.os_helper.EnvironmentVarGuard.unset': 'https://docs.python.org/3/library/test.html#test.support.os_helper.EnvironmentVarGuard.unset',
                                        'test.support.os_helper.FakePath': 'https://docs.python.org/3/library/test.html#test.support.os_helper.FakePath',
                                        'test.support.os_helper.can_symlink': 'https://docs.python.org/3/library/test.html#test.support.os_helper.can_symlink',
                                        'test.support.os_helper.can_xattr': 'https://docs.python.org/3/library/test.html#test.support.os_helper.can_xattr',
                                        'test.support.os_helper.change_cwd': 'https://docs.python.org/3/library/test.html#test.support.os_helper.change_cwd',
                                        'test.support.os_helper.create_empty_file': 'https://docs.python.org/3/library/test.html#test.support.os_helper.create_empty_file',
                                        'test.support.os_helper.fd_count': 'https://docs.python.org/3/library/test.html#test.support.os_helper.fd_count',
                                        'test.support.os_helper.fs_is_case_insensitive': 'https://docs.python.org/3/library/test.html#test.support.os_helper.fs_is_case_insensitive',
                                        'test.support.os_helper.make_bad_fd': 'https://docs.python.org/3/library/test.html#test.support.os_helper.make_bad_fd',
                                        'test.support.os_helper.rmdir': 'https://docs.python.org/3/library/test.html#test.support.os_helper.rmdir',
                                        'test.support.os_helper.rmtree': 'https://docs.python.org/3/library/test.html#test.support.os_helper.rmtree',
                                        'test.support.os_helper.skip_unless_symlink': 'https://docs.python.org/3/library/test.html#test.support.os_helper.skip_unless_symlink',
                                        'test.support.os_helper.skip_unless_xattr': 'https://docs.python.org/3/library/test.html#test.support.os_helper.skip_unless_xattr',
                                        'test.support.os_helper.temp_cwd': 'https://docs.python.org/3/library/test.html#test.support.os_helper.temp_cwd',
                                        'test.support.os_helper.temp_dir': 'https://docs.python.org/3/library/test.html#test.support.os_helper.temp_dir',
                                        'test.support.os_helper.temp_umask': 'https://docs.python.org/3/library/test.html#test.support.os_helper.temp_umask',
                                        'test.support.os_helper.unlink': 'https://docs.python.org/3/library/test.html#test.support.os_helper.unlink'},
            'test.support.script_helper': { 'test.support.script_helper.assert_python_failure': 'https://docs.python.org/3/library/test.html#test.support.script_helper.assert_python_failure',
                                            'test.support.script_helper.assert_python_ok': 'https://docs.python.org/3/library/test.html#test.support.script_helper.assert_python_ok',
                                            'test.support.script_helper.interpreter_requires_environment': 'https://docs.python.org/3/library/test.html#test.support.script_helper.interpreter_requires_environment',
                                            'test.support.script_helper.kill_python': 'https://docs.python.org/3/library/test.html#test.support.script_helper.kill_python',
                                            'test.support.script_helper.make_pkg': 'https://docs.python.org/3/library/test.html#test.support.script_helper.make_pkg',
                                            'test.support.script_helper.make_script': 'https://docs.python.org/3/library/test.html#test.support.script_helper.make_script',
                                            'test.support.script_helper.make_zip_pkg': 'https://docs.python.org/3/library/test.html#test.support.script_helper.make_zip_pkg',
                                            'test.support.script_helper.make_zip_script': 'https://docs.python.org/3/library/test.html#test.support.script_helper.make_zip_script',
                                            'test.support.script_helper.run_python_until_end': 'https://docs.python.org/3/library/test.html#test.support.script_helper.run_python_until_end',
                                            'test.support.script_helper.spawn_python': 'https://docs.python.org/3/library/test.html#test.support.script_helper.spawn_python'},
            'test.support.socket_helper': { 'test.support.socket_helper.bind_port': 'https://docs.python.org/3/library/test.html#test.support.socket_helper.bind_port',
                                            'test.support.socket_helper.bind_unix_socket': 'https://docs.python.org/3/library/test.html#test.support.socket_helper.bind_unix_socket',
                                            'test.support.socket_helper.find_unused_port': 'https://docs.python.org/3/library/test.html#test.support.socket_helper.find_unused_port',
                                            'test.support.socket_helper.skip_unless_bind_unix_socket': 'https://docs.python.org/3/library/test.html#test.support.socket_helper.skip_unless_bind_unix_socket',
                                            'test.support.socket_helper.transient_internet': 'https://docs.python.org/3/library/test.html#test.support.socket_helper.transient_internet'},
            'test.support.threading_helper': { 'test.support.threading_helper.catch_threading_exception': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.catch_threading_exception',
                                               'test.support.threading_helper.join_thread': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.join_thread',
                                               'test.support.threading_helper.reap_threads': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.reap_threads',
                                               'test.support.threading_helper.start_threads': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.start_threads',
                                               'test.support.threading_helper.threading_cleanup': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.threading_cleanup',
                                               'test.support.threading_helper.threading_setup': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.threading_setup',
                                               'test.support.threading_helper.wait_threads_exit': 'https://docs.python.org/3/library/test.html#test.support.threading_helper.wait_threads_exit'},
            'test.support.warnings_helper': { 'test.support.warnings_helper.WarningsRecorder': 'https://docs.python.org/3/library/test.html#test.support.warnings_helper.WarningsRecorder',
                                              'test.support.warnings_helper.check_no_resource_warning': 'https://docs.python.org/3/library/test.html#test.support.warnings_helper.check_no_resource_warning',
                                              'test.support.warnings_helper.check_syntax_warning': 'https://docs.python.org/3/library/test.html#test.support.warnings_helper.check_syntax_warning',
                                              'test.support.warnings_helper.check_warnings': 'https://docs.python.org/3/library/test.html#test.support.warnings_helper.check_warnings'},
            'textwrap': { 'textwrap.TextWrapper': 'https://docs.python.org/3/library/textwrap.html#textwrap.TextWrapper',
                          'textwrap.TextWrapper.fill': 'https://docs.python.org/3/library/textwrap.html#textwrap.TextWrapper.fill',
                          'textwrap.TextWrapper.wrap': 'https://docs.python.org/3/library/textwrap.html#textwrap.TextWrapper.wrap',
                          'textwrap.dedent': 'https://docs.python.org/3/library/textwrap.html#textwrap.dedent',
                          'textwrap.fill': 'https://docs.python.org/3/library/textwrap.html#textwrap.fill',
                          'textwrap.indent': 'https://docs.python.org/3/library/textwrap.html#textwrap.indent',
                          'textwrap.shorten': 'https://docs.python.org/3/library/textwrap.html#textwrap.shorten',
                          'textwrap.wrap': 'https://docs.python.org/3/library/textwrap.html#textwrap.wrap'},
            'threading': { 'threading.Barrier': 'https://docs.python.org/3/library/threading.html#threading.Barrier',
                           'threading.Barrier.abort': 'https://docs.python.org/3/library/threading.html#threading.Barrier.abort',
                           'threading.Barrier.reset': 'https://docs.python.org/3/library/threading.html#threading.Barrier.reset',
                           'threading.Barrier.wait': 'https://docs.python.org/3/library/threading.html#threading.Barrier.wait',
                           'threading.BoundedSemaphore': 'https://docs.python.org/3/library/threading.html#threading.BoundedSemaphore',
                           'threading.Condition': 'https://docs.python.org/3/library/threading.html#threading.Condition',
                           'threading.Condition.acquire': 'https://docs.python.org/3/library/threading.html#threading.Condition.acquire',
                           'threading.Condition.notify': 'https://docs.python.org/3/library/threading.html#threading.Condition.notify',
                           'threading.Condition.notify_all': 'https://docs.python.org/3/library/threading.html#threading.Condition.notify_all',
                           'threading.Condition.release': 'https://docs.python.org/3/library/threading.html#threading.Condition.release',
                           'threading.Condition.wait': 'https://docs.python.org/3/library/threading.html#threading.Condition.wait',
                           'threading.Condition.wait_for': 'https://docs.python.org/3/library/threading.html#threading.Condition.wait_for',
                           'threading.Event': 'https://docs.python.org/3/library/threading.html#threading.Event',
                           'threading.Event.clear': 'https://docs.python.org/3/library/threading.html#threading.Event.clear',
                           'threading.Event.is_set': 'https://docs.python.org/3/library/threading.html#threading.Event.is_set',
                           'threading.Event.set': 'https://docs.python.org/3/library/threading.html#threading.Event.set',
                           'threading.Event.wait': 'https://docs.python.org/3/library/threading.html#threading.Event.wait',
                           'threading.Lock': 'https://docs.python.org/3/library/threading.html#threading.Lock',
                           'threading.Lock.acquire': 'https://docs.python.org/3/library/threading.html#threading.Lock.acquire',
                           'threading.Lock.locked': 'https://docs.python.org/3/library/threading.html#threading.Lock.locked',
                           'threading.Lock.release': 'https://docs.python.org/3/library/threading.html#threading.Lock.release',
                           'threading.RLock': 'https://docs.python.org/3/library/threading.html#threading.RLock',
                           'threading.RLock.acquire': 'https://docs.python.org/3/library/threading.html#threading.RLock.acquire',
                           'threading.RLock.release': 'https://docs.python.org/3/library/threading.html#threading.RLock.release',
                           'threading.Semaphore': 'https://docs.python.org/3/library/threading.html#threading.Semaphore',
                           'threading.Semaphore.acquire': 'https://docs.python.org/3/library/threading.html#threading.Semaphore.acquire',
                           'threading.Semaphore.release': 'https://docs.python.org/3/library/threading.html#threading.Semaphore.release',
                           'threading.Thread': 'https://docs.python.org/3/library/threading.html#threading.Thread',
                           'threading.Thread.getName': 'https://docs.python.org/3/library/threading.html#threading.Thread.getName',
                           'threading.Thread.isDaemon': 'https://docs.python.org/3/library/threading.html#threading.Thread.isDaemon',
                           'threading.Thread.is_alive': 'https://docs.python.org/3/library/threading.html#threading.Thread.is_alive',
                           'threading.Thread.join': 'https://docs.python.org/3/library/threading.html#threading.Thread.join',
                           'threading.Thread.run': 'https://docs.python.org/3/library/threading.html#threading.Thread.run',
                           'threading.Thread.setDaemon': 'https://docs.python.org/3/library/threading.html#threading.Thread.setDaemon',
                           'threading.Thread.setName': 'https://docs.python.org/3/library/threading.html#threading.Thread.setName',
                           'threading.Thread.start': 'https://docs.python.org/3/library/threading.html#threading.Thread.start',
                           'threading.Timer': 'https://docs.python.org/3/library/threading.html#threading.Timer',
                           'threading.Timer.cancel': 'https://docs.python.org/3/library/threading.html#threading.Timer.cancel',
                           'threading.active_count': 'https://docs.python.org/3/library/threading.html#threading.active_count',
                           'threading.current_thread': 'https://docs.python.org/3/library/threading.html#threading.current_thread',
                           'threading.enumerate': 'https://docs.python.org/3/library/threading.html#threading.enumerate',
                           'threading.excepthook': 'https://docs.python.org/3/library/threading.html#threading.excepthook',
                           'threading.get_ident': 'https://docs.python.org/3/library/threading.html#threading.get_ident',
                           'threading.get_native_id': 'https://docs.python.org/3/library/threading.html#threading.get_native_id',
                           'threading.getprofile': 'https://docs.python.org/3/library/threading.html#threading.getprofile',
                           'threading.gettrace': 'https://docs.python.org/3/library/threading.html#threading.gettrace',
                           'threading.local': 'https://docs.python.org/3/library/threading.html#threading.local',
                           'threading.main_thread': 'https://docs.python.org/3/library/threading.html#threading.main_thread',
                           'threading.setprofile': 'https://docs.python.org/3/library/threading.html#threading.setprofile',
                           'threading.settrace': 'https://docs.python.org/3/library/threading.html#threading.settrace',
                           'threading.stack_size': 'https://docs.python.org/3/library/threading.html#threading.stack_size'},
            'time': { 'time.asctime': 'https://docs.python.org/3/library/time.html#time.asctime',
                      'time.clock_getres': 'https://docs.python.org/3/library/time.html#time.clock_getres',
                      'time.clock_gettime': 'https://docs.python.org/3/library/time.html#time.clock_gettime',
                      'time.clock_gettime_ns': 'https://docs.python.org/3/library/time.html#time.clock_gettime_ns',
                      'time.clock_settime': 'https://docs.python.org/3/library/time.html#time.clock_settime',
                      'time.clock_settime_ns': 'https://docs.python.org/3/library/time.html#time.clock_settime_ns',
                      'time.ctime': 'https://docs.python.org/3/library/time.html#time.ctime',
                      'time.get_clock_info': 'https://docs.python.org/3/library/time.html#time.get_clock_info',
                      'time.gmtime': 'https://docs.python.org/3/library/time.html#time.gmtime',
                      'time.localtime': 'https://docs.python.org/3/library/time.html#time.localtime',
                      'time.mktime': 'https://docs.python.org/3/library/time.html#time.mktime',
                      'time.monotonic': 'https://docs.python.org/3/library/time.html#time.monotonic',
                      'time.monotonic_ns': 'https://docs.python.org/3/library/time.html#time.monotonic_ns',
                      'time.perf_counter': 'https://docs.python.org/3/library/time.html#time.perf_counter',
                      'time.perf_counter_ns': 'https://docs.python.org/3/library/time.html#time.perf_counter_ns',
                      'time.process_time': 'https://docs.python.org/3/library/time.html#time.process_time',
                      'time.process_time_ns': 'https://docs.python.org/3/library/time.html#time.process_time_ns',
                      'time.pthread_getcpuclockid': 'https://docs.python.org/3/library/time.html#time.pthread_getcpuclockid',
                      'time.sleep': 'https://docs.python.org/3/library/time.html#time.sleep',
                      'time.strftime': 'https://docs.python.org/3/library/time.html#time.strftime',
                      'time.strptime': 'https://docs.python.org/3/library/time.html#time.strptime',
                      'time.struct_time': 'https://docs.python.org/3/library/time.html#time.struct_time',
                      'time.thread_time': 'https://docs.python.org/3/library/time.html#time.thread_time',
                      'time.thread_time_ns': 'https://docs.python.org/3/library/time.html#time.thread_time_ns',
                      'time.time': 'https://docs.python.org/3/library/time.html#time.time',
                      'time.time_ns': 'https://docs.python.org/3/library/time.html#time.time_ns',
                      'time.tzset': 'https://docs.python.org/3/library/time.html#time.tzset'},
            'timeit': { 'timeit.Timer': 'https://docs.python.org/3/library/timeit.html#timeit.Timer',
                        'timeit.Timer.autorange': 'https://docs.python.org/3/library/timeit.html#timeit.Timer.autorange',
                        'timeit.Timer.print_exc': 'https://docs.python.org/3/library/timeit.html#timeit.Timer.print_exc',
                        'timeit.Timer.repeat': 'https://docs.python.org/3/library/timeit.html#timeit.Timer.repeat',
                        'timeit.Timer.timeit': 'https://docs.python.org/3/library/timeit.html#timeit.Timer.timeit',
                        'timeit.default_timer': 'https://docs.python.org/3/library/timeit.html#timeit.default_timer',
                        'timeit.repeat': 'https://docs.python.org/3/library/timeit.html#timeit.repeat',
                        'timeit.timeit': 'https://docs.python.org/3/library/timeit.html#timeit.timeit'},
            'tkinter': { 'tkinter.Tcl': 'https://docs.python.org/3/library/tkinter.html#tkinter.Tcl',
                         'tkinter.Tk': 'https://docs.python.org/3/library/tkinter.html#tkinter.Tk',
                         'tkinter.colorchooser': 'https://docs.python.org/3/library/tkinter.colorchooser.html#module-tkinter.colorchooser',
                         'tkinter.commondialog': 'https://docs.python.org/3/library/dialog.html#module-tkinter.commondialog',
                         'tkinter.dnd': 'https://docs.python.org/3/library/tkinter.dnd.html#module-tkinter.dnd',
                         'tkinter.filedialog': 'https://docs.python.org/3/library/dialog.html#module-tkinter.filedialog',
                         'tkinter.font': 'https://docs.python.org/3/library/tkinter.font.html#module-tkinter.font',
                         'tkinter.messagebox': 'https://docs.python.org/3/library/tkinter.messagebox.html#module-tkinter.messagebox',
                         'tkinter.messagebox.askokcancel': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.askokcancel',
                         'tkinter.messagebox.askquestion': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.askquestion',
                         'tkinter.messagebox.askretrycancel': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.askretrycancel',
                         'tkinter.messagebox.askyesno': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.askyesno',
                         'tkinter.messagebox.askyesnocancel': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.askyesnocancel',
                         'tkinter.messagebox.showerror': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.showerror',
                         'tkinter.messagebox.showinfo': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.showinfo',
                         'tkinter.messagebox.showwarning': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.showwarning',
                         'tkinter.scrolledtext': 'https://docs.python.org/3/library/tkinter.scrolledtext.html#module-tkinter.scrolledtext',
                         'tkinter.simpledialog': 'https://docs.python.org/3/library/dialog.html#module-tkinter.simpledialog',
                         'tkinter.tix': 'https://docs.python.org/3/library/tkinter.tix.html#module-tkinter.tix',
                         'tkinter.ttk': 'https://docs.python.org/3/library/tkinter.ttk.html#module-tkinter.ttk'},
            'tkinter.Widget': { 'tkinter.Widget.tk.createfilehandler': 'https://docs.python.org/3/library/tkinter.html#tkinter.Widget.tk.createfilehandler',
                                'tkinter.Widget.tk.deletefilehandler': 'https://docs.python.org/3/library/tkinter.html#tkinter.Widget.tk.deletefilehandler'},
            'tkinter.colorchooser': { 'tkinter.colorchooser.Chooser': 'https://docs.python.org/3/library/tkinter.colorchooser.html#tkinter.colorchooser.Chooser',
                                      'tkinter.colorchooser.askcolor': 'https://docs.python.org/3/library/tkinter.colorchooser.html#tkinter.colorchooser.askcolor'},
            'tkinter.commondialog': { 'tkinter.commondialog.Dialog': 'https://docs.python.org/3/library/dialog.html#tkinter.commondialog.Dialog',
                                      'tkinter.commondialog.Dialog.show': 'https://docs.python.org/3/library/dialog.html#tkinter.commondialog.Dialog.show'},
            'tkinter.dnd': { 'tkinter.dnd.DndHandler': 'https://docs.python.org/3/library/tkinter.dnd.html#tkinter.dnd.DndHandler',
                             'tkinter.dnd.DndHandler.cancel': 'https://docs.python.org/3/library/tkinter.dnd.html#tkinter.dnd.DndHandler.cancel',
                             'tkinter.dnd.DndHandler.finish': 'https://docs.python.org/3/library/tkinter.dnd.html#tkinter.dnd.DndHandler.finish',
                             'tkinter.dnd.DndHandler.on_motion': 'https://docs.python.org/3/library/tkinter.dnd.html#tkinter.dnd.DndHandler.on_motion',
                             'tkinter.dnd.DndHandler.on_release': 'https://docs.python.org/3/library/tkinter.dnd.html#tkinter.dnd.DndHandler.on_release',
                             'tkinter.dnd.dnd_start': 'https://docs.python.org/3/library/tkinter.dnd.html#tkinter.dnd.dnd_start'},
            'tkinter.filedialog': { 'tkinter.filedialog.Directory': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.Directory',
                                    'tkinter.filedialog.FileDialog': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog',
                                    'tkinter.filedialog.FileDialog.cancel_command': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.cancel_command',
                                    'tkinter.filedialog.FileDialog.dirs_double_event': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.dirs_double_event',
                                    'tkinter.filedialog.FileDialog.dirs_select_event': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.dirs_select_event',
                                    'tkinter.filedialog.FileDialog.files_double_event': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.files_double_event',
                                    'tkinter.filedialog.FileDialog.files_select_event': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.files_select_event',
                                    'tkinter.filedialog.FileDialog.filter_command': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.filter_command',
                                    'tkinter.filedialog.FileDialog.get_filter': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.get_filter',
                                    'tkinter.filedialog.FileDialog.get_selection': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.get_selection',
                                    'tkinter.filedialog.FileDialog.go': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.go',
                                    'tkinter.filedialog.FileDialog.ok_event': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.ok_event',
                                    'tkinter.filedialog.FileDialog.quit': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.quit',
                                    'tkinter.filedialog.FileDialog.set_filter': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.set_filter',
                                    'tkinter.filedialog.FileDialog.set_selection': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.FileDialog.set_selection',
                                    'tkinter.filedialog.LoadFileDialog': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.LoadFileDialog',
                                    'tkinter.filedialog.LoadFileDialog.ok_command': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.LoadFileDialog.ok_command',
                                    'tkinter.filedialog.Open': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.Open',
                                    'tkinter.filedialog.SaveAs': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.SaveAs',
                                    'tkinter.filedialog.SaveFileDialog': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.SaveFileDialog',
                                    'tkinter.filedialog.SaveFileDialog.ok_command': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.SaveFileDialog.ok_command',
                                    'tkinter.filedialog.askdirectory': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.askdirectory',
                                    'tkinter.filedialog.askopenfile': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.askopenfile',
                                    'tkinter.filedialog.askopenfilename': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.askopenfilename',
                                    'tkinter.filedialog.askopenfilenames': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.askopenfilenames',
                                    'tkinter.filedialog.askopenfiles': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.askopenfiles',
                                    'tkinter.filedialog.asksaveasfile': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.asksaveasfile',
                                    'tkinter.filedialog.asksaveasfilename': 'https://docs.python.org/3/library/dialog.html#tkinter.filedialog.asksaveasfilename'},
            'tkinter.font': { 'tkinter.font.Font': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font',
                              'tkinter.font.Font.actual': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font.actual',
                              'tkinter.font.Font.cget': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font.cget',
                              'tkinter.font.Font.config': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font.config',
                              'tkinter.font.Font.copy': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font.copy',
                              'tkinter.font.Font.measure': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font.measure',
                              'tkinter.font.Font.metrics': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.Font.metrics',
                              'tkinter.font.families': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.families',
                              'tkinter.font.names': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.names',
                              'tkinter.font.nametofont': 'https://docs.python.org/3/library/tkinter.font.html#tkinter.font.nametofont'},
            'tkinter.messagebox': {'tkinter.messagebox.Message': 'https://docs.python.org/3/library/tkinter.messagebox.html#tkinter.messagebox.Message'},
            'tkinter.scrolledtext': { 'tkinter.scrolledtext.ScrolledText': 'https://docs.python.org/3/library/tkinter.scrolledtext.html#tkinter.scrolledtext.ScrolledText'},
            'tkinter.simpledialog': { 'tkinter.simpledialog.Dialog': 'https://docs.python.org/3/library/dialog.html#tkinter.simpledialog.Dialog',
                                      'tkinter.simpledialog.Dialog.body': 'https://docs.python.org/3/library/dialog.html#tkinter.simpledialog.Dialog.body',
                                      'tkinter.simpledialog.Dialog.buttonbox': 'https://docs.python.org/3/library/dialog.html#tkinter.simpledialog.Dialog.buttonbox',
                                      'tkinter.simpledialog.askfloat': 'https://docs.python.org/3/library/dialog.html#tkinter.simpledialog.askfloat',
                                      'tkinter.simpledialog.askinteger': 'https://docs.python.org/3/library/dialog.html#tkinter.simpledialog.askinteger',
                                      'tkinter.simpledialog.askstring': 'https://docs.python.org/3/library/dialog.html#tkinter.simpledialog.askstring'},
            'tkinter.tix': { 'tkinter.tix.Balloon': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Balloon',
                             'tkinter.tix.ButtonBox': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.ButtonBox',
                             'tkinter.tix.CheckList': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.CheckList',
                             'tkinter.tix.ComboBox': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.ComboBox',
                             'tkinter.tix.Control': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Control',
                             'tkinter.tix.DirList': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.DirList',
                             'tkinter.tix.DirSelectBox': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.DirSelectBox',
                             'tkinter.tix.DirSelectDialog': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.DirSelectDialog',
                             'tkinter.tix.DirTree': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.DirTree',
                             'tkinter.tix.ExFileSelectBox': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.ExFileSelectBox',
                             'tkinter.tix.FileEntry': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.FileEntry',
                             'tkinter.tix.FileSelectBox': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.FileSelectBox',
                             'tkinter.tix.Form': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Form',
                             'tkinter.tix.HList': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.HList',
                             'tkinter.tix.InputOnly': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.InputOnly',
                             'tkinter.tix.LabelEntry': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.LabelEntry',
                             'tkinter.tix.LabelFrame': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.LabelFrame',
                             'tkinter.tix.ListNoteBook': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.ListNoteBook',
                             'tkinter.tix.Meter': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Meter',
                             'tkinter.tix.NoteBook': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.NoteBook',
                             'tkinter.tix.OptionMenu': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.OptionMenu',
                             'tkinter.tix.PanedWindow': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.PanedWindow',
                             'tkinter.tix.PopupMenu': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.PopupMenu',
                             'tkinter.tix.Select': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Select',
                             'tkinter.tix.StdButtonBox': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.StdButtonBox',
                             'tkinter.tix.TList': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.TList',
                             'tkinter.tix.Tk': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Tk',
                             'tkinter.tix.Tree': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.Tree',
                             'tkinter.tix.tixCommand': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand',
                             'tkinter.tix.tixCommand.tix_addbitmapdir': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_addbitmapdir',
                             'tkinter.tix.tixCommand.tix_cget': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_cget',
                             'tkinter.tix.tixCommand.tix_configure': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_configure',
                             'tkinter.tix.tixCommand.tix_filedialog': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_filedialog',
                             'tkinter.tix.tixCommand.tix_getbitmap': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_getbitmap',
                             'tkinter.tix.tixCommand.tix_getimage': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_getimage',
                             'tkinter.tix.tixCommand.tix_option_get': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_option_get',
                             'tkinter.tix.tixCommand.tix_resetoptions': 'https://docs.python.org/3/library/tkinter.tix.html#tkinter.tix.tixCommand.tix_resetoptions'},
            'tkinter.ttk': { 'tkinter.ttk.Combobox': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Combobox',
                             'tkinter.ttk.Combobox.current': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Combobox.current',
                             'tkinter.ttk.Combobox.get': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Combobox.get',
                             'tkinter.ttk.Combobox.set': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Combobox.set',
                             'tkinter.ttk.Notebook': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook',
                             'tkinter.ttk.Notebook.add': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.add',
                             'tkinter.ttk.Notebook.enable_traversal': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.enable_traversal',
                             'tkinter.ttk.Notebook.forget': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.forget',
                             'tkinter.ttk.Notebook.hide': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.hide',
                             'tkinter.ttk.Notebook.identify': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.identify',
                             'tkinter.ttk.Notebook.index': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.index',
                             'tkinter.ttk.Notebook.insert': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.insert',
                             'tkinter.ttk.Notebook.select': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.select',
                             'tkinter.ttk.Notebook.tab': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.tab',
                             'tkinter.ttk.Notebook.tabs': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Notebook.tabs',
                             'tkinter.ttk.Progressbar': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Progressbar',
                             'tkinter.ttk.Progressbar.start': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Progressbar.start',
                             'tkinter.ttk.Progressbar.step': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Progressbar.step',
                             'tkinter.ttk.Progressbar.stop': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Progressbar.stop',
                             'tkinter.ttk.Spinbox': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Spinbox',
                             'tkinter.ttk.Spinbox.get': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Spinbox.get',
                             'tkinter.ttk.Spinbox.set': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Spinbox.set',
                             'tkinter.ttk.Style': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style',
                             'tkinter.ttk.Style.configure': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.configure',
                             'tkinter.ttk.Style.element_create': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.element_create',
                             'tkinter.ttk.Style.element_names': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.element_names',
                             'tkinter.ttk.Style.element_options': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.element_options',
                             'tkinter.ttk.Style.layout': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.layout',
                             'tkinter.ttk.Style.lookup': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.lookup',
                             'tkinter.ttk.Style.map': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.map',
                             'tkinter.ttk.Style.theme_create': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.theme_create',
                             'tkinter.ttk.Style.theme_names': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.theme_names',
                             'tkinter.ttk.Style.theme_settings': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.theme_settings',
                             'tkinter.ttk.Style.theme_use': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Style.theme_use',
                             'tkinter.ttk.Treeview': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview',
                             'tkinter.ttk.Treeview.bbox': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.bbox',
                             'tkinter.ttk.Treeview.column': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.column',
                             'tkinter.ttk.Treeview.delete': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.delete',
                             'tkinter.ttk.Treeview.detach': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.detach',
                             'tkinter.ttk.Treeview.exists': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.exists',
                             'tkinter.ttk.Treeview.focus': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.focus',
                             'tkinter.ttk.Treeview.get_children': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.get_children',
                             'tkinter.ttk.Treeview.heading': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.heading',
                             'tkinter.ttk.Treeview.identify': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.identify',
                             'tkinter.ttk.Treeview.identify_column': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.identify_column',
                             'tkinter.ttk.Treeview.identify_element': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.identify_element',
                             'tkinter.ttk.Treeview.identify_region': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.identify_region',
                             'tkinter.ttk.Treeview.identify_row': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.identify_row',
                             'tkinter.ttk.Treeview.index': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.index',
                             'tkinter.ttk.Treeview.insert': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.insert',
                             'tkinter.ttk.Treeview.item': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.item',
                             'tkinter.ttk.Treeview.move': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.move',
                             'tkinter.ttk.Treeview.next': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.next',
                             'tkinter.ttk.Treeview.parent': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.parent',
                             'tkinter.ttk.Treeview.prev': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.prev',
                             'tkinter.ttk.Treeview.reattach': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.reattach',
                             'tkinter.ttk.Treeview.see': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.see',
                             'tkinter.ttk.Treeview.selection': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.selection',
                             'tkinter.ttk.Treeview.selection_add': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.selection_add',
                             'tkinter.ttk.Treeview.selection_remove': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.selection_remove',
                             'tkinter.ttk.Treeview.selection_set': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.selection_set',
                             'tkinter.ttk.Treeview.selection_toggle': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.selection_toggle',
                             'tkinter.ttk.Treeview.set': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.set',
                             'tkinter.ttk.Treeview.set_children': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.set_children',
                             'tkinter.ttk.Treeview.tag_bind': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.tag_bind',
                             'tkinter.ttk.Treeview.tag_configure': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.tag_configure',
                             'tkinter.ttk.Treeview.tag_has': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.tag_has',
                             'tkinter.ttk.Treeview.xview': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.xview',
                             'tkinter.ttk.Treeview.yview': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Treeview.yview',
                             'tkinter.ttk.Widget': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Widget',
                             'tkinter.ttk.Widget.identify': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Widget.identify',
                             'tkinter.ttk.Widget.instate': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Widget.instate',
                             'tkinter.ttk.Widget.state': 'https://docs.python.org/3/library/tkinter.ttk.html#tkinter.ttk.Widget.state'},
            'token': { 'token.ISEOF': 'https://docs.python.org/3/library/token.html#token.ISEOF',
                       'token.ISNONTERMINAL': 'https://docs.python.org/3/library/token.html#token.ISNONTERMINAL',
                       'token.ISTERMINAL': 'https://docs.python.org/3/library/token.html#token.ISTERMINAL'},
            'tokenize': { 'tokenize.detect_encoding': 'https://docs.python.org/3/library/tokenize.html#tokenize.detect_encoding',
                          'tokenize.generate_tokens': 'https://docs.python.org/3/library/tokenize.html#tokenize.generate_tokens',
                          'tokenize.open': 'https://docs.python.org/3/library/tokenize.html#tokenize.open',
                          'tokenize.tokenize': 'https://docs.python.org/3/library/tokenize.html#tokenize.tokenize',
                          'tokenize.untokenize': 'https://docs.python.org/3/library/tokenize.html#tokenize.untokenize'},
            'trace': { 'trace.CoverageResults': 'https://docs.python.org/3/library/trace.html#trace.CoverageResults',
                       'trace.CoverageResults.update': 'https://docs.python.org/3/library/trace.html#trace.CoverageResults.update',
                       'trace.CoverageResults.write_results': 'https://docs.python.org/3/library/trace.html#trace.CoverageResults.write_results',
                       'trace.Trace': 'https://docs.python.org/3/library/trace.html#trace.Trace',
                       'trace.Trace.results': 'https://docs.python.org/3/library/trace.html#trace.Trace.results',
                       'trace.Trace.run': 'https://docs.python.org/3/library/trace.html#trace.Trace.run',
                       'trace.Trace.runctx': 'https://docs.python.org/3/library/trace.html#trace.Trace.runctx',
                       'trace.Trace.runfunc': 'https://docs.python.org/3/library/trace.html#trace.Trace.runfunc'},
            'traceback': { 'traceback.FrameSummary': 'https://docs.python.org/3/library/traceback.html#traceback.FrameSummary',
                           'traceback.StackSummary': 'https://docs.python.org/3/library/traceback.html#traceback.StackSummary',
                           'traceback.StackSummary.extract': 'https://docs.python.org/3/library/traceback.html#traceback.StackSummary.extract',
                           'traceback.StackSummary.format': 'https://docs.python.org/3/library/traceback.html#traceback.StackSummary.format',
                           'traceback.StackSummary.from_list': 'https://docs.python.org/3/library/traceback.html#traceback.StackSummary.from_list',
                           'traceback.TracebackException': 'https://docs.python.org/3/library/traceback.html#traceback.TracebackException',
                           'traceback.TracebackException.format': 'https://docs.python.org/3/library/traceback.html#traceback.TracebackException.format',
                           'traceback.TracebackException.format_exception_only': 'https://docs.python.org/3/library/traceback.html#traceback.TracebackException.format_exception_only',
                           'traceback.TracebackException.from_exception': 'https://docs.python.org/3/library/traceback.html#traceback.TracebackException.from_exception',
                           'traceback.clear_frames': 'https://docs.python.org/3/library/traceback.html#traceback.clear_frames',
                           'traceback.extract_stack': 'https://docs.python.org/3/library/traceback.html#traceback.extract_stack',
                           'traceback.extract_tb': 'https://docs.python.org/3/library/traceback.html#traceback.extract_tb',
                           'traceback.format_exc': 'https://docs.python.org/3/library/traceback.html#traceback.format_exc',
                           'traceback.format_exception': 'https://docs.python.org/3/library/traceback.html#traceback.format_exception',
                           'traceback.format_exception_only': 'https://docs.python.org/3/library/traceback.html#traceback.format_exception_only',
                           'traceback.format_list': 'https://docs.python.org/3/library/traceback.html#traceback.format_list',
                           'traceback.format_stack': 'https://docs.python.org/3/library/traceback.html#traceback.format_stack',
                           'traceback.format_tb': 'https://docs.python.org/3/library/traceback.html#traceback.format_tb',
                           'traceback.print_exc': 'https://docs.python.org/3/library/traceback.html#traceback.print_exc',
                           'traceback.print_exception': 'https://docs.python.org/3/library/traceback.html#traceback.print_exception',
                           'traceback.print_last': 'https://docs.python.org/3/library/traceback.html#traceback.print_last',
                           'traceback.print_stack': 'https://docs.python.org/3/library/traceback.html#traceback.print_stack',
                           'traceback.print_tb': 'https://docs.python.org/3/library/traceback.html#traceback.print_tb',
                           'traceback.walk_stack': 'https://docs.python.org/3/library/traceback.html#traceback.walk_stack',
                           'traceback.walk_tb': 'https://docs.python.org/3/library/traceback.html#traceback.walk_tb'},
            'tracemalloc': { 'tracemalloc.DomainFilter': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.DomainFilter',
                             'tracemalloc.Filter': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Filter',
                             'tracemalloc.Frame': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Frame',
                             'tracemalloc.Snapshot': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Snapshot',
                             'tracemalloc.Snapshot.compare_to': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Snapshot.compare_to',
                             'tracemalloc.Snapshot.dump': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Snapshot.dump',
                             'tracemalloc.Snapshot.filter_traces': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Snapshot.filter_traces',
                             'tracemalloc.Snapshot.load': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Snapshot.load',
                             'tracemalloc.Snapshot.statistics': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Snapshot.statistics',
                             'tracemalloc.Statistic': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Statistic',
                             'tracemalloc.StatisticDiff': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.StatisticDiff',
                             'tracemalloc.Trace': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Trace',
                             'tracemalloc.Traceback': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Traceback',
                             'tracemalloc.Traceback.format': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.Traceback.format',
                             'tracemalloc.clear_traces': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.clear_traces',
                             'tracemalloc.get_object_traceback': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.get_object_traceback',
                             'tracemalloc.get_traceback_limit': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.get_traceback_limit',
                             'tracemalloc.get_traced_memory': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.get_traced_memory',
                             'tracemalloc.get_tracemalloc_memory': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.get_tracemalloc_memory',
                             'tracemalloc.is_tracing': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.is_tracing',
                             'tracemalloc.reset_peak': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.reset_peak',
                             'tracemalloc.start': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.start',
                             'tracemalloc.stop': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.stop',
                             'tracemalloc.take_snapshot': 'https://docs.python.org/3/library/tracemalloc.html#tracemalloc.take_snapshot'},
            'tty': { 'tty.setcbreak': 'https://docs.python.org/3/library/tty.html#tty.setcbreak',
                     'tty.setraw': 'https://docs.python.org/3/library/tty.html#tty.setraw'},
            'turtle': { 'turtle.RawPen': 'https://docs.python.org/3/library/turtle.html#turtle.RawPen',
                        'turtle.RawTurtle': 'https://docs.python.org/3/library/turtle.html#turtle.RawTurtle',
                        'turtle.Screen': 'https://docs.python.org/3/library/turtle.html#turtle.Screen',
                        'turtle.ScrolledCanvas': 'https://docs.python.org/3/library/turtle.html#turtle.ScrolledCanvas',
                        'turtle.Shape': 'https://docs.python.org/3/library/turtle.html#turtle.Shape',
                        'turtle.Shape.addcomponent': 'https://docs.python.org/3/library/turtle.html#turtle.Shape.addcomponent',
                        'turtle.Turtle': 'https://docs.python.org/3/library/turtle.html#turtle.Turtle',
                        'turtle.TurtleScreen': 'https://docs.python.org/3/library/turtle.html#turtle.TurtleScreen',
                        'turtle.Vec2D': 'https://docs.python.org/3/library/turtle.html#turtle.Vec2D',
                        'turtle.addshape': 'https://docs.python.org/3/library/turtle.html#turtle.addshape',
                        'turtle.back': 'https://docs.python.org/3/library/turtle.html#turtle.back',
                        'turtle.backward': 'https://docs.python.org/3/library/turtle.html#turtle.backward',
                        'turtle.begin_fill': 'https://docs.python.org/3/library/turtle.html#turtle.begin_fill',
                        'turtle.begin_poly': 'https://docs.python.org/3/library/turtle.html#turtle.begin_poly',
                        'turtle.bgcolor': 'https://docs.python.org/3/library/turtle.html#turtle.bgcolor',
                        'turtle.bgpic': 'https://docs.python.org/3/library/turtle.html#turtle.bgpic',
                        'turtle.bk': 'https://docs.python.org/3/library/turtle.html#turtle.bk',
                        'turtle.bye': 'https://docs.python.org/3/library/turtle.html#turtle.bye',
                        'turtle.circle': 'https://docs.python.org/3/library/turtle.html#turtle.circle',
                        'turtle.clear': 'https://docs.python.org/3/library/turtle.html#turtle.clear',
                        'turtle.clearscreen': 'https://docs.python.org/3/library/turtle.html#turtle.clearscreen',
                        'turtle.clearstamp': 'https://docs.python.org/3/library/turtle.html#turtle.clearstamp',
                        'turtle.clearstamps': 'https://docs.python.org/3/library/turtle.html#turtle.clearstamps',
                        'turtle.clone': 'https://docs.python.org/3/library/turtle.html#turtle.clone',
                        'turtle.color': 'https://docs.python.org/3/library/turtle.html#turtle.color',
                        'turtle.colormode': 'https://docs.python.org/3/library/turtle.html#turtle.colormode',
                        'turtle.degrees': 'https://docs.python.org/3/library/turtle.html#turtle.degrees',
                        'turtle.delay': 'https://docs.python.org/3/library/turtle.html#turtle.delay',
                        'turtle.distance': 'https://docs.python.org/3/library/turtle.html#turtle.distance',
                        'turtle.done': 'https://docs.python.org/3/library/turtle.html#turtle.done',
                        'turtle.dot': 'https://docs.python.org/3/library/turtle.html#turtle.dot',
                        'turtle.down': 'https://docs.python.org/3/library/turtle.html#turtle.down',
                        'turtle.end_fill': 'https://docs.python.org/3/library/turtle.html#turtle.end_fill',
                        'turtle.end_poly': 'https://docs.python.org/3/library/turtle.html#turtle.end_poly',
                        'turtle.exitonclick': 'https://docs.python.org/3/library/turtle.html#turtle.exitonclick',
                        'turtle.fd': 'https://docs.python.org/3/library/turtle.html#turtle.fd',
                        'turtle.fillcolor': 'https://docs.python.org/3/library/turtle.html#turtle.fillcolor',
                        'turtle.filling': 'https://docs.python.org/3/library/turtle.html#turtle.filling',
                        'turtle.forward': 'https://docs.python.org/3/library/turtle.html#turtle.forward',
                        'turtle.get_poly': 'https://docs.python.org/3/library/turtle.html#turtle.get_poly',
                        'turtle.get_shapepoly': 'https://docs.python.org/3/library/turtle.html#turtle.get_shapepoly',
                        'turtle.getcanvas': 'https://docs.python.org/3/library/turtle.html#turtle.getcanvas',
                        'turtle.getpen': 'https://docs.python.org/3/library/turtle.html#turtle.getpen',
                        'turtle.getscreen': 'https://docs.python.org/3/library/turtle.html#turtle.getscreen',
                        'turtle.getshapes': 'https://docs.python.org/3/library/turtle.html#turtle.getshapes',
                        'turtle.getturtle': 'https://docs.python.org/3/library/turtle.html#turtle.getturtle',
                        'turtle.goto': 'https://docs.python.org/3/library/turtle.html#turtle.goto',
                        'turtle.heading': 'https://docs.python.org/3/library/turtle.html#turtle.heading',
                        'turtle.hideturtle': 'https://docs.python.org/3/library/turtle.html#turtle.hideturtle',
                        'turtle.home': 'https://docs.python.org/3/library/turtle.html#turtle.home',
                        'turtle.ht': 'https://docs.python.org/3/library/turtle.html#turtle.ht',
                        'turtle.isdown': 'https://docs.python.org/3/library/turtle.html#turtle.isdown',
                        'turtle.isvisible': 'https://docs.python.org/3/library/turtle.html#turtle.isvisible',
                        'turtle.left': 'https://docs.python.org/3/library/turtle.html#turtle.left',
                        'turtle.listen': 'https://docs.python.org/3/library/turtle.html#turtle.listen',
                        'turtle.lt': 'https://docs.python.org/3/library/turtle.html#turtle.lt',
                        'turtle.mainloop': 'https://docs.python.org/3/library/turtle.html#turtle.mainloop',
                        'turtle.mode': 'https://docs.python.org/3/library/turtle.html#turtle.mode',
                        'turtle.numinput': 'https://docs.python.org/3/library/turtle.html#turtle.numinput',
                        'turtle.onclick': 'https://docs.python.org/3/library/turtle.html#turtle.onclick',
                        'turtle.ondrag': 'https://docs.python.org/3/library/turtle.html#turtle.ondrag',
                        'turtle.onkey': 'https://docs.python.org/3/library/turtle.html#turtle.onkey',
                        'turtle.onkeypress': 'https://docs.python.org/3/library/turtle.html#turtle.onkeypress',
                        'turtle.onkeyrelease': 'https://docs.python.org/3/library/turtle.html#turtle.onkeyrelease',
                        'turtle.onrelease': 'https://docs.python.org/3/library/turtle.html#turtle.onrelease',
                        'turtle.onscreenclick': 'https://docs.python.org/3/library/turtle.html#turtle.onscreenclick',
                        'turtle.ontimer': 'https://docs.python.org/3/library/turtle.html#turtle.ontimer',
                        'turtle.pd': 'https://docs.python.org/3/library/turtle.html#turtle.pd',
                        'turtle.pen': 'https://docs.python.org/3/library/turtle.html#turtle.pen',
                        'turtle.pencolor': 'https://docs.python.org/3/library/turtle.html#turtle.pencolor',
                        'turtle.pendown': 'https://docs.python.org/3/library/turtle.html#turtle.pendown',
                        'turtle.pensize': 'https://docs.python.org/3/library/turtle.html#turtle.pensize',
                        'turtle.penup': 'https://docs.python.org/3/library/turtle.html#turtle.penup',
                        'turtle.pos': 'https://docs.python.org/3/library/turtle.html#turtle.pos',
                        'turtle.position': 'https://docs.python.org/3/library/turtle.html#turtle.position',
                        'turtle.pu': 'https://docs.python.org/3/library/turtle.html#turtle.pu',
                        'turtle.radians': 'https://docs.python.org/3/library/turtle.html#turtle.radians',
                        'turtle.register_shape': 'https://docs.python.org/3/library/turtle.html#turtle.register_shape',
                        'turtle.reset': 'https://docs.python.org/3/library/turtle.html#turtle.reset',
                        'turtle.resetscreen': 'https://docs.python.org/3/library/turtle.html#turtle.resetscreen',
                        'turtle.resizemode': 'https://docs.python.org/3/library/turtle.html#turtle.resizemode',
                        'turtle.right': 'https://docs.python.org/3/library/turtle.html#turtle.right',
                        'turtle.rt': 'https://docs.python.org/3/library/turtle.html#turtle.rt',
                        'turtle.screensize': 'https://docs.python.org/3/library/turtle.html#turtle.screensize',
                        'turtle.seth': 'https://docs.python.org/3/library/turtle.html#turtle.seth',
                        'turtle.setheading': 'https://docs.python.org/3/library/turtle.html#turtle.setheading',
                        'turtle.setpos': 'https://docs.python.org/3/library/turtle.html#turtle.setpos',
                        'turtle.setposition': 'https://docs.python.org/3/library/turtle.html#turtle.setposition',
                        'turtle.settiltangle': 'https://docs.python.org/3/library/turtle.html#turtle.settiltangle',
                        'turtle.setundobuffer': 'https://docs.python.org/3/library/turtle.html#turtle.setundobuffer',
                        'turtle.setup': 'https://docs.python.org/3/library/turtle.html#turtle.setup',
                        'turtle.setworldcoordinates': 'https://docs.python.org/3/library/turtle.html#turtle.setworldcoordinates',
                        'turtle.setx': 'https://docs.python.org/3/library/turtle.html#turtle.setx',
                        'turtle.sety': 'https://docs.python.org/3/library/turtle.html#turtle.sety',
                        'turtle.shape': 'https://docs.python.org/3/library/turtle.html#turtle.shape',
                        'turtle.shapesize': 'https://docs.python.org/3/library/turtle.html#turtle.shapesize',
                        'turtle.shapetransform': 'https://docs.python.org/3/library/turtle.html#turtle.shapetransform',
                        'turtle.shearfactor': 'https://docs.python.org/3/library/turtle.html#turtle.shearfactor',
                        'turtle.showturtle': 'https://docs.python.org/3/library/turtle.html#turtle.showturtle',
                        'turtle.speed': 'https://docs.python.org/3/library/turtle.html#turtle.speed',
                        'turtle.st': 'https://docs.python.org/3/library/turtle.html#turtle.st',
                        'turtle.stamp': 'https://docs.python.org/3/library/turtle.html#turtle.stamp',
                        'turtle.textinput': 'https://docs.python.org/3/library/turtle.html#turtle.textinput',
                        'turtle.tilt': 'https://docs.python.org/3/library/turtle.html#turtle.tilt',
                        'turtle.tiltangle': 'https://docs.python.org/3/library/turtle.html#turtle.tiltangle',
                        'turtle.title': 'https://docs.python.org/3/library/turtle.html#turtle.title',
                        'turtle.towards': 'https://docs.python.org/3/library/turtle.html#turtle.towards',
                        'turtle.tracer': 'https://docs.python.org/3/library/turtle.html#turtle.tracer',
                        'turtle.turtles': 'https://docs.python.org/3/library/turtle.html#turtle.turtles',
                        'turtle.turtlesize': 'https://docs.python.org/3/library/turtle.html#turtle.turtlesize',
                        'turtle.undo': 'https://docs.python.org/3/library/turtle.html#turtle.undo',
                        'turtle.undobufferentries': 'https://docs.python.org/3/library/turtle.html#turtle.undobufferentries',
                        'turtle.up': 'https://docs.python.org/3/library/turtle.html#turtle.up',
                        'turtle.update': 'https://docs.python.org/3/library/turtle.html#turtle.update',
                        'turtle.width': 'https://docs.python.org/3/library/turtle.html#turtle.width',
                        'turtle.window_height': 'https://docs.python.org/3/library/turtle.html#turtle.window_height',
                        'turtle.window_width': 'https://docs.python.org/3/library/turtle.html#turtle.window_width',
                        'turtle.write': 'https://docs.python.org/3/library/turtle.html#turtle.write',
                        'turtle.write_docstringdict': 'https://docs.python.org/3/library/turtle.html#turtle.write_docstringdict',
                        'turtle.xcor': 'https://docs.python.org/3/library/turtle.html#turtle.xcor',
                        'turtle.ycor': 'https://docs.python.org/3/library/turtle.html#turtle.ycor'},
            'types': { 'types.CodeType': 'https://docs.python.org/3/library/types.html#types.CodeType',
                       'types.CodeType.replace': 'https://docs.python.org/3/library/types.html#types.CodeType.replace',
                       'types.DynamicClassAttribute': 'https://docs.python.org/3/library/types.html#types.DynamicClassAttribute',
                       'types.GenericAlias': 'https://docs.python.org/3/library/types.html#types.GenericAlias',
                       'types.MappingProxyType': 'https://docs.python.org/3/library/types.html#types.MappingProxyType',
                       'types.MappingProxyType.copy': 'https://docs.python.org/3/library/types.html#types.MappingProxyType.copy',
                       'types.MappingProxyType.get': 'https://docs.python.org/3/library/types.html#types.MappingProxyType.get',
                       'types.MappingProxyType.items': 'https://docs.python.org/3/library/types.html#types.MappingProxyType.items',
                       'types.MappingProxyType.keys': 'https://docs.python.org/3/library/types.html#types.MappingProxyType.keys',
                       'types.MappingProxyType.values': 'https://docs.python.org/3/library/types.html#types.MappingProxyType.values',
                       'types.ModuleType': 'https://docs.python.org/3/library/types.html#types.ModuleType',
                       'types.SimpleNamespace': 'https://docs.python.org/3/library/types.html#types.SimpleNamespace',
                       'types.TracebackType': 'https://docs.python.org/3/library/types.html#types.TracebackType',
                       'types.UnionType': 'https://docs.python.org/3/library/types.html#types.UnionType',
                       'types.coroutine': 'https://docs.python.org/3/library/types.html#types.coroutine',
                       'types.new_class': 'https://docs.python.org/3/library/types.html#types.new_class',
                       'types.prepare_class': 'https://docs.python.org/3/library/types.html#types.prepare_class',
                       'types.resolve_bases': 'https://docs.python.org/3/library/types.html#types.resolve_bases'},
            'typing': { 'typing.AbstractSet': 'https://docs.python.org/3/library/typing.html#typing.AbstractSet',
                        'typing.AsyncContextManager': 'https://docs.python.org/3/library/typing.html#typing.AsyncContextManager',
                        'typing.AsyncGenerator': 'https://docs.python.org/3/library/typing.html#typing.AsyncGenerator',
                        'typing.AsyncIterable': 'https://docs.python.org/3/library/typing.html#typing.AsyncIterable',
                        'typing.AsyncIterator': 'https://docs.python.org/3/library/typing.html#typing.AsyncIterator',
                        'typing.Awaitable': 'https://docs.python.org/3/library/typing.html#typing.Awaitable',
                        'typing.BinaryIO': 'https://docs.python.org/3/library/typing.html#typing.BinaryIO',
                        'typing.ByteString': 'https://docs.python.org/3/library/typing.html#typing.ByteString',
                        'typing.ChainMap': 'https://docs.python.org/3/library/typing.html#typing.ChainMap',
                        'typing.Collection': 'https://docs.python.org/3/library/typing.html#typing.Collection',
                        'typing.Container': 'https://docs.python.org/3/library/typing.html#typing.Container',
                        'typing.ContextManager': 'https://docs.python.org/3/library/typing.html#typing.ContextManager',
                        'typing.Coroutine': 'https://docs.python.org/3/library/typing.html#typing.Coroutine',
                        'typing.Counter': 'https://docs.python.org/3/library/typing.html#typing.Counter',
                        'typing.DefaultDict': 'https://docs.python.org/3/library/typing.html#typing.DefaultDict',
                        'typing.Deque': 'https://docs.python.org/3/library/typing.html#typing.Deque',
                        'typing.Dict': 'https://docs.python.org/3/library/typing.html#typing.Dict',
                        'typing.ForwardRef': 'https://docs.python.org/3/library/typing.html#typing.ForwardRef',
                        'typing.FrozenSet': 'https://docs.python.org/3/library/typing.html#typing.FrozenSet',
                        'typing.Generator': 'https://docs.python.org/3/library/typing.html#typing.Generator',
                        'typing.Generic': 'https://docs.python.org/3/library/typing.html#typing.Generic',
                        'typing.Hashable': 'https://docs.python.org/3/library/typing.html#typing.Hashable',
                        'typing.IO': 'https://docs.python.org/3/library/typing.html#typing.IO',
                        'typing.ItemsView': 'https://docs.python.org/3/library/typing.html#typing.ItemsView',
                        'typing.Iterable': 'https://docs.python.org/3/library/typing.html#typing.Iterable',
                        'typing.Iterator': 'https://docs.python.org/3/library/typing.html#typing.Iterator',
                        'typing.KeysView': 'https://docs.python.org/3/library/typing.html#typing.KeysView',
                        'typing.List': 'https://docs.python.org/3/library/typing.html#typing.List',
                        'typing.Mapping': 'https://docs.python.org/3/library/typing.html#typing.Mapping',
                        'typing.MappingView': 'https://docs.python.org/3/library/typing.html#typing.MappingView',
                        'typing.Match': 'https://docs.python.org/3/library/typing.html#typing.Match',
                        'typing.MutableMapping': 'https://docs.python.org/3/library/typing.html#typing.MutableMapping',
                        'typing.MutableSequence': 'https://docs.python.org/3/library/typing.html#typing.MutableSequence',
                        'typing.MutableSet': 'https://docs.python.org/3/library/typing.html#typing.MutableSet',
                        'typing.NamedTuple': 'https://docs.python.org/3/library/typing.html#typing.NamedTuple',
                        'typing.NewType': 'https://docs.python.org/3/library/typing.html#typing.NewType',
                        'typing.OrderedDict': 'https://docs.python.org/3/library/typing.html#typing.OrderedDict',
                        'typing.ParamSpec': 'https://docs.python.org/3/library/typing.html#typing.ParamSpec',
                        'typing.Pattern': 'https://docs.python.org/3/library/typing.html#typing.Pattern',
                        'typing.Protocol': 'https://docs.python.org/3/library/typing.html#typing.Protocol',
                        'typing.Reversible': 'https://docs.python.org/3/library/typing.html#typing.Reversible',
                        'typing.Sequence': 'https://docs.python.org/3/library/typing.html#typing.Sequence',
                        'typing.Set': 'https://docs.python.org/3/library/typing.html#typing.Set',
                        'typing.Sized': 'https://docs.python.org/3/library/typing.html#typing.Sized',
                        'typing.SupportsAbs': 'https://docs.python.org/3/library/typing.html#typing.SupportsAbs',
                        'typing.SupportsBytes': 'https://docs.python.org/3/library/typing.html#typing.SupportsBytes',
                        'typing.SupportsComplex': 'https://docs.python.org/3/library/typing.html#typing.SupportsComplex',
                        'typing.SupportsFloat': 'https://docs.python.org/3/library/typing.html#typing.SupportsFloat',
                        'typing.SupportsIndex': 'https://docs.python.org/3/library/typing.html#typing.SupportsIndex',
                        'typing.SupportsInt': 'https://docs.python.org/3/library/typing.html#typing.SupportsInt',
                        'typing.SupportsRound': 'https://docs.python.org/3/library/typing.html#typing.SupportsRound',
                        'typing.Text': 'https://docs.python.org/3/library/typing.html#typing.Text',
                        'typing.TextIO': 'https://docs.python.org/3/library/typing.html#typing.TextIO',
                        'typing.Type': 'https://docs.python.org/3/library/typing.html#typing.Type',
                        'typing.TypeVar': 'https://docs.python.org/3/library/typing.html#typing.TypeVar',
                        'typing.TypedDict': 'https://docs.python.org/3/library/typing.html#typing.TypedDict',
                        'typing.ValuesView': 'https://docs.python.org/3/library/typing.html#typing.ValuesView',
                        'typing.cast': 'https://docs.python.org/3/library/typing.html#typing.cast',
                        'typing.final': 'https://docs.python.org/3/library/typing.html#typing.final',
                        'typing.get_args': 'https://docs.python.org/3/library/typing.html#typing.get_args',
                        'typing.get_origin': 'https://docs.python.org/3/library/typing.html#typing.get_origin',
                        'typing.get_type_hints': 'https://docs.python.org/3/library/typing.html#typing.get_type_hints',
                        'typing.is_typeddict': 'https://docs.python.org/3/library/typing.html#typing.is_typeddict',
                        'typing.no_type_check': 'https://docs.python.org/3/library/typing.html#typing.no_type_check',
                        'typing.no_type_check_decorator': 'https://docs.python.org/3/library/typing.html#typing.no_type_check_decorator',
                        'typing.overload': 'https://docs.python.org/3/library/typing.html#typing.overload',
                        'typing.runtime_checkable': 'https://docs.python.org/3/library/typing.html#typing.runtime_checkable',
                        'typing.type_check_only': 'https://docs.python.org/3/library/typing.html#typing.type_check_only'},
            'unicodedata': { 'unicodedata.bidirectional': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.bidirectional',
                             'unicodedata.category': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.category',
                             'unicodedata.combining': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.combining',
                             'unicodedata.decimal': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.decimal',
                             'unicodedata.decomposition': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.decomposition',
                             'unicodedata.digit': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.digit',
                             'unicodedata.east_asian_width': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.east_asian_width',
                             'unicodedata.is_normalized': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.is_normalized',
                             'unicodedata.lookup': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.lookup',
                             'unicodedata.mirrored': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.mirrored',
                             'unicodedata.name': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.name',
                             'unicodedata.normalize': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.normalize',
                             'unicodedata.numeric': 'https://docs.python.org/3/library/unicodedata.html#unicodedata.numeric'},
            'unittest': { 'unittest.FunctionTestCase': 'https://docs.python.org/3/library/unittest.html#unittest.FunctionTestCase',
                          'unittest.IsolatedAsyncioTestCase': 'https://docs.python.org/3/library/unittest.html#unittest.IsolatedAsyncioTestCase',
                          'unittest.IsolatedAsyncioTestCase.addAsyncCleanup': 'https://docs.python.org/3/library/unittest.html#unittest.IsolatedAsyncioTestCase.addAsyncCleanup',
                          'unittest.IsolatedAsyncioTestCase.asyncSetUp': 'https://docs.python.org/3/library/unittest.html#unittest.IsolatedAsyncioTestCase.asyncSetUp',
                          'unittest.IsolatedAsyncioTestCase.asyncTearDown': 'https://docs.python.org/3/library/unittest.html#unittest.IsolatedAsyncioTestCase.asyncTearDown',
                          'unittest.IsolatedAsyncioTestCase.run': 'https://docs.python.org/3/library/unittest.html#unittest.IsolatedAsyncioTestCase.run',
                          'unittest.TestCase': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase',
                          'unittest.TestCase.addClassCleanup': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.addClassCleanup',
                          'unittest.TestCase.addCleanup': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.addCleanup',
                          'unittest.TestCase.addTypeEqualityFunc': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.addTypeEqualityFunc',
                          'unittest.TestCase.assertAlmostEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertAlmostEqual',
                          'unittest.TestCase.assertCountEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertCountEqual',
                          'unittest.TestCase.assertDictEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertDictEqual',
                          'unittest.TestCase.assertEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertEqual',
                          'unittest.TestCase.assertFalse': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertFalse',
                          'unittest.TestCase.assertGreater': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertGreater',
                          'unittest.TestCase.assertGreaterEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertGreaterEqual',
                          'unittest.TestCase.assertIn': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertIn',
                          'unittest.TestCase.assertIs': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertIs',
                          'unittest.TestCase.assertIsInstance': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertIsInstance',
                          'unittest.TestCase.assertIsNone': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertIsNone',
                          'unittest.TestCase.assertIsNot': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertIsNot',
                          'unittest.TestCase.assertIsNotNone': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertIsNotNone',
                          'unittest.TestCase.assertLess': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertLess',
                          'unittest.TestCase.assertLessEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertLessEqual',
                          'unittest.TestCase.assertListEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertListEqual',
                          'unittest.TestCase.assertLogs': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertLogs',
                          'unittest.TestCase.assertMultiLineEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertMultiLineEqual',
                          'unittest.TestCase.assertNoLogs': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertNoLogs',
                          'unittest.TestCase.assertNotAlmostEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertNotAlmostEqual',
                          'unittest.TestCase.assertNotEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertNotEqual',
                          'unittest.TestCase.assertNotIn': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertNotIn',
                          'unittest.TestCase.assertNotIsInstance': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertNotIsInstance',
                          'unittest.TestCase.assertNotRegex': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertNotRegex',
                          'unittest.TestCase.assertRaises': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertRaises',
                          'unittest.TestCase.assertRaisesRegex': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertRaisesRegex',
                          'unittest.TestCase.assertRegex': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertRegex',
                          'unittest.TestCase.assertSequenceEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertSequenceEqual',
                          'unittest.TestCase.assertSetEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertSetEqual',
                          'unittest.TestCase.assertTrue': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertTrue',
                          'unittest.TestCase.assertTupleEqual': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertTupleEqual',
                          'unittest.TestCase.assertWarns': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertWarns',
                          'unittest.TestCase.assertWarnsRegex': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.assertWarnsRegex',
                          'unittest.TestCase.countTestCases': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.countTestCases',
                          'unittest.TestCase.debug': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.debug',
                          'unittest.TestCase.defaultTestResult': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.defaultTestResult',
                          'unittest.TestCase.doClassCleanups': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.doClassCleanups',
                          'unittest.TestCase.doCleanups': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.doCleanups',
                          'unittest.TestCase.fail': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.fail',
                          'unittest.TestCase.id': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.id',
                          'unittest.TestCase.run': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.run',
                          'unittest.TestCase.setUp': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.setUp',
                          'unittest.TestCase.setUpClass': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.setUpClass',
                          'unittest.TestCase.shortDescription': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.shortDescription',
                          'unittest.TestCase.skipTest': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.skipTest',
                          'unittest.TestCase.subTest': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.subTest',
                          'unittest.TestCase.tearDown': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.tearDown',
                          'unittest.TestCase.tearDownClass': 'https://docs.python.org/3/library/unittest.html#unittest.TestCase.tearDownClass',
                          'unittest.TestLoader': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader',
                          'unittest.TestLoader.discover': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader.discover',
                          'unittest.TestLoader.getTestCaseNames': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader.getTestCaseNames',
                          'unittest.TestLoader.loadTestsFromModule': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader.loadTestsFromModule',
                          'unittest.TestLoader.loadTestsFromName': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader.loadTestsFromName',
                          'unittest.TestLoader.loadTestsFromNames': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader.loadTestsFromNames',
                          'unittest.TestLoader.loadTestsFromTestCase': 'https://docs.python.org/3/library/unittest.html#unittest.TestLoader.loadTestsFromTestCase',
                          'unittest.TestResult': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult',
                          'unittest.TestResult.addError': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addError',
                          'unittest.TestResult.addExpectedFailure': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addExpectedFailure',
                          'unittest.TestResult.addFailure': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addFailure',
                          'unittest.TestResult.addSkip': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addSkip',
                          'unittest.TestResult.addSubTest': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addSubTest',
                          'unittest.TestResult.addSuccess': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addSuccess',
                          'unittest.TestResult.addUnexpectedSuccess': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.addUnexpectedSuccess',
                          'unittest.TestResult.startTest': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.startTest',
                          'unittest.TestResult.startTestRun': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.startTestRun',
                          'unittest.TestResult.stop': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.stop',
                          'unittest.TestResult.stopTest': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.stopTest',
                          'unittest.TestResult.stopTestRun': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.stopTestRun',
                          'unittest.TestResult.wasSuccessful': 'https://docs.python.org/3/library/unittest.html#unittest.TestResult.wasSuccessful',
                          'unittest.TestSuite': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite',
                          'unittest.TestSuite.__iter__': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite.__iter__',
                          'unittest.TestSuite.addTest': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite.addTest',
                          'unittest.TestSuite.addTests': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite.addTests',
                          'unittest.TestSuite.countTestCases': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite.countTestCases',
                          'unittest.TestSuite.debug': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite.debug',
                          'unittest.TestSuite.run': 'https://docs.python.org/3/library/unittest.html#unittest.TestSuite.run',
                          'unittest.TextTestResult': 'https://docs.python.org/3/library/unittest.html#unittest.TextTestResult',
                          'unittest.TextTestRunner': 'https://docs.python.org/3/library/unittest.html#unittest.TextTestRunner',
                          'unittest.TextTestRunner._makeResult': 'https://docs.python.org/3/library/unittest.html#unittest.TextTestRunner._makeResult',
                          'unittest.TextTestRunner.run': 'https://docs.python.org/3/library/unittest.html#unittest.TextTestRunner.run',
                          'unittest.addModuleCleanup': 'https://docs.python.org/3/library/unittest.html#unittest.addModuleCleanup',
                          'unittest.doModuleCleanups': 'https://docs.python.org/3/library/unittest.html#unittest.doModuleCleanups',
                          'unittest.expectedFailure': 'https://docs.python.org/3/library/unittest.html#unittest.expectedFailure',
                          'unittest.installHandler': 'https://docs.python.org/3/library/unittest.html#unittest.installHandler',
                          'unittest.main': 'https://docs.python.org/3/library/unittest.html#unittest.main',
                          'unittest.mock': 'https://docs.python.org/3/library/unittest.mock.html#module-unittest.mock',
                          'unittest.registerResult': 'https://docs.python.org/3/library/unittest.html#unittest.registerResult',
                          'unittest.removeHandler': 'https://docs.python.org/3/library/unittest.html#unittest.removeHandler',
                          'unittest.removeResult': 'https://docs.python.org/3/library/unittest.html#unittest.removeResult',
                          'unittest.skip': 'https://docs.python.org/3/library/unittest.html#unittest.skip',
                          'unittest.skipIf': 'https://docs.python.org/3/library/unittest.html#unittest.skipIf',
                          'unittest.skipUnless': 'https://docs.python.org/3/library/unittest.html#unittest.skipUnless'},
            'unittest.mock': { 'unittest.mock.AsyncMock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock',
                               'unittest.mock.AsyncMock.assert_any_await': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_any_await',
                               'unittest.mock.AsyncMock.assert_awaited': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_awaited',
                               'unittest.mock.AsyncMock.assert_awaited_once': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_awaited_once',
                               'unittest.mock.AsyncMock.assert_awaited_once_with': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_awaited_once_with',
                               'unittest.mock.AsyncMock.assert_awaited_with': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_awaited_with',
                               'unittest.mock.AsyncMock.assert_has_awaits': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_has_awaits',
                               'unittest.mock.AsyncMock.assert_not_awaited': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.assert_not_awaited',
                               'unittest.mock.AsyncMock.reset_mock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.AsyncMock.reset_mock',
                               'unittest.mock.MagicMock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.MagicMock',
                               'unittest.mock.Mock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock',
                               'unittest.mock.Mock.__dir__': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.__dir__',
                               'unittest.mock.Mock._get_child_mock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock._get_child_mock',
                               'unittest.mock.Mock.assert_any_call': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_any_call',
                               'unittest.mock.Mock.assert_called': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_called',
                               'unittest.mock.Mock.assert_called_once': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_called_once',
                               'unittest.mock.Mock.assert_called_once_with': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_called_once_with',
                               'unittest.mock.Mock.assert_called_with': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_called_with',
                               'unittest.mock.Mock.assert_has_calls': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_has_calls',
                               'unittest.mock.Mock.assert_not_called': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.assert_not_called',
                               'unittest.mock.Mock.attach_mock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.attach_mock',
                               'unittest.mock.Mock.configure_mock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.configure_mock',
                               'unittest.mock.Mock.mock_add_spec': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.mock_add_spec',
                               'unittest.mock.Mock.reset_mock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.Mock.reset_mock',
                               'unittest.mock.NonCallableMagicMock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.NonCallableMagicMock',
                               'unittest.mock.NonCallableMock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.NonCallableMock',
                               'unittest.mock.PropertyMock': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.PropertyMock',
                               'unittest.mock.call': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.call',
                               'unittest.mock.call.call_list': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.call.call_list',
                               'unittest.mock.create_autospec': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.create_autospec',
                               'unittest.mock.mock_open': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.mock_open',
                               'unittest.mock.patch': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.patch',
                               'unittest.mock.seal': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.seal'},
            'unittest.mock.patch': { 'unittest.mock.patch.dict': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.patch.dict',
                                     'unittest.mock.patch.multiple': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.patch.multiple',
                                     'unittest.mock.patch.object': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.patch.object',
                                     'unittest.mock.patch.stopall': 'https://docs.python.org/3/library/unittest.mock.html#unittest.mock.patch.stopall'},
            'urllib': { 'urllib.error': 'https://docs.python.org/3/library/urllib.error.html#module-urllib.error',
                        'urllib.parse': 'https://docs.python.org/3/library/urllib.parse.html#module-urllib.parse',
                        'urllib.request': 'https://docs.python.org/3/library/urllib.request.html#module-urllib.request',
                        'urllib.response': 'https://docs.python.org/3/library/urllib.request.html#module-urllib.response',
                        'urllib.robotparser': 'https://docs.python.org/3/library/urllib.robotparser.html#module-urllib.robotparser'},
            'urllib.parse': { 'urllib.parse.DefragResult': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.DefragResult',
                              'urllib.parse.DefragResultBytes': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.DefragResultBytes',
                              'urllib.parse.ParseResult': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.ParseResult',
                              'urllib.parse.ParseResultBytes': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.ParseResultBytes',
                              'urllib.parse.SplitResult': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.SplitResult',
                              'urllib.parse.SplitResultBytes': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.SplitResultBytes',
                              'urllib.parse.parse_qs': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.parse_qs',
                              'urllib.parse.parse_qsl': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.parse_qsl',
                              'urllib.parse.quote': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.quote',
                              'urllib.parse.quote_from_bytes': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.quote_from_bytes',
                              'urllib.parse.quote_plus': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.quote_plus',
                              'urllib.parse.unquote': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.unquote',
                              'urllib.parse.unquote_plus': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.unquote_plus',
                              'urllib.parse.unquote_to_bytes': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.unquote_to_bytes',
                              'urllib.parse.unwrap': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.unwrap',
                              'urllib.parse.urldefrag': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urldefrag',
                              'urllib.parse.urlencode': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urlencode',
                              'urllib.parse.urljoin': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urljoin',
                              'urllib.parse.urlparse': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urlparse',
                              'urllib.parse.urlsplit': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urlsplit',
                              'urllib.parse.urlunparse': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urlunparse',
                              'urllib.parse.urlunsplit': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urlunsplit'},
            'urllib.parse.urllib.parse': { 'urllib.parse.urllib.parse.SplitResult.geturl': 'https://docs.python.org/3/library/urllib.parse.html#urllib.parse.urllib.parse.SplitResult.geturl'},
            'urllib.request': { 'urllib.request.AbstractBasicAuthHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.AbstractBasicAuthHandler',
                                'urllib.request.AbstractBasicAuthHandler.http_error_auth_reqed': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.AbstractBasicAuthHandler.http_error_auth_reqed',
                                'urllib.request.AbstractDigestAuthHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.AbstractDigestAuthHandler',
                                'urllib.request.AbstractDigestAuthHandler.http_error_auth_reqed': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.AbstractDigestAuthHandler.http_error_auth_reqed',
                                'urllib.request.BaseHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.BaseHandler',
                                'urllib.request.BaseHandler.add_parent': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.BaseHandler.add_parent',
                                'urllib.request.BaseHandler.close': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.BaseHandler.close',
                                'urllib.request.BaseHandler.default_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.BaseHandler.default_open',
                                'urllib.request.BaseHandler.http_error_default': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.BaseHandler.http_error_default',
                                'urllib.request.BaseHandler.unknown_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.BaseHandler.unknown_open',
                                'urllib.request.CacheFTPHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.CacheFTPHandler',
                                'urllib.request.CacheFTPHandler.setMaxConns': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.CacheFTPHandler.setMaxConns',
                                'urllib.request.CacheFTPHandler.setTimeout': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.CacheFTPHandler.setTimeout',
                                'urllib.request.DataHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.DataHandler',
                                'urllib.request.DataHandler.data_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.DataHandler.data_open',
                                'urllib.request.FTPHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.FTPHandler',
                                'urllib.request.FTPHandler.ftp_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.FTPHandler.ftp_open',
                                'urllib.request.FancyURLopener': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.FancyURLopener',
                                'urllib.request.FancyURLopener.prompt_user_passwd': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.FancyURLopener.prompt_user_passwd',
                                'urllib.request.FileHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.FileHandler',
                                'urllib.request.FileHandler.file_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.FileHandler.file_open',
                                'urllib.request.HTTPBasicAuthHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPBasicAuthHandler',
                                'urllib.request.HTTPBasicAuthHandler.http_error_401': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPBasicAuthHandler.http_error_401',
                                'urllib.request.HTTPCookieProcessor': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPCookieProcessor',
                                'urllib.request.HTTPDefaultErrorHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPDefaultErrorHandler',
                                'urllib.request.HTTPDigestAuthHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPDigestAuthHandler',
                                'urllib.request.HTTPDigestAuthHandler.http_error_401': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPDigestAuthHandler.http_error_401',
                                'urllib.request.HTTPErrorProcessor': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPErrorProcessor',
                                'urllib.request.HTTPErrorProcessor.http_response': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPErrorProcessor.http_response',
                                'urllib.request.HTTPErrorProcessor.https_response': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPErrorProcessor.https_response',
                                'urllib.request.HTTPHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPHandler',
                                'urllib.request.HTTPHandler.http_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPHandler.http_open',
                                'urllib.request.HTTPPasswordMgr': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgr',
                                'urllib.request.HTTPPasswordMgr.add_password': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgr.add_password',
                                'urllib.request.HTTPPasswordMgr.find_user_password': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgr.find_user_password',
                                'urllib.request.HTTPPasswordMgrWithDefaultRealm': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgrWithDefaultRealm',
                                'urllib.request.HTTPPasswordMgrWithPriorAuth': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgrWithPriorAuth',
                                'urllib.request.HTTPPasswordMgrWithPriorAuth.add_password': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgrWithPriorAuth.add_password',
                                'urllib.request.HTTPPasswordMgrWithPriorAuth.find_user_password': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgrWithPriorAuth.find_user_password',
                                'urllib.request.HTTPPasswordMgrWithPriorAuth.is_authenticated': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgrWithPriorAuth.is_authenticated',
                                'urllib.request.HTTPPasswordMgrWithPriorAuth.update_authenticated': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPPasswordMgrWithPriorAuth.update_authenticated',
                                'urllib.request.HTTPRedirectHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPRedirectHandler',
                                'urllib.request.HTTPRedirectHandler.http_error_301': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPRedirectHandler.http_error_301',
                                'urllib.request.HTTPRedirectHandler.http_error_302': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPRedirectHandler.http_error_302',
                                'urllib.request.HTTPRedirectHandler.http_error_303': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPRedirectHandler.http_error_303',
                                'urllib.request.HTTPRedirectHandler.http_error_307': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPRedirectHandler.http_error_307',
                                'urllib.request.HTTPRedirectHandler.redirect_request': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPRedirectHandler.redirect_request',
                                'urllib.request.HTTPSHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPSHandler',
                                'urllib.request.HTTPSHandler.https_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.HTTPSHandler.https_open',
                                'urllib.request.OpenerDirector': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.OpenerDirector',
                                'urllib.request.OpenerDirector.add_handler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.OpenerDirector.add_handler',
                                'urllib.request.OpenerDirector.error': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.OpenerDirector.error',
                                'urllib.request.OpenerDirector.open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.OpenerDirector.open',
                                'urllib.request.ProxyBasicAuthHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.ProxyBasicAuthHandler',
                                'urllib.request.ProxyBasicAuthHandler.http_error_407': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.ProxyBasicAuthHandler.http_error_407',
                                'urllib.request.ProxyDigestAuthHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.ProxyDigestAuthHandler',
                                'urllib.request.ProxyDigestAuthHandler.http_error_407': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.ProxyDigestAuthHandler.http_error_407',
                                'urllib.request.ProxyHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.ProxyHandler',
                                'urllib.request.Request': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request',
                                'urllib.request.Request.add_header': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.add_header',
                                'urllib.request.Request.add_unredirected_header': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.add_unredirected_header',
                                'urllib.request.Request.get_full_url': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.get_full_url',
                                'urllib.request.Request.get_header': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.get_header',
                                'urllib.request.Request.get_method': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.get_method',
                                'urllib.request.Request.has_header': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.has_header',
                                'urllib.request.Request.header_items': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.header_items',
                                'urllib.request.Request.remove_header': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.remove_header',
                                'urllib.request.Request.set_proxy': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.Request.set_proxy',
                                'urllib.request.URLopener': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.URLopener',
                                'urllib.request.URLopener.open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.URLopener.open',
                                'urllib.request.URLopener.open_unknown': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.URLopener.open_unknown',
                                'urllib.request.URLopener.retrieve': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.URLopener.retrieve',
                                'urllib.request.UnknownHandler': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.UnknownHandler',
                                'urllib.request.UnknownHandler.unknown_open': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.UnknownHandler.unknown_open',
                                'urllib.request.build_opener': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.build_opener',
                                'urllib.request.getproxies': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.getproxies',
                                'urllib.request.install_opener': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.install_opener',
                                'urllib.request.pathname2url': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.pathname2url',
                                'urllib.request.url2pathname': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.url2pathname',
                                'urllib.request.urlcleanup': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.urlcleanup',
                                'urllib.request.urlopen': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.urlopen',
                                'urllib.request.urlretrieve': 'https://docs.python.org/3/library/urllib.request.html#urllib.request.urlretrieve'},
            'urllib.response': { 'urllib.response.addinfourl': 'https://docs.python.org/3/library/urllib.request.html#urllib.response.addinfourl',
                                 'urllib.response.addinfourl.getstatus': 'https://docs.python.org/3/library/urllib.request.html#urllib.response.addinfourl.getstatus',
                                 'urllib.response.addinfourl.geturl': 'https://docs.python.org/3/library/urllib.request.html#urllib.response.addinfourl.geturl',
                                 'urllib.response.addinfourl.info': 'https://docs.python.org/3/library/urllib.request.html#urllib.response.addinfourl.info'},
            'urllib.robotparser': { 'urllib.robotparser.RobotFileParser': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser',
                                    'urllib.robotparser.RobotFileParser.can_fetch': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.can_fetch',
                                    'urllib.robotparser.RobotFileParser.crawl_delay': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.crawl_delay',
                                    'urllib.robotparser.RobotFileParser.modified': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.modified',
                                    'urllib.robotparser.RobotFileParser.mtime': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.mtime',
                                    'urllib.robotparser.RobotFileParser.parse': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.parse',
                                    'urllib.robotparser.RobotFileParser.read': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.read',
                                    'urllib.robotparser.RobotFileParser.request_rate': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.request_rate',
                                    'urllib.robotparser.RobotFileParser.set_url': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.set_url',
                                    'urllib.robotparser.RobotFileParser.site_maps': 'https://docs.python.org/3/library/urllib.robotparser.html#urllib.robotparser.RobotFileParser.site_maps'},
            'uu': {'uu.decode': 'https://docs.python.org/3/library/uu.html#uu.decode', 'uu.encode': 'https://docs.python.org/3/library/uu.html#uu.encode'},
            'uuid': { 'uuid.SafeUUID': 'https://docs.python.org/3/library/uuid.html#uuid.SafeUUID',
                      'uuid.UUID': 'https://docs.python.org/3/library/uuid.html#uuid.UUID',
                      'uuid.getnode': 'https://docs.python.org/3/library/uuid.html#uuid.getnode',
                      'uuid.uuid1': 'https://docs.python.org/3/library/uuid.html#uuid.uuid1',
                      'uuid.uuid3': 'https://docs.python.org/3/library/uuid.html#uuid.uuid3',
                      'uuid.uuid4': 'https://docs.python.org/3/library/uuid.html#uuid.uuid4',
                      'uuid.uuid5': 'https://docs.python.org/3/library/uuid.html#uuid.uuid5'},
            'venv': { 'venv.EnvBuilder': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder',
                      'venv.EnvBuilder.create': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.create',
                      'venv.EnvBuilder.create_configuration': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.create_configuration',
                      'venv.EnvBuilder.ensure_directories': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.ensure_directories',
                      'venv.EnvBuilder.install_scripts': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.install_scripts',
                      'venv.EnvBuilder.post_setup': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.post_setup',
                      'venv.EnvBuilder.setup_python': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.setup_python',
                      'venv.EnvBuilder.setup_scripts': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.setup_scripts',
                      'venv.EnvBuilder.upgrade_dependencies': 'https://docs.python.org/3/library/venv.html#venv.EnvBuilder.upgrade_dependencies',
                      'venv.create': 'https://docs.python.org/3/library/venv.html#venv.create'},
            'warnings': { 'warnings.catch_warnings': 'https://docs.python.org/3/library/warnings.html#warnings.catch_warnings',
                          'warnings.filterwarnings': 'https://docs.python.org/3/library/warnings.html#warnings.filterwarnings',
                          'warnings.formatwarning': 'https://docs.python.org/3/library/warnings.html#warnings.formatwarning',
                          'warnings.resetwarnings': 'https://docs.python.org/3/library/warnings.html#warnings.resetwarnings',
                          'warnings.showwarning': 'https://docs.python.org/3/library/warnings.html#warnings.showwarning',
                          'warnings.simplefilter': 'https://docs.python.org/3/library/warnings.html#warnings.simplefilter',
                          'warnings.warn': 'https://docs.python.org/3/library/warnings.html#warnings.warn',
                          'warnings.warn_explicit': 'https://docs.python.org/3/library/warnings.html#warnings.warn_explicit'},
            'wave': { 'wave.Wave_read.close': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.close',
                      'wave.Wave_read.getcompname': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getcompname',
                      'wave.Wave_read.getcomptype': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getcomptype',
                      'wave.Wave_read.getframerate': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getframerate',
                      'wave.Wave_read.getmark': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getmark',
                      'wave.Wave_read.getmarkers': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getmarkers',
                      'wave.Wave_read.getnchannels': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getnchannels',
                      'wave.Wave_read.getnframes': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getnframes',
                      'wave.Wave_read.getparams': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getparams',
                      'wave.Wave_read.getsampwidth': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.getsampwidth',
                      'wave.Wave_read.readframes': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.readframes',
                      'wave.Wave_read.rewind': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.rewind',
                      'wave.Wave_read.setpos': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.setpos',
                      'wave.Wave_read.tell': 'https://docs.python.org/3/library/wave.html#wave.Wave_read.tell',
                      'wave.Wave_write.close': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.close',
                      'wave.Wave_write.setcomptype': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.setcomptype',
                      'wave.Wave_write.setframerate': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.setframerate',
                      'wave.Wave_write.setnchannels': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.setnchannels',
                      'wave.Wave_write.setnframes': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.setnframes',
                      'wave.Wave_write.setparams': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.setparams',
                      'wave.Wave_write.setsampwidth': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.setsampwidth',
                      'wave.Wave_write.tell': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.tell',
                      'wave.Wave_write.writeframes': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.writeframes',
                      'wave.Wave_write.writeframesraw': 'https://docs.python.org/3/library/wave.html#wave.Wave_write.writeframesraw',
                      'wave.open': 'https://docs.python.org/3/library/wave.html#wave.open'},
            'weakref': { 'weakref.WeakKeyDictionary': 'https://docs.python.org/3/library/weakref.html#weakref.WeakKeyDictionary',
                         'weakref.WeakKeyDictionary.keyrefs': 'https://docs.python.org/3/library/weakref.html#weakref.WeakKeyDictionary.keyrefs',
                         'weakref.WeakMethod': 'https://docs.python.org/3/library/weakref.html#weakref.WeakMethod',
                         'weakref.WeakSet': 'https://docs.python.org/3/library/weakref.html#weakref.WeakSet',
                         'weakref.WeakValueDictionary': 'https://docs.python.org/3/library/weakref.html#weakref.WeakValueDictionary',
                         'weakref.WeakValueDictionary.valuerefs': 'https://docs.python.org/3/library/weakref.html#weakref.WeakValueDictionary.valuerefs',
                         'weakref.finalize': 'https://docs.python.org/3/library/weakref.html#weakref.finalize',
                         'weakref.finalize.__call__': 'https://docs.python.org/3/library/weakref.html#weakref.finalize.__call__',
                         'weakref.finalize.detach': 'https://docs.python.org/3/library/weakref.html#weakref.finalize.detach',
                         'weakref.finalize.peek': 'https://docs.python.org/3/library/weakref.html#weakref.finalize.peek',
                         'weakref.getweakrefcount': 'https://docs.python.org/3/library/weakref.html#weakref.getweakrefcount',
                         'weakref.getweakrefs': 'https://docs.python.org/3/library/weakref.html#weakref.getweakrefs',
                         'weakref.proxy': 'https://docs.python.org/3/library/weakref.html#weakref.proxy',
                         'weakref.ref': 'https://docs.python.org/3/library/weakref.html#weakref.ref'},
            'webbrowser': { 'webbrowser.controller.open': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.controller.open',
                            'webbrowser.controller.open_new': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.controller.open_new',
                            'webbrowser.controller.open_new_tab': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.controller.open_new_tab',
                            'webbrowser.get': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.get',
                            'webbrowser.open': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.open',
                            'webbrowser.open_new': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.open_new',
                            'webbrowser.open_new_tab': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.open_new_tab',
                            'webbrowser.register': 'https://docs.python.org/3/library/webbrowser.html#webbrowser.register'},
            'winreg': { 'winreg.CloseKey': 'https://docs.python.org/3/library/winreg.html#winreg.CloseKey',
                        'winreg.ConnectRegistry': 'https://docs.python.org/3/library/winreg.html#winreg.ConnectRegistry',
                        'winreg.CreateKey': 'https://docs.python.org/3/library/winreg.html#winreg.CreateKey',
                        'winreg.CreateKeyEx': 'https://docs.python.org/3/library/winreg.html#winreg.CreateKeyEx',
                        'winreg.DeleteKey': 'https://docs.python.org/3/library/winreg.html#winreg.DeleteKey',
                        'winreg.DeleteKeyEx': 'https://docs.python.org/3/library/winreg.html#winreg.DeleteKeyEx',
                        'winreg.DeleteValue': 'https://docs.python.org/3/library/winreg.html#winreg.DeleteValue',
                        'winreg.DisableReflectionKey': 'https://docs.python.org/3/library/winreg.html#winreg.DisableReflectionKey',
                        'winreg.EnableReflectionKey': 'https://docs.python.org/3/library/winreg.html#winreg.EnableReflectionKey',
                        'winreg.EnumKey': 'https://docs.python.org/3/library/winreg.html#winreg.EnumKey',
                        'winreg.EnumValue': 'https://docs.python.org/3/library/winreg.html#winreg.EnumValue',
                        'winreg.ExpandEnvironmentStrings': 'https://docs.python.org/3/library/winreg.html#winreg.ExpandEnvironmentStrings',
                        'winreg.FlushKey': 'https://docs.python.org/3/library/winreg.html#winreg.FlushKey',
                        'winreg.LoadKey': 'https://docs.python.org/3/library/winreg.html#winreg.LoadKey',
                        'winreg.OpenKey': 'https://docs.python.org/3/library/winreg.html#winreg.OpenKey',
                        'winreg.OpenKeyEx': 'https://docs.python.org/3/library/winreg.html#winreg.OpenKeyEx',
                        'winreg.PyHKEY.Close': 'https://docs.python.org/3/library/winreg.html#winreg.PyHKEY.Close',
                        'winreg.PyHKEY.Detach': 'https://docs.python.org/3/library/winreg.html#winreg.PyHKEY.Detach',
                        'winreg.PyHKEY.__enter__': 'https://docs.python.org/3/library/winreg.html#winreg.PyHKEY.__enter__',
                        'winreg.PyHKEY.__exit__': 'https://docs.python.org/3/library/winreg.html#winreg.PyHKEY.__exit__',
                        'winreg.QueryInfoKey': 'https://docs.python.org/3/library/winreg.html#winreg.QueryInfoKey',
                        'winreg.QueryReflectionKey': 'https://docs.python.org/3/library/winreg.html#winreg.QueryReflectionKey',
                        'winreg.QueryValue': 'https://docs.python.org/3/library/winreg.html#winreg.QueryValue',
                        'winreg.QueryValueEx': 'https://docs.python.org/3/library/winreg.html#winreg.QueryValueEx',
                        'winreg.SaveKey': 'https://docs.python.org/3/library/winreg.html#winreg.SaveKey',
                        'winreg.SetValue': 'https://docs.python.org/3/library/winreg.html#winreg.SetValue',
                        'winreg.SetValueEx': 'https://docs.python.org/3/library/winreg.html#winreg.SetValueEx'},
            'winsound': { 'winsound.Beep': 'https://docs.python.org/3/library/winsound.html#winsound.Beep',
                          'winsound.MessageBeep': 'https://docs.python.org/3/library/winsound.html#winsound.MessageBeep',
                          'winsound.PlaySound': 'https://docs.python.org/3/library/winsound.html#winsound.PlaySound'},
            'wsgiref': { 'wsgiref.handlers': 'https://docs.python.org/3/library/wsgiref.html#module-wsgiref.handlers',
                         'wsgiref.headers': 'https://docs.python.org/3/library/wsgiref.html#module-wsgiref.headers',
                         'wsgiref.simple_server': 'https://docs.python.org/3/library/wsgiref.html#module-wsgiref.simple_server',
                         'wsgiref.util': 'https://docs.python.org/3/library/wsgiref.html#module-wsgiref.util',
                         'wsgiref.validate': 'https://docs.python.org/3/library/wsgiref.html#module-wsgiref.validate'},
            'wsgiref.handlers': { 'wsgiref.handlers.BaseCGIHandler': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseCGIHandler',
                                  'wsgiref.handlers.BaseHandler': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler',
                                  'wsgiref.handlers.BaseHandler._flush': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler._flush',
                                  'wsgiref.handlers.BaseHandler._write': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler._write',
                                  'wsgiref.handlers.BaseHandler.add_cgi_vars': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.add_cgi_vars',
                                  'wsgiref.handlers.BaseHandler.error_output': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.error_output',
                                  'wsgiref.handlers.BaseHandler.get_scheme': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.get_scheme',
                                  'wsgiref.handlers.BaseHandler.get_stderr': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.get_stderr',
                                  'wsgiref.handlers.BaseHandler.get_stdin': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.get_stdin',
                                  'wsgiref.handlers.BaseHandler.log_exception': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.log_exception',
                                  'wsgiref.handlers.BaseHandler.run': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.run',
                                  'wsgiref.handlers.BaseHandler.sendfile': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.sendfile',
                                  'wsgiref.handlers.BaseHandler.setup_environ': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.BaseHandler.setup_environ',
                                  'wsgiref.handlers.CGIHandler': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.CGIHandler',
                                  'wsgiref.handlers.IISCGIHandler': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.IISCGIHandler',
                                  'wsgiref.handlers.SimpleHandler': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.SimpleHandler',
                                  'wsgiref.handlers.read_environ': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.handlers.read_environ'},
            'wsgiref.headers': { 'wsgiref.headers.Headers': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.headers.Headers',
                                 'wsgiref.headers.Headers.add_header': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.headers.Headers.add_header',
                                 'wsgiref.headers.Headers.get_all': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.headers.Headers.get_all'},
            'wsgiref.simple_server': { 'wsgiref.simple_server.WSGIRequestHandler': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIRequestHandler',
                                       'wsgiref.simple_server.WSGIRequestHandler.get_environ': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIRequestHandler.get_environ',
                                       'wsgiref.simple_server.WSGIRequestHandler.get_stderr': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIRequestHandler.get_stderr',
                                       'wsgiref.simple_server.WSGIRequestHandler.handle': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIRequestHandler.handle',
                                       'wsgiref.simple_server.WSGIServer': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIServer',
                                       'wsgiref.simple_server.WSGIServer.get_app': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIServer.get_app',
                                       'wsgiref.simple_server.WSGIServer.set_app': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.WSGIServer.set_app',
                                       'wsgiref.simple_server.demo_app': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.demo_app',
                                       'wsgiref.simple_server.make_server': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.simple_server.make_server'},
            'wsgiref.util': { 'wsgiref.util.FileWrapper': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.FileWrapper',
                              'wsgiref.util.application_uri': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.application_uri',
                              'wsgiref.util.guess_scheme': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.guess_scheme',
                              'wsgiref.util.is_hop_by_hop': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.is_hop_by_hop',
                              'wsgiref.util.request_uri': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.request_uri',
                              'wsgiref.util.setup_testing_defaults': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.setup_testing_defaults',
                              'wsgiref.util.shift_path_info': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.util.shift_path_info'},
            'wsgiref.validate': {'wsgiref.validate.validator': 'https://docs.python.org/3/library/wsgiref.html#wsgiref.validate.validator'},
            'xdrlib': { 'xdrlib.Packer': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer',
                        'xdrlib.Packer.get_buffer': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.get_buffer',
                        'xdrlib.Packer.pack_array': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_array',
                        'xdrlib.Packer.pack_bytes': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_bytes',
                        'xdrlib.Packer.pack_double': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_double',
                        'xdrlib.Packer.pack_farray': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_farray',
                        'xdrlib.Packer.pack_float': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_float',
                        'xdrlib.Packer.pack_fopaque': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_fopaque',
                        'xdrlib.Packer.pack_fstring': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_fstring',
                        'xdrlib.Packer.pack_list': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_list',
                        'xdrlib.Packer.pack_opaque': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_opaque',
                        'xdrlib.Packer.pack_string': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.pack_string',
                        'xdrlib.Packer.reset': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Packer.reset',
                        'xdrlib.Unpacker': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker',
                        'xdrlib.Unpacker.done': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.done',
                        'xdrlib.Unpacker.get_buffer': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.get_buffer',
                        'xdrlib.Unpacker.get_position': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.get_position',
                        'xdrlib.Unpacker.reset': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.reset',
                        'xdrlib.Unpacker.set_position': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.set_position',
                        'xdrlib.Unpacker.unpack_array': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_array',
                        'xdrlib.Unpacker.unpack_bytes': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_bytes',
                        'xdrlib.Unpacker.unpack_double': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_double',
                        'xdrlib.Unpacker.unpack_farray': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_farray',
                        'xdrlib.Unpacker.unpack_float': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_float',
                        'xdrlib.Unpacker.unpack_fopaque': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_fopaque',
                        'xdrlib.Unpacker.unpack_fstring': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_fstring',
                        'xdrlib.Unpacker.unpack_list': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_list',
                        'xdrlib.Unpacker.unpack_opaque': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_opaque',
                        'xdrlib.Unpacker.unpack_string': 'https://docs.python.org/3/library/xdrlib.html#xdrlib.Unpacker.unpack_string'},
            'xml': { 'xml.dom': 'https://docs.python.org/3/library/xml.dom.html#module-xml.dom',
                     'xml.sax': 'https://docs.python.org/3/library/xml.sax.html#module-xml.sax'},
            'xml.dom': { 'xml.dom.DOMImplementation.createDocument': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.DOMImplementation.createDocument',
                         'xml.dom.DOMImplementation.createDocumentType': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.DOMImplementation.createDocumentType',
                         'xml.dom.DOMImplementation.hasFeature': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.DOMImplementation.hasFeature',
                         'xml.dom.Document.createAttribute': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createAttribute',
                         'xml.dom.Document.createAttributeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createAttributeNS',
                         'xml.dom.Document.createComment': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createComment',
                         'xml.dom.Document.createElement': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createElement',
                         'xml.dom.Document.createElementNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createElementNS',
                         'xml.dom.Document.createProcessingInstruction': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createProcessingInstruction',
                         'xml.dom.Document.createTextNode': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.createTextNode',
                         'xml.dom.Document.getElementsByTagName': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.getElementsByTagName',
                         'xml.dom.Document.getElementsByTagNameNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Document.getElementsByTagNameNS',
                         'xml.dom.Element.getAttribute': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.getAttribute',
                         'xml.dom.Element.getAttributeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.getAttributeNS',
                         'xml.dom.Element.getAttributeNode': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.getAttributeNode',
                         'xml.dom.Element.getAttributeNodeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.getAttributeNodeNS',
                         'xml.dom.Element.getElementsByTagName': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.getElementsByTagName',
                         'xml.dom.Element.getElementsByTagNameNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.getElementsByTagNameNS',
                         'xml.dom.Element.hasAttribute': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.hasAttribute',
                         'xml.dom.Element.hasAttributeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.hasAttributeNS',
                         'xml.dom.Element.removeAttribute': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.removeAttribute',
                         'xml.dom.Element.removeAttributeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.removeAttributeNS',
                         'xml.dom.Element.removeAttributeNode': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.removeAttributeNode',
                         'xml.dom.Element.setAttribute': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.setAttribute',
                         'xml.dom.Element.setAttributeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.setAttributeNS',
                         'xml.dom.Element.setAttributeNode': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.setAttributeNode',
                         'xml.dom.Element.setAttributeNodeNS': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Element.setAttributeNodeNS',
                         'xml.dom.NamedNodeMap.item': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.NamedNodeMap.item',
                         'xml.dom.Node.appendChild': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.appendChild',
                         'xml.dom.Node.cloneNode': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.cloneNode',
                         'xml.dom.Node.hasAttributes': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.hasAttributes',
                         'xml.dom.Node.hasChildNodes': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.hasChildNodes',
                         'xml.dom.Node.insertBefore': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.insertBefore',
                         'xml.dom.Node.isSameNode': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.isSameNode',
                         'xml.dom.Node.normalize': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.normalize',
                         'xml.dom.Node.removeChild': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.removeChild',
                         'xml.dom.Node.replaceChild': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.Node.replaceChild',
                         'xml.dom.NodeList.item': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.NodeList.item',
                         'xml.dom.getDOMImplementation': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.getDOMImplementation',
                         'xml.dom.minidom': 'https://docs.python.org/3/library/xml.dom.minidom.html#module-xml.dom.minidom',
                         'xml.dom.pulldom': 'https://docs.python.org/3/library/xml.dom.pulldom.html#module-xml.dom.pulldom',
                         'xml.dom.registerDOMImplementation': 'https://docs.python.org/3/library/xml.dom.html#xml.dom.registerDOMImplementation'},
            'xml.dom.minidom': { 'xml.dom.minidom.Node.toprettyxml': 'https://docs.python.org/3/library/xml.dom.minidom.html#xml.dom.minidom.Node.toprettyxml',
                                 'xml.dom.minidom.Node.toxml': 'https://docs.python.org/3/library/xml.dom.minidom.html#xml.dom.minidom.Node.toxml',
                                 'xml.dom.minidom.Node.unlink': 'https://docs.python.org/3/library/xml.dom.minidom.html#xml.dom.minidom.Node.unlink',
                                 'xml.dom.minidom.Node.writexml': 'https://docs.python.org/3/library/xml.dom.minidom.html#xml.dom.minidom.Node.writexml',
                                 'xml.dom.minidom.parse': 'https://docs.python.org/3/library/xml.dom.minidom.html#xml.dom.minidom.parse',
                                 'xml.dom.minidom.parseString': 'https://docs.python.org/3/library/xml.dom.minidom.html#xml.dom.minidom.parseString'},
            'xml.dom.pulldom': { 'xml.dom.pulldom.DOMEventStream': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.DOMEventStream',
                                 'xml.dom.pulldom.DOMEventStream.expandNode': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.DOMEventStream.expandNode',
                                 'xml.dom.pulldom.DOMEventStream.getEvent': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.DOMEventStream.getEvent',
                                 'xml.dom.pulldom.DOMEventStream.reset': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.DOMEventStream.reset',
                                 'xml.dom.pulldom.PullDom': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.PullDom',
                                 'xml.dom.pulldom.SAX2DOM': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.SAX2DOM',
                                 'xml.dom.pulldom.parse': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.parse',
                                 'xml.dom.pulldom.parseString': 'https://docs.python.org/3/library/xml.dom.pulldom.html#xml.dom.pulldom.parseString'},
            'xml.etree': {'xml.etree.ElementTree': 'https://docs.python.org/3/library/xml.etree.elementtree.html#module-xml.etree.ElementTree'},
            'xml.etree.ElementInclude': { 'xml.etree.ElementInclude.default_loader': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementInclude.default_loader',
                                          'xml.etree.ElementInclude.include': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementInclude.include'},
            'xml.etree.ElementTree': { 'xml.etree.ElementTree.C14NWriterTarget': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.C14NWriterTarget',
                                       'xml.etree.ElementTree.Comment': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Comment',
                                       'xml.etree.ElementTree.Element': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element',
                                       'xml.etree.ElementTree.Element.append': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.append',
                                       'xml.etree.ElementTree.Element.clear': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.clear',
                                       'xml.etree.ElementTree.Element.extend': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.extend',
                                       'xml.etree.ElementTree.Element.find': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.find',
                                       'xml.etree.ElementTree.Element.findall': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.findall',
                                       'xml.etree.ElementTree.Element.findtext': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.findtext',
                                       'xml.etree.ElementTree.Element.get': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.get',
                                       'xml.etree.ElementTree.Element.insert': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.insert',
                                       'xml.etree.ElementTree.Element.items': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.items',
                                       'xml.etree.ElementTree.Element.iter': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.iter',
                                       'xml.etree.ElementTree.Element.iterfind': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.iterfind',
                                       'xml.etree.ElementTree.Element.itertext': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.itertext',
                                       'xml.etree.ElementTree.Element.keys': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.keys',
                                       'xml.etree.ElementTree.Element.makeelement': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.makeelement',
                                       'xml.etree.ElementTree.Element.remove': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.remove',
                                       'xml.etree.ElementTree.Element.set': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element.set',
                                       'xml.etree.ElementTree.ElementTree': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree',
                                       'xml.etree.ElementTree.ElementTree._setroot': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree._setroot',
                                       'xml.etree.ElementTree.ElementTree.find': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.find',
                                       'xml.etree.ElementTree.ElementTree.findall': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.findall',
                                       'xml.etree.ElementTree.ElementTree.findtext': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.findtext',
                                       'xml.etree.ElementTree.ElementTree.getroot': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.getroot',
                                       'xml.etree.ElementTree.ElementTree.iter': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.iter',
                                       'xml.etree.ElementTree.ElementTree.iterfind': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.iterfind',
                                       'xml.etree.ElementTree.ElementTree.parse': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.parse',
                                       'xml.etree.ElementTree.ElementTree.write': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ElementTree.write',
                                       'xml.etree.ElementTree.ParseError': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ParseError',
                                       'xml.etree.ElementTree.ProcessingInstruction': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.ProcessingInstruction',
                                       'xml.etree.ElementTree.QName': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.QName',
                                       'xml.etree.ElementTree.SubElement': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.SubElement',
                                       'xml.etree.ElementTree.TreeBuilder': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder',
                                       'xml.etree.ElementTree.TreeBuilder.close': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.close',
                                       'xml.etree.ElementTree.TreeBuilder.comment': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.comment',
                                       'xml.etree.ElementTree.TreeBuilder.data': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.data',
                                       'xml.etree.ElementTree.TreeBuilder.doctype': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.doctype',
                                       'xml.etree.ElementTree.TreeBuilder.end': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.end',
                                       'xml.etree.ElementTree.TreeBuilder.end_ns': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.end_ns',
                                       'xml.etree.ElementTree.TreeBuilder.pi': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.pi',
                                       'xml.etree.ElementTree.TreeBuilder.start': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.start',
                                       'xml.etree.ElementTree.TreeBuilder.start_ns': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.TreeBuilder.start_ns',
                                       'xml.etree.ElementTree.XML': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XML',
                                       'xml.etree.ElementTree.XMLID': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLID',
                                       'xml.etree.ElementTree.XMLParser': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLParser',
                                       'xml.etree.ElementTree.XMLParser.close': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLParser.close',
                                       'xml.etree.ElementTree.XMLParser.feed': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLParser.feed',
                                       'xml.etree.ElementTree.XMLPullParser': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLPullParser',
                                       'xml.etree.ElementTree.XMLPullParser.close': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLPullParser.close',
                                       'xml.etree.ElementTree.XMLPullParser.feed': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLPullParser.feed',
                                       'xml.etree.ElementTree.XMLPullParser.read_events': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.XMLPullParser.read_events',
                                       'xml.etree.ElementTree.canonicalize': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.canonicalize',
                                       'xml.etree.ElementTree.dump': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.dump',
                                       'xml.etree.ElementTree.fromstring': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.fromstring',
                                       'xml.etree.ElementTree.fromstringlist': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.fromstringlist',
                                       'xml.etree.ElementTree.indent': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.indent',
                                       'xml.etree.ElementTree.iselement': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.iselement',
                                       'xml.etree.ElementTree.iterparse': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.iterparse',
                                       'xml.etree.ElementTree.parse': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.parse',
                                       'xml.etree.ElementTree.register_namespace': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.register_namespace',
                                       'xml.etree.ElementTree.tostring': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.tostring',
                                       'xml.etree.ElementTree.tostringlist': 'https://docs.python.org/3/library/xml.etree.elementtree.html#xml.etree.ElementTree.tostringlist'},
            'xml.parsers': {'xml.parsers.expat': 'https://docs.python.org/3/library/pyexpat.html#module-xml.parsers.expat'},
            'xml.parsers.expat': { 'xml.parsers.expat.ErrorString': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.ErrorString',
                                   'xml.parsers.expat.ParserCreate': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.ParserCreate',
                                   'xml.parsers.expat.errors': 'https://docs.python.org/3/library/pyexpat.html#module-xml.parsers.expat.errors',
                                   'xml.parsers.expat.model': 'https://docs.python.org/3/library/pyexpat.html#module-xml.parsers.expat.model',
                                   'xml.parsers.expat.xmlparser.AttlistDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.AttlistDeclHandler',
                                   'xml.parsers.expat.xmlparser.CharacterDataHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.CharacterDataHandler',
                                   'xml.parsers.expat.xmlparser.CommentHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.CommentHandler',
                                   'xml.parsers.expat.xmlparser.DefaultHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.DefaultHandler',
                                   'xml.parsers.expat.xmlparser.DefaultHandlerExpand': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.DefaultHandlerExpand',
                                   'xml.parsers.expat.xmlparser.ElementDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.ElementDeclHandler',
                                   'xml.parsers.expat.xmlparser.EndCdataSectionHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.EndCdataSectionHandler',
                                   'xml.parsers.expat.xmlparser.EndDoctypeDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.EndDoctypeDeclHandler',
                                   'xml.parsers.expat.xmlparser.EndElementHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.EndElementHandler',
                                   'xml.parsers.expat.xmlparser.EndNamespaceDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.EndNamespaceDeclHandler',
                                   'xml.parsers.expat.xmlparser.EntityDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.EntityDeclHandler',
                                   'xml.parsers.expat.xmlparser.ExternalEntityParserCreate': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.ExternalEntityParserCreate',
                                   'xml.parsers.expat.xmlparser.ExternalEntityRefHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.ExternalEntityRefHandler',
                                   'xml.parsers.expat.xmlparser.GetBase': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.GetBase',
                                   'xml.parsers.expat.xmlparser.GetInputContext': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.GetInputContext',
                                   'xml.parsers.expat.xmlparser.NotStandaloneHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.NotStandaloneHandler',
                                   'xml.parsers.expat.xmlparser.NotationDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.NotationDeclHandler',
                                   'xml.parsers.expat.xmlparser.Parse': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.Parse',
                                   'xml.parsers.expat.xmlparser.ParseFile': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.ParseFile',
                                   'xml.parsers.expat.xmlparser.ProcessingInstructionHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.ProcessingInstructionHandler',
                                   'xml.parsers.expat.xmlparser.SetBase': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.SetBase',
                                   'xml.parsers.expat.xmlparser.SetParamEntityParsing': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.SetParamEntityParsing',
                                   'xml.parsers.expat.xmlparser.StartCdataSectionHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.StartCdataSectionHandler',
                                   'xml.parsers.expat.xmlparser.StartDoctypeDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.StartDoctypeDeclHandler',
                                   'xml.parsers.expat.xmlparser.StartElementHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.StartElementHandler',
                                   'xml.parsers.expat.xmlparser.StartNamespaceDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.StartNamespaceDeclHandler',
                                   'xml.parsers.expat.xmlparser.UnparsedEntityDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.UnparsedEntityDeclHandler',
                                   'xml.parsers.expat.xmlparser.UseForeignDTD': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.UseForeignDTD',
                                   'xml.parsers.expat.xmlparser.XmlDeclHandler': 'https://docs.python.org/3/library/pyexpat.html#xml.parsers.expat.xmlparser.XmlDeclHandler'},
            'xml.sax': { 'xml.sax.SAXException.getException': 'https://docs.python.org/3/library/xml.sax.html#xml.sax.SAXException.getException',
                         'xml.sax.SAXException.getMessage': 'https://docs.python.org/3/library/xml.sax.html#xml.sax.SAXException.getMessage',
                         'xml.sax.handler': 'https://docs.python.org/3/library/xml.sax.handler.html#module-xml.sax.handler',
                         'xml.sax.make_parser': 'https://docs.python.org/3/library/xml.sax.html#xml.sax.make_parser',
                         'xml.sax.parse': 'https://docs.python.org/3/library/xml.sax.html#xml.sax.parse',
                         'xml.sax.parseString': 'https://docs.python.org/3/library/xml.sax.html#xml.sax.parseString',
                         'xml.sax.saxutils': 'https://docs.python.org/3/library/xml.sax.utils.html#module-xml.sax.saxutils',
                         'xml.sax.xmlreader': 'https://docs.python.org/3/library/xml.sax.reader.html#module-xml.sax.xmlreader'},
            'xml.sax.handler': { 'xml.sax.handler.ContentHandler': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler',
                                 'xml.sax.handler.ContentHandler.characters': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.characters',
                                 'xml.sax.handler.ContentHandler.endDocument': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.endDocument',
                                 'xml.sax.handler.ContentHandler.endElement': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.endElement',
                                 'xml.sax.handler.ContentHandler.endElementNS': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.endElementNS',
                                 'xml.sax.handler.ContentHandler.endPrefixMapping': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.endPrefixMapping',
                                 'xml.sax.handler.ContentHandler.ignorableWhitespace': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.ignorableWhitespace',
                                 'xml.sax.handler.ContentHandler.processingInstruction': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.processingInstruction',
                                 'xml.sax.handler.ContentHandler.setDocumentLocator': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.setDocumentLocator',
                                 'xml.sax.handler.ContentHandler.skippedEntity': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.skippedEntity',
                                 'xml.sax.handler.ContentHandler.startDocument': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.startDocument',
                                 'xml.sax.handler.ContentHandler.startElement': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.startElement',
                                 'xml.sax.handler.ContentHandler.startElementNS': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.startElementNS',
                                 'xml.sax.handler.ContentHandler.startPrefixMapping': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ContentHandler.startPrefixMapping',
                                 'xml.sax.handler.DTDHandler': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.DTDHandler',
                                 'xml.sax.handler.DTDHandler.notationDecl': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.DTDHandler.notationDecl',
                                 'xml.sax.handler.DTDHandler.unparsedEntityDecl': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.DTDHandler.unparsedEntityDecl',
                                 'xml.sax.handler.EntityResolver': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.EntityResolver',
                                 'xml.sax.handler.EntityResolver.resolveEntity': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.EntityResolver.resolveEntity',
                                 'xml.sax.handler.ErrorHandler': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ErrorHandler',
                                 'xml.sax.handler.ErrorHandler.error': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ErrorHandler.error',
                                 'xml.sax.handler.ErrorHandler.fatalError': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ErrorHandler.fatalError',
                                 'xml.sax.handler.ErrorHandler.warning': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.ErrorHandler.warning',
                                 'xml.sax.handler.LexicalHandler': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.LexicalHandler',
                                 'xml.sax.handler.LexicalHandler.comment': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.LexicalHandler.comment',
                                 'xml.sax.handler.LexicalHandler.endCDATA': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.LexicalHandler.endCDATA',
                                 'xml.sax.handler.LexicalHandler.endDTD': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.LexicalHandler.endDTD',
                                 'xml.sax.handler.LexicalHandler.startCDATA': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.LexicalHandler.startCDATA',
                                 'xml.sax.handler.LexicalHandler.startDTD': 'https://docs.python.org/3/library/xml.sax.handler.html#xml.sax.handler.LexicalHandler.startDTD'},
            'xml.sax.saxutils': { 'xml.sax.saxutils.XMLFilterBase': 'https://docs.python.org/3/library/xml.sax.utils.html#xml.sax.saxutils.XMLFilterBase',
                                  'xml.sax.saxutils.XMLGenerator': 'https://docs.python.org/3/library/xml.sax.utils.html#xml.sax.saxutils.XMLGenerator',
                                  'xml.sax.saxutils.escape': 'https://docs.python.org/3/library/xml.sax.utils.html#xml.sax.saxutils.escape',
                                  'xml.sax.saxutils.prepare_input_source': 'https://docs.python.org/3/library/xml.sax.utils.html#xml.sax.saxutils.prepare_input_source',
                                  'xml.sax.saxutils.quoteattr': 'https://docs.python.org/3/library/xml.sax.utils.html#xml.sax.saxutils.quoteattr',
                                  'xml.sax.saxutils.unescape': 'https://docs.python.org/3/library/xml.sax.utils.html#xml.sax.saxutils.unescape'},
            'xml.sax.xmlreader': { 'xml.sax.xmlreader.Attributes.getLength': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Attributes.getLength',
                                   'xml.sax.xmlreader.Attributes.getNames': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Attributes.getNames',
                                   'xml.sax.xmlreader.Attributes.getType': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Attributes.getType',
                                   'xml.sax.xmlreader.Attributes.getValue': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Attributes.getValue',
                                   'xml.sax.xmlreader.AttributesImpl': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.AttributesImpl',
                                   'xml.sax.xmlreader.AttributesNS.getNameByQName': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.AttributesNS.getNameByQName',
                                   'xml.sax.xmlreader.AttributesNS.getQNameByName': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.AttributesNS.getQNameByName',
                                   'xml.sax.xmlreader.AttributesNS.getQNames': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.AttributesNS.getQNames',
                                   'xml.sax.xmlreader.AttributesNS.getValueByQName': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.AttributesNS.getValueByQName',
                                   'xml.sax.xmlreader.AttributesNSImpl': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.AttributesNSImpl',
                                   'xml.sax.xmlreader.IncrementalParser': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.IncrementalParser',
                                   'xml.sax.xmlreader.IncrementalParser.close': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.IncrementalParser.close',
                                   'xml.sax.xmlreader.IncrementalParser.feed': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.IncrementalParser.feed',
                                   'xml.sax.xmlreader.IncrementalParser.reset': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.IncrementalParser.reset',
                                   'xml.sax.xmlreader.InputSource': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource',
                                   'xml.sax.xmlreader.InputSource.getByteStream': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.getByteStream',
                                   'xml.sax.xmlreader.InputSource.getCharacterStream': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.getCharacterStream',
                                   'xml.sax.xmlreader.InputSource.getEncoding': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.getEncoding',
                                   'xml.sax.xmlreader.InputSource.getPublicId': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.getPublicId',
                                   'xml.sax.xmlreader.InputSource.getSystemId': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.getSystemId',
                                   'xml.sax.xmlreader.InputSource.setByteStream': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.setByteStream',
                                   'xml.sax.xmlreader.InputSource.setCharacterStream': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.setCharacterStream',
                                   'xml.sax.xmlreader.InputSource.setEncoding': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.setEncoding',
                                   'xml.sax.xmlreader.InputSource.setPublicId': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.setPublicId',
                                   'xml.sax.xmlreader.InputSource.setSystemId': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.InputSource.setSystemId',
                                   'xml.sax.xmlreader.Locator': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Locator',
                                   'xml.sax.xmlreader.Locator.getColumnNumber': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Locator.getColumnNumber',
                                   'xml.sax.xmlreader.Locator.getLineNumber': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Locator.getLineNumber',
                                   'xml.sax.xmlreader.Locator.getPublicId': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Locator.getPublicId',
                                   'xml.sax.xmlreader.Locator.getSystemId': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.Locator.getSystemId',
                                   'xml.sax.xmlreader.XMLReader': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader',
                                   'xml.sax.xmlreader.XMLReader.getContentHandler': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.getContentHandler',
                                   'xml.sax.xmlreader.XMLReader.getDTDHandler': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.getDTDHandler',
                                   'xml.sax.xmlreader.XMLReader.getEntityResolver': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.getEntityResolver',
                                   'xml.sax.xmlreader.XMLReader.getErrorHandler': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.getErrorHandler',
                                   'xml.sax.xmlreader.XMLReader.getFeature': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.getFeature',
                                   'xml.sax.xmlreader.XMLReader.getProperty': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.getProperty',
                                   'xml.sax.xmlreader.XMLReader.parse': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.parse',
                                   'xml.sax.xmlreader.XMLReader.setContentHandler': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setContentHandler',
                                   'xml.sax.xmlreader.XMLReader.setDTDHandler': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setDTDHandler',
                                   'xml.sax.xmlreader.XMLReader.setEntityResolver': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setEntityResolver',
                                   'xml.sax.xmlreader.XMLReader.setErrorHandler': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setErrorHandler',
                                   'xml.sax.xmlreader.XMLReader.setFeature': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setFeature',
                                   'xml.sax.xmlreader.XMLReader.setLocale': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setLocale',
                                   'xml.sax.xmlreader.XMLReader.setProperty': 'https://docs.python.org/3/library/xml.sax.reader.html#xml.sax.xmlreader.XMLReader.setProperty'},
            'xmlrpc': { 'xmlrpc.client': 'https://docs.python.org/3/library/xmlrpc.client.html#module-xmlrpc.client',
                        'xmlrpc.server': 'https://docs.python.org/3/library/xmlrpc.server.html#module-xmlrpc.server'},
            'xmlrpc.client': { 'xmlrpc.client.Binary': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.Binary',
                               'xmlrpc.client.Binary.decode': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.Binary.decode',
                               'xmlrpc.client.Binary.encode': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.Binary.encode',
                               'xmlrpc.client.DateTime': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.DateTime',
                               'xmlrpc.client.DateTime.decode': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.DateTime.decode',
                               'xmlrpc.client.DateTime.encode': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.DateTime.encode',
                               'xmlrpc.client.Fault': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.Fault',
                               'xmlrpc.client.MultiCall': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.MultiCall',
                               'xmlrpc.client.ProtocolError': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.ProtocolError',
                               'xmlrpc.client.ServerProxy': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.ServerProxy',
                               'xmlrpc.client.dumps': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.dumps',
                               'xmlrpc.client.loads': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.loads'},
            'xmlrpc.client.ServerProxy': { 'xmlrpc.client.ServerProxy.system.listMethods': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.ServerProxy.system.listMethods',
                                           'xmlrpc.client.ServerProxy.system.methodHelp': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.ServerProxy.system.methodHelp',
                                           'xmlrpc.client.ServerProxy.system.methodSignature': 'https://docs.python.org/3/library/xmlrpc.client.html#xmlrpc.client.ServerProxy.system.methodSignature'},
            'xmlrpc.server': { 'xmlrpc.server.CGIXMLRPCRequestHandler': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.CGIXMLRPCRequestHandler',
                               'xmlrpc.server.CGIXMLRPCRequestHandler.handle_request': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.CGIXMLRPCRequestHandler.handle_request',
                               'xmlrpc.server.CGIXMLRPCRequestHandler.register_function': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.CGIXMLRPCRequestHandler.register_function',
                               'xmlrpc.server.CGIXMLRPCRequestHandler.register_instance': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.CGIXMLRPCRequestHandler.register_instance',
                               'xmlrpc.server.CGIXMLRPCRequestHandler.register_introspection_functions': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.CGIXMLRPCRequestHandler.register_introspection_functions',
                               'xmlrpc.server.CGIXMLRPCRequestHandler.register_multicall_functions': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.CGIXMLRPCRequestHandler.register_multicall_functions',
                               'xmlrpc.server.DocCGIXMLRPCRequestHandler': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocCGIXMLRPCRequestHandler',
                               'xmlrpc.server.DocCGIXMLRPCRequestHandler.set_server_documentation': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocCGIXMLRPCRequestHandler.set_server_documentation',
                               'xmlrpc.server.DocCGIXMLRPCRequestHandler.set_server_name': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocCGIXMLRPCRequestHandler.set_server_name',
                               'xmlrpc.server.DocCGIXMLRPCRequestHandler.set_server_title': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocCGIXMLRPCRequestHandler.set_server_title',
                               'xmlrpc.server.DocXMLRPCRequestHandler': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocXMLRPCRequestHandler',
                               'xmlrpc.server.DocXMLRPCServer': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocXMLRPCServer',
                               'xmlrpc.server.DocXMLRPCServer.set_server_documentation': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocXMLRPCServer.set_server_documentation',
                               'xmlrpc.server.DocXMLRPCServer.set_server_name': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocXMLRPCServer.set_server_name',
                               'xmlrpc.server.DocXMLRPCServer.set_server_title': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.DocXMLRPCServer.set_server_title',
                               'xmlrpc.server.SimpleXMLRPCRequestHandler': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.SimpleXMLRPCRequestHandler',
                               'xmlrpc.server.SimpleXMLRPCServer': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.SimpleXMLRPCServer',
                               'xmlrpc.server.SimpleXMLRPCServer.register_function': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.SimpleXMLRPCServer.register_function',
                               'xmlrpc.server.SimpleXMLRPCServer.register_instance': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.SimpleXMLRPCServer.register_instance',
                               'xmlrpc.server.SimpleXMLRPCServer.register_introspection_functions': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.SimpleXMLRPCServer.register_introspection_functions',
                               'xmlrpc.server.SimpleXMLRPCServer.register_multicall_functions': 'https://docs.python.org/3/library/xmlrpc.server.html#xmlrpc.server.SimpleXMLRPCServer.register_multicall_functions'},
            'zipapp': { 'zipapp.create_archive': 'https://docs.python.org/3/library/zipapp.html#zipapp.create_archive',
                        'zipapp.get_interpreter': 'https://docs.python.org/3/library/zipapp.html#zipapp.get_interpreter'},
            'zipfile': { 'zipfile.Path': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path',
                         'zipfile.Path.exists': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.exists',
                         'zipfile.Path.is_dir': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.is_dir',
                         'zipfile.Path.is_file': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.is_file',
                         'zipfile.Path.iterdir': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.iterdir',
                         'zipfile.Path.joinpath': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.joinpath',
                         'zipfile.Path.open': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.open',
                         'zipfile.Path.read_bytes': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.read_bytes',
                         'zipfile.Path.read_text': 'https://docs.python.org/3/library/zipfile.html#zipfile.Path.read_text',
                         'zipfile.PyZipFile': 'https://docs.python.org/3/library/zipfile.html#zipfile.PyZipFile',
                         'zipfile.PyZipFile.writepy': 'https://docs.python.org/3/library/zipfile.html#zipfile.PyZipFile.writepy',
                         'zipfile.ZipFile': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile',
                         'zipfile.ZipFile.close': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.close',
                         'zipfile.ZipFile.extract': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.extract',
                         'zipfile.ZipFile.extractall': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.extractall',
                         'zipfile.ZipFile.getinfo': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.getinfo',
                         'zipfile.ZipFile.infolist': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.infolist',
                         'zipfile.ZipFile.namelist': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.namelist',
                         'zipfile.ZipFile.open': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.open',
                         'zipfile.ZipFile.printdir': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.printdir',
                         'zipfile.ZipFile.read': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.read',
                         'zipfile.ZipFile.setpassword': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.setpassword',
                         'zipfile.ZipFile.testzip': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.testzip',
                         'zipfile.ZipFile.write': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.write',
                         'zipfile.ZipFile.writestr': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipFile.writestr',
                         'zipfile.ZipInfo': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipInfo',
                         'zipfile.ZipInfo.from_file': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipInfo.from_file',
                         'zipfile.ZipInfo.is_dir': 'https://docs.python.org/3/library/zipfile.html#zipfile.ZipInfo.is_dir',
                         'zipfile.is_zipfile': 'https://docs.python.org/3/library/zipfile.html#zipfile.is_zipfile'},
            'zipimport': { 'zipimport.zipimporter': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter',
                           'zipimport.zipimporter.create_module': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.create_module',
                           'zipimport.zipimporter.exec_module': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.exec_module',
                           'zipimport.zipimporter.find_loader': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.find_loader',
                           'zipimport.zipimporter.find_module': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.find_module',
                           'zipimport.zipimporter.find_spec': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.find_spec',
                           'zipimport.zipimporter.get_code': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.get_code',
                           'zipimport.zipimporter.get_data': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.get_data',
                           'zipimport.zipimporter.get_filename': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.get_filename',
                           'zipimport.zipimporter.get_source': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.get_source',
                           'zipimport.zipimporter.invalidate_caches': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.invalidate_caches',
                           'zipimport.zipimporter.is_package': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.is_package',
                           'zipimport.zipimporter.load_module': 'https://docs.python.org/3/library/zipimport.html#zipimport.zipimporter.load_module'},
            'zlib': { 'zlib.Compress.compress': 'https://docs.python.org/3/library/zlib.html#zlib.Compress.compress',
                      'zlib.Compress.copy': 'https://docs.python.org/3/library/zlib.html#zlib.Compress.copy',
                      'zlib.Compress.flush': 'https://docs.python.org/3/library/zlib.html#zlib.Compress.flush',
                      'zlib.Decompress.copy': 'https://docs.python.org/3/library/zlib.html#zlib.Decompress.copy',
                      'zlib.Decompress.decompress': 'https://docs.python.org/3/library/zlib.html#zlib.Decompress.decompress',
                      'zlib.Decompress.flush': 'https://docs.python.org/3/library/zlib.html#zlib.Decompress.flush',
                      'zlib.adler32': 'https://docs.python.org/3/library/zlib.html#zlib.adler32',
                      'zlib.compress': 'https://docs.python.org/3/library/zlib.html#zlib.compress',
                      'zlib.compressobj': 'https://docs.python.org/3/library/zlib.html#zlib.compressobj',
                      'zlib.crc32': 'https://docs.python.org/3/library/zlib.html#zlib.crc32',
                      'zlib.decompress': 'https://docs.python.org/3/library/zlib.html#zlib.decompress',
                      'zlib.decompressobj': 'https://docs.python.org/3/library/zlib.html#zlib.decompressobj'},
            'zoneinfo': { 'zoneinfo.ZoneInfo': 'https://docs.python.org/3/library/zoneinfo.html#zoneinfo.ZoneInfo',
                          'zoneinfo.ZoneInfo.clear_cache': 'https://docs.python.org/3/library/zoneinfo.html#zoneinfo.ZoneInfo.clear_cache',
                          'zoneinfo.ZoneInfo.from_file': 'https://docs.python.org/3/library/zoneinfo.html#zoneinfo.ZoneInfo.from_file',
                          'zoneinfo.ZoneInfo.no_cache': 'https://docs.python.org/3/library/zoneinfo.html#zoneinfo.ZoneInfo.no_cache',
                          'zoneinfo.available_timezones': 'https://docs.python.org/3/library/zoneinfo.html#zoneinfo.available_timezones',
                          'zoneinfo.reset_tzpath': 'https://docs.python.org/3/library/zoneinfo.html#zoneinfo.reset_tzpath'}}}
